from rdflib.namespace import DefinedNamespace, Namespace
from rdflib.term import URIRef


class QUDT_UNIT(DefinedNamespace):
    # Generated with namespacelib version 0.3.0
    _fail = True
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    PHON = URIRef("http://qudt.org/vocab/unit/PHON")
    TONNE_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY-BAR")
    M3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM")
    TON_UK_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-YD3")
    W_PER_M_K = URIRef("http://qudt.org/vocab/unit/W-PER-M-K")
    CentiC = URIRef("http://qudt.org/vocab/unit/CentiC")
    E_h = URIRef("http://qudt.org/vocab/unit/E_h")
    GAL_US = URIRef("http://qudt.org/vocab/unit/GAL_US")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    LB_F_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN")
    KiloGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM2")
    PER_DAY = URIRef("http://qudt.org/vocab/unit/PER-DAY")
    BTU_IT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    AttoJ_SEC = URIRef("http://qudt.org/vocab/unit/AttoJ-SEC")
    PER_DEG_F = URIRef("http://qudt.org/vocab/unit/PER-DEG_F")
    KiloS = URIRef("http://qudt.org/vocab/unit/KiloS")
    AC = URIRef("http://qudt.org/vocab/unit/AC")
    BU_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-DAY")
    MilliFARAD = URIRef("http://qudt.org/vocab/unit/MilliFARAD")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    KiloMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-SEC")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    PicoJ = URIRef("http://qudt.org/vocab/unit/PicoJ")
    MO_MeanGREGORIAN = URIRef("http://qudt.org/vocab/unit/MO_MeanGREGORIAN")
    GigaHZ = URIRef("http://qudt.org/vocab/unit/GigaHZ")
    CP = URIRef("http://qudt.org/vocab/unit/CP")
    GI_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-DAY")
    PER_YD3 = URIRef("http://qudt.org/vocab/unit/PER-YD3")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    MicroGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-KiloGM")
    MegaHZ = URIRef("http://qudt.org/vocab/unit/MegaHZ")
    MilliGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2")
    OZ_VOL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-DAY")
    MilliMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-GM")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    MOL_PER_KiloGM_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-PA")
    ERLANG = URIRef("http://qudt.org/vocab/unit/ERLANG")
    MicroGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M2-DAY")
    IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN3-PER-SEC")
    N_PER_A = URIRef("http://qudt.org/vocab/unit/N-PER-A")
    V_Stat_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-CentiM")
    BIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/BIT-PER-M3")
    LB_SEC_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-FT3")
    TeraW_HR = URIRef("http://qudt.org/vocab/unit/TeraW-HR")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    M5 = URIRef("http://qudt.org/vocab/unit/M5")
    PERCENT_SEC_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-IN3")
    PetaC = URIRef("http://qudt.org/vocab/unit/PetaC")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    PERCENT_PER_DAY = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DAY")
    KiloJ = URIRef("http://qudt.org/vocab/unit/KiloJ")
    MilliBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-KiloGM")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    MilliBAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-L-PER-SEC")
    LB_SEC_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-FT3")
    KiloJ_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-HR")
    MI2 = URIRef("http://qudt.org/vocab/unit/MI2")
    CentiM2_PER_SR_ERG = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SR-ERG")
    BAR = URIRef("http://qudt.org/vocab/unit/BAR")
    WB_PER_MilliM = URIRef("http://qudt.org/vocab/unit/WB-PER-MilliM")
    MegaBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaBTU_IT-PER-HR")
    PK_UK = URIRef("http://qudt.org/vocab/unit/PK_UK")
    DeciM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-SEC")
    MicroH = URIRef("http://qudt.org/vocab/unit/MicroH")
    MegaV = URIRef("http://qudt.org/vocab/unit/MegaV")
    BTU_IT_IN_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-SEC-FT2-DEG_F")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    PERCENT_PER_KiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-KiloCount")
    LM_PER_W = URIRef("http://qudt.org/vocab/unit/LM-PER-W")
    CAL_15_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_15_DEG_C")
    B = URIRef("http://qudt.org/vocab/unit/B")
    LB_F_PER_IN2_DEG_F = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-DEG_F")
    PINT_UK = URIRef("http://qudt.org/vocab/unit/PINT_UK")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    KiloM = URIRef("http://qudt.org/vocab/unit/KiloM")
    MilliGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-GM")
    CentiM_H2O_4DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_H2O_4DEG_C")
    KiloLB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-FT")
    WK = URIRef("http://qudt.org/vocab/unit/WK")
    R_PER_SEC = URIRef("http://qudt.org/vocab/unit/R-PER-SEC")
    MilliPA = URIRef("http://qudt.org/vocab/unit/MilliPA")
    K_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PER-SEC")
    MilliCi = URIRef("http://qudt.org/vocab/unit/MilliCi")
    MilliGM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M")
    TONNE_PER_HA = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    OZ_M = URIRef("http://qudt.org/vocab/unit/OZ_M")
    DEGREE_OECHSLE = URIRef("http://qudt.org/vocab/unit/DEGREE_OECHSLE")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    W_PER_FT2 = URIRef("http://qudt.org/vocab/unit/W-PER-FT2")
    LB_HR_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-FT3")
    LB_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_US")
    A_Ab_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-CentiM2")
    DYN_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM3")
    M2_SR = URIRef("http://qudt.org/vocab/unit/M2-SR")
    KiloGM_PER_MegaBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MegaBTU_IT")
    PA_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC")
    TON_Metric = URIRef("http://qudt.org/vocab/unit/TON_Metric")
    CI_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CI-PER-KiloGM")
    PINT_US_DRY = URIRef("http://qudt.org/vocab/unit/PINT_US_DRY")
    KiloTON_Metric = URIRef("http://qudt.org/vocab/unit/KiloTON_Metric")
    IU_PER_L = URIRef("http://qudt.org/vocab/unit/IU-PER-L")
    TeraBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/TeraBIT-PER-SEC")
    PlanckMomentum = URIRef("http://qudt.org/vocab/unit/PlanckMomentum")
    Stone_UK = URIRef("http://qudt.org/vocab/unit/Stone_UK")
    W_PER_M2_M = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M")
    MACH = URIRef("http://qudt.org/vocab/unit/MACH")
    OCTET_PER_SEC = URIRef("http://qudt.org/vocab/unit/OCTET-PER-SEC")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    DYN_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-CentiM")
    FARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/FARAD-PER-KiloM")
    PlanckPower = URIRef("http://qudt.org/vocab/unit/PlanckPower")
    MilliBQ = URIRef("http://qudt.org/vocab/unit/MilliBQ")
    MicroSEC = URIRef("http://qudt.org/vocab/unit/MicroSEC")
    FT_LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2")
    L_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-M2")
    N_M_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-RAD")
    PlanckTime = URIRef("http://qudt.org/vocab/unit/PlanckTime")
    GM_PER_M2 = URIRef("http://qudt.org/vocab/unit/GM-PER-M2")
    BTU_TH_FT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-HR-FT2-DEG_F")
    PicoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/PicoKAT-PER-L")
    M_K_PER_W = URIRef("http://qudt.org/vocab/unit/M-K-PER-W")
    LB_PER_FT_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-HR")
    KiloBTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH-PER-HR")
    SEC_PER_M3_RAD = URIRef("http://qudt.org/vocab/unit/SEC-PER-M3-RAD")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    MilliM2 = URIRef("http://qudt.org/vocab/unit/MilliM2")
    M3_PER_PA = URIRef("http://qudt.org/vocab/unit/M3-PER-PA")
    MilliGM_HR_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L-M3")
    KiloBTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH-PER-HR")
    GM_SEC_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M3-L")
    J_PER_KiloGM_K_PA = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-PA")
    PlanckDensity = URIRef("http://qudt.org/vocab/unit/PlanckDensity")
    PER_J = URIRef("http://qudt.org/vocab/unit/PER-J")
    CentiL = URIRef("http://qudt.org/vocab/unit/CentiL")
    FRAME_PER_SEC = URIRef("http://qudt.org/vocab/unit/FRAME-PER-SEC")
    M_KiloGM = URIRef("http://qudt.org/vocab/unit/M-KiloGM")
    KiloWB = URIRef("http://qudt.org/vocab/unit/KiloWB")
    GM_PER_L_POISE = URIRef("http://qudt.org/vocab/unit/GM-PER-L-POISE")
    GigaBasePair = URIRef("http://qudt.org/vocab/unit/GigaBasePair")
    GigaJ = URIRef("http://qudt.org/vocab/unit/GigaJ")
    M_K = URIRef("http://qudt.org/vocab/unit/M-K")
    KiloGM_PER_GigaJ = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-GigaJ")
    M_PER_BAR = URIRef("http://qudt.org/vocab/unit/M-PER-BAR")
    LB_PER_FT_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-DAY")
    C_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM3")
    LB_PER_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-PSI")
    PlanckEnergy = URIRef("http://qudt.org/vocab/unit/PlanckEnergy")
    M_PER_YR = URIRef("http://qudt.org/vocab/unit/M-PER-YR")
    GM_PER_M = URIRef("http://qudt.org/vocab/unit/GM-PER-M")
    PlanckFrequency = URIRef("http://qudt.org/vocab/unit/PlanckFrequency")
    QT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_US-PER-HR")
    GM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC-BAR")
    A_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM2")
    KiloGM_M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M2-PER-SEC")
    GM_PER_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY")
    KiloJ_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM-K")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    MicroV_PER_M = URIRef("http://qudt.org/vocab/unit/MicroV-PER-M")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    CentiC = URIRef("http://qudt.org/vocab/unit/CentiC")
    GRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/GRAY-PER-MIN")
    MilliA_PER_L_MIN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-L-MIN")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    PicoH = URIRef("http://qudt.org/vocab/unit/PicoH")
    Flight = URIRef("http://qudt.org/vocab/unit/Flight")
    M3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL-SEC")
    DYN_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM2")
    KiloMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-KiloGM")
    LB_FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT-PER-SEC")
    MicroV_PER_M = URIRef("http://qudt.org/vocab/unit/MicroV-PER-M")
    GM_PER_L_CentiPOISE = URIRef("http://qudt.org/vocab/unit/GM-PER-L-CentiPOISE")
    MilliM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC2")
    GM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-BAR")
    NanoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/NanoFARAD-PER-M")
    IU_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliGM")
    PicoC = URIRef("http://qudt.org/vocab/unit/PicoC")
    CentiM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN")
    MilliM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-M3")
    M2_PER_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ2")
    NanoJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoJ-PER-SEC")
    BTU_IT_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_R")
    GM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC-K")
    NanoMOL_PER_CentiM3_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-CentiM3-HR")
    PH = URIRef("http://qudt.org/vocab/unit/PH")
    BTU_IT_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_F")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    M2_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-HZ2")
    K_PER_T = URIRef("http://qudt.org/vocab/unit/K-PER-T")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    PER_V_A_SEC = URIRef("http://qudt.org/vocab/unit/PER-V-A-SEC")
    FT_LB_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-M2")
    DecaARE = URIRef("http://qudt.org/vocab/unit/DecaARE")
    MilliJ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-GM")
    PERCENT_SEC_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-GAL_US")
    BBL_UK_PET_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-MIN")
    OERSTED_CentiM = URIRef("http://qudt.org/vocab/unit/OERSTED-CentiM")
    PicoH = URIRef("http://qudt.org/vocab/unit/PicoH")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    DeciM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-M3")
    MilliMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2-DAY")
    SUSCEPTIBILITY_MAG = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_MAG")
    C2_M2_PER_J = URIRef("http://qudt.org/vocab/unit/C2-M2-PER-J")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    MilliW_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM-SR")
    TON_SHORT_PER_HR_PSI = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR-PSI")
    BTU_IT_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_F")
    KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-SEC2")
    TON_Metric_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY")
    EV_PER_K = URIRef("http://qudt.org/vocab/unit/EV-PER-K")
    LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN")
    MOL_PER_KiloGM_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-BAR")
    SLUG_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT-SEC")
    DEATHS_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000I-YR")
    MOL_LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-SEC")
    NanoGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DAY")
    IN_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC-PSI")
    MegaSEC = URIRef("http://qudt.org/vocab/unit/MegaSEC")
    LB_HR_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-IN3")
    OZ_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_UK")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    FT_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC-PSI")
    DEGREE_BAUME = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME")
    MilliSV = URIRef("http://qudt.org/vocab/unit/MilliSV")
    DeciC = URIRef("http://qudt.org/vocab/unit/DeciC")
    BBL_UK_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-SEC")
    PA_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC")
    ExaW = URIRef("http://qudt.org/vocab/unit/ExaW")
    OZ_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN3")
    ZeptoC = URIRef("http://qudt.org/vocab/unit/ZeptoC")
    FT_LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2")
    MicroTORR = URIRef("http://qudt.org/vocab/unit/MicroTORR")
    M3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-BAR")
    PER_FT3 = URIRef("http://qudt.org/vocab/unit/PER-FT3")
    PK_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-HR")
    KibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M")
    KiloGM_PER_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-K")
    PERCENT_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-M3")
    PDL_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-SEC-PER-FT2")
    GM_PER_MilliM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM-BAR")
    KiloMOL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-HR")
    TON_Metric_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY-BAR")
    LB_MIN_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-IN3")
    GAL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-DAY")
    MicroMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-DAY")
    FT3_PER_LB = URIRef("http://qudt.org/vocab/unit/FT3-PER-LB")
    MOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL-PER-MIN")
    KiloM = URIRef("http://qudt.org/vocab/unit/KiloM")
    CentiM3_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-CentiM3")
    NanoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MilliL")
    MilliH = URIRef("http://qudt.org/vocab/unit/MilliH")
    TONNE_PER_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-K")
    KiloT = URIRef("http://qudt.org/vocab/unit/KiloT")
    DeciTON_Metric = URIRef("http://qudt.org/vocab/unit/DeciTON_Metric")
    MicroV_PER_M = URIRef("http://qudt.org/vocab/unit/MicroV-PER-M")
    MegaS = URIRef("http://qudt.org/vocab/unit/MegaS")
    PicoJ = URIRef("http://qudt.org/vocab/unit/PicoJ")
    BTU_IT_PER_LB_MOL = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-MOL")
    MilliM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-HR")
    PlanckArea = URIRef("http://qudt.org/vocab/unit/PlanckArea")
    NanoMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-M2-DAY")
    K = URIRef("http://qudt.org/vocab/unit/K")
    MilliGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-K")
    KiloTONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloTONNE-PER-YR")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    BBL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-MIN")
    MilliL_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-K")
    KiloEV = URIRef("http://qudt.org/vocab/unit/KiloEV")
    MOL_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-BAR")
    W_M_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-M-PER-M2-SR")
    DeciL_PER_GM = URIRef("http://qudt.org/vocab/unit/DeciL-PER-GM")
    MilliGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-K")
    Kilo_FT3 = URIRef("http://qudt.org/vocab/unit/Kilo-FT3")
    MegaPA = URIRef("http://qudt.org/vocab/unit/MegaPA")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    QUAD = URIRef("http://qudt.org/vocab/unit/QUAD")
    MilliM_HG = URIRef("http://qudt.org/vocab/unit/MilliM_HG")
    MilliMOL_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3-DAY")
    LB_PER_YD3 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD3")
    A_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-M2")
    L = URIRef("http://qudt.org/vocab/unit/L")
    MicroMOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-SEC")
    FT3_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN")
    LB_PER_LB = URIRef("http://qudt.org/vocab/unit/LB-PER-LB")
    CUP = URIRef("http://qudt.org/vocab/unit/CUP")
    MilliGM_HR_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L2")
    GigaW_HR = URIRef("http://qudt.org/vocab/unit/GigaW-HR")
    FT_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC-PSI")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    KiloGM_PER_J = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-J")
    NanoGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M3")
    LB_MIN_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-YD3")
    L_PER_DAY = URIRef("http://qudt.org/vocab/unit/L-PER-DAY")
    PlanckLength = URIRef("http://qudt.org/vocab/unit/PlanckLength")
    ATM_T_PER_M = URIRef("http://qudt.org/vocab/unit/ATM_T-PER-M")
    TON_US_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_US-PER-YD3")
    NUM_PER_L = URIRef("http://qudt.org/vocab/unit/NUM-PER-L")
    KiloN_M = URIRef("http://qudt.org/vocab/unit/KiloN-M")
    FemtoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-L")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    PERCENT_PER_BAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-BAR")
    PINT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-DAY")
    LB_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN2")
    ERG_PER_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-SEC")
    A_PER_MilliM = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM")
    MilliM2 = URIRef("http://qudt.org/vocab/unit/MilliM2")
    KiloV_PER_M = URIRef("http://qudt.org/vocab/unit/KiloV-PER-M")
    NUM_PER_PicoL = URIRef("http://qudt.org/vocab/unit/NUM-PER-PicoL")
    RichterMagnitude = URIRef("http://qudt.org/vocab/unit/RichterMagnitude")
    DeciL_PER_GM = URIRef("http://qudt.org/vocab/unit/DeciL-PER-GM")
    MilliRAD_R_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliRAD_R-PER-HR")
    MegaHZ_PER_T = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-T")
    IN_PER_PSI = URIRef("http://qudt.org/vocab/unit/IN-PER-PSI")
    OZ_F_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ_F-PER-IN3")
    MillionUSD_PER_YR = URIRef("http://qudt.org/vocab/unit/MillionUSD-PER-YR")
    MilliGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-SEC")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    PicoM = URIRef("http://qudt.org/vocab/unit/PicoM")
    BTU_IT_IN_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-HR-FT2-DEG_F")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    MicroJ = URIRef("http://qudt.org/vocab/unit/MicroJ")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    T_Ab = URIRef("http://qudt.org/vocab/unit/T_Ab")
    J_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2-DAY")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    MegaV_A_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A-HR")
    PER_DAY = URIRef("http://qudt.org/vocab/unit/PER-DAY")
    KiloLB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-IN2")
    GAL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-SEC")
    M = URIRef("http://qudt.org/vocab/unit/M")
    MilliFARAD = URIRef("http://qudt.org/vocab/unit/MilliFARAD")
    RAD_PER_MIN = URIRef("http://qudt.org/vocab/unit/RAD-PER-MIN")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    DeciL_PER_GM = URIRef("http://qudt.org/vocab/unit/DeciL-PER-GM")
    NanoL = URIRef("http://qudt.org/vocab/unit/NanoL")
    NanoBQ = URIRef("http://qudt.org/vocab/unit/NanoBQ")
    ERG_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM2-SEC")
    W = URIRef("http://qudt.org/vocab/unit/W")
    KiloGM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM2-PER-SEC2")
    GigaW_HR = URIRef("http://qudt.org/vocab/unit/GigaW-HR")
    TON_LONG_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_LONG-PER-YD3")
    BBL_US = URIRef("http://qudt.org/vocab/unit/BBL_US")
    KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloMOL")
    NanoM_PER_MilliM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-MilliM-MegaPA")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    CAL_TH_PER_G = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-G")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    FRAME_PER_SEC = URIRef("http://qudt.org/vocab/unit/FRAME-PER-SEC")
    DeciL = URIRef("http://qudt.org/vocab/unit/DeciL")
    GM_PER_L = URIRef("http://qudt.org/vocab/unit/GM-PER-L")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    MilliGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-BAR")
    BAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-L-PER-SEC")
    PA_PER_K = URIRef("http://qudt.org/vocab/unit/PA-PER-K")
    L_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-K")
    MilliPA = URIRef("http://qudt.org/vocab/unit/MilliPA")
    M3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM")
    MilliBAR_PER_K = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-K")
    PPTH_PER_HR = URIRef("http://qudt.org/vocab/unit/PPTH-PER-HR")
    PERCENT_PER_K = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-K")
    LB_HR_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-YD3")
    NanoSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-MIN")
    SUSCEPTIBILITY_MAG = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_MAG")
    NanoA = URIRef("http://qudt.org/vocab/unit/NanoA")
    N_M_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-M")
    M_PER_FARAD = URIRef("http://qudt.org/vocab/unit/M-PER-FARAD")
    TONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-YR")
    MilliGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-BAR")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    MilliGM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR")
    FT3_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT3-PER-SEC")
    MilliGM_SEC_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M3-L")
    KN = URIRef("http://qudt.org/vocab/unit/KN")
    GM_HR_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L-M3")
    K_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PER-SEC")
    MilliL_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-K")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    K_PER_BAR = URIRef("http://qudt.org/vocab/unit/K-PER-BAR")
    NanoV = URIRef("http://qudt.org/vocab/unit/NanoV")
    MicroC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M3")
    N_M_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-M-PER-KiloGM")
    EV = URIRef("http://qudt.org/vocab/unit/EV")
    MilliGM_PER_L = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L")
    MilliL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M3")
    KiloBTU_TH = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH")
    MilliL_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-K")
    MilliV_PER_M = URIRef("http://qudt.org/vocab/unit/MilliV-PER-M")
    DEATHS_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000I-YR")
    CentiC = URIRef("http://qudt.org/vocab/unit/CentiC")
    MegaPSI = URIRef("http://qudt.org/vocab/unit/MegaPSI")
    J_PER_M3_K = URIRef("http://qudt.org/vocab/unit/J-PER-M3-K")
    HectoBAR = URIRef("http://qudt.org/vocab/unit/HectoBAR")
    IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC")
    W_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-PER-M3")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    Stone_UK = URIRef("http://qudt.org/vocab/unit/Stone_UK")
    C_M2 = URIRef("http://qudt.org/vocab/unit/C-M2")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    MicroH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-OHM")
    PlanckImpedance = URIRef("http://qudt.org/vocab/unit/PlanckImpedance")
    MicroGRAY = URIRef("http://qudt.org/vocab/unit/MicroGRAY")
    GigaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-HR")
    GAL_US_DRY = URIRef("http://qudt.org/vocab/unit/GAL_US_DRY")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    DeciB_M = URIRef("http://qudt.org/vocab/unit/DeciB_M")
    CentiM3_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY-BAR")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    MegaV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive-HR")
    OZ_MIN_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-GAL_UK")
    W_PER_M2_M_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M-SR")
    CP = URIRef("http://qudt.org/vocab/unit/CP")
    L_PER_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-SEC")
    L_PER_MIN = URIRef("http://qudt.org/vocab/unit/L-PER-MIN")
    J_PER_SEC = URIRef("http://qudt.org/vocab/unit/J-PER-SEC")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    PicoA_PER_MicroMOL_L = URIRef("http://qudt.org/vocab/unit/PicoA-PER-MicroMOL-L")
    MDOLLAR_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MDOLLAR-PER-FLIGHT")
    CAL_TH_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-DEG_C")
    MegaJ_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M3")
    GRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/GRAY-PER-HR")
    GM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3-BAR")
    M5 = URIRef("http://qudt.org/vocab/unit/M5")
    KiloBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBIT-PER-SEC")
    KiloGM_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-PA")
    KiloL = URIRef("http://qudt.org/vocab/unit/KiloL")
    L = URIRef("http://qudt.org/vocab/unit/L")
    DYN_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM2")
    MegaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M2")
    GigaC = URIRef("http://qudt.org/vocab/unit/GigaC")
    YD3_PER_HR = URIRef("http://qudt.org/vocab/unit/YD3-PER-HR")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    HeartBeat = URIRef("http://qudt.org/vocab/unit/HeartBeat")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    FT_LB_F_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-HR")
    NanoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/NanoKAT-PER-L")
    C_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM3")
    DeciM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-SEC")
    KiloGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-PA-SEC")
    M_K_PER_W = URIRef("http://qudt.org/vocab/unit/M-K-PER-W")
    MicroGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-MilliL")
    PSI = URIRef("http://qudt.org/vocab/unit/PSI")
    AttoJ = URIRef("http://qudt.org/vocab/unit/AttoJ")
    A_MIN = URIRef("http://qudt.org/vocab/unit/A-MIN")
    NanoMOL_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-GM-SEC")
    MOL_PER_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-HR")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    BTU_IT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_F")
    GM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-L-BAR")
    FT_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC2")
    MDOLLAR_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MDOLLAR-PER-FLIGHT")
    FR = URIRef("http://qudt.org/vocab/unit/FR")
    MilliKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MilliKAT-PER-L")
    PER_WK = URIRef("http://qudt.org/vocab/unit/PER-WK")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    LB_PER_GAL = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL")
    PER_T_M = URIRef("http://qudt.org/vocab/unit/PER-T-M")
    KiloGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-K")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    DeciM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-SEC")
    TON_US_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_US-PER-YD3")
    LB_IN2_PER_GAL_US_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-GAL_US-LB_F-SEC")
    ARCMIN = URIRef("http://qudt.org/vocab/unit/ARCMIN")
    PER_MilliGM = URIRef("http://qudt.org/vocab/unit/PER-MilliGM")
    N_M_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-M-PER-KiloGM")
    HP = URIRef("http://qudt.org/vocab/unit/HP")
    ERG_PER_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-SEC")
    L_PER_DAY = URIRef("http://qudt.org/vocab/unit/L-PER-DAY")
    PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PER-M3-SEC")
    GM_PER_M3_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-MilliPA-SEC")
    PER_SEC_M2_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2-SR")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    TON_LONG_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_LONG-PER-YD3")
    NanoGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DAY")
    GM_PER_CentiM2_YR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2-YR")
    FARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/FARAD-PER-KiloM")
    PER_V = URIRef("http://qudt.org/vocab/unit/PER-V")
    NanoMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-M2-DAY")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    BTU_IT_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_F")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    GigaBIT = URIRef("http://qudt.org/vocab/unit/GigaBIT")
    KiloV_A_Reactive = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive")
    TEX = URIRef("http://qudt.org/vocab/unit/TEX")
    MilliGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-K")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    GM_PER_MilliL_K = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL-K")
    L_PER_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-BAR")
    AttoSEC = URIRef("http://qudt.org/vocab/unit/AttoSEC")
    MilliA_SEC = URIRef("http://qudt.org/vocab/unit/MilliA-SEC")
    NanoS_PER_M = URIRef("http://qudt.org/vocab/unit/NanoS-PER-M")
    OZ_PER_GAL = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL")
    GM_HR_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L2")
    KiloCAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-MIN")
    M2_PER_N = URIRef("http://qudt.org/vocab/unit/M2-PER-N")
    ATM = URIRef("http://qudt.org/vocab/unit/ATM")
    FT = URIRef("http://qudt.org/vocab/unit/FT")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    M3_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-BAR")
    BTU_IT_PER_MOL_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    PER_V_A_SEC = URIRef("http://qudt.org/vocab/unit/PER-V-A-SEC")
    GibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M")
    PicoA = URIRef("http://qudt.org/vocab/unit/PicoA")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    MilliC = URIRef("http://qudt.org/vocab/unit/MilliC")
    CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-GM")
    PERCENT_HR_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-L")
    BTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    MebiBYTE = URIRef("http://qudt.org/vocab/unit/MebiBYTE")
    DeciM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-M3")
    RT = URIRef("http://qudt.org/vocab/unit/RT")
    PERCENT_PER_DecaK = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaK")
    MIN = URIRef("http://qudt.org/vocab/unit/MIN")
    MilliGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-GM")
    YR_TROPICAL = URIRef("http://qudt.org/vocab/unit/YR_TROPICAL")
    MOL_PER_M2_SEC_M = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-M")
    PPQ = URIRef("http://qudt.org/vocab/unit/PPQ")
    PER_CentiM = URIRef("http://qudt.org/vocab/unit/PER-CentiM")
    GM_MIN_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L2")
    MilliV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliV-PER-MIN")
    W_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M3")
    SLUG_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT-SEC")
    P = URIRef("http://qudt.org/vocab/unit/P")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    ExaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/ExaJ-PER-SEC")
    ExaBYTE = URIRef("http://qudt.org/vocab/unit/ExaBYTE")
    FT2_PER_HR = URIRef("http://qudt.org/vocab/unit/FT2-PER-HR")
    DeciM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-DAY")
    HR_FT2 = URIRef("http://qudt.org/vocab/unit/HR-FT2")
    TONNE_PER_MO = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MO")
    MilliGM_MIN_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M3-CentiM3")
    AT_PER_M = URIRef("http://qudt.org/vocab/unit/AT-PER-M")
    Pennyweight = URIRef("http://qudt.org/vocab/unit/Pennyweight")
    GigaBIT = URIRef("http://qudt.org/vocab/unit/GigaBIT")
    PA_M = URIRef("http://qudt.org/vocab/unit/PA-M")
    PA_M0pt5 = URIRef("http://qudt.org/vocab/unit/PA-M0pt5")
    CAL_TH_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2-MIN")
    C_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM3")
    MicroS_PER_M = URIRef("http://qudt.org/vocab/unit/MicroS-PER-M")
    YD3_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD3-PER-MIN")
    KiloCAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-SEC")
    BTU_IT_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC")
    V_A_HR = URIRef("http://qudt.org/vocab/unit/V-A-HR")
    MilliM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliM-PER-K")
    MegaN = URIRef("http://qudt.org/vocab/unit/MegaN")
    M2_PER_SR = URIRef("http://qudt.org/vocab/unit/M2-PER-SR")
    MilliT = URIRef("http://qudt.org/vocab/unit/MilliT")
    FATH = URIRef("http://qudt.org/vocab/unit/FATH")
    PebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M2")
    CentiN_M = URIRef("http://qudt.org/vocab/unit/CentiN-M")
    MegaGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-M3")
    KiloV = URIRef("http://qudt.org/vocab/unit/KiloV")
    KiloGM_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-YR")
    MegaPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-BAR")
    GAL_UK = URIRef("http://qudt.org/vocab/unit/GAL_UK")
    NanoGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DeciL")
    FT3_PER_LB = URIRef("http://qudt.org/vocab/unit/FT3-PER-LB")
    PA2_SEC = URIRef("http://qudt.org/vocab/unit/PA2-SEC")
    CentiM3_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-K")
    KiloCAL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-MIN")
    A_SEC = URIRef("http://qudt.org/vocab/unit/A-SEC")
    KiloA_HR = URIRef("http://qudt.org/vocab/unit/KiloA-HR")
    KiloN_M_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-M")
    PER_J_M3 = URIRef("http://qudt.org/vocab/unit/PER-J-M3")
    PK_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-DAY")
    PicoC = URIRef("http://qudt.org/vocab/unit/PicoC")
    BTU_IT_PER_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL-DEG_F")
    TONNE_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC-K")
    MicroV_PER_M = URIRef("http://qudt.org/vocab/unit/MicroV-PER-M")
    DeciL_PER_GM = URIRef("http://qudt.org/vocab/unit/DeciL-PER-GM")
    A_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-PER-DEG_C")
    NanoA_PER_K = URIRef("http://qudt.org/vocab/unit/NanoA-PER-K")
    YD3_PER_DAY = URIRef("http://qudt.org/vocab/unit/YD3-PER-DAY")
    BTU_IT_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-IN2-SEC")
    W_M_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-M-PER-M2-SR")
    Pennyweight = URIRef("http://qudt.org/vocab/unit/Pennyweight")
    MilliN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliN-M-PER-M2")
    PERCENT_MIN_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-CentiM3")
    MegaEV_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-CentiM")
    KiloSEC = URIRef("http://qudt.org/vocab/unit/KiloSEC")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    CWT_LONG = URIRef("http://qudt.org/vocab/unit/CWT_LONG")
    KiloGM_F = URIRef("http://qudt.org/vocab/unit/KiloGM_F")
    MicroSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-MIN")
    BTU_59DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_59DEG_F")
    TONNE_PER_HR_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR-K")
    GM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloGM")
    HectoPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-M3-PER-SEC")
    MicroATM = URIRef("http://qudt.org/vocab/unit/MicroATM")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    OHM_KiloM = URIRef("http://qudt.org/vocab/unit/OHM-KiloM")
    HA = URIRef("http://qudt.org/vocab/unit/HA")
    PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/PER-KiloGM-SEC")
    KiloPA_M2_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloPA-M2-PER-GM")
    M2_HZ = URIRef("http://qudt.org/vocab/unit/M2-HZ")
    DecaARE = URIRef("http://qudt.org/vocab/unit/DecaARE")
    PPM = URIRef("http://qudt.org/vocab/unit/PPM")
    LB_F_FT = URIRef("http://qudt.org/vocab/unit/LB_F-FT")
    KiloA = URIRef("http://qudt.org/vocab/unit/KiloA")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    MilliM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-M3")
    NanoA_PER_K = URIRef("http://qudt.org/vocab/unit/NanoA-PER-K")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    KiloTONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloTONNE-PER-YR")
    PicoW = URIRef("http://qudt.org/vocab/unit/PicoW")
    MilliL_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR")
    CentiGRAY = URIRef("http://qudt.org/vocab/unit/CentiGRAY")
    RAYL = URIRef("http://qudt.org/vocab/unit/RAYL")
    DECADE = URIRef("http://qudt.org/vocab/unit/DECADE")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    M = URIRef("http://qudt.org/vocab/unit/M")
    M_SEC = URIRef("http://qudt.org/vocab/unit/M-SEC")
    MI_US_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/MI_US-PER-SEC2")
    TON_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_US-PER-DAY")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    GRAIN_PER_GAL = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL")
    MACH = URIRef("http://qudt.org/vocab/unit/MACH")
    GM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM_F-PER-CentiM2")
    MicroN_M = URIRef("http://qudt.org/vocab/unit/MicroN-M")
    OERSTED = URIRef("http://qudt.org/vocab/unit/OERSTED")
    FT3_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN")
    MI_N_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI_N-PER-MIN")
    PER_TONNE = URIRef("http://qudt.org/vocab/unit/PER-TONNE")
    MilliM2 = URIRef("http://qudt.org/vocab/unit/MilliM2")
    PERMEABILITY_EM_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_EM_REL")
    GM_F = URIRef("http://qudt.org/vocab/unit/GM_F")
    KibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M3")
    BTU_IT_PER_LB_F_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_F")
    NanoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/NanoFARAD-PER-M")
    MicroKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MicroKAT-PER-L")
    DEG_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC2")
    BQ_PER_M2 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M2")
    CHAIN_US = URIRef("http://qudt.org/vocab/unit/CHAIN_US")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    KIP_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KIP_F-PER-IN2")
    MegaHZ_PER_T = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-T")
    PT_BIG = URIRef("http://qudt.org/vocab/unit/PT_BIG")
    TON_Metric_PER_HA = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HA")
    LB_PER_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-HR")
    BTU_IT_PER_FT2_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR")
    DEG_F_HR_FT2_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH")
    PlanckTime = URIRef("http://qudt.org/vocab/unit/PlanckTime")
    MegaC = URIRef("http://qudt.org/vocab/unit/MegaC")
    REM = URIRef("http://qudt.org/vocab/unit/REM")
    FUR_Long = URIRef("http://qudt.org/vocab/unit/FUR_Long")
    GRAIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL_US")
    H = URIRef("http://qudt.org/vocab/unit/H")
    MilliPA = URIRef("http://qudt.org/vocab/unit/MilliPA")
    BTU_IT_PER_HR_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2")
    MicroJ = URIRef("http://qudt.org/vocab/unit/MicroJ")
    MilliM2 = URIRef("http://qudt.org/vocab/unit/MilliM2")
    DEG_C_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-HR")
    C_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-CentiM2")
    KiloGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC")
    MilliMOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2-SEC")
    BAN = URIRef("http://qudt.org/vocab/unit/BAN")
    MebiBYTE = URIRef("http://qudt.org/vocab/unit/MebiBYTE")
    LB_F_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN")
    PER_YR = URIRef("http://qudt.org/vocab/unit/PER-YR")
    GigaW = URIRef("http://qudt.org/vocab/unit/GigaW")
    MicroV = URIRef("http://qudt.org/vocab/unit/MicroV")
    MegaC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M2")
    BTU_TH_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2")
    DEG2 = URIRef("http://qudt.org/vocab/unit/DEG2")
    CASES_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-1000I-YR")
    AT = URIRef("http://qudt.org/vocab/unit/AT")
    GM_PER_MOL = URIRef("http://qudt.org/vocab/unit/GM-PER-MOL")
    DeciM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MOL")
    S_PER_CentiM = URIRef("http://qudt.org/vocab/unit/S-PER-CentiM")
    MilliGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    Pennyweight = URIRef("http://qudt.org/vocab/unit/Pennyweight")
    MilliBAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-BAR")
    FA = URIRef("http://qudt.org/vocab/unit/FA")
    TON_FG_HR = URIRef("http://qudt.org/vocab/unit/TON_FG-HR")
    RAD_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-KiloGM")
    MOL_K = URIRef("http://qudt.org/vocab/unit/MOL-K")
    GRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/GRAY-PER-SEC")
    V = URIRef("http://qudt.org/vocab/unit/V")
    PetaA = URIRef("http://qudt.org/vocab/unit/PetaA")
    GAL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-DAY")
    M = URIRef("http://qudt.org/vocab/unit/M")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    KiloN_M = URIRef("http://qudt.org/vocab/unit/KiloN-M")
    MicroKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MicroKAT-PER-L")
    LB_MIN_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-YD3")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    MegaPA_M0pt5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0pt5")
    MilliL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-MIN")
    GALILEO = URIRef("http://qudt.org/vocab/unit/GALILEO")
    DEG_F_HR_FT2_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT")
    CAL_IT_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM2-K")
    PetaJ = URIRef("http://qudt.org/vocab/unit/PetaJ")
    MicroBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-L")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    L = URIRef("http://qudt.org/vocab/unit/L")
    W_PER_GM = URIRef("http://qudt.org/vocab/unit/W-PER-GM")
    MilliGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-K")
    WB_M = URIRef("http://qudt.org/vocab/unit/WB-M")
    W_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM-SR")
    KiloTONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloTONNE-PER-YR")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    B = URIRef("http://qudt.org/vocab/unit/B")
    BU_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-HR")
    J_PER_SEC = URIRef("http://qudt.org/vocab/unit/J-PER-SEC")
    LB_PER_IN = URIRef("http://qudt.org/vocab/unit/LB-PER-IN")
    MilliL_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR")
    C_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Ab-PER-CentiM2")
    LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN")
    failures_in_time = URIRef("http://qudt.org/vocab/unit/failures-in-time")
    FATH = URIRef("http://qudt.org/vocab/unit/FATH")
    MegaJ = URIRef("http://qudt.org/vocab/unit/MegaJ")
    KiloA = URIRef("http://qudt.org/vocab/unit/KiloA")
    OZ_M = URIRef("http://qudt.org/vocab/unit/OZ_M")
    MicroMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MOL")
    MegaJ = URIRef("http://qudt.org/vocab/unit/MegaJ")
    KiloEV = URIRef("http://qudt.org/vocab/unit/KiloEV")
    LB_IN2_PER_GAL_UK_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-GAL_UK-LB_F-SEC")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    MegaTOE = URIRef("http://qudt.org/vocab/unit/MegaTOE")
    K_PER_K = URIRef("http://qudt.org/vocab/unit/K-PER-K")
    MilliJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-M2")
    M3_PER_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-BAR")
    DEG2 = URIRef("http://qudt.org/vocab/unit/DEG2")
    MicroPOISE = URIRef("http://qudt.org/vocab/unit/MicroPOISE")
    IN3_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN3-PER-MIN")
    M3_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-BAR")
    QT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_US-PER-MIN")
    MegaN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaN-M-PER-M2")
    KiloGM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3")
    MilliGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-CentiM2")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    FARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/FARAD-PER-KiloM")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    BTU_TH_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT3")
    EUR_PER_W_SEC = URIRef("http://qudt.org/vocab/unit/EUR-PER-W-SEC")
    ERG_PER_CentiM = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM")
    OZ_FT2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/OZ-FT2-PER-IN3-LB_F-SEC")
    BTU_IT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MIN")
    MilliM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliM-PER-M")
    MOL_LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-SEC")
    MilliGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC")
    MilliBAR = URIRef("http://qudt.org/vocab/unit/MilliBAR")
    GM_F = URIRef("http://qudt.org/vocab/unit/GM_F")
    CentiM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    BTU_IT_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_F")
    MilliGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-SEC")
    PicoMOL_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M3-SEC")
    AMU = URIRef("http://qudt.org/vocab/unit/AMU")
    PK_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-DAY")
    TON_Metric_PER_M3_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3-K")
    CentiM4 = URIRef("http://qudt.org/vocab/unit/CentiM4")
    KibiBYTE = URIRef("http://qudt.org/vocab/unit/KibiBYTE")
    N_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM2")
    MilliGM_PER_L_PA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-PA-SEC")
    CentiM3_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-CentiM3")
    KiloC = URIRef("http://qudt.org/vocab/unit/KiloC")
    TONNE = URIRef("http://qudt.org/vocab/unit/TONNE")
    DYN_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM3")
    ARCSEC = URIRef("http://qudt.org/vocab/unit/ARCSEC")
    S = URIRef("http://qudt.org/vocab/unit/S")
    C_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM2")
    PicoA = URIRef("http://qudt.org/vocab/unit/PicoA")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    LB_SEC_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-FT3")
    BU_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-SEC")
    PK_US_DRY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY")
    PERCENT_HR_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-YD3")
    FM = URIRef("http://qudt.org/vocab/unit/FM")
    EV_SEC = URIRef("http://qudt.org/vocab/unit/EV-SEC")
    MicroGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-GM")
    PER_GigaEV2 = URIRef("http://qudt.org/vocab/unit/PER-GigaEV2")
    GRAIN = URIRef("http://qudt.org/vocab/unit/GRAIN")
    BTU_TH_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-FT2-HR-DEG_F")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    MilliPA_SEC_PER_K = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-K")
    MilliDEG_C = URIRef("http://qudt.org/vocab/unit/MilliDEG_C")
    KiloW_PER_M_K = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M-K")
    N_M2 = URIRef("http://qudt.org/vocab/unit/N-M2")
    KiloM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloM-PER-DAY")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    BBL_US_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-SEC")
    MicroBAR = URIRef("http://qudt.org/vocab/unit/MicroBAR")
    MilliL_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-K")
    ERG_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM3")
    ARCMIN = URIRef("http://qudt.org/vocab/unit/ARCMIN")
    FT_LB_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-M2")
    BTU_39DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_39DEG_F")
    CentiM3_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR-BAR")
    FT2_PER_HR = URIRef("http://qudt.org/vocab/unit/FT2-PER-HR")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    MDOLLAR_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MDOLLAR-PER-FLIGHT")
    M_PER_BAR = URIRef("http://qudt.org/vocab/unit/M-PER-BAR")
    J_SEC_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-SEC-PER-MOL")
    GigaEV = URIRef("http://qudt.org/vocab/unit/GigaEV")
    GigaV = URIRef("http://qudt.org/vocab/unit/GigaV")
    CAL_IT_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM-K")
    FT3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT3-PER-DEG_F")
    MicroV = URIRef("http://qudt.org/vocab/unit/MicroV")
    MilliGM_HR_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L2")
    PERCENT_MIN_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-YD3")
    SEC2 = URIRef("http://qudt.org/vocab/unit/SEC2")
    GAL_UK = URIRef("http://qudt.org/vocab/unit/GAL_UK")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    LB_IN2_PER_GAL_US_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-GAL_US-LB_F-SEC")
    TON_SHORT_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-YD3")
    MilliM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-M3")
    W_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM-SR")
    MACH = URIRef("http://qudt.org/vocab/unit/MACH")
    J_PER_MOL_K = URIRef("http://qudt.org/vocab/unit/J-PER-MOL-K")
    MilliW_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM-SR")
    NanoT = URIRef("http://qudt.org/vocab/unit/NanoT")
    MilliMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-L")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    RAD_PER_HR = URIRef("http://qudt.org/vocab/unit/RAD-PER-HR")
    PSI_IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-IN3-PER-SEC")
    V_PER_M2 = URIRef("http://qudt.org/vocab/unit/V-PER-M2")
    A_PER_MilliM = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM")
    FT_SEC_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-GAL_US")
    A_HR = URIRef("http://qudt.org/vocab/unit/A-HR")
    KiloCAL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-SEC")
    POISE = URIRef("http://qudt.org/vocab/unit/POISE")
    PicoMOL = URIRef("http://qudt.org/vocab/unit/PicoMOL")
    EV_PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/EV-PER-ANGSTROM")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    NP_PER_SEC = URIRef("http://qudt.org/vocab/unit/NP-PER-SEC")
    FemtoV = URIRef("http://qudt.org/vocab/unit/FemtoV")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    LB_PER_YD = URIRef("http://qudt.org/vocab/unit/LB-PER-YD")
    MilliA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/MilliA-PER-MilliM")
    FT_LB_F = URIRef("http://qudt.org/vocab/unit/FT-LB_F")
    KiloGM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR")
    OCTET = URIRef("http://qudt.org/vocab/unit/OCTET")
    PERM_US = URIRef("http://qudt.org/vocab/unit/PERM_US")
    KiloGM_PER_L = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    ZeptoC = URIRef("http://qudt.org/vocab/unit/ZeptoC")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    KiloOHM = URIRef("http://qudt.org/vocab/unit/KiloOHM")
    PPTM = URIRef("http://qudt.org/vocab/unit/PPTM")
    KiloW = URIRef("http://qudt.org/vocab/unit/KiloW")
    GM_PER_MOL = URIRef("http://qudt.org/vocab/unit/GM-PER-MOL")
    YD3 = URIRef("http://qudt.org/vocab/unit/YD3")
    KiloCAL_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM-SEC-DEG_C")
    KiloGM_PER_GigaJ = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-GigaJ")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    PicoMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M3")
    LB_FT2 = URIRef("http://qudt.org/vocab/unit/LB-FT2")
    DECADE = URIRef("http://qudt.org/vocab/unit/DECADE")
    ERG_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM")
    FT_H2O_39dot2DEG_F = URIRef("http://qudt.org/vocab/unit/FT_H2O_39dot2DEG_F")
    MilliSV = URIRef("http://qudt.org/vocab/unit/MilliSV")
    CH = URIRef("http://qudt.org/vocab/unit/CH")
    OHM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/OHM-PER-KiloM")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    M_KiloGM = URIRef("http://qudt.org/vocab/unit/M-KiloGM")
    AttoFARAD = URIRef("http://qudt.org/vocab/unit/AttoFARAD")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    YD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/YD-PER-SEC2")
    MegaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M2")
    N_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-RAD")
    MilliL_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-K")
    KiloH = URIRef("http://qudt.org/vocab/unit/KiloH")
    MicroGM_PER_IN2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-IN2")
    MicroJ = URIRef("http://qudt.org/vocab/unit/MicroJ")
    W_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M2")
    OZ_MIN_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-YD3")
    BU_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-HR")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    LB_HR_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-FT3")
    NanoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-KiloGM")
    MilliOHM = URIRef("http://qudt.org/vocab/unit/MilliOHM")
    KiloLB_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloLB-PER-HR")
    CentiM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY")
    DeciS_PER_M = URIRef("http://qudt.org/vocab/unit/DeciS-PER-M")
    PERM_Metric_23DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_Metric_23DEG_C")
    MilliT = URIRef("http://qudt.org/vocab/unit/MilliT")
    HectoPA = URIRef("http://qudt.org/vocab/unit/HectoPA")
    IN3 = URIRef("http://qudt.org/vocab/unit/IN3")
    KiloBAUD = URIRef("http://qudt.org/vocab/unit/KiloBAUD")
    PERMITTIVITY_REL = URIRef("http://qudt.org/vocab/unit/PERMITTIVITY_REL")
    MicroL = URIRef("http://qudt.org/vocab/unit/MicroL")
    KiloLB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-FT")
    PER_WB = URIRef("http://qudt.org/vocab/unit/PER-WB")
    MOMME_Pearl = URIRef("http://qudt.org/vocab/unit/MOMME_Pearl")
    FT_HR_PER_IN3 = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-IN3")
    MilliGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    TON_Metric_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN-K")
    LB_FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT-PER-SEC")
    PINT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-HR")
    FemtoC = URIRef("http://qudt.org/vocab/unit/FemtoC")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    AttoFARAD = URIRef("http://qudt.org/vocab/unit/AttoFARAD")
    NP_PER_SEC = URIRef("http://qudt.org/vocab/unit/NP-PER-SEC")
    MegaBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaBQ-PER-KiloGM")
    NanoGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M2-PA-SEC")
    DEG_F_HR_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_IT")
    KiloN_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M2")
    AttoFARAD = URIRef("http://qudt.org/vocab/unit/AttoFARAD")
    CentiPOISE = URIRef("http://qudt.org/vocab/unit/CentiPOISE")
    PERCENT_PER_10KiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-10KiloCount")
    MilliBQ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-GM")
    MilliARCSEC = URIRef("http://qudt.org/vocab/unit/MilliARCSEC")
    KiloCAL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MIN")
    M2_PER_HZ = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ")
    MilliC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M3")
    MOL_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-L-BAR")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    GibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M3")
    THERM_US = URIRef("http://qudt.org/vocab/unit/THERM_US")
    BTU_TH = URIRef("http://qudt.org/vocab/unit/BTU_TH")
    REV_PER_MIN = URIRef("http://qudt.org/vocab/unit/REV-PER-MIN")
    MOL_PER_L = URIRef("http://qudt.org/vocab/unit/MOL-PER-L")
    C_Stat_PER_MOL = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-MOL")
    TON_Metric_PER_M3 = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3")
    GigaV_A_Reactive = URIRef("http://qudt.org/vocab/unit/GigaV-A_Reactive")
    NanoM_PER_CentiM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-MegaPA")
    M2_SR = URIRef("http://qudt.org/vocab/unit/M2-SR")
    MegaN_M = URIRef("http://qudt.org/vocab/unit/MegaN-M")
    DYN_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-CentiM")
    OZ_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_UK")
    CentiBAR = URIRef("http://qudt.org/vocab/unit/CentiBAR")
    BU_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-SEC")
    PicoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/PicoKAT-PER-L")
    OHM_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-PER-M")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    MilliL_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-K")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    M_K = URIRef("http://qudt.org/vocab/unit/M-K")
    MegaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBIT-PER-SEC")
    H = URIRef("http://qudt.org/vocab/unit/H")
    SLUG_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT-SEC")
    HZ_PER_V = URIRef("http://qudt.org/vocab/unit/HZ-PER-V")
    MilliBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-KiloGM")
    NanoA = URIRef("http://qudt.org/vocab/unit/NanoA")
    KiloGM_PER_L = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L")
    NanoV_A = URIRef("http://qudt.org/vocab/unit/NanoV-A")
    GM_PER_L_K = URIRef("http://qudt.org/vocab/unit/GM-PER-L-K")
    GM_HR_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L2")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    MillionUSD_PER_YR = URIRef("http://qudt.org/vocab/unit/MillionUSD-PER-YR")
    EV_M2 = URIRef("http://qudt.org/vocab/unit/EV-M2")
    MilliM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliM-PER-K")
    V_Ab = URIRef("http://qudt.org/vocab/unit/V_Ab")
    DECADE = URIRef("http://qudt.org/vocab/unit/DECADE")
    MilliS = URIRef("http://qudt.org/vocab/unit/MilliS")
    N_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-M-PER-M2")
    GAL_US_DRY = URIRef("http://qudt.org/vocab/unit/GAL_US_DRY")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    MicroM_PER_M = URIRef("http://qudt.org/vocab/unit/MicroM-PER-M")
    TON_Metric_PER_SEC = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC")
    DecaPA = URIRef("http://qudt.org/vocab/unit/DecaPA")
    KiloGM_F_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-SEC")
    IN = URIRef("http://qudt.org/vocab/unit/IN")
    MilliM2 = URIRef("http://qudt.org/vocab/unit/MilliM2")
    PERCENT_PER_V = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-V")
    GAL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-MIN")
    DecaM3 = URIRef("http://qudt.org/vocab/unit/DecaM3")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    MicroMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-DAY")
    M3_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-PA")
    KAT_PER_MicroL = URIRef("http://qudt.org/vocab/unit/KAT-PER-MicroL")
    YD3_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD3-PER-MIN")
    MOL_PER_KiloGM_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-PA")
    FT3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT3-PER-DEG_F")
    A_M2_PER_J_SEC = URIRef("http://qudt.org/vocab/unit/A-M2-PER-J-SEC")
    MHO_Stat = URIRef("http://qudt.org/vocab/unit/MHO_Stat")
    NP_PER_SEC = URIRef("http://qudt.org/vocab/unit/NP-PER-SEC")
    KAT_PER_MicroL = URIRef("http://qudt.org/vocab/unit/KAT-PER-MicroL")
    KiloGM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM2")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    PER_OZ = URIRef("http://qudt.org/vocab/unit/PER-OZ")
    HectoPA_PER_M = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-M")
    IU_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliGM")
    L_PER_MIN = URIRef("http://qudt.org/vocab/unit/L-PER-MIN")
    MilliGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-BAR")
    BQ_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-SEC-PER-M3")
    NanoGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2")
    KiloGM_PER_KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloMOL")
    J_PER_MIN = URIRef("http://qudt.org/vocab/unit/J-PER-MIN")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    DeciM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-M3")
    YR_TROPICAL = URIRef("http://qudt.org/vocab/unit/YR_TROPICAL")
    J_PER_SEC = URIRef("http://qudt.org/vocab/unit/J-PER-SEC")
    LB_PER_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-HR")
    MilliK_PER_K = URIRef("http://qudt.org/vocab/unit/MilliK-PER-K")
    M2_PER_GM = URIRef("http://qudt.org/vocab/unit/M2-PER-GM")
    PINT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-SEC")
    M3_PER_KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM-SEC2")
    NAT = URIRef("http://qudt.org/vocab/unit/NAT")
    W_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/W-PER-CentiM2")
    A_Ab = URIRef("http://qudt.org/vocab/unit/A_Ab")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    MilliM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-HR")
    KiloA = URIRef("http://qudt.org/vocab/unit/KiloA")
    QT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-HR")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    MegaOHM = URIRef("http://qudt.org/vocab/unit/MegaOHM")
    KiloCAL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-MIN")
    BARAD = URIRef("http://qudt.org/vocab/unit/BARAD")
    MilliA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/MilliA-PER-MilliM")
    GM_PER_L_CentiPOISE = URIRef("http://qudt.org/vocab/unit/GM-PER-L-CentiPOISE")
    MilliW = URIRef("http://qudt.org/vocab/unit/MilliW")
    PicoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-KiloGM")
    OHM_CentiM = URIRef("http://qudt.org/vocab/unit/OHM-CentiM")
    CentiM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SEC")
    FT = URIRef("http://qudt.org/vocab/unit/FT")
    GM_MIN_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M3-CentiM3")
    BARYE = URIRef("http://qudt.org/vocab/unit/BARYE")
    LB_PER_IN3_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3-DEG_F")
    PERCENT_SEC_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-FT3")
    M3_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-K")
    BTU_IT_PER_LB_F_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_R")
    M3_PER_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-BAR")
    MicroS_PER_M = URIRef("http://qudt.org/vocab/unit/MicroS-PER-M")
    DecaGM = URIRef("http://qudt.org/vocab/unit/DecaGM")
    DEG_F_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-HR")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    MilliGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC")
    W_PER_M = URIRef("http://qudt.org/vocab/unit/W-PER-M")
    K_M2_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/K-M2-PER-KiloGM-SEC")
    KiloCAL_Mean = URIRef("http://qudt.org/vocab/unit/KiloCAL_Mean")
    KiloM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC")
    KiloPOND = URIRef("http://qudt.org/vocab/unit/KiloPOND")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    L_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-BAR")
    GigaBasePair = URIRef("http://qudt.org/vocab/unit/GigaBasePair")
    C = URIRef("http://qudt.org/vocab/unit/C")
    PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-PER-SEC")
    PSI_YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-YD3-PER-SEC")
    PetaFLOPS = URIRef("http://qudt.org/vocab/unit/PetaFLOPS")
    PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2")
    TON_UK_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-YD3")
    MilliW_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-MilliGM")
    PHON = URIRef("http://qudt.org/vocab/unit/PHON")
    MilliDEG_C = URIRef("http://qudt.org/vocab/unit/MilliDEG_C")
    PERCENT_MIN_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-IN3")
    DEG_F_HR_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_IT")
    C_M2_PER_V = URIRef("http://qudt.org/vocab/unit/C-M2-PER-V")
    YD_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD-PER-SEC")
    PDL_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/PDL-SEC-PER-IN2")
    W_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/W-PER-CentiM2")
    BREATH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BREATH-PER-MIN")
    QUAD = URIRef("http://qudt.org/vocab/unit/QUAD")
    MI3 = URIRef("http://qudt.org/vocab/unit/MI3")
    KiloGM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR")
    PER_MO = URIRef("http://qudt.org/vocab/unit/PER-MO")
    GibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M2")
    DEGREE_BAUME_US_LIGHT = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_LIGHT")
    LB_HR_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-IN3")
    PINT = URIRef("http://qudt.org/vocab/unit/PINT")
    KiloW_HR = URIRef("http://qudt.org/vocab/unit/KiloW-HR")
    DeciM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-SEC")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    MegaBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaBQ-PER-KiloGM")
    ERG_PER_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-SEC")
    KiloMOL_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3-K")
    YD_PER_HR = URIRef("http://qudt.org/vocab/unit/YD-PER-HR")
    PERCENT_MIN_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-L")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    BTU_TH_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_R")
    DWT = URIRef("http://qudt.org/vocab/unit/DWT")
    TON_US_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_US-PER-YD3")
    LB_SEC_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-IN3")
    NanoGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DeciL")
    KiloCD = URIRef("http://qudt.org/vocab/unit/KiloCD")
    LB_SEC_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-FT3")
    KiloGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-BAR")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    NUM_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/NUM-PER-MilliM3")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    PetaC = URIRef("http://qudt.org/vocab/unit/PetaC")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    EUR_PER_W_SEC = URIRef("http://qudt.org/vocab/unit/EUR-PER-W-SEC")
    GM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloM")
    Hundredweight_US = URIRef("http://qudt.org/vocab/unit/Hundredweight_US")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    LB_F_IN_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN-PER-IN")
    MOL_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-DeciM3")
    PT = URIRef("http://qudt.org/vocab/unit/PT")
    PlanckVolt = URIRef("http://qudt.org/vocab/unit/PlanckVolt")
    TONNE_PER_M3 = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3")
    HK = URIRef("http://qudt.org/vocab/unit/HK")
    MilliM_HGA = URIRef("http://qudt.org/vocab/unit/MilliM_HGA")
    W_HR_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-HR-PER-KiloGM")
    KiloCAL_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM-DEG_C")
    MicroT = URIRef("http://qudt.org/vocab/unit/MicroT")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    CD_PER_IN2 = URIRef("http://qudt.org/vocab/unit/CD-PER-IN2")
    A_PER_J = URIRef("http://qudt.org/vocab/unit/A-PER-J")
    PicoA = URIRef("http://qudt.org/vocab/unit/PicoA")
    MilliDEG_C = URIRef("http://qudt.org/vocab/unit/MilliDEG_C")
    QT_US_DRY = URIRef("http://qudt.org/vocab/unit/QT_US_DRY")
    PER_M_NanoM_SR = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM-SR")
    LB_MIN_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT6")
    MilliMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-MOL")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    MicroC = URIRef("http://qudt.org/vocab/unit/MicroC")
    MilliW = URIRef("http://qudt.org/vocab/unit/MilliW")
    IU = URIRef("http://qudt.org/vocab/unit/IU")
    PicoPA_PER_KiloM = URIRef("http://qudt.org/vocab/unit/PicoPA-PER-KiloM")
    DYN_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM2")
    KiloBQ = URIRef("http://qudt.org/vocab/unit/KiloBQ")
    N_M2_PER_A = URIRef("http://qudt.org/vocab/unit/N-M2-PER-A")
    IN_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC2")
    DeciTON_Metric = URIRef("http://qudt.org/vocab/unit/DeciTON_Metric")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    MegaJ = URIRef("http://qudt.org/vocab/unit/MegaJ")
    PER_MilliSEC = URIRef("http://qudt.org/vocab/unit/PER-MilliSEC")
    KiloMOL_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3-BAR")
    MegaEV = URIRef("http://qudt.org/vocab/unit/MegaEV")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    PER_TON = URIRef("http://qudt.org/vocab/unit/PER-TON")
    NanoOHM_M = URIRef("http://qudt.org/vocab/unit/NanoOHM-M")
    W_PER_SR_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-SR-M2")
    TONNE_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY-BAR")
    BTU_IT_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-IN2-SEC")
    NanoGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-SEC")
    OZ_FT_SEC_PER_IN3_LB = URIRef("http://qudt.org/vocab/unit/OZ-FT-SEC-PER-IN3-LB")
    TON_US = URIRef("http://qudt.org/vocab/unit/TON_US")
    YD_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD-PER-SEC")
    BBL_UK_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-HR")
    BTU_IT_PER_MOL_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB")
    BU_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-HR")
    KiloGM_PER_MegaBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MegaBTU_IT")
    TON_Metric = URIRef("http://qudt.org/vocab/unit/TON_Metric")
    TeraHZ = URIRef("http://qudt.org/vocab/unit/TeraHZ")
    GigaC = URIRef("http://qudt.org/vocab/unit/GigaC")
    NanoGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DeciL")
    FT_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC-DEG_F")
    Hundredweight_UK = URIRef("http://qudt.org/vocab/unit/Hundredweight_UK")
    MegaW = URIRef("http://qudt.org/vocab/unit/MegaW")
    CAL_IT = URIRef("http://qudt.org/vocab/unit/CAL_IT")
    NP_PER_SEC = URIRef("http://qudt.org/vocab/unit/NP-PER-SEC")
    ExaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/ExaJ-PER-SEC")
    M = URIRef("http://qudt.org/vocab/unit/M")
    FemtoJ = URIRef("http://qudt.org/vocab/unit/FemtoJ")
    PER_MIN = URIRef("http://qudt.org/vocab/unit/PER-MIN")
    PebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M")
    KiloGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloGM")
    ATM_M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/ATM-M3-PER-MOL")
    CentiPOISE_PER_K = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-K")
    MegaOHM_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-M")
    FT_LB_F_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-HR")
    MilliL_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-BAR")
    NAT_PER_SEC = URIRef("http://qudt.org/vocab/unit/NAT-PER-SEC")
    PA_PER_MIN = URIRef("http://qudt.org/vocab/unit/PA-PER-MIN")
    KiloWB = URIRef("http://qudt.org/vocab/unit/KiloWB")
    MilliJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-SEC")
    PSI_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-L-PER-SEC")
    HectoPA_PER_M = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-M")
    GM_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/GM-PER-DEG_C")
    OZ_HR_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN6")
    LB_PER_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-PSI")
    IN2_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN2-PER-SEC")
    NanoMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL")
    BARYE = URIRef("http://qudt.org/vocab/unit/BARYE")
    PER_J_M3 = URIRef("http://qudt.org/vocab/unit/PER-J-M3")
    J_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2-DAY")
    DEG_F_HR_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_IT")
    FT_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT-PER-DAY")
    PicoPA_PER_KiloM = URIRef("http://qudt.org/vocab/unit/PicoPA-PER-KiloM")
    KiloN_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M2")
    MilliC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M3")
    FC = URIRef("http://qudt.org/vocab/unit/FC")
    KiloGM_M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M2-PER-SEC")
    MilliL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-SEC")
    GM_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM2")
    MegaEV_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-CentiM")
    MegaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBYTE-PER-SEC")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    MilliRAD = URIRef("http://qudt.org/vocab/unit/MilliRAD")
    MegaW_HR = URIRef("http://qudt.org/vocab/unit/MegaW-HR")
    PERCENT_PER_V = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-V")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    MegaBQ = URIRef("http://qudt.org/vocab/unit/MegaBQ")
    LB_FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT-PER-SEC")
    MegaJ = URIRef("http://qudt.org/vocab/unit/MegaJ")
    W_HR_PER_L = URIRef("http://qudt.org/vocab/unit/W-HR-PER-L")
    CentiM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC-BAR")
    C_M2 = URIRef("http://qudt.org/vocab/unit/C-M2")
    KiloW_PER_M2_K = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M2-K")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    ANGSTROM3 = URIRef("http://qudt.org/vocab/unit/ANGSTROM3")
    IN3 = URIRef("http://qudt.org/vocab/unit/IN3")
    HART_PER_SEC = URIRef("http://qudt.org/vocab/unit/HART-PER-SEC")
    MilliA_PER_IN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-IN")
    MI_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI-PER-MIN")
    PK_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-SEC")
    MilliL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-GM")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    BU_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-SEC")
    MilliL_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY")
    HectoPA_PER_M = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-M")
    V2_PER_K2 = URIRef("http://qudt.org/vocab/unit/V2-PER-K2")
    BTU_IT_PER_LB_MOL = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-MOL")
    ExaJ = URIRef("http://qudt.org/vocab/unit/ExaJ")
    KiloSEC = URIRef("http://qudt.org/vocab/unit/KiloSEC")
    OZ_HR_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-YD3")
    NUM_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/NUM-PER-MilliGM")
    MilliGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN")
    PicoW = URIRef("http://qudt.org/vocab/unit/PicoW")
    S_PER_CentiM = URIRef("http://qudt.org/vocab/unit/S-PER-CentiM")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    LB_MIN_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-YD3")
    N_M_PER_MIN_Angle = URIRef("http://qudt.org/vocab/unit/N-M-PER-MIN_Angle")
    J_PER_HR = URIRef("http://qudt.org/vocab/unit/J-PER-HR")
    FATH = URIRef("http://qudt.org/vocab/unit/FATH")
    N_CentiM = URIRef("http://qudt.org/vocab/unit/N-CentiM")
    HP_Boiler = URIRef("http://qudt.org/vocab/unit/HP_Boiler")
    MilliL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC")
    N_M_PER_M_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-M-RAD")
    PER_BAR = URIRef("http://qudt.org/vocab/unit/PER-BAR")
    KiloGM_PER_HA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HA")
    PER_MilliGM = URIRef("http://qudt.org/vocab/unit/PER-MilliGM")
    MilliDARCY = URIRef("http://qudt.org/vocab/unit/MilliDARCY")
    MilliL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN")
    BBL_US = URIRef("http://qudt.org/vocab/unit/BBL_US")
    MilliA_IN2_PER_LB_F = URIRef("http://qudt.org/vocab/unit/MilliA-IN2-PER-LB_F")
    POND = URIRef("http://qudt.org/vocab/unit/POND")
    YD3_PER_PSI = URIRef("http://qudt.org/vocab/unit/YD3-PER-PSI")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    MilliJ = URIRef("http://qudt.org/vocab/unit/MilliJ")
    ST_PER_PA = URIRef("http://qudt.org/vocab/unit/ST-PER-PA")
    PER_EV2 = URIRef("http://qudt.org/vocab/unit/PER-EV2")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    YD3_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD3-PER-MIN")
    J_PER_GM_K = URIRef("http://qudt.org/vocab/unit/J-PER-GM-K")
    GM_SEC_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L-CentiM3")
    MilliM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliM-PER-MIN")
    LB_SEC_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-GAL_UK")
    OZ_SEC_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN6")
    KiloGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY")
    PSI_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-M3-PER-SEC")
    A_PER_A_HR = URIRef("http://qudt.org/vocab/unit/A-PER-A-HR")
    BBL_UK_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-SEC")
    MicroIN = URIRef("http://qudt.org/vocab/unit/MicroIN")
    H_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/H_Stat-PER-CentiM")
    MOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    MilliGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DeciL")
    A = URIRef("http://qudt.org/vocab/unit/A")
    MicroFARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-KiloM")
    GM_PER_M2 = URIRef("http://qudt.org/vocab/unit/GM-PER-M2")
    G = URIRef("http://qudt.org/vocab/unit/G")
    NanoMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-M2-DAY")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    KiloBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBYTE-PER-SEC")
    PER_T_M = URIRef("http://qudt.org/vocab/unit/PER-T-M")
    NanoM_PER_CentiM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-MegaPA")
    C_Stat = URIRef("http://qudt.org/vocab/unit/C_Stat")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    T = URIRef("http://qudt.org/vocab/unit/T")
    PERCENT_MIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-M3")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    HectoPA = URIRef("http://qudt.org/vocab/unit/HectoPA")
    LB_FT2_PER_GAL_US_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-GAL_US-LB_F-SEC")
    CH = URIRef("http://qudt.org/vocab/unit/CH")
    PicoS_PER_M = URIRef("http://qudt.org/vocab/unit/PicoS-PER-M")
    MicroMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-DAY")
    N_M_PER_ARCMIN = URIRef("http://qudt.org/vocab/unit/N-M-PER-ARCMIN")
    L_PER_K = URIRef("http://qudt.org/vocab/unit/L-PER-K")
    PERCENT_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-M3")
    BTU_MEAN = URIRef("http://qudt.org/vocab/unit/BTU_MEAN")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    OZ_M = URIRef("http://qudt.org/vocab/unit/OZ_M")
    ExbiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M2")
    M3_PER_K = URIRef("http://qudt.org/vocab/unit/M3-PER-K")
    V_PER_L_MIN = URIRef("http://qudt.org/vocab/unit/V-PER-L-MIN")
    LB_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT2")
    MilliMOL_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3-DAY")
    KiloGM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3")
    W_PER_GM = URIRef("http://qudt.org/vocab/unit/W-PER-GM")
    NanoMOL_PER_CentiM3_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-CentiM3-HR")
    CentiM3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL-SEC")
    A_M2_PER_J_SEC = URIRef("http://qudt.org/vocab/unit/A-M2-PER-J-SEC")
    M2_PER_J = URIRef("http://qudt.org/vocab/unit/M2-PER-J")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    ATM_M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/ATM-M3-PER-MOL")
    MilliL_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-K")
    MilliS_PER_M = URIRef("http://qudt.org/vocab/unit/MilliS-PER-M")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    MilliS = URIRef("http://qudt.org/vocab/unit/MilliS")
    N_M_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-RAD")
    N_M_PER_DEG_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG-M")
    N_M2 = URIRef("http://qudt.org/vocab/unit/N-M2")
    Stone_UK = URIRef("http://qudt.org/vocab/unit/Stone_UK")
    TonEnergy = URIRef("http://qudt.org/vocab/unit/TonEnergy")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    W_M2 = URIRef("http://qudt.org/vocab/unit/W-M2")
    MegaPA = URIRef("http://qudt.org/vocab/unit/MegaPA")
    PetaC = URIRef("http://qudt.org/vocab/unit/PetaC")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    KiloA = URIRef("http://qudt.org/vocab/unit/KiloA")
    M3_PER_DAY = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY")
    GigaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-SEC")
    L_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/L-PER-KiloGM")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    FemtoFARAD = URIRef("http://qudt.org/vocab/unit/FemtoFARAD")
    NanoM = URIRef("http://qudt.org/vocab/unit/NanoM")
    IN_HG = URIRef("http://qudt.org/vocab/unit/IN_HG")
    DeciN_M = URIRef("http://qudt.org/vocab/unit/DeciN-M")
    GM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC")
    MegaV_PER_M = URIRef("http://qudt.org/vocab/unit/MegaV-PER-M")
    L_PER_DAY = URIRef("http://qudt.org/vocab/unit/L-PER-DAY")
    MilliM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DAY")
    TONNE_PER_MIN = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN")
    GI_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_US-PER-SEC")
    V_PER_K = URIRef("http://qudt.org/vocab/unit/V-PER-K")
    CentiM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SEC")
    W_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-PER-KiloGM")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    ERG_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM")
    R = URIRef("http://qudt.org/vocab/unit/R")
    NanoW = URIRef("http://qudt.org/vocab/unit/NanoW")
    MegaTON = URIRef("http://qudt.org/vocab/unit/MegaTON")
    NanoS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/NanoS-PER-CentiM")
    NanoS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/NanoS-PER-CentiM")
    MebiBIT = URIRef("http://qudt.org/vocab/unit/MebiBIT")
    MicroG_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroG-PER-CentiM2")
    FC = URIRef("http://qudt.org/vocab/unit/FC")
    PPQ = URIRef("http://qudt.org/vocab/unit/PPQ")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    ERG_SEC = URIRef("http://qudt.org/vocab/unit/ERG-SEC")
    BAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-L-PER-SEC")
    PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/PER-ANGSTROM")
    THERM_EC = URIRef("http://qudt.org/vocab/unit/THERM_EC")
    MilliM3 = URIRef("http://qudt.org/vocab/unit/MilliM3")
    TONNE_PER_MIN = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN")
    MilliM4 = URIRef("http://qudt.org/vocab/unit/MilliM4")
    ERG_CentiM2 = URIRef("http://qudt.org/vocab/unit/ERG-CentiM2")
    MilliM3 = URIRef("http://qudt.org/vocab/unit/MilliM3")
    ExaBYTE = URIRef("http://qudt.org/vocab/unit/ExaBYTE")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    GM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloM")
    M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/M2-PER-MOL")
    GigaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-HR")
    U = URIRef("http://qudt.org/vocab/unit/U")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    BU_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-SEC")
    N_PER_MilliM = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM")
    GAL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-DAY")
    ElementaryCharge = URIRef("http://qudt.org/vocab/unit/ElementaryCharge")
    MilliS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MilliS-PER-CentiM")
    ENZ_PER_L = URIRef("http://qudt.org/vocab/unit/ENZ-PER-L")
    GM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY-BAR")
    LB_MIN_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US2")
    N_PER_C = URIRef("http://qudt.org/vocab/unit/N-PER-C")
    KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloGM-K")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    KiloGM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-CentiM2")
    IU_PER_L = URIRef("http://qudt.org/vocab/unit/IU-PER-L")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    IN_PDL = URIRef("http://qudt.org/vocab/unit/IN-PDL")
    NanoJ = URIRef("http://qudt.org/vocab/unit/NanoJ")
    LB_MIN_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US2")
    MilliL_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-BAR")
    GM_PER_CentiM2_YR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2-YR")
    N_M_PER_M_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-M-RAD")
    CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3")
    MegaA_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaA-PER-M2")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    MilliGM_HR_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L-M3")
    Hundredweight_UK = URIRef("http://qudt.org/vocab/unit/Hundredweight_UK")
    MilliGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-BAR")
    PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-PER-SEC")
    LA = URIRef("http://qudt.org/vocab/unit/LA")
    SLUG = URIRef("http://qudt.org/vocab/unit/SLUG")
    MilloMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilloMOL-PER-L")
    S_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/S-M2-PER-MOL")
    A_HR = URIRef("http://qudt.org/vocab/unit/A-HR")
    KiloGM_PER_M3_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-PA")
    OZ_PER_FT2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-FT2")
    PERMITTIVITY_REL = URIRef("http://qudt.org/vocab/unit/PERMITTIVITY_REL")
    FemtoSEC = URIRef("http://qudt.org/vocab/unit/FemtoSEC")
    ARCMIN = URIRef("http://qudt.org/vocab/unit/ARCMIN")
    KiloN = URIRef("http://qudt.org/vocab/unit/KiloN")
    FATH = URIRef("http://qudt.org/vocab/unit/FATH")
    MegaBAR = URIRef("http://qudt.org/vocab/unit/MegaBAR")
    MicroPA = URIRef("http://qudt.org/vocab/unit/MicroPA")
    FA = URIRef("http://qudt.org/vocab/unit/FA")
    MegaGM = URIRef("http://qudt.org/vocab/unit/MegaGM")
    PINT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-SEC")
    NanoM_PER_CentiM_PSI = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-PSI")
    MegaL = URIRef("http://qudt.org/vocab/unit/MegaL")
    MilliL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M3")
    MicroV = URIRef("http://qudt.org/vocab/unit/MicroV")
    RT = URIRef("http://qudt.org/vocab/unit/RT")
    MegaHZ = URIRef("http://qudt.org/vocab/unit/MegaHZ")
    DeciS = URIRef("http://qudt.org/vocab/unit/DeciS")
    MegaV_A = URIRef("http://qudt.org/vocab/unit/MegaV-A")
    FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC")
    MicroPA = URIRef("http://qudt.org/vocab/unit/MicroPA")
    ONE = URIRef("http://qudt.org/vocab/unit/ONE")
    M2_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/M2-SEC-PER-RAD")
    BBL = URIRef("http://qudt.org/vocab/unit/BBL")
    C = URIRef("http://qudt.org/vocab/unit/C")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    MicroRAD = URIRef("http://qudt.org/vocab/unit/MicroRAD")
    KiloCAL_PER_MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL-DEG_C")
    GAL_US = URIRef("http://qudt.org/vocab/unit/GAL_US")
    EV = URIRef("http://qudt.org/vocab/unit/EV")
    BTU_TH_FT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-HR-FT2-DEG_F")
    LB_PER_IN3 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3")
    NUM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/NUM-PER-M2-DAY")
    A_Ab_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-CentiM2")
    MegaS = URIRef("http://qudt.org/vocab/unit/MegaS")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    LB_MIN_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-FT3")
    PA_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC")
    RAD_R = URIRef("http://qudt.org/vocab/unit/RAD_R")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    N_M_PER_A = URIRef("http://qudt.org/vocab/unit/N-M-PER-A")
    PicoPA_PER_KiloM = URIRef("http://qudt.org/vocab/unit/PicoPA-PER-KiloM")
    B = URIRef("http://qudt.org/vocab/unit/B")
    PER_MILLE_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PSI")
    GM_PER_CentiM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM-BAR")
    BQ_PER_L = URIRef("http://qudt.org/vocab/unit/BQ-PER-L")
    N = URIRef("http://qudt.org/vocab/unit/N")
    M2_HR_DEG_C_PER_KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/M2-HR-DEG_C-PER-KiloCAL_IT")
    J_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    MicroC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M2")
    KiloM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM2-PER-SEC2")
    DEG_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC2")
    AttoJ_SEC = URIRef("http://qudt.org/vocab/unit/AttoJ-SEC")
    YD2 = URIRef("http://qudt.org/vocab/unit/YD2")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    M3_PER_HA = URIRef("http://qudt.org/vocab/unit/M3-PER-HA")
    K_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/K-PER-SEC2")
    NanoW = URIRef("http://qudt.org/vocab/unit/NanoW")
    PicoMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L-HR")
    MilliGM_PER_L_PA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-PA-SEC")
    MilliARCSEC = URIRef("http://qudt.org/vocab/unit/MilliARCSEC")
    MicroM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroM-PER-SEC")
    GM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC-K")
    GigaPA = URIRef("http://qudt.org/vocab/unit/GigaPA")
    NanoGM = URIRef("http://qudt.org/vocab/unit/NanoGM")
    GM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2")
    GM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN-K")
    PER_WB = URIRef("http://qudt.org/vocab/unit/PER-WB")
    M3_PER_PA = URIRef("http://qudt.org/vocab/unit/M3-PER-PA")
    DEG_R_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-SEC")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    M3_PER_HA = URIRef("http://qudt.org/vocab/unit/M3-PER-HA")
    GM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/GM-PER-HR-K")
    NanoMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L-HR")
    DEGREE_BALLING = URIRef("http://qudt.org/vocab/unit/DEGREE_BALLING")
    CentiM3_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN-K")
    MegaW = URIRef("http://qudt.org/vocab/unit/MegaW")
    A_SEC2 = URIRef("http://qudt.org/vocab/unit/A-SEC2")
    NUM_PER_GM = URIRef("http://qudt.org/vocab/unit/NUM-PER-GM")
    FT2 = URIRef("http://qudt.org/vocab/unit/FT2")
    KN = URIRef("http://qudt.org/vocab/unit/KN")
    K_PER_W = URIRef("http://qudt.org/vocab/unit/K-PER-W")
    NP = URIRef("http://qudt.org/vocab/unit/NP")
    M2_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/M2-SEC-PER-RAD")
    CORD = URIRef("http://qudt.org/vocab/unit/CORD")
    GM_MIN_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L-CentiM3")
    CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-GM")
    NanoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L")
    TON_Metric_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY-K")
    GAL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-DAY")
    FRACTION = URIRef("http://qudt.org/vocab/unit/FRACTION")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    ERG_SEC = URIRef("http://qudt.org/vocab/unit/ERG-SEC")
    MicroGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-MilliL")
    BTU_TH_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-FT2-HR-DEG_F")
    KiloBAR = URIRef("http://qudt.org/vocab/unit/KiloBAR")
    WB_PER_MilliM = URIRef("http://qudt.org/vocab/unit/WB-PER-MilliM")
    MilliM3 = URIRef("http://qudt.org/vocab/unit/MilliM3")
    MilliBAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-L-PER-SEC")
    MicroM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-M3")
    PA_M = URIRef("http://qudt.org/vocab/unit/PA-M")
    MilliGM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-BAR")
    KiloN_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M2")
    FT2_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT2-PER-SEC")
    M3_PER_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-M2")
    NanoGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-HR")
    SEC2 = URIRef("http://qudt.org/vocab/unit/SEC2")
    DeciM3 = URIRef("http://qudt.org/vocab/unit/DeciM3")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    FT_SEC_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-GAL_UK")
    CAL_IT_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM2-K")
    CentiM3_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY-K")
    SEC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/SEC-PER-KiloGM")
    MOL_PER_L = URIRef("http://qudt.org/vocab/unit/MOL-PER-L")
    MicroBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-KiloGM")
    KiloJ_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MIN")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    MilliA_PER_L_MIN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-L-MIN")
    MilliJ = URIRef("http://qudt.org/vocab/unit/MilliJ")
    CentiN = URIRef("http://qudt.org/vocab/unit/CentiN")
    TeraV_A = URIRef("http://qudt.org/vocab/unit/TeraV-A")
    FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-SEC-DEG_F")
    M2_PER_KiloW = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloW")
    L_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-HR-BAR")
    PK_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-MIN")
    MicroM_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/MicroM-PER-L-DAY")
    PK_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-MIN")
    GM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY-BAR")
    TON_Metric_PER_HA = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HA")
    FT3_PER_HR = URIRef("http://qudt.org/vocab/unit/FT3-PER-HR")
    EV_M2 = URIRef("http://qudt.org/vocab/unit/EV-M2")
    YD3_PER_DAY = URIRef("http://qudt.org/vocab/unit/YD3-PER-DAY")
    CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3")
    QT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_US-PER-DAY")
    LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT2")
    ERG_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM2-SEC")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN")
    F = URIRef("http://qudt.org/vocab/unit/F")
    MegaV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive")
    LB_F_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-FT2")
    TeraA = URIRef("http://qudt.org/vocab/unit/TeraA")
    MilliA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/MilliA-PER-MilliM")
    GM_PER_CentiM3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3-BAR")
    MicroH_PER_M = URIRef("http://qudt.org/vocab/unit/MicroH-PER-M")
    BTU_TH_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-HR-DEG_F")
    KiloGM_PER_M_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-HR")
    OZ = URIRef("http://qudt.org/vocab/unit/OZ")
    C_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-M2-PER-KiloGM")
    FemtoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-L")
    GM_Nitrogen_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Nitrogen-PER-M2-DAY")
    C3_M_PER_J2 = URIRef("http://qudt.org/vocab/unit/C3-M-PER-J2")
    CFU = URIRef("http://qudt.org/vocab/unit/CFU")
    LB_M = URIRef("http://qudt.org/vocab/unit/LB_M")
    M_PER_K = URIRef("http://qudt.org/vocab/unit/M-PER-K")
    KiloGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-SEC")
    BTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2")
    PERCENT_PER_BAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-BAR")
    M2_SR = URIRef("http://qudt.org/vocab/unit/M2-SR")
    KiloGM_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM2")
    MegaA_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaA-PER-M2")
    KiloBIT = URIRef("http://qudt.org/vocab/unit/KiloBIT")
    KiloC_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M2")
    N_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM2")
    FT3_PER_PSI = URIRef("http://qudt.org/vocab/unit/FT3-PER-PSI")
    KiloC = URIRef("http://qudt.org/vocab/unit/KiloC")
    M3_PER_HR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR")
    KiloA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M")
    A_MIN = URIRef("http://qudt.org/vocab/unit/A-MIN")
    N_CentiM = URIRef("http://qudt.org/vocab/unit/N-CentiM")
    failures_in_time = URIRef("http://qudt.org/vocab/unit/failures-in-time")
    FUR = URIRef("http://qudt.org/vocab/unit/FUR")
    HZ_PER_T = URIRef("http://qudt.org/vocab/unit/HZ-PER-T")
    M_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-K")
    MegaW = URIRef("http://qudt.org/vocab/unit/MegaW")
    MicroM_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/MicroM-PER-L-DAY")
    MicroW = URIRef("http://qudt.org/vocab/unit/MicroW")
    PER_WB = URIRef("http://qudt.org/vocab/unit/PER-WB")
    LB_IN2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-IN3-LB_F-SEC")
    MicroFARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-KiloM")
    GigaW = URIRef("http://qudt.org/vocab/unit/GigaW")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    MilliMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2")
    BBL = URIRef("http://qudt.org/vocab/unit/BBL")
    KiloGM_F_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-MilliM2")
    BQ_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-SEC-PER-M3")
    KiloMIL_Circ = URIRef("http://qudt.org/vocab/unit/KiloMIL_Circ")
    MIL = URIRef("http://qudt.org/vocab/unit/MIL")
    MilliR = URIRef("http://qudt.org/vocab/unit/MilliR")
    S_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/S-M2-PER-MOL")
    W_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M3")
    DEG_F_HR_FT2_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT")
    GI_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-SEC")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    J_PER_M = URIRef("http://qudt.org/vocab/unit/J-PER-M")
    DIOPTER = URIRef("http://qudt.org/vocab/unit/DIOPTER")
    MegaPA_PER_K = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-K")
    A_Ab = URIRef("http://qudt.org/vocab/unit/A_Ab")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    OZ_MIN_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-GAL_US")
    BARAD = URIRef("http://qudt.org/vocab/unit/BARAD")
    DecaC = URIRef("http://qudt.org/vocab/unit/DecaC")
    PINT_UK = URIRef("http://qudt.org/vocab/unit/PINT_UK")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    MegaL = URIRef("http://qudt.org/vocab/unit/MegaL")
    BIOT = URIRef("http://qudt.org/vocab/unit/BIOT")
    KiloL = URIRef("http://qudt.org/vocab/unit/KiloL")
    N_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M3")
    MegaA_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaA-PER-M2")
    MegaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M3")
    OZ_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN3")
    LM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LM-PER-FT2")
    CentiM_H2O = URIRef("http://qudt.org/vocab/unit/CentiM_H2O")
    PERCENT_MIN_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-FT3")
    DeciGM = URIRef("http://qudt.org/vocab/unit/DeciGM")
    GI_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_US-PER-DAY")
    SLUG_PER_FT = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT")
    CentiM3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-BAR")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    H_PER_M = URIRef("http://qudt.org/vocab/unit/H-PER-M")
    Kilo_FT3 = URIRef("http://qudt.org/vocab/unit/Kilo-FT3")
    MilliW_PER_CentiM2_MicroM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-CentiM2-MicroM-SR")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    KiloBTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-FT2")
    KiloGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-BAR")
    LB_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-DEG_F")
    MicroGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-DeciL")
    DeciB_M = URIRef("http://qudt.org/vocab/unit/DeciB_M")
    MilLength = URIRef("http://qudt.org/vocab/unit/MilLength")
    OZ_HR_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN6")
    BAR_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/BAR-PER-DEG_C")
    NTU = URIRef("http://qudt.org/vocab/unit/NTU")
    M2_K = URIRef("http://qudt.org/vocab/unit/M2-K")
    T_SEC = URIRef("http://qudt.org/vocab/unit/T-SEC")
    A = URIRef("http://qudt.org/vocab/unit/A")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    A2_SEC = URIRef("http://qudt.org/vocab/unit/A2-SEC")
    PicoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/PicoFARAD-PER-M")
    W_PER_K = URIRef("http://qudt.org/vocab/unit/W-PER-K")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    LB_PER_M3 = URIRef("http://qudt.org/vocab/unit/LB-PER-M3")
    ExaBYTE = URIRef("http://qudt.org/vocab/unit/ExaBYTE")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    PlanckImpedance = URIRef("http://qudt.org/vocab/unit/PlanckImpedance")
    FT_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-PER-HR")
    CUP = URIRef("http://qudt.org/vocab/unit/CUP")
    KiloGM_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MOL")
    MicroS = URIRef("http://qudt.org/vocab/unit/MicroS")
    KiloM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC2")
    MilliSV = URIRef("http://qudt.org/vocab/unit/MilliSV")
    TONNE_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR-BAR")
    MIN = URIRef("http://qudt.org/vocab/unit/MIN")
    KiloOHM = URIRef("http://qudt.org/vocab/unit/KiloOHM")
    DecaL = URIRef("http://qudt.org/vocab/unit/DecaL")
    MicroBQ = URIRef("http://qudt.org/vocab/unit/MicroBQ")
    MegaC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M2")
    NUM_PER_HR = URIRef("http://qudt.org/vocab/unit/NUM-PER-HR")
    NanoL = URIRef("http://qudt.org/vocab/unit/NanoL")
    DYN_SEC_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM")
    THM_US_PER_HR = URIRef("http://qudt.org/vocab/unit/THM_US-PER-HR")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    MilliOHM = URIRef("http://qudt.org/vocab/unit/MilliOHM")
    CentiST = URIRef("http://qudt.org/vocab/unit/CentiST")
    GibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M")
    NanoC = URIRef("http://qudt.org/vocab/unit/NanoC")
    KiloJ_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM-K")
    TeraOHM = URIRef("http://qudt.org/vocab/unit/TeraOHM")
    SLUG_PER_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-SEC")
    PlanckMomentum = URIRef("http://qudt.org/vocab/unit/PlanckMomentum")
    GigaJ = URIRef("http://qudt.org/vocab/unit/GigaJ")
    KibiBIT = URIRef("http://qudt.org/vocab/unit/KibiBIT")
    GAUGE_FR = URIRef("http://qudt.org/vocab/unit/GAUGE_FR")
    BTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2")
    LB_PER_FT = URIRef("http://qudt.org/vocab/unit/LB-PER-FT")
    PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PER-KiloGM")
    J_PER_GM = URIRef("http://qudt.org/vocab/unit/J-PER-GM")
    BBL_UK_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-SEC")
    MicroS = URIRef("http://qudt.org/vocab/unit/MicroS")
    MicroBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-L")
    ERG_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM-SEC")
    PERCENT_HR_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-GAL_UK")
    YD3_PER_HR = URIRef("http://qudt.org/vocab/unit/YD3-PER-HR")
    MilliGM_HR_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M3-L")
    V_Stat_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-CentiM")
    BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    M3_PER_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-BAR")
    W_HR = URIRef("http://qudt.org/vocab/unit/W-HR")
    OHM_KiloM = URIRef("http://qudt.org/vocab/unit/OHM-KiloM")
    QT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_US-PER-HR")
    FT3_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT3-PER-SEC")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    ROD = URIRef("http://qudt.org/vocab/unit/ROD")
    ERG_CentiM2 = URIRef("http://qudt.org/vocab/unit/ERG-CentiM2")
    EV = URIRef("http://qudt.org/vocab/unit/EV")
    PER_T_M = URIRef("http://qudt.org/vocab/unit/PER-T-M")
    OZ_F_IN = URIRef("http://qudt.org/vocab/unit/OZ_F-IN")
    OZ_FT2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/OZ-FT2-PER-IN3-LB_F-SEC")
    CentiM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SEC")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    V_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Ab-PER-CentiM")
    BU_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-SEC")
    CentiM_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-K")
    KiloWB_PER_M = URIRef("http://qudt.org/vocab/unit/KiloWB-PER-M")
    GM_HR_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M3-L")
    GM_PER_L_K = URIRef("http://qudt.org/vocab/unit/GM-PER-L-K")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    DecaPA = URIRef("http://qudt.org/vocab/unit/DecaPA")
    FemtoSEC = URIRef("http://qudt.org/vocab/unit/FemtoSEC")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    MegaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-HR")
    C_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM2")
    PlanckCurrent = URIRef("http://qudt.org/vocab/unit/PlanckCurrent")
    J = URIRef("http://qudt.org/vocab/unit/J")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    Hundredweight_UK = URIRef("http://qudt.org/vocab/unit/Hundredweight_UK")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    GigaW_HR = URIRef("http://qudt.org/vocab/unit/GigaW-HR")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    PCA = URIRef("http://qudt.org/vocab/unit/PCA")
    LB_PER_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-HR")
    MilliGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-K")
    KiloGM_PER_M2_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC2")
    MOL_PER_L = URIRef("http://qudt.org/vocab/unit/MOL-PER-L")
    Megahertz_KiloM = URIRef("http://qudt.org/vocab/unit/Megahertz-KiloM")
    GI_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-MIN")
    BBL_US_DRY = URIRef("http://qudt.org/vocab/unit/BBL_US_DRY")
    OHM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/OHM-PER-KiloM")
    PDL_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/PDL-SEC-PER-IN2")
    A = URIRef("http://qudt.org/vocab/unit/A")
    PlanckMomentum = URIRef("http://qudt.org/vocab/unit/PlanckMomentum")
    MegaPA_M0pt5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0pt5")
    KiloGM_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-YR")
    NanoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-KiloGM")
    DEG_F_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-K")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    PlanckForce = URIRef("http://qudt.org/vocab/unit/PlanckForce")
    QT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-HR")
    FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC")
    MilliARCSEC = URIRef("http://qudt.org/vocab/unit/MilliARCSEC")
    MilliFARAD = URIRef("http://qudt.org/vocab/unit/MilliFARAD")
    ARCSEC = URIRef("http://qudt.org/vocab/unit/ARCSEC")
    IN_PER_YR = URIRef("http://qudt.org/vocab/unit/IN-PER-YR")
    W_PER_SR = URIRef("http://qudt.org/vocab/unit/W-PER-SR")
    BARYE = URIRef("http://qudt.org/vocab/unit/BARYE")
    TeraV = URIRef("http://qudt.org/vocab/unit/TeraV")
    OZ_PER_FT2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-FT2")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    Megahertz_KiloM = URIRef("http://qudt.org/vocab/unit/Megahertz-KiloM")
    FT3_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN")
    LB_FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT-PER-SEC")
    MilliG = URIRef("http://qudt.org/vocab/unit/MilliG")
    NP_PER_SEC = URIRef("http://qudt.org/vocab/unit/NP-PER-SEC")
    RAD_R = URIRef("http://qudt.org/vocab/unit/RAD_R")
    MilliIN = URIRef("http://qudt.org/vocab/unit/MilliIN")
    H_PER_M = URIRef("http://qudt.org/vocab/unit/H-PER-M")
    DEG_C_CentiM = URIRef("http://qudt.org/vocab/unit/DEG_C-CentiM")
    OZ_F_IN = URIRef("http://qudt.org/vocab/unit/OZ_F-IN")
    DEG_F_PER_BAR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-BAR")
    KiloGM_M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M2-PER-SEC")
    MI_US_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/MI_US-PER-SEC2")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    GM_PER_L_PA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-L-PA-SEC")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    MilliGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DeciL")
    C = URIRef("http://qudt.org/vocab/unit/C")
    GI_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_US-PER-DAY")
    TON_US = URIRef("http://qudt.org/vocab/unit/TON_US")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    MegaSEC = URIRef("http://qudt.org/vocab/unit/MegaSEC")
    KiloCAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-SEC")
    YD2 = URIRef("http://qudt.org/vocab/unit/YD2")
    TSP = URIRef("http://qudt.org/vocab/unit/TSP")
    HectoC = URIRef("http://qudt.org/vocab/unit/HectoC")
    DEG_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC")
    KiloN_M_PER_DEG_M = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-DEG-M")
    M3_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-BAR")
    MOL_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-BAR")
    MegaDOLLAR_US_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MegaDOLLAR_US-PER-FLIGHT")
    PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2")
    STILB = URIRef("http://qudt.org/vocab/unit/STILB")
    K_M = URIRef("http://qudt.org/vocab/unit/K-M")
    IU_PER_L = URIRef("http://qudt.org/vocab/unit/IU-PER-L")
    FT3_PER_LB = URIRef("http://qudt.org/vocab/unit/FT3-PER-LB")
    FT_LB_F_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2-SEC")
    W_PER_M2_K = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    W_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-SEC-PER-M2")
    MilliV_A_PER_K = URIRef("http://qudt.org/vocab/unit/MilliV-A-PER-K")
    C4_M4_PER_J3 = URIRef("http://qudt.org/vocab/unit/C4-M4-PER-J3")
    FT_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-PER-MIN")
    K_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-M-PER-SEC")
    LB_SEC_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-YD3")
    NTU = URIRef("http://qudt.org/vocab/unit/NTU")
    KiloCAL_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2")
    GAL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-HR")
    SLUG_PER_FT = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT")
    BARYE = URIRef("http://qudt.org/vocab/unit/BARYE")
    OZ_PER_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD3")
    POISE = URIRef("http://qudt.org/vocab/unit/POISE")
    LB_SEC_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN6")
    LB_HR_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-IN3")
    M_PER_HR = URIRef("http://qudt.org/vocab/unit/M-PER-HR")
    QT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-HR")
    TON_SHIPPING_UK = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_UK")
    S_Stat = URIRef("http://qudt.org/vocab/unit/S_Stat")
    MilliGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-KiloGM")
    LM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LM-PER-FT2")
    TONNE_PER_MIN = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN")
    MilliGM_PER_L = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L")
    MegaV_A = URIRef("http://qudt.org/vocab/unit/MegaV-A")
    C_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Ab-PER-CentiM2")
    KiloJ = URIRef("http://qudt.org/vocab/unit/KiloJ")
    KiloEV = URIRef("http://qudt.org/vocab/unit/KiloEV")
    GI_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_US-PER-DAY")
    S = URIRef("http://qudt.org/vocab/unit/S")
    KiloYR = URIRef("http://qudt.org/vocab/unit/KiloYR")
    DEG_F_SEC_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-SEC-PER-BTU_TH")
    YD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/YD-PER-SEC2")
    DeciM3_PER_HR = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-HR")
    LB_IN2_PER_FT3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-FT3-LB_F-SEC")
    GigaHZ = URIRef("http://qudt.org/vocab/unit/GigaHZ")
    N = URIRef("http://qudt.org/vocab/unit/N")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    MilliGM = URIRef("http://qudt.org/vocab/unit/MilliGM")
    BTU_IT_PER_LB_F_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_F")
    BAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-M3-PER-SEC")
    KiloC_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M2")
    GM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3")
    NUM_PER_M = URIRef("http://qudt.org/vocab/unit/NUM-PER-M")
    KiloGM_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MOL")
    BTU_IT_PER_SEC_FT_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT-DEG_R")
    CentiN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/CentiN-M-PER-M2")
    BTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR")
    MicroFARAD = URIRef("http://qudt.org/vocab/unit/MicroFARAD")
    MilliM_PER_DEG_C_M = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DEG_C-M")
    MebiBIT = URIRef("http://qudt.org/vocab/unit/MebiBIT")
    BTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2")
    MilliL_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-BAR")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    MegaBIT = URIRef("http://qudt.org/vocab/unit/MegaBIT")
    TSP = URIRef("http://qudt.org/vocab/unit/TSP")
    GAUSS = URIRef("http://qudt.org/vocab/unit/GAUSS")
    DeciM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-DAY")
    PA_M0pt5 = URIRef("http://qudt.org/vocab/unit/PA-M0pt5")
    NP = URIRef("http://qudt.org/vocab/unit/NP")
    M3_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-K")
    BTU_IT_FT = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT")
    MOL_PER_TONNE = URIRef("http://qudt.org/vocab/unit/MOL-PER-TONNE")
    MegaJ_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M3")
    MilliOHM = URIRef("http://qudt.org/vocab/unit/MilliOHM")
    TONNE_PER_SEC = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC")
    MilliGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    MilliW_PER_CentiM2_MicroM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-CentiM2-MicroM-SR")
    BTU_IT_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_R")
    YD3_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD3-PER-MIN")
    KiloGM_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MOL")
    GM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC-K")
    TON_SHORT_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR")
    W_PER_GM = URIRef("http://qudt.org/vocab/unit/W-PER-GM")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    KiloA_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M2")
    MilliBQ_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-M2-DAY")
    ST_PER_PA = URIRef("http://qudt.org/vocab/unit/ST-PER-PA")
    KiloGM_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-M2")
    KiloCAL = URIRef("http://qudt.org/vocab/unit/KiloCAL")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    KiloGM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3")
    DeciTON_Metric = URIRef("http://qudt.org/vocab/unit/DeciTON_Metric")
    W = URIRef("http://qudt.org/vocab/unit/W")
    CAL_IT_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM-K")
    R = URIRef("http://qudt.org/vocab/unit/R")
    MicroBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-L")
    KiloCAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-SEC")
    J_M2 = URIRef("http://qudt.org/vocab/unit/J-M2")
    CentiM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-M3")
    NanoM = URIRef("http://qudt.org/vocab/unit/NanoM")
    K_PER_MIN = URIRef("http://qudt.org/vocab/unit/K-PER-MIN")
    TONNE_PER_M3 = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3")
    GI_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_US-PER-HR")
    LB_IN = URIRef("http://qudt.org/vocab/unit/LB-IN")
    MicroS = URIRef("http://qudt.org/vocab/unit/MicroS")
    EUR_PER_W_HR = URIRef("http://qudt.org/vocab/unit/EUR-PER-W-HR")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    PERCENT_FT_HR_PER_LB = URIRef("http://qudt.org/vocab/unit/PERCENT-FT-HR-PER-LB")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    KiloCAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-SEC")
    IN_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC2")
    GigaHZ = URIRef("http://qudt.org/vocab/unit/GigaHZ")
    TON = URIRef("http://qudt.org/vocab/unit/TON")
    OZ_SEC_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-GAL_UK")
    E_h = URIRef("http://qudt.org/vocab/unit/E_h")
    PCA = URIRef("http://qudt.org/vocab/unit/PCA")
    GAUGE_FR = URIRef("http://qudt.org/vocab/unit/GAUGE_FR")
    KiloCD = URIRef("http://qudt.org/vocab/unit/KiloCD")
    TeraBQ = URIRef("http://qudt.org/vocab/unit/TeraBQ")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    DEATHS_PER_1000000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000000I-YR")
    MilliL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M2-DAY")
    NanoC = URIRef("http://qudt.org/vocab/unit/NanoC")
    KiloA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M")
    M2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2")
    KiloGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-BAR")
    NUM_PER_NanoL = URIRef("http://qudt.org/vocab/unit/NUM-PER-NanoL")
    OZ_HR_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-GAL_UK")
    OHM_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-PER-M")
    HA = URIRef("http://qudt.org/vocab/unit/HA")
    DeciL_PER_GM = URIRef("http://qudt.org/vocab/unit/DeciL-PER-GM")
    MicroW = URIRef("http://qudt.org/vocab/unit/MicroW")
    M2_HZ4 = URIRef("http://qudt.org/vocab/unit/M2-HZ4")
    MilliBAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-L-PER-SEC")
    SEC_PER_M = URIRef("http://qudt.org/vocab/unit/SEC-PER-M")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    MilliGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-K")
    Pennyweight = URIRef("http://qudt.org/vocab/unit/Pennyweight")
    PDL_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-FT2")
    MilliH = URIRef("http://qudt.org/vocab/unit/MilliH")
    PK_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-HR")
    LB_HR_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-YD3")
    PER_M2 = URIRef("http://qudt.org/vocab/unit/PER-M2")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    N_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M2")
    CentiM_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-HR")
    MI = URIRef("http://qudt.org/vocab/unit/MI")
    BTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR")
    DEG_R_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-SEC")
    OZ_VOL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-HR")
    MilliGM_HR_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L2")
    LB_IN2 = URIRef("http://qudt.org/vocab/unit/LB-IN2")
    TeraOHM = URIRef("http://qudt.org/vocab/unit/TeraOHM")
    FT3_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT3-PER-DAY")
    ERG_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM")
    TeraV = URIRef("http://qudt.org/vocab/unit/TeraV")
    M3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-K")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    KiloGM_PER_M_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-DAY")
    MilliG = URIRef("http://qudt.org/vocab/unit/MilliG")
    V_PER_BAR = URIRef("http://qudt.org/vocab/unit/V-PER-BAR")
    GigaV_A_Reactive = URIRef("http://qudt.org/vocab/unit/GigaV-A_Reactive")
    MilliRAD_R = URIRef("http://qudt.org/vocab/unit/MilliRAD_R")
    PPTR = URIRef("http://qudt.org/vocab/unit/PPTR")
    BAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-M3-PER-SEC")
    KiloPA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-K")
    FemtoGM_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-L")
    KiloTONNE = URIRef("http://qudt.org/vocab/unit/KiloTONNE")
    BTU_TH_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-FT2-HR-DEG_F")
    N_M_PER_A = URIRef("http://qudt.org/vocab/unit/N-M-PER-A")
    GM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY-BAR")
    IN_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN-PER-MIN")
    ElementaryCharge = URIRef("http://qudt.org/vocab/unit/ElementaryCharge")
    PER_J2 = URIRef("http://qudt.org/vocab/unit/PER-J2")
    LB_PER_LB = URIRef("http://qudt.org/vocab/unit/LB-PER-LB")
    LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT2")
    PERCENT_PER_DecaK = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaK")
    M2_PER_GM = URIRef("http://qudt.org/vocab/unit/M2-PER-GM")
    J_PER_M3_K = URIRef("http://qudt.org/vocab/unit/J-PER-M3-K")
    PetaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/PetaJ-PER-SEC")
    BTU_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC")
    IN2 = URIRef("http://qudt.org/vocab/unit/IN2")
    PINT_US = URIRef("http://qudt.org/vocab/unit/PINT_US")
    DEG_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC")
    H_Stat = URIRef("http://qudt.org/vocab/unit/H_Stat")
    CentiM6 = URIRef("http://qudt.org/vocab/unit/CentiM6")
    MilliGM_PER_L = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L")
    TON_SHORT_PER_PSI = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-PSI")
    GM_Nitrogen_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Nitrogen-PER-M2-DAY")
    KiloMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3")
    OCTET_PER_SEC = URIRef("http://qudt.org/vocab/unit/OCTET-PER-SEC")
    PicoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/PicoKAT-PER-L")
    TONNE_PER_M3_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3-K")
    YR = URIRef("http://qudt.org/vocab/unit/YR")
    YR_TROPICAL = URIRef("http://qudt.org/vocab/unit/YR_TROPICAL")
    MicroN_M = URIRef("http://qudt.org/vocab/unit/MicroN-M")
    DEGREE_API = URIRef("http://qudt.org/vocab/unit/DEGREE_API")
    NUM_PER_HectoGM = URIRef("http://qudt.org/vocab/unit/NUM-PER-HectoGM")
    SEC2 = URIRef("http://qudt.org/vocab/unit/SEC2")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    MilliGM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-K")
    M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/M2-PER-MOL")
    MOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-DAY")
    KiloLB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-FT")
    DEG_F_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-K")
    PicoMOL = URIRef("http://qudt.org/vocab/unit/PicoMOL")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    BTU_IT_PER_SEC_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2")
    PINT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-MIN")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    KiloSEC = URIRef("http://qudt.org/vocab/unit/KiloSEC")
    DeciS = URIRef("http://qudt.org/vocab/unit/DeciS")
    DEG_C_PER_M = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-M")
    FM = URIRef("http://qudt.org/vocab/unit/FM")
    Gs = URIRef("http://qudt.org/vocab/unit/Gs")
    DEATHS_PER_MegaINDIV_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-MegaINDIV-YR")
    FT_PER_PSI = URIRef("http://qudt.org/vocab/unit/FT-PER-PSI")
    MilliM3_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-GM")
    KiloS = URIRef("http://qudt.org/vocab/unit/KiloS")
    SLUG_PER_HR = URIRef("http://qudt.org/vocab/unit/SLUG-PER-HR")
    KiloGM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-FT2")
    T = URIRef("http://qudt.org/vocab/unit/T")
    C_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM2")
    MicroGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3")
    V = URIRef("http://qudt.org/vocab/unit/V")
    KiloCi = URIRef("http://qudt.org/vocab/unit/KiloCi")
    PicoH = URIRef("http://qudt.org/vocab/unit/PicoH")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    M_K = URIRef("http://qudt.org/vocab/unit/M-K")
    MicroGRAY = URIRef("http://qudt.org/vocab/unit/MicroGRAY")
    LB_PER_GAL = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL")
    HZ_M = URIRef("http://qudt.org/vocab/unit/HZ-M")
    BAR = URIRef("http://qudt.org/vocab/unit/BAR")
    PER_MILLE_PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PER-PSI")
    N = URIRef("http://qudt.org/vocab/unit/N")
    SEC_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-FT2")
    MilliN = URIRef("http://qudt.org/vocab/unit/MilliN")
    MilliBAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-BAR")
    MegaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M2")
    ATM_M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/ATM-M3-PER-MOL")
    STR = URIRef("http://qudt.org/vocab/unit/STR")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    H = URIRef("http://qudt.org/vocab/unit/H")
    IN3_PER_HR = URIRef("http://qudt.org/vocab/unit/IN3-PER-HR")
    GM_MIN_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L-CentiM3")
    GigaPA = URIRef("http://qudt.org/vocab/unit/GigaPA")
    KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-SEC2")
    MilliSV = URIRef("http://qudt.org/vocab/unit/MilliSV")
    DEG_C_CentiM = URIRef("http://qudt.org/vocab/unit/DEG_C-CentiM")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    N_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-RAD")
    LB_HR_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-FT3")
    QT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_US-PER-MIN")
    CentiM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-M3")
    N_M_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-M-PER-KiloGM")
    MicroMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-DAY")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    KiloGM_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-MilliM2")
    BTU_IT_PER_MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB-DEG_F")
    KiloWB_PER_M = URIRef("http://qudt.org/vocab/unit/KiloWB-PER-M")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    QT_UK = URIRef("http://qudt.org/vocab/unit/QT_UK")
    MilliGAL_PER_MO = URIRef("http://qudt.org/vocab/unit/MilliGAL-PER-MO")
    CWT_SHORT = URIRef("http://qudt.org/vocab/unit/CWT_SHORT")
    TOE = URIRef("http://qudt.org/vocab/unit/TOE")
    PicoJ = URIRef("http://qudt.org/vocab/unit/PicoJ")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    MilliGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-BAR")
    POISE = URIRef("http://qudt.org/vocab/unit/POISE")
    MilliW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2")
    MegaGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-HA")
    CentiGM = URIRef("http://qudt.org/vocab/unit/CentiGM")
    FT_H2O = URIRef("http://qudt.org/vocab/unit/FT_H2O")
    QT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-SEC")
    FemtoJ = URIRef("http://qudt.org/vocab/unit/FemtoJ")
    MilliGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DeciL")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    NanoGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DAY")
    C_M2_PER_V = URIRef("http://qudt.org/vocab/unit/C-M2-PER-V")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    YD3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD3-PER-DEG_F")
    MilliIN = URIRef("http://qudt.org/vocab/unit/MilliIN")
    FemtoM = URIRef("http://qudt.org/vocab/unit/FemtoM")
    C_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM3")
    MegaTON = URIRef("http://qudt.org/vocab/unit/MegaTON")
    SEC_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-FT2")
    KiloOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-BAR")
    MilliGM_PER_L = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L")
    KiloN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-M2")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    SAMPLE_PER_SEC = URIRef("http://qudt.org/vocab/unit/SAMPLE-PER-SEC")
    CentiM2_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-CentiM3")
    DecaM3 = URIRef("http://qudt.org/vocab/unit/DecaM3")
    TeraOHM = URIRef("http://qudt.org/vocab/unit/TeraOHM")
    NUM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/NUM-PER-KiloM2")
    OZ_TROY = URIRef("http://qudt.org/vocab/unit/OZ_TROY")
    MegaV_A = URIRef("http://qudt.org/vocab/unit/MegaV-A")
    KiloHZ = URIRef("http://qudt.org/vocab/unit/KiloHZ")
    MicroCi = URIRef("http://qudt.org/vocab/unit/MicroCi")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    M2_PER_HA = URIRef("http://qudt.org/vocab/unit/M2-PER-HA")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    M3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL-SEC")
    MicroM_PER_K = URIRef("http://qudt.org/vocab/unit/MicroM-PER-K")
    MicroM = URIRef("http://qudt.org/vocab/unit/MicroM")
    MegaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBIT-PER-SEC")
    GM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciL")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    DEG_C_KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/DEG_C-KiloGM-PER-M2")
    N_M_PER_A = URIRef("http://qudt.org/vocab/unit/N-M-PER-A")
    PSU = URIRef("http://qudt.org/vocab/unit/PSU")
    TeraC = URIRef("http://qudt.org/vocab/unit/TeraC")
    MilliS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MilliS-PER-CentiM")
    PER_MilliL = URIRef("http://qudt.org/vocab/unit/PER-MilliL")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    DEGREE_BAUME = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME")
    M2_PER_SR = URIRef("http://qudt.org/vocab/unit/M2-PER-SR")
    MilliGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-SEC")
    KiloN_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M")
    N_M_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-M")
    KiloFARAD = URIRef("http://qudt.org/vocab/unit/KiloFARAD")
    PER_MicroMOL_L = URIRef("http://qudt.org/vocab/unit/PER-MicroMOL-L")
    GRAIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-M3")
    CentiM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-M3")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    YR_TROPICAL = URIRef("http://qudt.org/vocab/unit/YR_TROPICAL")
    unit = URIRef("http://qudt.org/vocab/unit")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    GM_PER_M = URIRef("http://qudt.org/vocab/unit/GM-PER-M")
    KiloGM_PER_M_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC")
    BBL_UK_PET = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET")
    DecaARE = URIRef("http://qudt.org/vocab/unit/DecaARE")
    TON_Metric_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN-K")
    EUR_PER_W = URIRef("http://qudt.org/vocab/unit/EUR-PER-W")
    FT2_HR_DEG_F_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F-PER-BTU_IT")
    MilliM_HG = URIRef("http://qudt.org/vocab/unit/MilliM_HG")
    KiloGM_M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M2-PER-SEC")
    BBL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-MIN")
    IN_H2O_60DEG_F = URIRef("http://qudt.org/vocab/unit/IN_H2O_60DEG_F")
    KiloMOL_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3-K")
    QT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_US-PER-DAY")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    TON_Metric_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY-K")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    NanoGM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MicroL")
    M3_PER_HA = URIRef("http://qudt.org/vocab/unit/M3-PER-HA")
    BTU_IT_PER_SEC_FT_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT-DEG_R")
    KiloMOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-MIN")
    KiloBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloBQ-PER-KiloGM")
    M3_PER_M3 = URIRef("http://qudt.org/vocab/unit/M3-PER-M3")
    OHM_M2_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-M2-PER-M")
    LB_FT2 = URIRef("http://qudt.org/vocab/unit/LB-FT2")
    GI_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-MIN")
    MilliGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HA")
    V_A_Reactive = URIRef("http://qudt.org/vocab/unit/V-A_Reactive")
    MicroH = URIRef("http://qudt.org/vocab/unit/MicroH")
    CFU = URIRef("http://qudt.org/vocab/unit/CFU")
    PINT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-MIN")
    MilliL_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-K")
    R_PER_SEC = URIRef("http://qudt.org/vocab/unit/R-PER-SEC")
    CentiN_M = URIRef("http://qudt.org/vocab/unit/CentiN-M")
    PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/PER-M2-SEC")
    MilliM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliM-PER-M")
    MilliM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-KiloGM")
    GigaW = URIRef("http://qudt.org/vocab/unit/GigaW")
    LB_HR_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-FT3")
    N_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM2")
    DeciN_M = URIRef("http://qudt.org/vocab/unit/DeciN-M")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    CP = URIRef("http://qudt.org/vocab/unit/CP")
    W_M2_PER_SR = URIRef("http://qudt.org/vocab/unit/W-M2-PER-SR")
    IN_HG_32DEG_F = URIRef("http://qudt.org/vocab/unit/IN_HG_32DEG_F")
    PicoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/PicoW-PER-M2")
    PlanckDensity = URIRef("http://qudt.org/vocab/unit/PlanckDensity")
    NanoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/NanoFARAD-PER-M")
    MicroH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-OHM")
    KiloBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-HR")
    MicroM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-M3")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    GigaV = URIRef("http://qudt.org/vocab/unit/GigaV")
    SV_PER_HR = URIRef("http://qudt.org/vocab/unit/SV-PER-HR")
    LB_F_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    NanoV_A_Reactive = URIRef("http://qudt.org/vocab/unit/NanoV-A_Reactive")
    MilliMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2")
    LB_PER_MIN_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN-DEG_F")
    J_PER_M4 = URIRef("http://qudt.org/vocab/unit/J-PER-M4")
    KiloGM_PER_M_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-HR")
    MOL_PER_L = URIRef("http://qudt.org/vocab/unit/MOL-PER-L")
    GM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC")
    PicoH = URIRef("http://qudt.org/vocab/unit/PicoH")
    MilliJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-M2")
    MilliGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC")
    BBL_UK_PET_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-DAY")
    M3_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-K")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    PER_L = URIRef("http://qudt.org/vocab/unit/PER-L")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    KiloGM_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MOL")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    GM_PER_M3 = URIRef("http://qudt.org/vocab/unit/GM-PER-M3")
    MicroSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-SEC")
    BTU_IT = URIRef("http://qudt.org/vocab/unit/BTU_IT")
    KiloV_A_PER_K = URIRef("http://qudt.org/vocab/unit/KiloV-A-PER-K")
    PicoFARAD = URIRef("http://qudt.org/vocab/unit/PicoFARAD")
    PicoW_PER_CentiM2_L = URIRef("http://qudt.org/vocab/unit/PicoW-PER-CentiM2-L")
    LB_HR_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US2")
    TON_Metric_PER_MIN = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN")
    W = URIRef("http://qudt.org/vocab/unit/W")
    PER_YR = URIRef("http://qudt.org/vocab/unit/PER-YR")
    KiloGM_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-M2")
    MOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM")
    PK_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-HR")
    MIN = URIRef("http://qudt.org/vocab/unit/MIN")
    H_Ab = URIRef("http://qudt.org/vocab/unit/H_Ab")
    MilliM_PER_YR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-YR")
    MilliM3_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-GM")
    ExaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/ExaJ-PER-SEC")
    PlanckArea = URIRef("http://qudt.org/vocab/unit/PlanckArea")
    MilliM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-M3")
    KiloBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT")
    MilliIN = URIRef("http://qudt.org/vocab/unit/MilliIN")
    PicoGM_PER_GM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-GM")
    ANGSTROM = URIRef("http://qudt.org/vocab/unit/ANGSTROM")
    RichterMagnitude = URIRef("http://qudt.org/vocab/unit/RichterMagnitude")
    MOL_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-K")
    PCA = URIRef("http://qudt.org/vocab/unit/PCA")
    ARCMIN = URIRef("http://qudt.org/vocab/unit/ARCMIN")
    AttoJ_SEC = URIRef("http://qudt.org/vocab/unit/AttoJ-SEC")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    MI_US = URIRef("http://qudt.org/vocab/unit/MI_US")
    MI3 = URIRef("http://qudt.org/vocab/unit/MI3")
    TONNE_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY-K")
    PicoH = URIRef("http://qudt.org/vocab/unit/PicoH")
    THM_EEC = URIRef("http://qudt.org/vocab/unit/THM_EEC")
    C = URIRef("http://qudt.org/vocab/unit/C")
    EUR_PER_KiloW_HR = URIRef("http://qudt.org/vocab/unit/EUR-PER-KiloW-HR")
    NanoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/NanoFARAD-PER-M")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    MOL_K = URIRef("http://qudt.org/vocab/unit/MOL-K")
    KiloGM_M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M2-PER-SEC")
    CentiN_M = URIRef("http://qudt.org/vocab/unit/CentiN-M")
    BBL_UK_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-HR")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    KiloCAL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MIN")
    C4_M4_PER_J3 = URIRef("http://qudt.org/vocab/unit/C4-M4-PER-J3")
    MilliL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC")
    MicroGRAY = URIRef("http://qudt.org/vocab/unit/MicroGRAY")
    MilliGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-SEC")
    PSU = URIRef("http://qudt.org/vocab/unit/PSU")
    C = URIRef("http://qudt.org/vocab/unit/C")
    CentiN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/CentiN-M-PER-M2")
    CentiGM = URIRef("http://qudt.org/vocab/unit/CentiGM")
    GM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3-K")
    FT_HG = URIRef("http://qudt.org/vocab/unit/FT_HG")
    PA_PER_K = URIRef("http://qudt.org/vocab/unit/PA-PER-K")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    TON_Metric_PER_M3_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3-K")
    Da = URIRef("http://qudt.org/vocab/unit/Da")
    DEG_C_CentiM = URIRef("http://qudt.org/vocab/unit/DEG_C-CentiM")
    LB_HR_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-YD3")
    MilliMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2-DAY")
    MilliL_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-BAR")
    ERG_CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-CentiM2-PER-GM")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    MOMME_Pearl = URIRef("http://qudt.org/vocab/unit/MOMME_Pearl")
    A_PER_CentiM = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM")
    ExaBIT_PER_M = URIRef("http://qudt.org/vocab/unit/ExaBIT-PER-M")
    MicroGM_PER_L = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L")
    CAL_IT_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM2-K")
    DEGREE_API = URIRef("http://qudt.org/vocab/unit/DEGREE_API")
    MicroRAD = URIRef("http://qudt.org/vocab/unit/MicroRAD")
    MilliS_PER_M = URIRef("http://qudt.org/vocab/unit/MilliS-PER-M")
    DEG_F_PER_BAR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-BAR")
    FARAD_Stat = URIRef("http://qudt.org/vocab/unit/FARAD_Stat")
    W_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/W-PER-CentiM2")
    CentiPOISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-BAR")
    MicroA_PER_K = URIRef("http://qudt.org/vocab/unit/MicroA-PER-K")
    PicoMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M2-DAY")
    MicroGM_PER_CentiM2_WK = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2-WK")
    CentiM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC-K")
    KiloWB_PER_M = URIRef("http://qudt.org/vocab/unit/KiloWB-PER-M")
    CentiM3_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY-K")
    B = URIRef("http://qudt.org/vocab/unit/B")
    DYN_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM")
    LM_SEC = URIRef("http://qudt.org/vocab/unit/LM-SEC")
    CAL_IT_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-DEG_C")
    HR_Sidereal = URIRef("http://qudt.org/vocab/unit/HR_Sidereal")
    MI2 = URIRef("http://qudt.org/vocab/unit/MI2")
    DEG_C_KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/DEG_C-KiloGM-PER-M2")
    MilliA = URIRef("http://qudt.org/vocab/unit/MilliA")
    BU_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-DAY")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    MilliGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-MIN")
    OZ_MIN_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-GAL_US")
    MegaEV = URIRef("http://qudt.org/vocab/unit/MegaEV")
    GibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M2")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    B = URIRef("http://qudt.org/vocab/unit/B")
    KiloGM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR")
    QT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-DAY")
    CAL_TH_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2-MIN")
    E_h = URIRef("http://qudt.org/vocab/unit/E_h")
    FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/FT2-PER-BTU_IT-IN")
    DAY_Sidereal = URIRef("http://qudt.org/vocab/unit/DAY_Sidereal")
    OZ_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_UK")
    MIL = URIRef("http://qudt.org/vocab/unit/MIL")
    BTU_IT_PER_MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB-DEG_F")
    SEC_PER_RAD_M3 = URIRef("http://qudt.org/vocab/unit/SEC-PER-RAD-M3")
    GAL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-DAY")
    PERCENT_PER_WK = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-WK")
    PERCENT_RH = URIRef("http://qudt.org/vocab/unit/PERCENT_RH")
    NanoC = URIRef("http://qudt.org/vocab/unit/NanoC")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    PERCENT_SEC_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-FT3")
    ROD = URIRef("http://qudt.org/vocab/unit/ROD")
    UNKNOWN = URIRef("http://qudt.org/vocab/unit/UNKNOWN")
    YD_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD-PER-MIN")
    R = URIRef("http://qudt.org/vocab/unit/R")
    W_PER_M_K = URIRef("http://qudt.org/vocab/unit/W-PER-M-K")
    DYN = URIRef("http://qudt.org/vocab/unit/DYN")
    KiloMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-KiloGM")
    HZ_PER_T = URIRef("http://qudt.org/vocab/unit/HZ-PER-T")
    GM_PER_M2 = URIRef("http://qudt.org/vocab/unit/GM-PER-M2")
    PER_IN3 = URIRef("http://qudt.org/vocab/unit/PER-IN3")
    KiloGM_PER_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA")
    T_M = URIRef("http://qudt.org/vocab/unit/T-M")
    KiloJ_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-DAY")
    DeciM2 = URIRef("http://qudt.org/vocab/unit/DeciM2")
    KiloGM_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-MilliM2")
    BTU_TH_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR-FT2-DEG_F")
    A_Stat = URIRef("http://qudt.org/vocab/unit/A_Stat")
    DEG_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-MIN")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    Pennyweight = URIRef("http://qudt.org/vocab/unit/Pennyweight")
    C = URIRef("http://qudt.org/vocab/unit/C")
    MilliGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MilliL")
    MicroC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M2")
    CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3")
    MilliM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliM-PER-MIN")
    GM_F = URIRef("http://qudt.org/vocab/unit/GM_F")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    PA_M0pt5 = URIRef("http://qudt.org/vocab/unit/PA-M0pt5")
    PicoA_PER_HectoPA = URIRef("http://qudt.org/vocab/unit/PicoA-PER-HectoPA")
    PINT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-MIN")
    GM_PER_M3_POISE = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-POISE")
    MI_PER_HR = URIRef("http://qudt.org/vocab/unit/MI-PER-HR")
    BTU_IT_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_R")
    PSI_IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-IN3-PER-SEC")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    T_M = URIRef("http://qudt.org/vocab/unit/T-M")
    DECADE = URIRef("http://qudt.org/vocab/unit/DECADE")
    MegaA_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaA-PER-M2")
    IN_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC-DEG_F")
    DEG_C_WK = URIRef("http://qudt.org/vocab/unit/DEG_C-WK")
    MicroM3 = URIRef("http://qudt.org/vocab/unit/MicroM3")
    KibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M2")
    PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PER-CentiM3")
    GM_MilliM = URIRef("http://qudt.org/vocab/unit/GM-MilliM")
    GM_MIN_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L-M3")
    DeciM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MIN")
    FemtoM = URIRef("http://qudt.org/vocab/unit/FemtoM")
    MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/MOL_LB-DEG_F")
    PERCENT_SEC_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-GAL_UK")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    MebiBYTE = URIRef("http://qudt.org/vocab/unit/MebiBYTE")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    ExaC = URIRef("http://qudt.org/vocab/unit/ExaC")
    GRAIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-M3")
    PicoS_PER_M = URIRef("http://qudt.org/vocab/unit/PicoS-PER-M")
    STR = URIRef("http://qudt.org/vocab/unit/STR")
    DYN_SEC_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM")
    BTU_IT_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC-DEG_F")
    TON_Metric_PER_M3_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3-K")
    CD_PER_IN2 = URIRef("http://qudt.org/vocab/unit/CD-PER-IN2")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    OZ_MIN_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN6")
    NUM_PER_GM = URIRef("http://qudt.org/vocab/unit/NUM-PER-GM")
    MOL_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-DeciM3")
    OERSTED_CentiM = URIRef("http://qudt.org/vocab/unit/OERSTED-CentiM")
    KiloCAL_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2")
    PetaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/PetaBIT-PER-SEC")
    TONNE_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR-BAR")
    PERMEABILITY_EM_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_EM_REL")
    PA_SEC_PER_L = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-L")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    N_M_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-M")
    C_Ab = URIRef("http://qudt.org/vocab/unit/C_Ab")
    TON_Metric_PER_M3_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3-K")
    C = URIRef("http://qudt.org/vocab/unit/C")
    MegaPSI = URIRef("http://qudt.org/vocab/unit/MegaPSI")
    CentiGRAY = URIRef("http://qudt.org/vocab/unit/CentiGRAY")
    PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-PSI")
    M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/M2-PER-MOL")
    MicroGM_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L-HR")
    MilliGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-BAR")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    MegaEV_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-CentiM")
    KiloCAL = URIRef("http://qudt.org/vocab/unit/KiloCAL")
    KiloCi = URIRef("http://qudt.org/vocab/unit/KiloCi")
    KiloV_A_Reactive = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive")
    YD_PER_HR = URIRef("http://qudt.org/vocab/unit/YD-PER-HR")
    MicroMHO = URIRef("http://qudt.org/vocab/unit/MicroMHO")
    TON_Metric_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR-BAR")
    MilliGM_MIN_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L-CentiM3")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    KiloC_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M2")
    PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-PSI")
    HR_FT2 = URIRef("http://qudt.org/vocab/unit/HR-FT2")
    MOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3")
    PER_HR = URIRef("http://qudt.org/vocab/unit/PER-HR")
    V = URIRef("http://qudt.org/vocab/unit/V")
    KiloGM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC2")
    KiloGM_PER_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA")
    UnitPole = URIRef("http://qudt.org/vocab/unit/UnitPole")
    YD_PER_HR = URIRef("http://qudt.org/vocab/unit/YD-PER-HR")
    BTU_IT_FT = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT")
    KiloOHM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-M")
    LB_MIN_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-IN3")
    SLUG_PER_FT3 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT3")
    OZ_HR_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN6")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    MegaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-M")
    GAL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-SEC")
    DEG_C_KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/DEG_C-KiloGM-PER-M2")
    PER_M_SEC = URIRef("http://qudt.org/vocab/unit/PER-M-SEC")
    NanoM = URIRef("http://qudt.org/vocab/unit/NanoM")
    IN_HG_32DEG_F = URIRef("http://qudt.org/vocab/unit/IN_HG_32DEG_F")
    NanoFARAD = URIRef("http://qudt.org/vocab/unit/NanoFARAD")
    V_PER_V = URIRef("http://qudt.org/vocab/unit/V-PER-V")
    KiloCAL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MIN")
    GigaBasePair = URIRef("http://qudt.org/vocab/unit/GigaBasePair")
    W_M2_PER_SR = URIRef("http://qudt.org/vocab/unit/W-M2-PER-SR")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    YD_PER_HR = URIRef("http://qudt.org/vocab/unit/YD-PER-HR")
    MegaOHM_KiloM = URIRef("http://qudt.org/vocab/unit/MegaOHM-KiloM")
    KiloN = URIRef("http://qudt.org/vocab/unit/KiloN")
    MicroMOL_PER_MicroMOL_DAY = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MicroMOL-DAY")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    OZ_F = URIRef("http://qudt.org/vocab/unit/OZ_F")
    EV_PER_T = URIRef("http://qudt.org/vocab/unit/EV-PER-T")
    V_Ab_SEC = URIRef("http://qudt.org/vocab/unit/V_Ab-SEC")
    AT_PER_IN = URIRef("http://qudt.org/vocab/unit/AT-PER-IN")
    MegaPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-M3-PER-SEC")
    FT_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT-PER-DAY")
    C2_M2_PER_J = URIRef("http://qudt.org/vocab/unit/C2-M2-PER-J")
    TONNE_PER_M3 = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3")
    MOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL-PER-MIN")
    KiloGM_PER_M_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-MIN")
    V_PER_SEC = URIRef("http://qudt.org/vocab/unit/V-PER-SEC")
    KiloTONNE = URIRef("http://qudt.org/vocab/unit/KiloTONNE")
    LB_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-MOL-DEG_F")
    NanoM_PER_CentiM_PSI = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-PSI")
    GM_SEC_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L2")
    MicroH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-OHM")
    NanoSV_PER_HR = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-HR")
    BTU_IT_PER_MOL_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    MilliGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3")
    REV_PER_SEC = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    V_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/V-A_Reactive-PER-K")
    PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/PER-MilliM3")
    CAL_TH_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM-K")
    TON_Metric_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY")
    PER_GM = URIRef("http://qudt.org/vocab/unit/PER-GM")
    V_PER_L_MIN = URIRef("http://qudt.org/vocab/unit/V-PER-L-MIN")
    BTU_IT_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_R")
    YottaC = URIRef("http://qudt.org/vocab/unit/YottaC")
    DARCY = URIRef("http://qudt.org/vocab/unit/DARCY")
    M3_PER_M3 = URIRef("http://qudt.org/vocab/unit/M3-PER-M3")
    MicroSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-SEC")
    KiloGM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3")
    V_M = URIRef("http://qudt.org/vocab/unit/V-M")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    N_PER_A = URIRef("http://qudt.org/vocab/unit/N-PER-A")
    PERCENT_SEC_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-IN3")
    LB_MIN_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-YD3")
    ROD = URIRef("http://qudt.org/vocab/unit/ROD")
    PER_PA_SEC = URIRef("http://qudt.org/vocab/unit/PER-PA-SEC")
    NanoSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-SEC")
    TON_Metric_PER_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-BAR")
    GR = URIRef("http://qudt.org/vocab/unit/GR")
    KiloLB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-IN2")
    MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/MOL-DEG_C")
    MicroFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-M")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    FT3_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT3-PER-DAY")
    MOL_LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-MIN")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    BIOT = URIRef("http://qudt.org/vocab/unit/BIOT")
    CP = URIRef("http://qudt.org/vocab/unit/CP")
    TON_Metric_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR-BAR")
    KiloCAL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-SEC")
    PicoGM = URIRef("http://qudt.org/vocab/unit/PicoGM")
    GM_PER_M3_POISE = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-POISE")
    M_PER_FARAD = URIRef("http://qudt.org/vocab/unit/M-PER-FARAD")
    TONNE_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC-K")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    MilliGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-GM")
    GR = URIRef("http://qudt.org/vocab/unit/GR")
    SV_PER_HR = URIRef("http://qudt.org/vocab/unit/SV-PER-HR")
    DeciN_M = URIRef("http://qudt.org/vocab/unit/DeciN-M")
    MilliM4 = URIRef("http://qudt.org/vocab/unit/MilliM4")
    OZ_FT2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/OZ-FT2-PER-IN3-LB_F-SEC")
    W_PER_IN2 = URIRef("http://qudt.org/vocab/unit/W-PER-IN2")
    MilliGM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-BAR")
    C = URIRef("http://qudt.org/vocab/unit/C")
    MegaPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-L-PER-SEC")
    OZ_MIN_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-FT3")
    KiloBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBIT-PER-SEC")
    MilliOHM_M = URIRef("http://qudt.org/vocab/unit/MilliOHM-M")
    PINT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-MIN")
    MegaEV_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-CentiM")
    MicroGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-DeciL")
    NanoS_PER_M = URIRef("http://qudt.org/vocab/unit/NanoS-PER-M")
    BU_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-MIN")
    LB_SEC_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT6")
    OHM_M2_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-M2-PER-M")
    YD2 = URIRef("http://qudt.org/vocab/unit/YD2")
    YD2 = URIRef("http://qudt.org/vocab/unit/YD2")
    OZ_PER_YD2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD2")
    MilliBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-L")
    PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PER-KiloGM")
    FT_US = URIRef("http://qudt.org/vocab/unit/FT_US")
    MegaJ = URIRef("http://qudt.org/vocab/unit/MegaJ")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    MilliOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-BAR")
    KiloBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-HR")
    CentiM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC-K")
    PER_RAD = URIRef("http://qudt.org/vocab/unit/PER-RAD")
    TONNE_PER_HA = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA")
    PicoM = URIRef("http://qudt.org/vocab/unit/PicoM")
    L = URIRef("http://qudt.org/vocab/unit/L")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    ExaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/ExaBIT-PER-SEC")
    GM_PER_HR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR")
    HectoPA_PER_K = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-K")
    GM_PER_GM = URIRef("http://qudt.org/vocab/unit/GM-PER-GM")
    Quarter_UK = URIRef("http://qudt.org/vocab/unit/Quarter_UK")
    M3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-BAR")
    MicroW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroW-PER-M2")
    J_PER_KiloGM_K_PA = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-PA")
    J_PER_M3_K = URIRef("http://qudt.org/vocab/unit/J-PER-M3-K")
    OZ_MIN_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-GAL_US")
    L_PER_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-SEC")
    MilliV_PER_M = URIRef("http://qudt.org/vocab/unit/MilliV-PER-M")
    MilliL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-KiloGM")
    LB_HR_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-GAL_US")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    HP_Electric = URIRef("http://qudt.org/vocab/unit/HP_Electric")
    MilliMOL_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3-DAY")
    DEG_C_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-HR")
    MicroG = URIRef("http://qudt.org/vocab/unit/MicroG")
    MilliW_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM")
    MegaBQ = URIRef("http://qudt.org/vocab/unit/MegaBQ")
    K = URIRef("http://qudt.org/vocab/unit/K")
    MegaJ = URIRef("http://qudt.org/vocab/unit/MegaJ")
    KiloV = URIRef("http://qudt.org/vocab/unit/KiloV")
    LB_HR_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-GAL_US")
    DeciL = URIRef("http://qudt.org/vocab/unit/DeciL")
    KiloCAL_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM-DEG_C")
    MilliA_PER_K = URIRef("http://qudt.org/vocab/unit/MilliA-PER-K")
    LB_IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN-PER-SEC")
    PER_MilliSEC = URIRef("http://qudt.org/vocab/unit/PER-MilliSEC")
    KiloGM_PER_DeciM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-K")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    PA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-L-PER-SEC")
    MegaJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-KiloGM")
    MilliMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-MOL")
    B_PER_M = URIRef("http://qudt.org/vocab/unit/B-PER-M")
    PA_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PA-M2-PER-KiloGM")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    IN_HG = URIRef("http://qudt.org/vocab/unit/IN_HG")
    CD_PER_M2 = URIRef("http://qudt.org/vocab/unit/CD-PER-M2")
    MilliL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-GM")
    GM_MIN_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L-CentiM3")
    KiloGM_PER_KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloMOL")
    W_PER_M_K = URIRef("http://qudt.org/vocab/unit/W-PER-M-K")
    OZ_VOL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-HR")
    ATM_T_PER_M = URIRef("http://qudt.org/vocab/unit/ATM_T-PER-M")
    KiloBQ = URIRef("http://qudt.org/vocab/unit/KiloBQ")
    V_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V-PER-CentiM")
    KiloGM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3")
    BBL_US_DRY = URIRef("http://qudt.org/vocab/unit/BBL_US_DRY")
    FT_HR_PER_IN3 = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-IN3")
    QT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-DAY")
    OZ_PER_FT2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-FT2")
    MOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-SEC")
    GM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-BAR")
    MilliC = URIRef("http://qudt.org/vocab/unit/MilliC")
    A_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-PER-DEG_C")
    KiloGM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-FT2")
    GM_PER_L_K = URIRef("http://qudt.org/vocab/unit/GM-PER-L-K")
    A_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-PER-DEG_C")
    IN_PER_2PiRAD = URIRef("http://qudt.org/vocab/unit/IN-PER-2PiRAD")
    MilliGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MilliL")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    GibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M2")
    MilliGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DeciL")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    N_M_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-M")
    MilliL_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY")
    OZ_PER_YD2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD2")
    DEG_C_PER_BAR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-BAR")
    PINT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-DAY")
    K_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PER-SEC")
    FARAD_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/FARAD_Ab-PER-CentiM")
    GALILEO = URIRef("http://qudt.org/vocab/unit/GALILEO")
    LB_HR_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-YD3")
    BTU_TH_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_R")
    MegaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-HR")
    PER_PERCENT = URIRef("http://qudt.org/vocab/unit/PER-PERCENT")
    MicroM = URIRef("http://qudt.org/vocab/unit/MicroM")
    MO_MeanJulian = URIRef("http://qudt.org/vocab/unit/MO_MeanJulian")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    LB_FT2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-IN3-LB_F-SEC")
    MilliW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2")
    PA_M0dot5 = URIRef("http://qudt.org/vocab/unit/PA-M0dot5")
    failures_in_time = URIRef("http://qudt.org/vocab/unit/failures-in-time")
    C_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM3")
    PlanckImpedance = URIRef("http://qudt.org/vocab/unit/PlanckImpedance")
    NanoFARAD = URIRef("http://qudt.org/vocab/unit/NanoFARAD")
    C_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Ab-PER-CentiM2")
    M3_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-BAR")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    DeciB_W = URIRef("http://qudt.org/vocab/unit/DeciB-W")
    PDL = URIRef("http://qudt.org/vocab/unit/PDL")
    LB_HR_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-GAL_UK")
    TeraHZ = URIRef("http://qudt.org/vocab/unit/TeraHZ")
    GigaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-HR")
    PERCENT_PER_MO = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MO")
    BAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/BAR-PER-BAR")
    QT_US_DRY = URIRef("http://qudt.org/vocab/unit/QT_US_DRY")
    CentiM3_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY-K")
    PK_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-MIN")
    J_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2-DAY")
    KiloW_PER_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M-DEG_C")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    KiloCAL_TH = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH")
    PDL_PER_IN = URIRef("http://qudt.org/vocab/unit/PDL-PER-IN")
    K_PER_HR = URIRef("http://qudt.org/vocab/unit/K-PER-HR")
    PERCENT_MIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-M3")
    HR_FT2 = URIRef("http://qudt.org/vocab/unit/HR-FT2")
    BAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-L-PER-SEC")
    CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-SEC")
    N_M_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-RAD")
    MilliDEG_C = URIRef("http://qudt.org/vocab/unit/MilliDEG_C")
    FARAD_Ab = URIRef("http://qudt.org/vocab/unit/FARAD_Ab")
    LB_PER_IN = URIRef("http://qudt.org/vocab/unit/LB-PER-IN")
    MilliPA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-BAR")
    DEG_F_HR_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_IT")
    MilliM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC")
    DEG_F_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-HR")
    KAT_PER_L = URIRef("http://qudt.org/vocab/unit/KAT-PER-L")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    PFUND = URIRef("http://qudt.org/vocab/unit/PFUND")
    J_PER_M4 = URIRef("http://qudt.org/vocab/unit/J-PER-M4")
    TON_SHORT_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR")
    J_M2 = URIRef("http://qudt.org/vocab/unit/J-M2")
    A_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/A-PER-KiloGM")
    DEG_F_SEC_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-SEC-PER-BTU_IT")
    MilliC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliC-PER-KiloGM")
    GALILEO = URIRef("http://qudt.org/vocab/unit/GALILEO")
    N_M_PER_W0dot5 = URIRef("http://qudt.org/vocab/unit/N-M-PER-W0dot5")
    N_M_PER_W0dot5 = URIRef("http://qudt.org/vocab/unit/N-M-PER-W0dot5")
    PERCENT_FT_SEC_PER_LB = URIRef("http://qudt.org/vocab/unit/PERCENT-FT-SEC-PER-LB")
    AttoJ = URIRef("http://qudt.org/vocab/unit/AttoJ")
    H = URIRef("http://qudt.org/vocab/unit/H")
    GR = URIRef("http://qudt.org/vocab/unit/GR")
    OZ_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ-PER-MIN")
    ExaC = URIRef("http://qudt.org/vocab/unit/ExaC")
    N_M_PER_MIN_Angle = URIRef("http://qudt.org/vocab/unit/N-M-PER-MIN_Angle")
    FT_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-PER-MIN")
    KiloGM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MilliM")
    J = URIRef("http://qudt.org/vocab/unit/J")
    NanoMOL_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-GM-SEC")
    PERCENT_PER_POISE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-POISE")
    YD3_PER_DAY = URIRef("http://qudt.org/vocab/unit/YD3-PER-DAY")
    GM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3")
    PER_V = URIRef("http://qudt.org/vocab/unit/PER-V")
    MilliBAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-L-PER-SEC")
    KiloMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-KiloGM")
    YD3_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD3-PER-MIN")
    PicoFARAD = URIRef("http://qudt.org/vocab/unit/PicoFARAD")
    CAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC")
    LB_FT2_PER_GAL_UK_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-GAL_UK-LB_F-SEC")
    PERCENT_PER_POISE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-POISE")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    CAL_TH_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM-K")
    MilliCi = URIRef("http://qudt.org/vocab/unit/MilliCi")
    PER_YD3 = URIRef("http://qudt.org/vocab/unit/PER-YD3")
    GI = URIRef("http://qudt.org/vocab/unit/GI")
    KiloGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloGM")
    MicroGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M2-DAY")
    BTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2")
    GigaA = URIRef("http://qudt.org/vocab/unit/GigaA")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    KiloBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-HR")
    PSI_IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-IN3-PER-SEC")
    N_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-PER-RAD")
    KiloCAL_IT_PER_HR_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-HR-M-DEG_C")
    H = URIRef("http://qudt.org/vocab/unit/H")
    MilliGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-K")
    BTU_TH_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-SEC-DEG_F")
    BTU_IT_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB")
    MegaLB_F = URIRef("http://qudt.org/vocab/unit/MegaLB_F")
    L_PER_K = URIRef("http://qudt.org/vocab/unit/L-PER-K")
    ANGSTROM3 = URIRef("http://qudt.org/vocab/unit/ANGSTROM3")
    DEG_C_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-MIN")
    OZ_HR_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-GAL_US")
    CentiM3_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-K")
    MilliGM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M")
    TONNE_PER_M3 = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3")
    MOL_LB_PER_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-LB")
    PERCENT_MIN_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-L")
    MilliGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2")
    V = URIRef("http://qudt.org/vocab/unit/V")
    MicroM_PER_N = URIRef("http://qudt.org/vocab/unit/MicroM-PER-N")
    QT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_US-PER-HR")
    M3_PER_MIN = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN")
    J = URIRef("http://qudt.org/vocab/unit/J")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    KiloW = URIRef("http://qudt.org/vocab/unit/KiloW")
    TORR = URIRef("http://qudt.org/vocab/unit/TORR")
    KiloGM_PER_KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloMOL")
    RAD_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-KiloGM")
    PER_GM = URIRef("http://qudt.org/vocab/unit/PER-GM")
    MegaN_M = URIRef("http://qudt.org/vocab/unit/MegaN-M")
    A_PER_PA = URIRef("http://qudt.org/vocab/unit/A-PER-PA")
    TON_Metric_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY")
    MilliA_HR_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliA-HR-PER-GM")
    LB_IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN-PER-SEC")
    MilliN_PER_M = URIRef("http://qudt.org/vocab/unit/MilliN-PER-M")
    BTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR")
    MicroH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-OHM")
    PER_WK = URIRef("http://qudt.org/vocab/unit/PER-WK")
    FT_LB_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-MIN")
    CAL_TH = URIRef("http://qudt.org/vocab/unit/CAL_TH")
    MOL_PER_L_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-L-K")
    OZ_VOL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-SEC")
    TON_Register = URIRef("http://qudt.org/vocab/unit/TON_Register")
    MicroPOISE = URIRef("http://qudt.org/vocab/unit/MicroPOISE")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    C_Stat = URIRef("http://qudt.org/vocab/unit/C_Stat")
    BARN_PER_SR_EV = URIRef("http://qudt.org/vocab/unit/BARN-PER-SR-EV")
    LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT2")
    PER_L = URIRef("http://qudt.org/vocab/unit/PER-L")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    MOL_K = URIRef("http://qudt.org/vocab/unit/MOL-K")
    PA_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-PER-BAR")
    IN_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC-DEG_F")
    YottaC = URIRef("http://qudt.org/vocab/unit/YottaC")
    PicoGM = URIRef("http://qudt.org/vocab/unit/PicoGM")
    PlanckPressure = URIRef("http://qudt.org/vocab/unit/PlanckPressure")
    MilliM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-KiloGM")
    WB_PER_MilliM = URIRef("http://qudt.org/vocab/unit/WB-PER-MilliM")
    LB_M = URIRef("http://qudt.org/vocab/unit/LB_M")
    PERCENT_MIN_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-CentiM3")
    MilliGM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-K")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    PicoMOL_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M3-SEC")
    L_PER_L = URIRef("http://qudt.org/vocab/unit/L-PER-L")
    H = URIRef("http://qudt.org/vocab/unit/H")
    PHON = URIRef("http://qudt.org/vocab/unit/PHON")
    PER_J_M3 = URIRef("http://qudt.org/vocab/unit/PER-J-M3")
    PSI_PER_IN = URIRef("http://qudt.org/vocab/unit/PSI-PER-IN")
    TONNE_PER_MIN = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN")
    PetaBIT = URIRef("http://qudt.org/vocab/unit/PetaBIT")
    V_IN2_PER_LB_F = URIRef("http://qudt.org/vocab/unit/V-IN2-PER-LB_F")
    MI3 = URIRef("http://qudt.org/vocab/unit/MI3")
    CUP = URIRef("http://qudt.org/vocab/unit/CUP")
    BBL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-MIN")
    DYN = URIRef("http://qudt.org/vocab/unit/DYN")
    H_PER_M = URIRef("http://qudt.org/vocab/unit/H-PER-M")
    Ci = URIRef("http://qudt.org/vocab/unit/Ci")
    FemtoGM = URIRef("http://qudt.org/vocab/unit/FemtoGM")
    KiloCAL_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-HR")
    FATH = URIRef("http://qudt.org/vocab/unit/FATH")
    N_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-PER-M3")
    NanoGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M3")
    LB_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT2")
    BTU_IT_PER_HR_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_R")
    PlanckVolt = URIRef("http://qudt.org/vocab/unit/PlanckVolt")
    PHOT = URIRef("http://qudt.org/vocab/unit/PHOT")
    CAL_IT = URIRef("http://qudt.org/vocab/unit/CAL_IT")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    CAL_TH_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM-K")
    W_PER_M_K = URIRef("http://qudt.org/vocab/unit/W-PER-M-K")
    GM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC")
    FT_LB_F_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-HR")
    KN = URIRef("http://qudt.org/vocab/unit/KN")
    FT_SEC_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-GAL_UK")
    GigaBQ = URIRef("http://qudt.org/vocab/unit/GigaBQ")
    MilLength = URIRef("http://qudt.org/vocab/unit/MilLength")
    NanoV_A = URIRef("http://qudt.org/vocab/unit/NanoV-A")
    M_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-PA")
    GM_PER_MilliM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM-BAR")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    PERCENT_SEC_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-L")
    CD_PER_IN2 = URIRef("http://qudt.org/vocab/unit/CD-PER-IN2")
    LB_IN2 = URIRef("http://qudt.org/vocab/unit/LB-IN2")
    MilliGM_PER_L_POISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-POISE")
    PlanckPressure = URIRef("http://qudt.org/vocab/unit/PlanckPressure")
    MicroGM_PER_L = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L")
    CARAT = URIRef("http://qudt.org/vocab/unit/CARAT")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    YD3 = URIRef("http://qudt.org/vocab/unit/YD3")
    KiloW_HR = URIRef("http://qudt.org/vocab/unit/KiloW-HR")
    STR = URIRef("http://qudt.org/vocab/unit/STR")
    CH = URIRef("http://qudt.org/vocab/unit/CH")
    PicoGM = URIRef("http://qudt.org/vocab/unit/PicoGM")
    BARN_PER_SR = URIRef("http://qudt.org/vocab/unit/BARN-PER-SR")
    PlanckVolt = URIRef("http://qudt.org/vocab/unit/PlanckVolt")
    BIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/BIT-PER-M3")
    KiloJ = URIRef("http://qudt.org/vocab/unit/KiloJ")
    CentiM6 = URIRef("http://qudt.org/vocab/unit/CentiM6")
    C_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-CentiM2")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    KibiBIT = URIRef("http://qudt.org/vocab/unit/KibiBIT")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    GAL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-HR")
    BTU_TH_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-HR-DEG_F")
    MicroFARAD = URIRef("http://qudt.org/vocab/unit/MicroFARAD")
    GigaPA = URIRef("http://qudt.org/vocab/unit/GigaPA")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    K = URIRef("http://qudt.org/vocab/unit/K")
    TONNE_PER_SEC = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC")
    K_M = URIRef("http://qudt.org/vocab/unit/K-M")
    S_PER_CentiM = URIRef("http://qudt.org/vocab/unit/S-PER-CentiM")
    MebiBIT = URIRef("http://qudt.org/vocab/unit/MebiBIT")
    IN_PDL = URIRef("http://qudt.org/vocab/unit/IN-PDL")
    GM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloGM")
    W_PER_K = URIRef("http://qudt.org/vocab/unit/W-PER-K")
    GM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-K")
    KiloBTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-FT2")
    LB_MIN_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-GAL_UK")
    LB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT")
    PINT_US_DRY = URIRef("http://qudt.org/vocab/unit/PINT_US_DRY")
    TONNE_PER_HA_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA-YR")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    MegaBIT = URIRef("http://qudt.org/vocab/unit/MegaBIT")
    SLUG_PER_FT = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT")
    GI_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-DAY")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    CAL_TH_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM-SEC-DEG_C")
    MilliR_man = URIRef("http://qudt.org/vocab/unit/MilliR_man")
    MilliGM_PER_L_CentiPOISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-CentiPOISE")
    PicoS = URIRef("http://qudt.org/vocab/unit/PicoS")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    OERSTED = URIRef("http://qudt.org/vocab/unit/OERSTED")
    FT_HR_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-GAL_US")
    FT_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-PER-HR")
    HectoPA_PER_HR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-HR")
    LB_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_UK")
    MicroN = URIRef("http://qudt.org/vocab/unit/MicroN")
    CentiM_H20_4DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_H20_4DEG_C")
    MilliA_PER_K = URIRef("http://qudt.org/vocab/unit/MilliA-PER-K")
    KiloGM_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM2")
    PicoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/PicoKAT-PER-L")
    GM_MilliM = URIRef("http://qudt.org/vocab/unit/GM-MilliM")
    LB_F_PER_YD = URIRef("http://qudt.org/vocab/unit/LB_F-PER-YD")
    BAR_PER_K = URIRef("http://qudt.org/vocab/unit/BAR-PER-K")
    TON_Metric_PER_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-K")
    L_PER_HR = URIRef("http://qudt.org/vocab/unit/L-PER-HR")
    MilliGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-HR")
    CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM-SEC-DEG_C")
    KiloLB_F_FT_PER_A = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-A")
    MilliM3 = URIRef("http://qudt.org/vocab/unit/MilliM3")
    J_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-M2-PER-KiloGM")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    DEG_F_PER_BAR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-BAR")
    CentiM_HG_0DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_HG_0DEG_C")
    N_PER_CentiM = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM")
    PPM_PER_K = URIRef("http://qudt.org/vocab/unit/PPM-PER-K")
    FARAD_Stat = URIRef("http://qudt.org/vocab/unit/FARAD_Stat")
    DeciM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-KiloGM")
    LB_MIN_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-FT3")
    N_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM2")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    Hundredweight_US = URIRef("http://qudt.org/vocab/unit/Hundredweight_US")
    PER_MILLE_PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PER-PSI")
    PER_CentiM = URIRef("http://qudt.org/vocab/unit/PER-CentiM")
    GI_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_US-PER-SEC")
    TON_SHORT_PER_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR-DEG_F")
    GRAIN = URIRef("http://qudt.org/vocab/unit/GRAIN")
    CLO = URIRef("http://qudt.org/vocab/unit/CLO")
    DEG_F_HR_FT2_PER_BTU_TH_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH-IN")
    GM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC")
    FemtoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-L")
    MicroGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-MilliL")
    LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC")
    KiloGM_F = URIRef("http://qudt.org/vocab/unit/KiloGM_F")
    PER_M_NanoM_SR = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM-SR")
    MicroM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM-PER-MilliL")
    LB_HR_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-FT3")
    PINT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-MIN")
    A_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM2")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/PER-MilliM3")
    KiloN = URIRef("http://qudt.org/vocab/unit/KiloN")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    MilliM_HG = URIRef("http://qudt.org/vocab/unit/MilliM_HG")
    EUR_PER_W_HR = URIRef("http://qudt.org/vocab/unit/EUR-PER-W-HR")
    GAL_IMP = URIRef("http://qudt.org/vocab/unit/GAL_IMP")
    MicroMOL = URIRef("http://qudt.org/vocab/unit/MicroMOL")
    MX = URIRef("http://qudt.org/vocab/unit/MX")
    TON_SHORT_PER_HR_PSI = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR-PSI")
    K_M_PER_W = URIRef("http://qudt.org/vocab/unit/K-M-PER-W")
    DeciTONNE = URIRef("http://qudt.org/vocab/unit/DeciTONNE")
    AT = URIRef("http://qudt.org/vocab/unit/AT")
    GM_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/GM-PER-DEG_C")
    KiloGM_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-PA")
    KiloGM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-CentiM2")
    MicroMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM")
    BARN = URIRef("http://qudt.org/vocab/unit/BARN")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    GibiBIT = URIRef("http://qudt.org/vocab/unit/GibiBIT")
    MilliA = URIRef("http://qudt.org/vocab/unit/MilliA")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    MegaHZ_M = URIRef("http://qudt.org/vocab/unit/MegaHZ-M")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    IN3 = URIRef("http://qudt.org/vocab/unit/IN3")
    MilliW = URIRef("http://qudt.org/vocab/unit/MilliW")
    N_M2_PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/N-M2-PER-KiloGM2")
    PA_PER_HR = URIRef("http://qudt.org/vocab/unit/PA-PER-HR")
    MilliL = URIRef("http://qudt.org/vocab/unit/MilliL")
    M3_PER_DAY = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY")
    TONNE_PER_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-BAR")
    KiloA_HR = URIRef("http://qudt.org/vocab/unit/KiloA-HR")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    KiloL = URIRef("http://qudt.org/vocab/unit/KiloL")
    MicroM_PER_K = URIRef("http://qudt.org/vocab/unit/MicroM-PER-K")
    TON = URIRef("http://qudt.org/vocab/unit/TON")
    BBL_UK_PET = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET")
    RichterMagnitude = URIRef("http://qudt.org/vocab/unit/RichterMagnitude")
    LB_SEC_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-FT3")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    ERG_CentiM2 = URIRef("http://qudt.org/vocab/unit/ERG-CentiM2")
    OZ_FT_HR_PER_IN3_LB = URIRef("http://qudt.org/vocab/unit/OZ-FT-HR-PER-IN3-LB")
    MilliGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-HR")
    OZ_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ-PER-DAY")
    LB_SEC_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-IN3")
    M2_K_PER_W = URIRef("http://qudt.org/vocab/unit/M2-K-PER-W")
    MilliW = URIRef("http://qudt.org/vocab/unit/MilliW")
    PA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-BAR")
    PetaBIT = URIRef("http://qudt.org/vocab/unit/PetaBIT")
    CentiM3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL-SEC")
    PER_SEC_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    PER_FT3 = URIRef("http://qudt.org/vocab/unit/PER-FT3")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    OZ_HR_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-GAL_US")
    C_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM2")
    DEG_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-MIN")
    PINT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-MIN")
    QT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_US-PER-HR")
    TON_US_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_US-PER-YD3")
    LB_PER_IN3_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3-DEG_F")
    GigaOHM = URIRef("http://qudt.org/vocab/unit/GigaOHM")
    KiloGRAY = URIRef("http://qudt.org/vocab/unit/KiloGRAY")
    A_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM2")
    MilliGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-KiloGM")
    DYN_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM")
    TeraC = URIRef("http://qudt.org/vocab/unit/TeraC")
    MI_PER_HR = URIRef("http://qudt.org/vocab/unit/MI-PER-HR")
    MilliBQ = URIRef("http://qudt.org/vocab/unit/MilliBQ")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    KiloPOND = URIRef("http://qudt.org/vocab/unit/KiloPOND")
    GI = URIRef("http://qudt.org/vocab/unit/GI")
    PK_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-HR")
    W_PER_FT2 = URIRef("http://qudt.org/vocab/unit/W-PER-FT2")
    MegaL = URIRef("http://qudt.org/vocab/unit/MegaL")
    DEG_C_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-MIN")
    L_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/L-PER-MicroMOL")
    MilliGM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR")
    FT3_PER_HR = URIRef("http://qudt.org/vocab/unit/FT3-PER-HR")
    MilliL_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-BAR")
    BTU_IT_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB")
    V_PER_L_MIN = URIRef("http://qudt.org/vocab/unit/V-PER-L-MIN")
    KiloHZ = URIRef("http://qudt.org/vocab/unit/KiloHZ")
    MicroMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-KiloGM")
    W_PER_M = URIRef("http://qudt.org/vocab/unit/W-PER-M")
    P = URIRef("http://qudt.org/vocab/unit/P")
    MilliM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC")
    MicroGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-BAR")
    GALILEO = URIRef("http://qudt.org/vocab/unit/GALILEO")
    IN = URIRef("http://qudt.org/vocab/unit/IN")
    OZ_VOL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-DAY")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    LB_FT2 = URIRef("http://qudt.org/vocab/unit/LB-FT2")
    KiloGM_PER_DeciM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-K")
    GRAIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL_US")
    UnitPole = URIRef("http://qudt.org/vocab/unit/UnitPole")
    ZettaC = URIRef("http://qudt.org/vocab/unit/ZettaC")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    K = URIRef("http://qudt.org/vocab/unit/K")
    MilliOHM_M = URIRef("http://qudt.org/vocab/unit/MilliOHM-M")
    BTU_TH_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB")
    GM_HR_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M3-CentiM3")
    LB_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-SEC")
    IN2_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN2-PER-SEC")
    GigaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-SEC")
    KiloCAL_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL")
    NanoC = URIRef("http://qudt.org/vocab/unit/NanoC")
    CentiMOL = URIRef("http://qudt.org/vocab/unit/CentiMOL")
    BU_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-DAY")
    A_PER_M2_K2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2-K2")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    N_M_PER_ARCMIN = URIRef("http://qudt.org/vocab/unit/N-M-PER-ARCMIN")
    SV_PER_HR = URIRef("http://qudt.org/vocab/unit/SV-PER-HR")
    BTU_TH_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_F")
    DEG_C_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-SEC")
    MilliGM_PER_L_CentiPOISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-CentiPOISE")
    MOL_K = URIRef("http://qudt.org/vocab/unit/MOL-K")
    AWG = URIRef("http://qudt.org/vocab/unit/AWG")
    W_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM-SR")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    CAL_TH_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    MillionUSD_PER_YR = URIRef("http://qudt.org/vocab/unit/MillionUSD-PER-YR")
    J_PER_SEC = URIRef("http://qudt.org/vocab/unit/J-PER-SEC")
    TON_SHORT = URIRef("http://qudt.org/vocab/unit/TON_SHORT")
    POISE = URIRef("http://qudt.org/vocab/unit/POISE")
    M2_PER_N = URIRef("http://qudt.org/vocab/unit/M2-PER-N")
    BTU_TH_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_F")
    MilliL_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR")
    FT_SEC_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-GAL_UK")
    MegaBQ = URIRef("http://qudt.org/vocab/unit/MegaBQ")
    YD_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD-PER-MIN")
    MilliSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-MIN")
    CASES_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-1000I-YR")
    LB_FT2_PER_GAL_US_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-GAL_US-LB_F-SEC")
    LB_SEC_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-GAL_US")
    PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-PER-SEC")
    PPTM_PER_K = URIRef("http://qudt.org/vocab/unit/PPTM-PER-K")
    TON_US_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_US-PER-HR")
    ATM_T = URIRef("http://qudt.org/vocab/unit/ATM_T")
    V_PER_MicroSEC = URIRef("http://qudt.org/vocab/unit/V-PER-MicroSEC")
    SHANNON_PER_SEC = URIRef("http://qudt.org/vocab/unit/SHANNON-PER-SEC")
    LB_IN = URIRef("http://qudt.org/vocab/unit/LB-IN")
    CAL_MEAN = URIRef("http://qudt.org/vocab/unit/CAL_MEAN")
    A_M2_PER_J_SEC = URIRef("http://qudt.org/vocab/unit/A-M2-PER-J-SEC")
    LB = URIRef("http://qudt.org/vocab/unit/LB")
    G = URIRef("http://qudt.org/vocab/unit/G")
    TORR_PER_M = URIRef("http://qudt.org/vocab/unit/TORR-PER-M")
    Standard = URIRef("http://qudt.org/vocab/unit/Standard")
    MicroJ = URIRef("http://qudt.org/vocab/unit/MicroJ")
    KiloGM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    N_M_PER_DEG_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG-M")
    MegaTONNE = URIRef("http://qudt.org/vocab/unit/MegaTONNE")
    DYN_SEC_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM")
    KiloGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM2")
    THM_EEC = URIRef("http://qudt.org/vocab/unit/THM_EEC")
    HK = URIRef("http://qudt.org/vocab/unit/HK")
    GM_HR_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L-CentiM3")
    MicroCi = URIRef("http://qudt.org/vocab/unit/MicroCi")
    PA_SEC_PER_L = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-L")
    TONNE_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY-BAR")
    MilliW = URIRef("http://qudt.org/vocab/unit/MilliW")
    NAT_PER_SEC = URIRef("http://qudt.org/vocab/unit/NAT-PER-SEC")
    CHAIN_US = URIRef("http://qudt.org/vocab/unit/CHAIN_US")
    C_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM2")
    MI2 = URIRef("http://qudt.org/vocab/unit/MI2")
    PER_WK = URIRef("http://qudt.org/vocab/unit/PER-WK")
    YD3_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD3-PER-MIN")
    BIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BIT-PER-SEC")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    C3_M_PER_J2 = URIRef("http://qudt.org/vocab/unit/C3-M-PER-J2")
    KiloGM_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-MilliM2")
    J_PER_M = URIRef("http://qudt.org/vocab/unit/J-PER-M")
    MegaGRAY = URIRef("http://qudt.org/vocab/unit/MegaGRAY")
    MilliGM_PER_L_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-MilliPA-SEC")
    MilliL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-MIN")
    KiloBAUD = URIRef("http://qudt.org/vocab/unit/KiloBAUD")
    M2_PER_J = URIRef("http://qudt.org/vocab/unit/M2-PER-J")
    MilliL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN")
    DeciM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-SEC")
    KiloGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-BAR")
    LB_F_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN")
    BTU_TH_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-HR-DEG_F")
    KiloN_M_PER_DEG_M = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-DEG-M")
    NanoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/NanoKAT-PER-L")
    LA_FT = URIRef("http://qudt.org/vocab/unit/LA_FT")
    DeciN_M = URIRef("http://qudt.org/vocab/unit/DeciN-M")
    MicroGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M2-DAY")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    GibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M2")
    MegaEV_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-CentiM")
    PFUND = URIRef("http://qudt.org/vocab/unit/PFUND")
    KiloLB_F_FT_PER_LB = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-LB")
    MilliGM_PER_L = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L")
    V = URIRef("http://qudt.org/vocab/unit/V")
    POISE = URIRef("http://qudt.org/vocab/unit/POISE")
    MicroMOL = URIRef("http://qudt.org/vocab/unit/MicroMOL")
    K_PER_W = URIRef("http://qudt.org/vocab/unit/K-PER-W")
    MilliL_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-BAR")
    BU_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-DAY")
    MegaPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-M3-PER-SEC")
    KiloGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN")
    LB = URIRef("http://qudt.org/vocab/unit/LB")
    KiloGM_F_M_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-CentiM2")
    M2_PER_HZ = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ")
    MicroMOL_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-HR")
    FT_LB_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-SEC")
    OZ_F_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ_F-PER-IN3")
    MilliOHM = URIRef("http://qudt.org/vocab/unit/MilliOHM")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    W_SEC = URIRef("http://qudt.org/vocab/unit/W-SEC")
    BTU_IT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC")
    GAL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-SEC")
    M_PER_MIN = URIRef("http://qudt.org/vocab/unit/M-PER-MIN")
    MegaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-M")
    PK_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-SEC")
    MegaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M3")
    MilliN = URIRef("http://qudt.org/vocab/unit/MilliN")
    MicroM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-M3")
    KiloN_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-DEG")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    SEC2 = URIRef("http://qudt.org/vocab/unit/SEC2")
    HectoPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-L-PER-SEC")
    LB_PER_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-DAY")
    KiloM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC-BAR")
    RAD_R = URIRef("http://qudt.org/vocab/unit/RAD_R")
    GAL_US_DRY = URIRef("http://qudt.org/vocab/unit/GAL_US_DRY")
    V_A_HR = URIRef("http://qudt.org/vocab/unit/V-A-HR")
    MI_US = URIRef("http://qudt.org/vocab/unit/MI_US")
    GM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC")
    TONNE_PER_DAY = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY")
    PER_MIN = URIRef("http://qudt.org/vocab/unit/PER-MIN")
    MilliGM_MIN_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L2")
    M2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2")
    OZ_IN = URIRef("http://qudt.org/vocab/unit/OZ-IN")
    MegaJ = URIRef("http://qudt.org/vocab/unit/MegaJ")
    W_PER_K = URIRef("http://qudt.org/vocab/unit/W-PER-K")
    MegaC = URIRef("http://qudt.org/vocab/unit/MegaC")
    DeciM = URIRef("http://qudt.org/vocab/unit/DeciM")
    MIL_Circ = URIRef("http://qudt.org/vocab/unit/MIL_Circ")
    J_PER_SEC = URIRef("http://qudt.org/vocab/unit/J-PER-SEC")
    LUX_SEC = URIRef("http://qudt.org/vocab/unit/LUX-SEC")
    OZ_IN = URIRef("http://qudt.org/vocab/unit/OZ-IN")
    MilliV = URIRef("http://qudt.org/vocab/unit/MilliV")
    GRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/GRAY-PER-MIN")
    M4_PER_SEC = URIRef("http://qudt.org/vocab/unit/M4-PER-SEC")
    W_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-SEC-PER-M2")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    MOHM = URIRef("http://qudt.org/vocab/unit/MOHM")
    PINT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-SEC")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    ExbiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M2")
    GM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM_F-PER-CentiM2")
    TON_Metric_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC-BAR")
    DeciS_PER_M = URIRef("http://qudt.org/vocab/unit/DeciS-PER-M")
    KiloCAL_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM-DEG_C")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    DARCY = URIRef("http://qudt.org/vocab/unit/DARCY")
    PDL_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-FT2")
    LB_HR_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-GAL_US")
    GM_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/GM-PER-DEG_C")
    DEG_R_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-HR")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    NanoGM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MicroL")
    DEG_R = URIRef("http://qudt.org/vocab/unit/DEG_R")
    Da = URIRef("http://qudt.org/vocab/unit/Da")
    KiloMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3")
    PERCENT_HR_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-GAL_UK")
    SLUG_PER_DAY = URIRef("http://qudt.org/vocab/unit/SLUG-PER-DAY")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    A = URIRef("http://qudt.org/vocab/unit/A")
    PERCENT_PER_IN = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-IN")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    KiloGM_PER_DeciM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-K")
    MegaHZ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-K")
    AttoJ_SEC = URIRef("http://qudt.org/vocab/unit/AttoJ-SEC")
    KiloC_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M3")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    KIP_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KIP_F-PER-IN2")
    J_PER_GM_K = URIRef("http://qudt.org/vocab/unit/J-PER-GM-K")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/FT2-PER-BTU_IT-IN")
    BBL = URIRef("http://qudt.org/vocab/unit/BBL")
    CHAIN_US = URIRef("http://qudt.org/vocab/unit/CHAIN_US")
    MicroGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-SEC")
    MilliMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-GM")
    MilliMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-MOL")
    TONNE_PER_MO = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MO")
    M2_PER_K = URIRef("http://qudt.org/vocab/unit/M2-PER-K")
    LB_MIN_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US2")
    MI_N_PER_HR = URIRef("http://qudt.org/vocab/unit/MI_N-PER-HR")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    MilliV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliV-PER-MIN")
    AT_PER_M = URIRef("http://qudt.org/vocab/unit/AT-PER-M")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    CAL_TH_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM-SEC-DEG_C")
    DEGREE_OECHSLE = URIRef("http://qudt.org/vocab/unit/DEGREE_OECHSLE")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    AMU = URIRef("http://qudt.org/vocab/unit/AMU")
    AU = URIRef("http://qudt.org/vocab/unit/AU")
    A_PER_K = URIRef("http://qudt.org/vocab/unit/A-PER-K")
    PA_PER_M = URIRef("http://qudt.org/vocab/unit/PA-PER-M")
    BAN = URIRef("http://qudt.org/vocab/unit/BAN")
    BTU_60DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_60DEG_F")
    J_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K")
    LB_HR_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-YD3")
    MilliGM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-BAR")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    H = URIRef("http://qudt.org/vocab/unit/H")
    GM_PER_L_PA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-L-PA-SEC")
    CentiM3_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR")
    MegaW = URIRef("http://qudt.org/vocab/unit/MegaW")
    KiloN_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M")
    MilliBAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-BAR")
    AU = URIRef("http://qudt.org/vocab/unit/AU")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    BIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BIT-PER-SEC")
    PERM_Metric_23DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_Metric_23DEG_C")
    CAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-MIN")
    Flight = URIRef("http://qudt.org/vocab/unit/Flight")
    LB_PER_FT_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-HR")
    NUM_PER_YR = URIRef("http://qudt.org/vocab/unit/NUM-PER-YR")
    EV_PER_M = URIRef("http://qudt.org/vocab/unit/EV-PER-M")
    J_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-GM-DEG_C")
    YR = URIRef("http://qudt.org/vocab/unit/YR")
    NanoA_PER_K = URIRef("http://qudt.org/vocab/unit/NanoA-PER-K")
    PicoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/PicoFARAD-PER-M")
    LB_PER_YD3 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD3")
    PDL = URIRef("http://qudt.org/vocab/unit/PDL")
    TONNE_PER_SEC = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC")
    MegaEV_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-CentiM")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    KIP_F = URIRef("http://qudt.org/vocab/unit/KIP_F")
    MilliPA = URIRef("http://qudt.org/vocab/unit/MilliPA")
    LB_SEC_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-FT3")
    KibiBYTE = URIRef("http://qudt.org/vocab/unit/KibiBYTE")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    MilliL = URIRef("http://qudt.org/vocab/unit/MilliL")
    GAL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-HR")
    KiloJ_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-DAY")
    MHO = URIRef("http://qudt.org/vocab/unit/MHO")
    CAL_IT_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM-K")
    J_M2 = URIRef("http://qudt.org/vocab/unit/J-M2")
    LB_PER_MIN_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN-DEG_F")
    N_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-M-PER-M2")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    TeraW_HR = URIRef("http://qudt.org/vocab/unit/TeraW-HR")
    DRAM_US = URIRef("http://qudt.org/vocab/unit/DRAM_US")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    BREATH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BREATH-PER-MIN")
    GM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/GM-PER-HR-K")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    MilliM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-M3")
    MilliGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-K")
    OZ_MIN_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-GAL_US")
    MilliM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-KiloGM")
    LB_PER_IN = URIRef("http://qudt.org/vocab/unit/LB-PER-IN")
    MicroMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L-HR")
    LB_PER_MIN_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN-DEG_F")
    MegaOHM_KiloM = URIRef("http://qudt.org/vocab/unit/MegaOHM-KiloM")
    MilliN_M = URIRef("http://qudt.org/vocab/unit/MilliN-M")
    PSI_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-L-PER-SEC")
    TeraFLOPS = URIRef("http://qudt.org/vocab/unit/TeraFLOPS")
    GM_Nitrogen_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Nitrogen-PER-M2-DAY")
    GM_PER_M3_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-MilliPA-SEC")
    A = URIRef("http://qudt.org/vocab/unit/A")
    PER_GigaEV2 = URIRef("http://qudt.org/vocab/unit/PER-GigaEV2")
    FemtoM = URIRef("http://qudt.org/vocab/unit/FemtoM")
    TON_FG_HR = URIRef("http://qudt.org/vocab/unit/TON_FG-HR")
    OZ_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ-PER-DAY")
    MIL_Circ = URIRef("http://qudt.org/vocab/unit/MIL_Circ")
    YR_TROPICAL = URIRef("http://qudt.org/vocab/unit/YR_TROPICAL")
    LY = URIRef("http://qudt.org/vocab/unit/LY")
    MOL_PER_L = URIRef("http://qudt.org/vocab/unit/MOL-PER-L")
    MilliL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC")
    KiloGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-PA-SEC")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    GT = URIRef("http://qudt.org/vocab/unit/GT")
    MegaV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    OZ_VOL_US = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US")
    MilliBAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-L-PER-SEC")
    HZ_PER_T = URIRef("http://qudt.org/vocab/unit/HZ-PER-T")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    PERMEABILITY_EM_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_EM_REL")
    MegaGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-HA")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    M_PER_FARAD = URIRef("http://qudt.org/vocab/unit/M-PER-FARAD")
    EUR_PER_KiloW = URIRef("http://qudt.org/vocab/unit/EUR-PER-KiloW")
    IN_PER_2PiRAD = URIRef("http://qudt.org/vocab/unit/IN-PER-2PiRAD")
    BTU_IT = URIRef("http://qudt.org/vocab/unit/BTU_IT")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT")
    PER_M_K = URIRef("http://qudt.org/vocab/unit/PER-M-K")
    OZ_HR_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-GAL_UK")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    PA_PER_HR = URIRef("http://qudt.org/vocab/unit/PA-PER-HR")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    GM_HR_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L-M3")
    MilliN_PER_M = URIRef("http://qudt.org/vocab/unit/MilliN-PER-M")
    MicroMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L")
    K = URIRef("http://qudt.org/vocab/unit/K")
    M3_PER_MIN = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN")
    HectoM = URIRef("http://qudt.org/vocab/unit/HectoM")
    MilliGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY")
    J_PER_HR = URIRef("http://qudt.org/vocab/unit/J-PER-HR")
    M3_PER_M3 = URIRef("http://qudt.org/vocab/unit/M3-PER-M3")
    REV_PER_MIN = URIRef("http://qudt.org/vocab/unit/REV-PER-MIN")
    N_CentiM = URIRef("http://qudt.org/vocab/unit/N-CentiM")
    GM_HR_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L-CentiM3")
    CentiM3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-BAR")
    P = URIRef("http://qudt.org/vocab/unit/P")
    KiloGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM2")
    TEX = URIRef("http://qudt.org/vocab/unit/TEX")
    GM_PER_MIN = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN")
    A_PER_M2_K2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2-K2")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    HectoPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-M3-PER-SEC")
    MegaV_A = URIRef("http://qudt.org/vocab/unit/MegaV-A")
    GM_MilliM = URIRef("http://qudt.org/vocab/unit/GM-MilliM")
    MOL_PER_TONNE = URIRef("http://qudt.org/vocab/unit/MOL-PER-TONNE")
    IN_HG = URIRef("http://qudt.org/vocab/unit/IN_HG")
    TONNE_PER_HR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR")
    N = URIRef("http://qudt.org/vocab/unit/N")
    PA2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA2-PER-SEC2")
    HP_Boiler = URIRef("http://qudt.org/vocab/unit/HP_Boiler")
    PDL_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/PDL-SEC-PER-IN2")
    M4 = URIRef("http://qudt.org/vocab/unit/M4")
    MegaGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-HA")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    GI_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_US-PER-MIN")
    TONNE_PER_M3 = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3")
    MIN_Sidereal = URIRef("http://qudt.org/vocab/unit/MIN_Sidereal")
    QT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_US-PER-DAY")
    LB_T = URIRef("http://qudt.org/vocab/unit/LB_T")
    PARSEC = URIRef("http://qudt.org/vocab/unit/PARSEC")
    CAL_IT_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM2-K")
    CentiGM = URIRef("http://qudt.org/vocab/unit/CentiGM")
    MegaEV_PER_SpeedOfLight = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-SpeedOfLight")
    T = URIRef("http://qudt.org/vocab/unit/T")
    BTU_IT_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC-DEG_F")
    LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN")
    PERMEABILITY_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_REL")
    Hundredweight_US = URIRef("http://qudt.org/vocab/unit/Hundredweight_US")
    UnitPole = URIRef("http://qudt.org/vocab/unit/UnitPole")
    MicroM_PER_K = URIRef("http://qudt.org/vocab/unit/MicroM-PER-K")
    BTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2")
    J_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-M2-PER-KiloGM")
    PERCENT_HR_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-IN3")
    BFT = URIRef("http://qudt.org/vocab/unit/BFT")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    GRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/GRAY-PER-MIN")
    MicroT = URIRef("http://qudt.org/vocab/unit/MicroT")
    DEG2 = URIRef("http://qudt.org/vocab/unit/DEG2")
    KiloCAL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-SEC")
    KiloHZ = URIRef("http://qudt.org/vocab/unit/KiloHZ")
    PERCENT_PER_HR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-HR")
    MOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2")
    LB_PER_FT_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-MIN")
    PlanckVolume = URIRef("http://qudt.org/vocab/unit/PlanckVolume")
    EV_SEC = URIRef("http://qudt.org/vocab/unit/EV-SEC")
    OHM_CentiM = URIRef("http://qudt.org/vocab/unit/OHM-CentiM")
    TOE = URIRef("http://qudt.org/vocab/unit/TOE")
    MegaOHM_PER_K = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-K")
    YD2 = URIRef("http://qudt.org/vocab/unit/YD2")
    PA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M3-PER-SEC")
    PER_FT3 = URIRef("http://qudt.org/vocab/unit/PER-FT3")
    PER_EV2 = URIRef("http://qudt.org/vocab/unit/PER-EV2")
    PER_K = URIRef("http://qudt.org/vocab/unit/PER-K")
    MilliM3 = URIRef("http://qudt.org/vocab/unit/MilliM3")
    K_M2_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/K-M2-PER-KiloGM-SEC")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    TON_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-DAY")
    OZ_VOL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-MIN")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    GT = URIRef("http://qudt.org/vocab/unit/GT")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    MilliSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-MIN")
    KiloGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-PA-SEC")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    MilliA_PER_L_MIN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-L-MIN")
    MilliC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliC-PER-KiloGM")
    ST_PER_K = URIRef("http://qudt.org/vocab/unit/ST-PER-K")
    TONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-YR")
    M2_PER_J = URIRef("http://qudt.org/vocab/unit/M2-PER-J")
    CFU = URIRef("http://qudt.org/vocab/unit/CFU")
    DYN_M = URIRef("http://qudt.org/vocab/unit/DYN-M")
    EUR_PER_W_SEC = URIRef("http://qudt.org/vocab/unit/EUR-PER-W-SEC")
    PINT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-HR")
    K_PER_M = URIRef("http://qudt.org/vocab/unit/K-PER-M")
    MicroGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-HR")
    CWT_LONG = URIRef("http://qudt.org/vocab/unit/CWT_LONG")
    MegaC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M2")
    MilliGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-DAY")
    J_PER_M = URIRef("http://qudt.org/vocab/unit/J-PER-M")
    MebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M2")
    KiloGM_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-MilliM2")
    SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-PER-FT2")
    KiloJ_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM-K")
    PetaFLOPS = URIRef("http://qudt.org/vocab/unit/PetaFLOPS")
    DEG2 = URIRef("http://qudt.org/vocab/unit/DEG2")
    LB_SEC_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN6")
    MilliGM_HR_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M3-L")
    CAL_TH_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM2-K")
    KiloC = URIRef("http://qudt.org/vocab/unit/KiloC")
    KiloGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-K")
    K_PER_W = URIRef("http://qudt.org/vocab/unit/K-PER-W")
    FemtoMOL = URIRef("http://qudt.org/vocab/unit/FemtoMOL")
    LB_FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT-PER-SEC")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    QT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-MIN")
    A = URIRef("http://qudt.org/vocab/unit/A")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    LB_FT2_PER_GAL_UK_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-GAL_UK-LB_F-SEC")
    KiloCAL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-MIN")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    OZ_VOL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-HR")
    LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    W_SEC = URIRef("http://qudt.org/vocab/unit/W-SEC")
    GigaPA = URIRef("http://qudt.org/vocab/unit/GigaPA")
    TebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M2")
    N_M_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-RAD")
    MebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M2")
    C_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM2")
    MilliL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-MIN")
    NanoMOL_PER_MicroMOL_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL-DAY")
    HectoPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-BAR")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    SEC2 = URIRef("http://qudt.org/vocab/unit/SEC2")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    MI_US2 = URIRef("http://qudt.org/vocab/unit/MI_US2")
    FT3_PER_MIN_FT2 = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN-FT2")
    OZ_VOL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-DAY")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    PERCENT_MIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-M3")
    MilliGM_HR_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M3-CentiM3")
    KiloPA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-K")
    PERCENT_PER_HectoBAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-HectoBAR")
    J_PER_GM = URIRef("http://qudt.org/vocab/unit/J-PER-GM")
    M = URIRef("http://qudt.org/vocab/unit/M")
    HectoPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-L-PER-SEC")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    KiloCD = URIRef("http://qudt.org/vocab/unit/KiloCD")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    HP_Electric = URIRef("http://qudt.org/vocab/unit/HP_Electric")
    BTU_TH_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-FT2-HR-DEG_F")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    AT_PER_M = URIRef("http://qudt.org/vocab/unit/AT-PER-M")
    PicoMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L-HR")
    BTU_TH_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_F")
    ERLANG = URIRef("http://qudt.org/vocab/unit/ERLANG")
    CAL_IT_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM2-K")
    FT_LB_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-SEC")
    GibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M3")
    YR = URIRef("http://qudt.org/vocab/unit/YR")
    LUX_SEC = URIRef("http://qudt.org/vocab/unit/LUX-SEC")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    MicroMHO = URIRef("http://qudt.org/vocab/unit/MicroMHO")
    GigaOHM = URIRef("http://qudt.org/vocab/unit/GigaOHM")
    NanoMOL_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL")
    HectoPA_PER_K = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-K")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    W_SEC = URIRef("http://qudt.org/vocab/unit/W-SEC")
    PERCENT_PER_DecaKiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaKiloCount")
    RPK = URIRef("http://qudt.org/vocab/unit/RPK")
    MilliGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-K")
    BTU_IT_PER_FT2_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR")
    BTU_IT_FT = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT")
    CAL_TH_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-K")
    NanoGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DAY")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    LB_F_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN")
    V2_PER_K2 = URIRef("http://qudt.org/vocab/unit/V2-PER-K2")
    L_PER_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-BAR")
    MOL_PER_TONNE = URIRef("http://qudt.org/vocab/unit/MOL-PER-TONNE")
    SEC2 = URIRef("http://qudt.org/vocab/unit/SEC2")
    M2_PER_SR = URIRef("http://qudt.org/vocab/unit/M2-PER-SR")
    GAL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-MIN")
    M3_PER_C = URIRef("http://qudt.org/vocab/unit/M3-PER-C")
    KiloCAL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MIN")
    GALILEO = URIRef("http://qudt.org/vocab/unit/GALILEO")
    MilliH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-OHM")
    TeraW = URIRef("http://qudt.org/vocab/unit/TeraW")
    V_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V-PER-CentiM")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    SHANNON_PER_SEC = URIRef("http://qudt.org/vocab/unit/SHANNON-PER-SEC")
    PINT_US = URIRef("http://qudt.org/vocab/unit/PINT_US")
    MilliL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M2-DAY")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    PK_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-HR")
    DYN_SEC_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM")
    DEG_R_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-SEC")
    KibiBYTE = URIRef("http://qudt.org/vocab/unit/KibiBYTE")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    MicroTORR = URIRef("http://qudt.org/vocab/unit/MicroTORR")
    PER_T_SEC = URIRef("http://qudt.org/vocab/unit/PER-T-SEC")
    A_PER_M2_K2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2-K2")
    KiloBTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH-PER-HR")
    GigaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/GigaC-PER-M3")
    DEG_R_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-HR")
    WK = URIRef("http://qudt.org/vocab/unit/WK")
    M5 = URIRef("http://qudt.org/vocab/unit/M5")
    IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN3-PER-SEC")
    KiloGM_F_M = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    MI2 = URIRef("http://qudt.org/vocab/unit/MI2")
    TebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M3")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    YD_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD-PER-SEC")
    MilliGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MilliL")
    BU_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-DAY")
    LB_PER_YD3 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD3")
    PA_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PA-M2-PER-KiloGM")
    W_SEC = URIRef("http://qudt.org/vocab/unit/W-SEC")
    FT3_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT3-PER-SEC")
    LB_SEC_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-GAL_US")
    M3_PER_PA = URIRef("http://qudt.org/vocab/unit/M3-PER-PA")
    NanoGM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MicroL")
    KiloGM_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM2")
    BBL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-MIN")
    PERCENT_FT_SEC_PER_LB = URIRef("http://qudt.org/vocab/unit/PERCENT-FT-SEC-PER-LB")
    BBL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-MIN")
    FARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/FARAD-PER-KiloM")
    MilliMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-L")
    LB_M = URIRef("http://qudt.org/vocab/unit/LB_M")
    CentiM3_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-CentiM3")
    MicroGM_PER_L = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L")
    MilliSV = URIRef("http://qudt.org/vocab/unit/MilliSV")
    MI_US = URIRef("http://qudt.org/vocab/unit/MI_US")
    MebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M3")
    N_PER_A = URIRef("http://qudt.org/vocab/unit/N-PER-A")
    BTU_TH_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-SEC")
    MicroSEC = URIRef("http://qudt.org/vocab/unit/MicroSEC")
    CORD = URIRef("http://qudt.org/vocab/unit/CORD")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    GigaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/GigaC-PER-M3")
    LB_PER_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-HR-DEG_F")
    TeraC = URIRef("http://qudt.org/vocab/unit/TeraC")
    KiloV = URIRef("http://qudt.org/vocab/unit/KiloV")
    V_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/V-A_Reactive-HR")
    FT3_PER_MIN_FT2 = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN-FT2")
    AttoC = URIRef("http://qudt.org/vocab/unit/AttoC")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    MIN_Angle = URIRef("http://qudt.org/vocab/unit/MIN_Angle")
    BTU_IT_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-HR-DEG_F")
    BU_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-SEC")
    TONNE_PER_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-BAR")
    failures_in_time = URIRef("http://qudt.org/vocab/unit/failures-in-time")
    SH = URIRef("http://qudt.org/vocab/unit/SH")
    MilliGM_HR_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L-CentiM3")
    MilliGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-K")
    CentiM6 = URIRef("http://qudt.org/vocab/unit/CentiM6")
    GI_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_US-PER-MIN")
    DEGREE_TWADDELL = URIRef("http://qudt.org/vocab/unit/DEGREE_TWADDELL")
    PCA = URIRef("http://qudt.org/vocab/unit/PCA")
    BBL_US = URIRef("http://qudt.org/vocab/unit/BBL_US")
    BTU_TH_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2")
    IN3_PER_LB = URIRef("http://qudt.org/vocab/unit/IN3-PER-LB")
    DEG_F_HR_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_TH")
    LB_F_PER_YD = URIRef("http://qudt.org/vocab/unit/LB_F-PER-YD")
    GM_PER_M3_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-MilliPA-SEC")
    PPTH_PER_HR = URIRef("http://qudt.org/vocab/unit/PPTH-PER-HR")
    MicroBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-L")
    BTU_TH_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-SEC-DEG_F")
    TON_FG = URIRef("http://qudt.org/vocab/unit/TON_FG")
    CentiM_H20_4DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_H20_4DEG_C")
    LB_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC-PSI")
    DecaM3 = URIRef("http://qudt.org/vocab/unit/DecaM3")
    GigaOHM_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-M")
    CentiMOL_PER_L = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-L")
    HZ_PER_T = URIRef("http://qudt.org/vocab/unit/HZ-PER-T")
    KiloPA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-M")
    MilliSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-SEC")
    KAT_PER_L = URIRef("http://qudt.org/vocab/unit/KAT-PER-L")
    MilliGM_HR_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M3-L")
    SUSCEPTIBILITY_MAG = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_MAG")
    DeciB_MilliW = URIRef("http://qudt.org/vocab/unit/DeciB-MilliW")
    MegaGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-HA")
    MilliGM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M")
    N = URIRef("http://qudt.org/vocab/unit/N")
    GM_PER_M3_PA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-PA-SEC")
    KiloV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive-HR")
    RAYL = URIRef("http://qudt.org/vocab/unit/RAYL")
    MHO = URIRef("http://qudt.org/vocab/unit/MHO")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    M2_PER_HZ_DEG = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ-DEG")
    GAL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-SEC")
    PERMEABILITY_EM_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_EM_REL")
    V_PER_BAR = URIRef("http://qudt.org/vocab/unit/V-PER-BAR")
    SLUG_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT-SEC")
    MilliM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-HR")
    N_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-PER-RAD")
    NAT = URIRef("http://qudt.org/vocab/unit/NAT")
    PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-PER-SEC")
    MicroM3 = URIRef("http://qudt.org/vocab/unit/MicroM3")
    GigaOHM = URIRef("http://qudt.org/vocab/unit/GigaOHM")
    RPK = URIRef("http://qudt.org/vocab/unit/RPK")
    GibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M")
    MegaS_PER_M = URIRef("http://qudt.org/vocab/unit/MegaS-PER-M")
    PINT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-SEC")
    NanoH = URIRef("http://qudt.org/vocab/unit/NanoH")
    GigaJ = URIRef("http://qudt.org/vocab/unit/GigaJ")
    W_PER_SR = URIRef("http://qudt.org/vocab/unit/W-PER-SR")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    Gs = URIRef("http://qudt.org/vocab/unit/Gs")
    MegaA = URIRef("http://qudt.org/vocab/unit/MegaA")
    N_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-PER-RAD")
    PicoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-KiloGM")
    KiloOHM_M = URIRef("http://qudt.org/vocab/unit/KiloOHM-M")
    GAL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-MIN")
    KiloA_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M2")
    PicoC = URIRef("http://qudt.org/vocab/unit/PicoC")
    AT_PER_IN = URIRef("http://qudt.org/vocab/unit/AT-PER-IN")
    DeciB_M = URIRef("http://qudt.org/vocab/unit/DeciB_M")
    K_PER_W = URIRef("http://qudt.org/vocab/unit/K-PER-W")
    CentiM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN")
    DeciL = URIRef("http://qudt.org/vocab/unit/DeciL")
    IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN3-PER-SEC")
    MilliM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-KiloGM")
    PERCENT_FT_SEC_PER_LB = URIRef("http://qudt.org/vocab/unit/PERCENT-FT-SEC-PER-LB")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    KiloPA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-MilliM")
    FARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/FARAD-PER-KiloM")
    KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-SEC2")
    FT_LA = URIRef("http://qudt.org/vocab/unit/FT-LA")
    LB_MIN_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-GAL_UK")
    SUSCEPTIBILITY_ELEC = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_ELEC")
    CAL_TH_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2")
    BBL_UK_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-HR")
    MilliN_M = URIRef("http://qudt.org/vocab/unit/MilliN-M")
    MI3 = URIRef("http://qudt.org/vocab/unit/MI3")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    MilliH = URIRef("http://qudt.org/vocab/unit/MilliH")
    BAR_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/BAR-PER-DEG_C")
    GAL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-SEC")
    KiloN_M = URIRef("http://qudt.org/vocab/unit/KiloN-M")
    PPTM_PER_K = URIRef("http://qudt.org/vocab/unit/PPTM-PER-K")
    DeciM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MOL")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    PetaW = URIRef("http://qudt.org/vocab/unit/PetaW")
    GRAIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL_US")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    PicoJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/PicoJ-PER-SEC")
    PicoS_PER_M = URIRef("http://qudt.org/vocab/unit/PicoS-PER-M")
    TON_Metric_PER_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-K")
    B = URIRef("http://qudt.org/vocab/unit/B")
    KiloHZ_M = URIRef("http://qudt.org/vocab/unit/KiloHZ-M")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    MicroC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M3")
    OZ_F_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ_F-PER-IN3")
    CAL_TH_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM-K")
    W_PER_K = URIRef("http://qudt.org/vocab/unit/W-PER-K")
    OZ = URIRef("http://qudt.org/vocab/unit/OZ")
    BTU_IT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_F")
    MegaPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-M3-PER-SEC")
    TON_Assay = URIRef("http://qudt.org/vocab/unit/TON_Assay")
    V_PER_BAR = URIRef("http://qudt.org/vocab/unit/V-PER-BAR")
    KiloA_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M2")
    KiloYR = URIRef("http://qudt.org/vocab/unit/KiloYR")
    FT3_PER_LB = URIRef("http://qudt.org/vocab/unit/FT3-PER-LB")
    KiloLB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-IN2")
    LUX_SEC = URIRef("http://qudt.org/vocab/unit/LUX-SEC")
    CentiPOISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-BAR")
    LB_MIN_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US2")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    L_PER_L = URIRef("http://qudt.org/vocab/unit/L-PER-L")
    PA2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA2-PER-SEC2")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    BAR_PER_K = URIRef("http://qudt.org/vocab/unit/BAR-PER-K")
    TONNE_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN-BAR")
    NanoGM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MicroL")
    SUSCEPTIBILITY_MAG = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_MAG")
    YD2 = URIRef("http://qudt.org/vocab/unit/YD2")
    DEATHS_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000I-YR")
    LB_SEC_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT6")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    FemtoL = URIRef("http://qudt.org/vocab/unit/FemtoL")
    LB_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN2")
    J_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2")
    CAL_IT_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM2-K")
    KiloGM_F_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-SEC")
    OZ_PER_GAL = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL")
    ExaC = URIRef("http://qudt.org/vocab/unit/ExaC")
    PT_BIG = URIRef("http://qudt.org/vocab/unit/PT_BIG")
    LB_HR_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-YD3")
    M_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-V-SEC")
    PINT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-HR")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    KiloBQ = URIRef("http://qudt.org/vocab/unit/KiloBQ")
    MilliL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliL-PER-L")
    ATM_T = URIRef("http://qudt.org/vocab/unit/ATM_T")
    CAL_IT_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM")
    AU = URIRef("http://qudt.org/vocab/unit/AU")
    M2_PER_K = URIRef("http://qudt.org/vocab/unit/M2-PER-K")
    YR = URIRef("http://qudt.org/vocab/unit/YR")
    V_PER_K = URIRef("http://qudt.org/vocab/unit/V-PER-K")
    Ci = URIRef("http://qudt.org/vocab/unit/Ci")
    EUR_PER_W = URIRef("http://qudt.org/vocab/unit/EUR-PER-W")
    LB_HR_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-YD3")
    MOL_PER_M3_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-PA")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    M3_PER_HR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR")
    CentiBAR = URIRef("http://qudt.org/vocab/unit/CentiBAR")
    V_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/V-SEC-PER-M")
    DeciM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MIN")
    ERLANG = URIRef("http://qudt.org/vocab/unit/ERLANG")
    KiloA_HR = URIRef("http://qudt.org/vocab/unit/KiloA-HR")
    C_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Ab-PER-CentiM2")
    MilliH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-KiloOHM")
    MegaEV_FemtoM = URIRef("http://qudt.org/vocab/unit/MegaEV-FemtoM")
    CentiM_HG_0DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_HG_0DEG_C")
    MOL_LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-MIN")
    Hundredweight_US = URIRef("http://qudt.org/vocab/unit/Hundredweight_US")
    LM_PER_W = URIRef("http://qudt.org/vocab/unit/LM-PER-W")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    GM_MIN_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L2")
    TONNE = URIRef("http://qudt.org/vocab/unit/TONNE")
    GigaV_A = URIRef("http://qudt.org/vocab/unit/GigaV-A")
    W_PER_M_K = URIRef("http://qudt.org/vocab/unit/W-PER-M-K")
    ROD = URIRef("http://qudt.org/vocab/unit/ROD")
    PetaV_A = URIRef("http://qudt.org/vocab/unit/PetaV-A")
    TORR = URIRef("http://qudt.org/vocab/unit/TORR")
    KiloGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-PA-SEC")
    GM_MIN_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M3-CentiM3")
    KiloW_HR = URIRef("http://qudt.org/vocab/unit/KiloW-HR")
    PERM_0DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_0DEG_C")
    DeciL = URIRef("http://qudt.org/vocab/unit/DeciL")
    BQ_PER_L = URIRef("http://qudt.org/vocab/unit/BQ-PER-L")
    BAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-M3-PER-SEC")
    DRAM_UK = URIRef("http://qudt.org/vocab/unit/DRAM_UK")
    NanoS_PER_M = URIRef("http://qudt.org/vocab/unit/NanoS-PER-M")
    MOL_PER_L = URIRef("http://qudt.org/vocab/unit/MOL-PER-L")
    PPM = URIRef("http://qudt.org/vocab/unit/PPM")
    MilliGM_MIN_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M3-CentiM3")
    MilliL_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-BAR")
    MegaC = URIRef("http://qudt.org/vocab/unit/MegaC")
    NanoM2 = URIRef("http://qudt.org/vocab/unit/NanoM2")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    A_M2_PER_J_SEC = URIRef("http://qudt.org/vocab/unit/A-M2-PER-J-SEC")
    MilliGM_HR_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M3-L")
    MilliS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MilliS-PER-CentiM")
    TON_Metric_PER_MIN = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN")
    PlanckDensity = URIRef("http://qudt.org/vocab/unit/PlanckDensity")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    BTU_IT_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-SEC-DEG_F")
    DeciTONNE = URIRef("http://qudt.org/vocab/unit/DeciTONNE")
    OZ_VOL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-SEC")
    GM_PER_M2 = URIRef("http://qudt.org/vocab/unit/GM-PER-M2")
    CAL_TH_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2-SEC")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    TON_F_US = URIRef("http://qudt.org/vocab/unit/TON_F_US")
    N_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-M-PER-M2")
    AT_PER_M = URIRef("http://qudt.org/vocab/unit/AT-PER-M")
    MilliH = URIRef("http://qudt.org/vocab/unit/MilliH")
    A_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM2")
    A_PER_M2_K2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2-K2")
    LB_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-MOL-DEG_F")
    NanoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-KiloGM")
    MilliH = URIRef("http://qudt.org/vocab/unit/MilliH")
    PINT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-HR")
    MilliGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-BAR")
    CentiM3_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR")
    GI_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_US-PER-HR")
    KiloGM_PER_J = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-J")
    DeciB_ISO = URIRef("http://qudt.org/vocab/unit/DeciB_ISO")
    M_PER_RAD = URIRef("http://qudt.org/vocab/unit/M-PER-RAD")
    M2_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-V-SEC")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    MilliN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliN-M-PER-M2")
    GibiBIT = URIRef("http://qudt.org/vocab/unit/GibiBIT")
    HectoPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-BAR")
    FemtoGM_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-L")
    NanoM_PER_CentiM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-MegaPA")
    DeciL = URIRef("http://qudt.org/vocab/unit/DeciL")
    KiloTONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloTONNE-PER-YR")
    KiloCAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-GM-K")
    MOL_PER_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-HR")
    MilliGM_HR_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M6")
    KiloPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-BAR")
    W_HR = URIRef("http://qudt.org/vocab/unit/W-HR")
    B_PER_M = URIRef("http://qudt.org/vocab/unit/B-PER-M")
    BFT = URIRef("http://qudt.org/vocab/unit/BFT")
    W_PER_FT2 = URIRef("http://qudt.org/vocab/unit/W-PER-FT2")
    PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-PSI")
    GigaHZ = URIRef("http://qudt.org/vocab/unit/GigaHZ")
    MicroM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroM-PER-SEC")
    SUSCEPTIBILITY_ELEC = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_ELEC")
    BTU_IT_PER_SEC_FT_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT-DEG_R")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    MebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M3")
    NanoS = URIRef("http://qudt.org/vocab/unit/NanoS")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    OZ_F_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ_F-PER-IN3")
    BTU_IT_PER_LB_F_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_R")
    PER_SEC_SR_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR-M2")
    V_PER_K = URIRef("http://qudt.org/vocab/unit/V-PER-K")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    SEC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/SEC-PER-KiloGM")
    MilliMOL = URIRef("http://qudt.org/vocab/unit/MilliMOL")
    MilliGM_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-HR")
    MicroM3_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-MilliL")
    NanoT = URIRef("http://qudt.org/vocab/unit/NanoT")
    FT3_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT3-PER-SEC")
    MilliGM_HR_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M6")
    IU_PER_MilliL = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliL")
    BTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR")
    PDL = URIRef("http://qudt.org/vocab/unit/PDL")
    PSI_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-M3-PER-SEC")
    V_M = URIRef("http://qudt.org/vocab/unit/V-M")
    LB_MIN_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-YD3")
    LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN")
    DEG_C_CentiM = URIRef("http://qudt.org/vocab/unit/DEG_C-CentiM")
    TebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M2")
    M2_PER_HA = URIRef("http://qudt.org/vocab/unit/M2-PER-HA")
    MilliIN = URIRef("http://qudt.org/vocab/unit/MilliIN")
    DEGREE_BRIX = URIRef("http://qudt.org/vocab/unit/DEGREE_BRIX")
    PA_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PA-M2-PER-KiloGM")
    MilliGM = URIRef("http://qudt.org/vocab/unit/MilliGM")
    K2 = URIRef("http://qudt.org/vocab/unit/K2")
    CLO = URIRef("http://qudt.org/vocab/unit/CLO")
    YoctoC = URIRef("http://qudt.org/vocab/unit/YoctoC")
    ST = URIRef("http://qudt.org/vocab/unit/ST")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    PDL_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-SEC-PER-FT2")
    MilliBQ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-GM")
    KiloW_PER_M2_K = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M2-K")
    A_PER_A_HR = URIRef("http://qudt.org/vocab/unit/A-PER-A-HR")
    PERM_US = URIRef("http://qudt.org/vocab/unit/PERM_US")
    LB_HR_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-IN3")
    NanoV = URIRef("http://qudt.org/vocab/unit/NanoV")
    KiloGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-SEC")
    MilliV_PER_M = URIRef("http://qudt.org/vocab/unit/MilliV-PER-M")
    DeciSEC = URIRef("http://qudt.org/vocab/unit/DeciSEC")
    TON_SHORT_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR")
    KiloCAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-GM-K")
    KiloCAL_PER_MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL-DEG_C")
    TON_Metric_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN-K")
    KiloBTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-FT2")
    CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-GM")
    PDL = URIRef("http://qudt.org/vocab/unit/PDL")
    KiloM3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM3-PER-SEC2")
    W_PER_GM = URIRef("http://qudt.org/vocab/unit/W-PER-GM")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    PicoW_PER_CentiM2_L = URIRef("http://qudt.org/vocab/unit/PicoW-PER-CentiM2-L")
    PPTR_VOL = URIRef("http://qudt.org/vocab/unit/PPTR_VOL")
    PPTH_PER_HR = URIRef("http://qudt.org/vocab/unit/PPTH-PER-HR")
    V_PER_PA = URIRef("http://qudt.org/vocab/unit/V-PER-PA")
    J_PER_KiloGM_K_PA = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-PA")
    MHO = URIRef("http://qudt.org/vocab/unit/MHO")
    NUM_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/NUM-PER-MilliM3")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    K_SEC = URIRef("http://qudt.org/vocab/unit/K-SEC")
    KiloMOL_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3-K")
    PERCENT_HR_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-IN3")
    MilliA_HR = URIRef("http://qudt.org/vocab/unit/MilliA-HR")
    MilliW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2")
    MilliOHM_M = URIRef("http://qudt.org/vocab/unit/MilliOHM-M")
    NUM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NUM-PER-MicroL")
    PK_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-MIN")
    MHO = URIRef("http://qudt.org/vocab/unit/MHO")
    W = URIRef("http://qudt.org/vocab/unit/W")
    TON_Metric_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY")
    LB_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-SEC")
    OZ_SEC_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-FT3")
    LB_PER_FT_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-DAY")
    MilliGM_HR_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M3-CentiM3")
    KiloCAL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-MIN")
    KiloM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-HR")
    M2_PER_SR_J = URIRef("http://qudt.org/vocab/unit/M2-PER-SR-J")
    MOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC")
    MilliM_H2O = URIRef("http://qudt.org/vocab/unit/MilliM_H2O")
    L_PER_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-SEC")
    NanoGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2")
    A2_SEC = URIRef("http://qudt.org/vocab/unit/A2-SEC")
    MOL_PER_GM_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-GM-HR")
    MOL_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-DeciM3")
    PERCENT_PER_DektoKiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DektoKiloCount")
    M2_PER_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ2")
    KiloR = URIRef("http://qudt.org/vocab/unit/KiloR")
    PER_TONNE = URIRef("http://qudt.org/vocab/unit/PER-TONNE")
    CentiM_H2O = URIRef("http://qudt.org/vocab/unit/CentiM_H2O")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    IN = URIRef("http://qudt.org/vocab/unit/IN")
    NanoMOL_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL")
    MilliM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-HR")
    PDL_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-FT2")
    PSU = URIRef("http://qudt.org/vocab/unit/PSU")
    PER_T_M = URIRef("http://qudt.org/vocab/unit/PER-T-M")
    PER_M_NanoM = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    K_PER_T = URIRef("http://qudt.org/vocab/unit/K-PER-T")
    KiloJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM")
    MegaN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaN-M-PER-M2")
    KiloJ_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-HR")
    KibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M2")
    PPB = URIRef("http://qudt.org/vocab/unit/PPB")
    KiloN = URIRef("http://qudt.org/vocab/unit/KiloN")
    N_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-PER-KiloGM")
    HK = URIRef("http://qudt.org/vocab/unit/HK")
    QT_US_DRY = URIRef("http://qudt.org/vocab/unit/QT_US_DRY")
    C_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Ab-PER-CentiM2")
    FT_LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2")
    A_Ab_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-CentiM2")
    KiloOHM_M = URIRef("http://qudt.org/vocab/unit/KiloOHM-M")
    KiloGM_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-MilliM2")
    N_M_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-RAD")
    MicroA_PER_K = URIRef("http://qudt.org/vocab/unit/MicroA-PER-K")
    A_HR_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-HR-PER-DEG_C")
    TON_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_US-PER-DAY")
    LB_MIN_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-IN3")
    N = URIRef("http://qudt.org/vocab/unit/N")
    TON_SHORT = URIRef("http://qudt.org/vocab/unit/TON_SHORT")
    BBL_US = URIRef("http://qudt.org/vocab/unit/BBL_US")
    OZ_FT_HR_PER_IN3_LB = URIRef("http://qudt.org/vocab/unit/OZ-FT-HR-PER-IN3-LB")
    OZ_VOL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-HR")
    B = URIRef("http://qudt.org/vocab/unit/B")
    MicroH = URIRef("http://qudt.org/vocab/unit/MicroH")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    L_PER_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-BAR")
    MilliW_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-MilliGM")
    MebiBIT = URIRef("http://qudt.org/vocab/unit/MebiBIT")
    KiloP = URIRef("http://qudt.org/vocab/unit/KiloP")
    W_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-PER-M3")
    YoctoC = URIRef("http://qudt.org/vocab/unit/YoctoC")
    LB_PER_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-DAY")
    OZ_F = URIRef("http://qudt.org/vocab/unit/OZ_F")
    N_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-PER-M3")
    BTU_MEAN = URIRef("http://qudt.org/vocab/unit/BTU_MEAN")
    ERG = URIRef("http://qudt.org/vocab/unit/ERG")
    LB_PER_HR_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-HR-PSI")
    M2_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-PA")
    MilliGM_HR_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M3-L")
    MicroGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-K")
    GM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC-K")
    PicoA_PER_MicroMOL_L = URIRef("http://qudt.org/vocab/unit/PicoA-PER-MicroMOL-L")
    BTU_IT_FT = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT")
    BTU_TH_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC-FT2-DEG_F")
    BTU_TH_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_F")
    KiloWB = URIRef("http://qudt.org/vocab/unit/KiloWB")
    W_SEC = URIRef("http://qudt.org/vocab/unit/W-SEC")
    CH = URIRef("http://qudt.org/vocab/unit/CH")
    PA_PER_M = URIRef("http://qudt.org/vocab/unit/PA-PER-M")
    MilliV_PER_M = URIRef("http://qudt.org/vocab/unit/MilliV-PER-M")
    M3_PER_HA = URIRef("http://qudt.org/vocab/unit/M3-PER-HA")
    V_PER_K = URIRef("http://qudt.org/vocab/unit/V-PER-K")
    PT_BIG = URIRef("http://qudt.org/vocab/unit/PT_BIG")
    ENZ_PER_L = URIRef("http://qudt.org/vocab/unit/ENZ-PER-L")
    MilliBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-KiloGM")
    TebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M2")
    MilliV = URIRef("http://qudt.org/vocab/unit/MilliV")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    HectoPA = URIRef("http://qudt.org/vocab/unit/HectoPA")
    PK_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-DAY")
    W_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/W-PER-CentiM2")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    EV_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/EV-M2-PER-KiloGM")
    M2_PER_N = URIRef("http://qudt.org/vocab/unit/M2-PER-N")
    FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-SEC-DEG_F")
    PPTR_VOL = URIRef("http://qudt.org/vocab/unit/PPTR_VOL")
    DYN_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM3")
    B = URIRef("http://qudt.org/vocab/unit/B")
    M2_PER_M2 = URIRef("http://qudt.org/vocab/unit/M2-PER-M2")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    M2_PER_K = URIRef("http://qudt.org/vocab/unit/M2-PER-K")
    GigaBIT_PER_M = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-M")
    PetaJ = URIRef("http://qudt.org/vocab/unit/PetaJ")
    BIOT = URIRef("http://qudt.org/vocab/unit/BIOT")
    CentiM_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-K")
    MilliGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY")
    MilliW_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM")
    CentiN_M = URIRef("http://qudt.org/vocab/unit/CentiN-M")
    KY = URIRef("http://qudt.org/vocab/unit/KY")
    CAL_IT_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-DEG_C")
    LB_F_IN_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN-PER-IN")
    PERCENT_PER_PA_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-PA-SEC")
    ATM_PER_M = URIRef("http://qudt.org/vocab/unit/ATM-PER-M")
    MilliV = URIRef("http://qudt.org/vocab/unit/MilliV")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    MicroM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroM-PER-SEC")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    W_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M2")
    TON_Metric = URIRef("http://qudt.org/vocab/unit/TON_Metric")
    KiloGM_PER_M_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC2")
    MicroM_PER_K = URIRef("http://qudt.org/vocab/unit/MicroM-PER-K")
    MilliV_PER_M = URIRef("http://qudt.org/vocab/unit/MilliV-PER-M")
    PlanckLength = URIRef("http://qudt.org/vocab/unit/PlanckLength")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    OZ_FT_HR_PER_IN3_LB = URIRef("http://qudt.org/vocab/unit/OZ-FT-HR-PER-IN3-LB")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    QT_US_DRY = URIRef("http://qudt.org/vocab/unit/QT_US_DRY")
    KiloGM_PER_CentiM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-BAR")
    CentiM3_PER_HR_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR-K")
    GI_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_US-PER-SEC")
    DeciM = URIRef("http://qudt.org/vocab/unit/DeciM")
    B = URIRef("http://qudt.org/vocab/unit/B")
    V_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-PER-CentiM")
    SUSCEPTIBILITY_MAG = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_MAG")
    MilliGM_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-HR")
    NanoS = URIRef("http://qudt.org/vocab/unit/NanoS")
    REM_PER_SEC = URIRef("http://qudt.org/vocab/unit/REM-PER-SEC")
    PPB = URIRef("http://qudt.org/vocab/unit/PPB")
    BAR = URIRef("http://qudt.org/vocab/unit/BAR")
    M2_PER_GM_DRY = URIRef("http://qudt.org/vocab/unit/M2-PER-GM_DRY")
    TON_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-DAY")
    MilliGM_MIN_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L-M3")
    GigaW = URIRef("http://qudt.org/vocab/unit/GigaW")
    MicroSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-SEC")
    N_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-M-PER-M2")
    MegaPA = URIRef("http://qudt.org/vocab/unit/MegaPA")
    K_PER_HR = URIRef("http://qudt.org/vocab/unit/K-PER-HR")
    OZ = URIRef("http://qudt.org/vocab/unit/OZ")
    LM_SEC = URIRef("http://qudt.org/vocab/unit/LM-SEC")
    FT3_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT3-PER-DAY")
    PERCENT_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-CentiM3")
    TSP = URIRef("http://qudt.org/vocab/unit/TSP")
    IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN3-PER-SEC")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    L_PER_MIN = URIRef("http://qudt.org/vocab/unit/L-PER-MIN")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    A_HR_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-HR-PER-DEG_C")
    PA_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PA-M2-PER-KiloGM")
    K_PER_W = URIRef("http://qudt.org/vocab/unit/K-PER-W")
    MI_N_PER_HR = URIRef("http://qudt.org/vocab/unit/MI_N-PER-HR")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    NanoM_PER_CentiM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-MegaPA")
    ANGSTROM = URIRef("http://qudt.org/vocab/unit/ANGSTROM")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    DEG_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC")
    KiloC = URIRef("http://qudt.org/vocab/unit/KiloC")
    MilliGM_HR_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M6")
    DEG_C_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-HR")
    MicroW = URIRef("http://qudt.org/vocab/unit/MicroW")
    MilliA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliA-PER-BAR")
    KiloGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-K")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    MicroGM_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L-HR")
    MilliL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-GM")
    GM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-M2-DAY")
    PER_YR = URIRef("http://qudt.org/vocab/unit/PER-YR")
    PSI_IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-IN3-PER-SEC")
    MilliS_PER_M = URIRef("http://qudt.org/vocab/unit/MilliS-PER-M")
    BBL_US_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-SEC")
    MilliC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M2")
    N_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-M-PER-M2")
    OZ_MIN_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN6")
    PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-PSI")
    KiloGM_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-M2")
    KiloMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-SEC")
    H = URIRef("http://qudt.org/vocab/unit/H")
    CentiN = URIRef("http://qudt.org/vocab/unit/CentiN")
    GibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M3")
    KiloGM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM2")
    MOL_PER_L = URIRef("http://qudt.org/vocab/unit/MOL-PER-L")
    J_M_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-M-PER-MOL")
    PERCENT_PER_HR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-HR")
    K = URIRef("http://qudt.org/vocab/unit/K")
    GigaV_A = URIRef("http://qudt.org/vocab/unit/GigaV-A")
    TON_UK = URIRef("http://qudt.org/vocab/unit/TON_UK")
    HectoC = URIRef("http://qudt.org/vocab/unit/HectoC")
    V_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/V-A_Reactive-HR")
    MicroMHO = URIRef("http://qudt.org/vocab/unit/MicroMHO")
    M_PER_YR = URIRef("http://qudt.org/vocab/unit/M-PER-YR")
    KiloGM_PER_M_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC2")
    SLUG_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT-SEC")
    CASES_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-1000I-YR")
    M2_K = URIRef("http://qudt.org/vocab/unit/M2-K")
    KiloCAL_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM-SEC-DEG_C")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    MicroM_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/MicroM-PER-L-DAY")
    MilliM2 = URIRef("http://qudt.org/vocab/unit/MilliM2")
    MegaFLOPS = URIRef("http://qudt.org/vocab/unit/MegaFLOPS")
    LB_SEC_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-YD3")
    TON_SHORT_PER_HR_PSI = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR-PSI")
    LB_IN2_PER_GAL_UK_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-GAL_UK-LB_F-SEC")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    PERCENT_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-CentiM3")
    MilliPA_PER_M = URIRef("http://qudt.org/vocab/unit/MilliPA-PER-M")
    KiloGM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MilliM")
    NAT = URIRef("http://qudt.org/vocab/unit/NAT")
    CARAT = URIRef("http://qudt.org/vocab/unit/CARAT")
    KiloL = URIRef("http://qudt.org/vocab/unit/KiloL")
    CAL_IT_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM")
    MicroC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M2")
    LB_F_PER_YD = URIRef("http://qudt.org/vocab/unit/LB_F-PER-YD")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    MegaBAR = URIRef("http://qudt.org/vocab/unit/MegaBAR")
    PicoW_PER_CentiM2_L = URIRef("http://qudt.org/vocab/unit/PicoW-PER-CentiM2-L")
    C_M2_PER_V = URIRef("http://qudt.org/vocab/unit/C-M2-PER-V")
    MilliL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M3")
    KiloGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-SEC")
    M3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL-SEC")
    MOL_PER_GM_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-GM-HR")
    GAL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-MIN")
    ENZ = URIRef("http://qudt.org/vocab/unit/ENZ")
    PK_US_DRY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY")
    PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-PSI")
    MilliGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-GM")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    V = URIRef("http://qudt.org/vocab/unit/V")
    DEG_R_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-SEC")
    OERSTED = URIRef("http://qudt.org/vocab/unit/OERSTED")
    M3_PER_HA = URIRef("http://qudt.org/vocab/unit/M3-PER-HA")
    MilliJ = URIRef("http://qudt.org/vocab/unit/MilliJ")
    BTU_IT_PER_HR_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2")
    MilliGM_PER_M3_PA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-PA-SEC")
    LB_F_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN")
    MilliL_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-K")
    LB_DEG_R = URIRef("http://qudt.org/vocab/unit/LB-DEG_R")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    N_PER_C = URIRef("http://qudt.org/vocab/unit/N-PER-C")
    CentiBAR = URIRef("http://qudt.org/vocab/unit/CentiBAR")
    FUR = URIRef("http://qudt.org/vocab/unit/FUR")
    KiloM3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM3-PER-SEC2")
    MOL_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-K")
    GM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3-BAR")
    BARN_PER_SR_EV = URIRef("http://qudt.org/vocab/unit/BARN-PER-SR-EV")
    BTU_TH_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_R")
    DEG_R_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-HR")
    PINT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-MIN")
    GigaPA = URIRef("http://qudt.org/vocab/unit/GigaPA")
    MI_US = URIRef("http://qudt.org/vocab/unit/MI_US")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    AttoFARAD = URIRef("http://qudt.org/vocab/unit/AttoFARAD")
    PicoMOL_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L-DAY")
    SLUG_PER_FT3 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT3")
    SUSCEPTIBILITY_MAG = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_MAG")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    DEG_F_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-K")
    IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC")
    TeraW = URIRef("http://qudt.org/vocab/unit/TeraW")
    YR = URIRef("http://qudt.org/vocab/unit/YR")
    M_PER_FARAD = URIRef("http://qudt.org/vocab/unit/M-PER-FARAD")
    NanoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/NanoKAT-PER-L")
    PPB = URIRef("http://qudt.org/vocab/unit/PPB")
    PINT = URIRef("http://qudt.org/vocab/unit/PINT")
    L = URIRef("http://qudt.org/vocab/unit/L")
    NUM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/NUM-PER-M2-DAY")
    KiloGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-SEC")
    YD_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD-PER-DEG_F")
    L_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-M2")
    NUM_PER_HA = URIRef("http://qudt.org/vocab/unit/NUM-PER-HA")
    OHM_CentiM = URIRef("http://qudt.org/vocab/unit/OHM-CentiM")
    PER_EV2 = URIRef("http://qudt.org/vocab/unit/PER-EV2")
    PINT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-SEC")
    MegaBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaBQ-PER-KiloGM")
    C2_M2_PER_J = URIRef("http://qudt.org/vocab/unit/C2-M2-PER-J")
    NanoMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL")
    PINT = URIRef("http://qudt.org/vocab/unit/PINT")
    MilliM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliM-PER-M")
    DEG_C_GROWING_CEREAL_DAY = URIRef("http://qudt.org/vocab/unit/DEG_C_GROWING_CEREAL-DAY")
    CAL_IT_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM-K")
    KiloN = URIRef("http://qudt.org/vocab/unit/KiloN")
    LUX_SEC = URIRef("http://qudt.org/vocab/unit/LUX-SEC")
    N_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M")
    KiloGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC")
    NanoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/NanoFARAD-PER-M")
    MilliGRAY = URIRef("http://qudt.org/vocab/unit/MilliGRAY")
    MicroBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-L")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    MilliV_A_PER_K = URIRef("http://qudt.org/vocab/unit/MilliV-A-PER-K")
    ExaJ = URIRef("http://qudt.org/vocab/unit/ExaJ")
    LB_PER_FT3 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3")
    NUM_PER_PicoL = URIRef("http://qudt.org/vocab/unit/NUM-PER-PicoL")
    MilliMOL_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3-DAY")
    PicoV_A = URIRef("http://qudt.org/vocab/unit/PicoV-A")
    NanoGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-MIN")
    MOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MOL-PER-MOL")
    BTU_IT_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-HR-DEG_F")
    KiloM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM2-PER-SEC2")
    BU_UK = URIRef("http://qudt.org/vocab/unit/BU_UK")
    S_Ab = URIRef("http://qudt.org/vocab/unit/S_Ab")
    MilliRAD_R_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliRAD_R-PER-HR")
    KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloGM-K")
    BU_UK = URIRef("http://qudt.org/vocab/unit/BU_UK")
    M_PER_K = URIRef("http://qudt.org/vocab/unit/M-PER-K")
    PlanckTemperature = URIRef("http://qudt.org/vocab/unit/PlanckTemperature")
    CAL_TH_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM")
    AT = URIRef("http://qudt.org/vocab/unit/AT")
    FT_HG = URIRef("http://qudt.org/vocab/unit/FT_HG")
    KiloGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloGM")
    CentiM3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-BAR")
    KiloV = URIRef("http://qudt.org/vocab/unit/KiloV")
    DIOPTER = URIRef("http://qudt.org/vocab/unit/DIOPTER")
    MilliL_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR")
    PER_T_M = URIRef("http://qudt.org/vocab/unit/PER-T-M")
    N_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-PER-KiloGM")
    L_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-BAR")
    V_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/V-SEC-PER-M")
    M3_PER_MIN = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN")
    NanoMOL_PER_MicroGM_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroGM-HR")
    LB_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC-DEG_F")
    KiloWB = URIRef("http://qudt.org/vocab/unit/KiloWB")
    unit = URIRef("http://qudt.org/vocab/unit")
    MegaN = URIRef("http://qudt.org/vocab/unit/MegaN")
    A_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-PER-CentiM2")
    GM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloGM")
    GM_PER_CentiM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM-BAR")
    CAL_IT_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    DeciM2 = URIRef("http://qudt.org/vocab/unit/DeciM2")
    LB_HR_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-IN3")
    NanoFARAD = URIRef("http://qudt.org/vocab/unit/NanoFARAD")
    LB_MIN_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-YD3")
    QT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-HR")
    LB_PER_YD2 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD2")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    Z = URIRef("http://qudt.org/vocab/unit/Z")
    A_PER_J = URIRef("http://qudt.org/vocab/unit/A-PER-J")
    KY = URIRef("http://qudt.org/vocab/unit/KY")
    QT_US = URIRef("http://qudt.org/vocab/unit/QT_US")
    DEGREE_BAUME = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME")
    CentiL = URIRef("http://qudt.org/vocab/unit/CentiL")
    TON_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_US-PER-DAY")
    MOL_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-SEC")
    GigaBQ = URIRef("http://qudt.org/vocab/unit/GigaBQ")
    GM_PER_K = URIRef("http://qudt.org/vocab/unit/GM-PER-K")
    MicroS_PER_M = URIRef("http://qudt.org/vocab/unit/MicroS-PER-M")
    OZ_PER_YD2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD2")
    GigaPA = URIRef("http://qudt.org/vocab/unit/GigaPA")
    KiloC_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M3")
    BBL_US_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-HR")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    CAL_20DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_20DEG_C")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    LB = URIRef("http://qudt.org/vocab/unit/LB")
    GM_HR_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M6")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    MegaPA_PER_K = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-K")
    MilliMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2")
    MilliGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HA")
    L_PER_K = URIRef("http://qudt.org/vocab/unit/L-PER-K")
    T = URIRef("http://qudt.org/vocab/unit/T")
    OZ_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN3")
    C_PER_MOL = URIRef("http://qudt.org/vocab/unit/C-PER-MOL")
    CentiM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN")
    A_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-M3")
    BU_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-HR")
    BAR = URIRef("http://qudt.org/vocab/unit/BAR")
    CentiBAR = URIRef("http://qudt.org/vocab/unit/CentiBAR")
    MO_MeanJulian = URIRef("http://qudt.org/vocab/unit/MO_MeanJulian")
    MilliM3 = URIRef("http://qudt.org/vocab/unit/MilliM3")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    M3_PER_C = URIRef("http://qudt.org/vocab/unit/M3-PER-C")
    FBM = URIRef("http://qudt.org/vocab/unit/FBM")
    DeciBAR = URIRef("http://qudt.org/vocab/unit/DeciBAR")
    FT_US = URIRef("http://qudt.org/vocab/unit/FT_US")
    MilliGM_HR_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L-CentiM3")
    MilliOHM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-M")
    PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PER-KiloGM")
    DEG_F_PER_BAR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-BAR")
    MilliGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-CentiM2")
    OZ_F_IN = URIRef("http://qudt.org/vocab/unit/OZ_F-IN")
    GM_HR_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L2")
    HectoPA_PER_K = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-K")
    CentiM_PER_KiloYR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-KiloYR")
    EV_PER_M = URIRef("http://qudt.org/vocab/unit/EV-PER-M")
    J_PER_KiloGM_K_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-M3")
    MilliGM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M")
    KiloMIL_Circ = URIRef("http://qudt.org/vocab/unit/KiloMIL_Circ")
    PER_BAR = URIRef("http://qudt.org/vocab/unit/PER-BAR")
    PicoPA_PER_KiloM = URIRef("http://qudt.org/vocab/unit/PicoPA-PER-KiloM")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    MilliGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3")
    TONNE_PER_HA = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA")
    TONNE_PER_M3 = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3")
    KiloM = URIRef("http://qudt.org/vocab/unit/KiloM")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    ERLANG = URIRef("http://qudt.org/vocab/unit/ERLANG")
    TON_Metric_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC-BAR")
    MilliGM_MIN_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M6")
    LB_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN2")
    MegaDOLLAR_US_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MegaDOLLAR_US-PER-FLIGHT")
    KiloGM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-CentiM2")
    BTU_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-MIN")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    PDL_PER_IN2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-IN2")
    BTU_IT_PER_SEC_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_R")
    FT_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-PER-HR")
    PINT_US_DRY = URIRef("http://qudt.org/vocab/unit/PINT_US_DRY")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    V_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-PER-CentiM")
    ExaC = URIRef("http://qudt.org/vocab/unit/ExaC")
    J_PER_M = URIRef("http://qudt.org/vocab/unit/J-PER-M")
    ATM_T_PER_M = URIRef("http://qudt.org/vocab/unit/ATM_T-PER-M")
    PERCENT_PER_POISE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-POISE")
    J_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2")
    TON_US = URIRef("http://qudt.org/vocab/unit/TON_US")
    MegaGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-M3")
    BTU_IT_PER_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL-DEG_F")
    LB_F_FT_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-FT-PER-IN")
    A_M2 = URIRef("http://qudt.org/vocab/unit/A-M2")
    MilliGM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR")
    MilliBAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-L-PER-SEC")
    BBL_UK_PET = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET")
    TeraW = URIRef("http://qudt.org/vocab/unit/TeraW")
    BYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/BYTE-PER-SEC")
    YottaC = URIRef("http://qudt.org/vocab/unit/YottaC")
    DAY_Sidereal = URIRef("http://qudt.org/vocab/unit/DAY_Sidereal")
    KiloV_A_PER_K = URIRef("http://qudt.org/vocab/unit/KiloV-A-PER-K")
    MilliGM_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-DAY")
    PER_WB = URIRef("http://qudt.org/vocab/unit/PER-WB")
    MilliGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-MIN")
    L_PER_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-SEC")
    FT_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC2")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    DEGREE_PLATO = URIRef("http://qudt.org/vocab/unit/DEGREE_PLATO")
    MicroM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM-PER-MilliL")
    YR_Sidereal = URIRef("http://qudt.org/vocab/unit/YR_Sidereal")
    BQ_PER_M2 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M2")
    TON = URIRef("http://qudt.org/vocab/unit/TON")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    MilliA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/MilliA-PER-MilliM")
    K_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/K-PER-SEC2")
    OZ_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN3")
    GigaOHM_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-M")
    GigaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-HR")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    MegaHZ_PER_T = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-T")
    ARE = URIRef("http://qudt.org/vocab/unit/ARE")
    POND = URIRef("http://qudt.org/vocab/unit/POND")
    MilliN = URIRef("http://qudt.org/vocab/unit/MilliN")
    KiloGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-K")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    CentiC = URIRef("http://qudt.org/vocab/unit/CentiC")
    PlanckVolume = URIRef("http://qudt.org/vocab/unit/PlanckVolume")
    MilliL = URIRef("http://qudt.org/vocab/unit/MilliL")
    V_IN2_PER_LB_F = URIRef("http://qudt.org/vocab/unit/V-IN2-PER-LB_F")
    MilliM_HG = URIRef("http://qudt.org/vocab/unit/MilliM_HG")
    MOL_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB")
    KiloGM_PER_M_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC2")
    NanoM2 = URIRef("http://qudt.org/vocab/unit/NanoM2")
    YD2 = URIRef("http://qudt.org/vocab/unit/YD2")
    MilliSV = URIRef("http://qudt.org/vocab/unit/MilliSV")
    MilliM_HG = URIRef("http://qudt.org/vocab/unit/MilliM_HG")
    MilliR_man = URIRef("http://qudt.org/vocab/unit/MilliR_man")
    DYN_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM")
    AC = URIRef("http://qudt.org/vocab/unit/AC")
    CentiM3_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-K")
    DeciM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-SEC")
    MicroG = URIRef("http://qudt.org/vocab/unit/MicroG")
    A_HR = URIRef("http://qudt.org/vocab/unit/A-HR")
    LB_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_US")
    KAT_PER_L = URIRef("http://qudt.org/vocab/unit/KAT-PER-L")
    V_PER_MicroSEC = URIRef("http://qudt.org/vocab/unit/V-PER-MicroSEC")
    LB_FT2_PER_GAL_UK_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-GAL_UK-LB_F-SEC")
    ExbiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M")
    KiloGM_PER_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA")
    OZ_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_US")
    TonEnergy = URIRef("http://qudt.org/vocab/unit/TonEnergy")
    KiloS_PER_M = URIRef("http://qudt.org/vocab/unit/KiloS-PER-M")
    HP_Metric = URIRef("http://qudt.org/vocab/unit/HP_Metric")
    H = URIRef("http://qudt.org/vocab/unit/H")
    LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT2")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    REM = URIRef("http://qudt.org/vocab/unit/REM")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    M = URIRef("http://qudt.org/vocab/unit/M")
    DeciB_PER_M = URIRef("http://qudt.org/vocab/unit/DeciB-PER-M")
    IN_H2O_39dot2DEG_F = URIRef("http://qudt.org/vocab/unit/IN_H2O_39dot2DEG_F")
    KiloGM_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MOL")
    PERM_Metric_0DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_Metric_0DEG_C")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    TON_SHIPPING_US = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_US")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    MicroMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM")
    GM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY-BAR")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    PicoS = URIRef("http://qudt.org/vocab/unit/PicoS")
    DEATHS_PER_MegaINDIV_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-MegaINDIV-YR")
    NUM_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/NUM-PER-MilliGM")
    PK_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-MIN")
    OZ_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ-PER-HR")
    MegaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBIT-PER-SEC")
    KiloGM_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-BAR")
    MilliGM_PER_M3_POISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-POISE")
    CentiMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-KiloGM")
    QT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-DAY")
    PIXEL = URIRef("http://qudt.org/vocab/unit/PIXEL")
    GM_PER_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY")
    MilliL_PER_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-K")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    MegaC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M2")
    KiloC_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M3")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    W_PER_M = URIRef("http://qudt.org/vocab/unit/W-PER-M")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    NAT = URIRef("http://qudt.org/vocab/unit/NAT")
    TeraV_A_Reactive = URIRef("http://qudt.org/vocab/unit/TeraV-A_Reactive")
    GM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2")
    CentiM_PER_KiloYR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-KiloYR")
    KiloGM_F_M_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-CentiM2")
    L_PER_HR = URIRef("http://qudt.org/vocab/unit/L-PER-HR")
    M2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2")
    YD3_PER_HR = URIRef("http://qudt.org/vocab/unit/YD3-PER-HR")
    PER_GM = URIRef("http://qudt.org/vocab/unit/PER-GM")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    V2_PER_K2 = URIRef("http://qudt.org/vocab/unit/V2-PER-K2")
    Quarter_UK = URIRef("http://qudt.org/vocab/unit/Quarter_UK")
    L = URIRef("http://qudt.org/vocab/unit/L")
    LB_IN2_PER_GAL_UK_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-GAL_UK-LB_F-SEC")
    THERM_US = URIRef("http://qudt.org/vocab/unit/THERM_US")
    NanoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/NanoFARAD-PER-M")
    BU_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-DAY")
    MicroGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-K")
    TORR = URIRef("http://qudt.org/vocab/unit/TORR")
    OZ_VOL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-DAY")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-PER-FT2")
    FT_SEC_PER_IN3 = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-IN3")
    KiloW = URIRef("http://qudt.org/vocab/unit/KiloW")
    LB_IN2 = URIRef("http://qudt.org/vocab/unit/LB-IN2")
    BTU_IT_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-IN2-SEC")
    MilliGM_PER_L = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    MilliGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-SEC")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    FemtoSEC = URIRef("http://qudt.org/vocab/unit/FemtoSEC")
    PER_IN3 = URIRef("http://qudt.org/vocab/unit/PER-IN3")
    ExaBIT_PER_M = URIRef("http://qudt.org/vocab/unit/ExaBIT-PER-M")
    TONNE_PER_HR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR")
    W_HR_PER_L = URIRef("http://qudt.org/vocab/unit/W-HR-PER-L")
    L_PER_MOL = URIRef("http://qudt.org/vocab/unit/L-PER-MOL")
    MilliOHM_M = URIRef("http://qudt.org/vocab/unit/MilliOHM-M")
    MicroSV = URIRef("http://qudt.org/vocab/unit/MicroSV")
    KiloGAUSS = URIRef("http://qudt.org/vocab/unit/KiloGAUSS")
    PER_IN2 = URIRef("http://qudt.org/vocab/unit/PER-IN2")
    KiloM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM2-PER-SEC2")
    KiloGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloGM")
    W_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/W-PER-CentiM2")
    M3_PER_HR_K = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-K")
    TONNE_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC-BAR")
    PERCENT_PER_WK = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-WK")
    MOL_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-K")
    PetaBIT = URIRef("http://qudt.org/vocab/unit/PetaBIT")
    MI_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI-PER-MIN")
    BTU_TH_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT3")
    TONNE = URIRef("http://qudt.org/vocab/unit/TONNE")
    NanoGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-MIN")
    P = URIRef("http://qudt.org/vocab/unit/P")
    YD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/YD-PER-SEC2")
    GI = URIRef("http://qudt.org/vocab/unit/GI")
    MilliGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-K")
    MegaJ_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M3")
    N_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M2")
    MilliFARAD = URIRef("http://qudt.org/vocab/unit/MilliFARAD")
    LB_MIN_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-FT3")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    FT2_PER_HR = URIRef("http://qudt.org/vocab/unit/FT2-PER-HR")
    M_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-BAR")
    N_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M")
    ERG_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM")
    CAL_IT_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM")
    DYN_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM2")
    LB_PER_MIN_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN-PSI")
    DeciM2 = URIRef("http://qudt.org/vocab/unit/DeciM2")
    DeciM3_PER_HR = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-HR")
    DEG_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG-PER-HR")
    MIN_Sidereal = URIRef("http://qudt.org/vocab/unit/MIN_Sidereal")
    V_PER_V = URIRef("http://qudt.org/vocab/unit/V-PER-V")
    MilliM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-M3")
    CentiGM = URIRef("http://qudt.org/vocab/unit/CentiGM")
    KiloPA_A = URIRef("http://qudt.org/vocab/unit/KiloPA_A")
    NanoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/NanoW-PER-M2")
    KiloCAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-SEC")
    W = URIRef("http://qudt.org/vocab/unit/W")
    FT = URIRef("http://qudt.org/vocab/unit/FT")
    DEG_C_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-SEC")
    R_man = URIRef("http://qudt.org/vocab/unit/R_man")
    MI_US = URIRef("http://qudt.org/vocab/unit/MI_US")
    CD_PER_M2 = URIRef("http://qudt.org/vocab/unit/CD-PER-M2")
    KiloGM_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM2")
    MegaW_HR = URIRef("http://qudt.org/vocab/unit/MegaW-HR")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    MO_MeanJulian = URIRef("http://qudt.org/vocab/unit/MO_MeanJulian")
    MOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MOL-PER-MOL")
    MilliGM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    CentiM2_PER_ERG = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-ERG")
    DeciC = URIRef("http://qudt.org/vocab/unit/DeciC")
    FT3_PER_LB = URIRef("http://qudt.org/vocab/unit/FT3-PER-LB")
    NanoN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/NanoN-M-PER-M2")
    MilliM4 = URIRef("http://qudt.org/vocab/unit/MilliM4")
    CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM-SEC-DEG_C")
    PERM_US = URIRef("http://qudt.org/vocab/unit/PERM_US")
    DEG_F_SEC_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-SEC-PER-BTU_TH")
    WB_M = URIRef("http://qudt.org/vocab/unit/WB-M")
    KiloGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloGM")
    MegaBAR = URIRef("http://qudt.org/vocab/unit/MegaBAR")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    DRAM_UK = URIRef("http://qudt.org/vocab/unit/DRAM_UK")
    OERSTED = URIRef("http://qudt.org/vocab/unit/OERSTED")
    LB_PER_YD = URIRef("http://qudt.org/vocab/unit/LB-PER-YD")
    KiloOHM_M = URIRef("http://qudt.org/vocab/unit/KiloOHM-M")
    IN4 = URIRef("http://qudt.org/vocab/unit/IN4")
    TeraBIT = URIRef("http://qudt.org/vocab/unit/TeraBIT")
    LB_PER_YD = URIRef("http://qudt.org/vocab/unit/LB-PER-YD")
    TONNE_PER_MIN = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN")
    LB_PER_IN = URIRef("http://qudt.org/vocab/unit/LB-PER-IN")
    GT = URIRef("http://qudt.org/vocab/unit/GT")
    MilliM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM2-PER-SEC")
    CAL_IT_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM2-K")
    TON_Metric_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN-BAR")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    FT3_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN")
    PSI_PER_IN = URIRef("http://qudt.org/vocab/unit/PSI-PER-IN")
    MicroV_A = URIRef("http://qudt.org/vocab/unit/MicroV-A")
    N_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-PER-M3")
    MegaPA = URIRef("http://qudt.org/vocab/unit/MegaPA")
    R_PER_SEC = URIRef("http://qudt.org/vocab/unit/R-PER-SEC")
    LB_SEC_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-YD3")
    GM_MIN_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M3-CentiM3")
    GM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN-BAR")
    J_PER_MOL_K = URIRef("http://qudt.org/vocab/unit/J-PER-MOL-K")
    LB_PER_FT3_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3-DEG_F")
    K_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PER-SEC")
    MilliGM_SEC_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L2")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    W_PER_M2_PA = URIRef("http://qudt.org/vocab/unit/W-PER-M2-PA")
    KiloCAL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-SEC")
    KiloTON_Metric = URIRef("http://qudt.org/vocab/unit/KiloTON_Metric")
    L_PER_MIN = URIRef("http://qudt.org/vocab/unit/L-PER-MIN")
    GI_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_US-PER-SEC")
    DecaGM = URIRef("http://qudt.org/vocab/unit/DecaGM")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    SEC_PER_M = URIRef("http://qudt.org/vocab/unit/SEC-PER-M")
    PicoS = URIRef("http://qudt.org/vocab/unit/PicoS")
    LB_MIN_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-IN3")
    MilliWB = URIRef("http://qudt.org/vocab/unit/MilliWB")
    M3_PER_DAY = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY")
    NanoGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M3")
    KiloA_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M2")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    KiloN_M = URIRef("http://qudt.org/vocab/unit/KiloN-M")
    M3_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-K")
    GM_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/GM-PER-DEG_C")
    MOL_PER_L_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-L-K")
    EV_PER_T = URIRef("http://qudt.org/vocab/unit/EV-PER-T")
    LB_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-MOL-DEG_F")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    MilliL_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-BAR")
    CAL_IT = URIRef("http://qudt.org/vocab/unit/CAL_IT")
    A_PER_J = URIRef("http://qudt.org/vocab/unit/A-PER-J")
    LB_MIN_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-GAL_UK")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    DEG_F_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-HR")
    NanoMOL_PER_MicroMOL_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL-DAY")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    NP_PER_SEC = URIRef("http://qudt.org/vocab/unit/NP-PER-SEC")
    PINT = URIRef("http://qudt.org/vocab/unit/PINT")
    CD_PER_LM = URIRef("http://qudt.org/vocab/unit/CD-PER-LM")
    PlanckTime = URIRef("http://qudt.org/vocab/unit/PlanckTime")
    MicroV_A_PER_K = URIRef("http://qudt.org/vocab/unit/MicroV-A-PER-K")
    MilliJ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-GM")
    A_PER_MilliM = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    NanoM_PER_CentiM_PSI = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-PSI")
    DeciM2 = URIRef("http://qudt.org/vocab/unit/DeciM2")
    PERCENT_PER_10KiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-10KiloCount")
    KiloHZ_M = URIRef("http://qudt.org/vocab/unit/KiloHZ-M")
    MilliGM_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-DAY")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    MilliGM_PER_L_POISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-POISE")
    ATM_PER_M = URIRef("http://qudt.org/vocab/unit/ATM-PER-M")
    LB_MOL = URIRef("http://qudt.org/vocab/unit/LB-MOL")
    N_M2_PER_A = URIRef("http://qudt.org/vocab/unit/N-M2-PER-A")
    NanoV_A = URIRef("http://qudt.org/vocab/unit/NanoV-A")
    IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN3-PER-SEC")
    N_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM2")
    KiloJ_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MOL")
    NanoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L")
    NanoBQ = URIRef("http://qudt.org/vocab/unit/NanoBQ")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    NanoSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-SEC")
    KiloV_A = URIRef("http://qudt.org/vocab/unit/KiloV-A")
    KiloLB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-IN2")
    KiloGM_F = URIRef("http://qudt.org/vocab/unit/KiloGM_F")
    KiloCD = URIRef("http://qudt.org/vocab/unit/KiloCD")
    FT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-DEG_F")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    MilliGM_MIN_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M3-CentiM3")
    K_PER_HR = URIRef("http://qudt.org/vocab/unit/K-PER-HR")
    PERM_0DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_0DEG_C")
    FT2_HR_DEG_F_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F-PER-BTU_IT")
    FT_LB_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-SEC")
    DEG_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG-PER-HR")
    BTU_IT_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_R")
    EU_PER_L = URIRef("http://qudt.org/vocab/unit/EU-PER-L")
    REM_PER_SEC = URIRef("http://qudt.org/vocab/unit/REM-PER-SEC")
    R = URIRef("http://qudt.org/vocab/unit/R")
    MilliBAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-BAR")
    HART = URIRef("http://qudt.org/vocab/unit/HART")
    CentiM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN")
    IN_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-DEG_F")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    S = URIRef("http://qudt.org/vocab/unit/S")
    BBL_US_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-SEC")
    DeciS_PER_M = URIRef("http://qudt.org/vocab/unit/DeciS-PER-M")
    FT_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-PER-HR")
    Hundredweight_US = URIRef("http://qudt.org/vocab/unit/Hundredweight_US")
    MicroC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M3")
    CentiPOISE_PER_K = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-K")
    PER_WB = URIRef("http://qudt.org/vocab/unit/PER-WB")
    PER_SEC_M2_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2-SR")
    LANGLEY = URIRef("http://qudt.org/vocab/unit/LANGLEY")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    W_SEC = URIRef("http://qudt.org/vocab/unit/W-SEC")
    MicroMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-DAY")
    KiloGM_PER_L = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L")
    NanoGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M2-PA-SEC")
    KiloCAL_TH = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    C_M2 = URIRef("http://qudt.org/vocab/unit/C-M2")
    W_M_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-M-PER-M2-SR")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    DWT = URIRef("http://qudt.org/vocab/unit/DWT")
    W_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-SEC-PER-M2")
    POISE_PER_PA = URIRef("http://qudt.org/vocab/unit/POISE-PER-PA")
    MilliGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-GM")
    CentiM4 = URIRef("http://qudt.org/vocab/unit/CentiM4")
    MicroGM_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L-HR")
    V_PER_MicroSEC = URIRef("http://qudt.org/vocab/unit/V-PER-MicroSEC")
    MilliH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-OHM")
    PFERDESTAERKE = URIRef("http://qudt.org/vocab/unit/PFERDESTAERKE")
    BTU_IT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR-DEG_F")
    RAD_R = URIRef("http://qudt.org/vocab/unit/RAD_R")
    IN = URIRef("http://qudt.org/vocab/unit/IN")
    MilliGM_PER_M3_CentiPOISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-CentiPOISE")
    FT2 = URIRef("http://qudt.org/vocab/unit/FT2")
    PicoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/PicoW-PER-M2")
    MicroJ = URIRef("http://qudt.org/vocab/unit/MicroJ")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    MegaV_A_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A-HR")
    CentiM6 = URIRef("http://qudt.org/vocab/unit/CentiM6")
    L_PER_L = URIRef("http://qudt.org/vocab/unit/L-PER-L")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    S = URIRef("http://qudt.org/vocab/unit/S")
    PK_UK = URIRef("http://qudt.org/vocab/unit/PK_UK")
    DecaM = URIRef("http://qudt.org/vocab/unit/DecaM")
    NanoH_PER_M = URIRef("http://qudt.org/vocab/unit/NanoH-PER-M")
    MilliSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-SEC")
    MilliM4 = URIRef("http://qudt.org/vocab/unit/MilliM4")
    PetaJ = URIRef("http://qudt.org/vocab/unit/PetaJ")
    V_Stat = URIRef("http://qudt.org/vocab/unit/V_Stat")
    ExaBIT_PER_M = URIRef("http://qudt.org/vocab/unit/ExaBIT-PER-M")
    LB_PER_IN3_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3-DEG_F")
    GM_Nitrogen_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Nitrogen-PER-M2-DAY")
    PicoGM_PER_L = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-L")
    AttoSEC = URIRef("http://qudt.org/vocab/unit/AttoSEC")
    MilliA_PER_L_MIN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-L-MIN")
    MilliBAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-L-PER-SEC")
    CLO = URIRef("http://qudt.org/vocab/unit/CLO")
    W = URIRef("http://qudt.org/vocab/unit/W")
    DecaGM = URIRef("http://qudt.org/vocab/unit/DecaGM")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    AttoJ = URIRef("http://qudt.org/vocab/unit/AttoJ")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    DeciC = URIRef("http://qudt.org/vocab/unit/DeciC")
    M_SEC = URIRef("http://qudt.org/vocab/unit/M-SEC")
    KiloGM_PER_M_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-MIN")
    PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-PSI")
    MilliV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliV-PER-MIN")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    GM_PER_MilliL_K = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL-K")
    IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC")
    KiloW = URIRef("http://qudt.org/vocab/unit/KiloW")
    KiloCAL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-SEC")
    KiloGM_PER_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-K")
    C_M2 = URIRef("http://qudt.org/vocab/unit/C-M2")
    KiloGM_M = URIRef("http://qudt.org/vocab/unit/KiloGM-M")
    MegaV_A_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A-HR")
    KiloGM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM2")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    N_M_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-M-PER-KiloGM")
    PERCENT_PER_HectoBAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-HectoBAR")
    MicroW = URIRef("http://qudt.org/vocab/unit/MicroW")
    REV_PER_SEC = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC")
    MegaEV = URIRef("http://qudt.org/vocab/unit/MegaEV")
    KiloJ_PER_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-K")
    NanoM2 = URIRef("http://qudt.org/vocab/unit/NanoM2")
    NanoGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2")
    GM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2")
    CAL_TH_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM-K")
    Standard = URIRef("http://qudt.org/vocab/unit/Standard")
    NAT = URIRef("http://qudt.org/vocab/unit/NAT")
    MicroSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-MIN")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    LB_FT2_PER_GAL_US_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-GAL_US-LB_F-SEC")
    SUSCEPTIBILITY_ELEC = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_ELEC")
    PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PER-SEC2")
    PicoS_PER_M = URIRef("http://qudt.org/vocab/unit/PicoS-PER-M")
    A_Stat = URIRef("http://qudt.org/vocab/unit/A_Stat")
    J_M_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-M-PER-MOL")
    MicroGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-GM")
    TON_Metric_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR-BAR")
    MicroGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-DeciL")
    GigaPA = URIRef("http://qudt.org/vocab/unit/GigaPA")
    GigaBasePair = URIRef("http://qudt.org/vocab/unit/GigaBasePair")
    CAL_TH_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-DEG_C")
    MIN_Sidereal = URIRef("http://qudt.org/vocab/unit/MIN_Sidereal")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    SLUG = URIRef("http://qudt.org/vocab/unit/SLUG")
    BTU_IT_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_R")
    MilliL_PER_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-K")
    ExaJ = URIRef("http://qudt.org/vocab/unit/ExaJ")
    THM_EEC = URIRef("http://qudt.org/vocab/unit/THM_EEC")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    PERCENT_RH = URIRef("http://qudt.org/vocab/unit/PERCENT_RH")
    PERCENT_PER_M = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-M")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    NUM_PER_PicoL = URIRef("http://qudt.org/vocab/unit/NUM-PER-PicoL")
    MicroPOISE = URIRef("http://qudt.org/vocab/unit/MicroPOISE")
    N_M_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-M")
    MilliGM_HR_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L2")
    KiloL = URIRef("http://qudt.org/vocab/unit/KiloL")
    NanoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MilliL")
    KiloGM_PER_M_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-DAY")
    MIN = URIRef("http://qudt.org/vocab/unit/MIN")
    MilliL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-KiloGM")
    NanoMOL_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-GM-SEC")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    DYN_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-CentiM")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    TON_Metric = URIRef("http://qudt.org/vocab/unit/TON_Metric")
    C_M2_PER_V = URIRef("http://qudt.org/vocab/unit/C-M2-PER-V")
    KiloGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloGM")
    NanoMOL_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L-DAY")
    MicroW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroW-PER-M2")
    GM_HR_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M3-CentiM3")
    MicroFARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-KiloM")
    M3_PER_K = URIRef("http://qudt.org/vocab/unit/M3-PER-K")
    KiloGM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-K")
    CD_PER_M2 = URIRef("http://qudt.org/vocab/unit/CD-PER-M2")
    M_PER_RAD = URIRef("http://qudt.org/vocab/unit/M-PER-RAD")
    MicroFARAD = URIRef("http://qudt.org/vocab/unit/MicroFARAD")
    MicroMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-KiloGM")
    CentiMOL_PER_L = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-L")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    OZ_SEC_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-GAL_UK")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    BTU_TH_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_F")
    N_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M")
    MI2 = URIRef("http://qudt.org/vocab/unit/MI2")
    N_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM2")
    ERG_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM")
    MilliN = URIRef("http://qudt.org/vocab/unit/MilliN")
    PERCENT_MIN_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-YD3")
    KiloGM_PER_M2_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC2")
    V_PER_M2 = URIRef("http://qudt.org/vocab/unit/V-PER-M2")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    GM_HR_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M6")
    RT = URIRef("http://qudt.org/vocab/unit/RT")
    BTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2")
    YD_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD-PER-DEG_F")
    MicroA = URIRef("http://qudt.org/vocab/unit/MicroA")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    MegaSEC = URIRef("http://qudt.org/vocab/unit/MegaSEC")
    GM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloM")
    LB_MIN_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-IN3")
    MicroV_A = URIRef("http://qudt.org/vocab/unit/MicroV-A")
    NanoH_PER_M = URIRef("http://qudt.org/vocab/unit/NanoH-PER-M")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    BTU_IT_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT3")
    IN3_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN3-PER-MIN")
    LB_SEC_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-GAL_US")
    OZ_HR_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-YD3")
    PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-PER-SEC")
    HP = URIRef("http://qudt.org/vocab/unit/HP")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    DeciC = URIRef("http://qudt.org/vocab/unit/DeciC")
    MilliM4 = URIRef("http://qudt.org/vocab/unit/MilliM4")
    MilliM2 = URIRef("http://qudt.org/vocab/unit/MilliM2")
    PA2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA2-PER-SEC2")
    MilliA_IN2_PER_LB_F = URIRef("http://qudt.org/vocab/unit/MilliA-IN2-PER-LB_F")
    Quarter_UK = URIRef("http://qudt.org/vocab/unit/Quarter_UK")
    MilliV_PER_M = URIRef("http://qudt.org/vocab/unit/MilliV-PER-M")
    REV_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC2")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    MicroOHM = URIRef("http://qudt.org/vocab/unit/MicroOHM")
    MOL_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-L-BAR")
    MilliGM_MIN_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M3-L")
    TORR_PER_M = URIRef("http://qudt.org/vocab/unit/TORR-PER-M")
    FT2_HR_DEG_F_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F-PER-BTU_IT")
    YR_TROPICAL = URIRef("http://qudt.org/vocab/unit/YR_TROPICAL")
    MilliW_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-MilliGM")
    GigaOHM = URIRef("http://qudt.org/vocab/unit/GigaOHM")
    KiloGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-BAR")
    SEC_PER_M3_RAD = URIRef("http://qudt.org/vocab/unit/SEC-PER-M3-RAD")
    MicroFARAD = URIRef("http://qudt.org/vocab/unit/MicroFARAD")
    LB_HR_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-FT3")
    LB_IN2_PER_FT3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-FT3-LB_F-SEC")
    KiloMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3")
    GALILEO = URIRef("http://qudt.org/vocab/unit/GALILEO")
    FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F")
    FemtoM = URIRef("http://qudt.org/vocab/unit/FemtoM")
    FT_HR_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-GAL_UK")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    MegaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-HR")
    PER_M_NanoM = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM")
    PER_OZ = URIRef("http://qudt.org/vocab/unit/PER-OZ")
    MilliW = URIRef("http://qudt.org/vocab/unit/MilliW")
    CentiGRAY = URIRef("http://qudt.org/vocab/unit/CentiGRAY")
    MegaOHM_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-M")
    MicroH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-OHM")
    FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-DEG_F")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    Gamma = URIRef("http://qudt.org/vocab/unit/Gamma")
    HP_Boiler = URIRef("http://qudt.org/vocab/unit/HP_Boiler")
    M = URIRef("http://qudt.org/vocab/unit/M")
    MilliGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-HR")
    HectoL = URIRef("http://qudt.org/vocab/unit/HectoL")
    MicroMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MOL")
    CORD = URIRef("http://qudt.org/vocab/unit/CORD")
    R = URIRef("http://qudt.org/vocab/unit/R")
    RAD_R = URIRef("http://qudt.org/vocab/unit/RAD_R")
    FT3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT3-PER-DEG_F")
    RT = URIRef("http://qudt.org/vocab/unit/RT")
    NanoS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/NanoS-PER-CentiM")
    NanoMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-M2-DAY")
    DeciS = URIRef("http://qudt.org/vocab/unit/DeciS")
    OZ_PER_YD2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD2")
    MicroL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroL-PER-L")
    V_PER_SEC = URIRef("http://qudt.org/vocab/unit/V-PER-SEC")
    PER_HR = URIRef("http://qudt.org/vocab/unit/PER-HR")
    LB_PER_YD3 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD3")
    TON_SHORT_PER_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR-DEG_F")
    GI_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_US-PER-HR")
    FT_HR_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-GAL_UK")
    PlanckTime = URIRef("http://qudt.org/vocab/unit/PlanckTime")
    MegaEV_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-CentiM")
    ExaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/ExaJ-PER-SEC")
    LB_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC-DEG_F")
    H_Ab = URIRef("http://qudt.org/vocab/unit/H_Ab")
    FT_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT-PER-DAY")
    LM_SEC = URIRef("http://qudt.org/vocab/unit/LM-SEC")
    OZ_PER_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD3")
    A_PER_J = URIRef("http://qudt.org/vocab/unit/A-PER-J")
    PER_J_M3 = URIRef("http://qudt.org/vocab/unit/PER-J-M3")
    FT_LB_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-MIN")
    K_M_PER_W = URIRef("http://qudt.org/vocab/unit/K-M-PER-W")
    MACH = URIRef("http://qudt.org/vocab/unit/MACH")
    DeciM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-M3")
    REV_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC2")
    CentiM3_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR")
    KiloCAL_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-HR")
    GM_SEC_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M3-L")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    LB_DEG_R = URIRef("http://qudt.org/vocab/unit/LB-DEG_R")
    PERCENT_PER_WK = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-WK")
    YD = URIRef("http://qudt.org/vocab/unit/YD")
    N_M_PER_MIN_Angle = URIRef("http://qudt.org/vocab/unit/N-M-PER-MIN_Angle")
    KiloGM_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-M2")
    DARCY = URIRef("http://qudt.org/vocab/unit/DARCY")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    MegaBAR = URIRef("http://qudt.org/vocab/unit/MegaBAR")
    RHE = URIRef("http://qudt.org/vocab/unit/RHE")
    KiloM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC2")
    MebiBYTE = URIRef("http://qudt.org/vocab/unit/MebiBYTE")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    K_M_PER_W = URIRef("http://qudt.org/vocab/unit/K-M-PER-W")
    NanoBQ_PER_L = URIRef("http://qudt.org/vocab/unit/NanoBQ-PER-L")
    W_PER_M_DEG_C = URIRef("http://qudt.org/vocab/unit/W-PER-M-DEG_C")
    GRAIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL_US")
    TeraBIT = URIRef("http://qudt.org/vocab/unit/TeraBIT")
    ERG_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM2-SEC")
    LB_F_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-FT2")
    NUM_PER_PicoL = URIRef("http://qudt.org/vocab/unit/NUM-PER-PicoL")
    MicroMOL_PER_GM_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM-HR")
    MicroGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-HR")
    PCA = URIRef("http://qudt.org/vocab/unit/PCA")
    Da = URIRef("http://qudt.org/vocab/unit/Da")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    V_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/V-A_Reactive-PER-K")
    DPI = URIRef("http://qudt.org/vocab/unit/DPI")
    FATH = URIRef("http://qudt.org/vocab/unit/FATH")
    MicroFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-M")
    MilliRAD = URIRef("http://qudt.org/vocab/unit/MilliRAD")
    MilliM_HGA = URIRef("http://qudt.org/vocab/unit/MilliM_HGA")
    BTU_IT_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_F")
    PicoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/PicoW-PER-M2")
    A = URIRef("http://qudt.org/vocab/unit/A")
    BIOT = URIRef("http://qudt.org/vocab/unit/BIOT")
    MI_PER_HR = URIRef("http://qudt.org/vocab/unit/MI-PER-HR")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    ERG_PER_G = URIRef("http://qudt.org/vocab/unit/ERG-PER-G")
    ARCSEC = URIRef("http://qudt.org/vocab/unit/ARCSEC")
    NanoMOL_PER_MicroMOL_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL-DAY")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    FRACTION = URIRef("http://qudt.org/vocab/unit/FRACTION")
    HR_Sidereal = URIRef("http://qudt.org/vocab/unit/HR_Sidereal")
    HectoPA = URIRef("http://qudt.org/vocab/unit/HectoPA")
    V_A_Reactive = URIRef("http://qudt.org/vocab/unit/V-A_Reactive")
    POISE = URIRef("http://qudt.org/vocab/unit/POISE")
    BTU_IT_PER_LB_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F")
    FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F")
    BTU_IT_PER_LB_MOL = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-MOL")
    CentiM_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-HR")
    W_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM-SR")
    CASES_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-1000I-YR")
    GM_HR_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M3-L")
    MO_MeanJulian = URIRef("http://qudt.org/vocab/unit/MO_MeanJulian")
    LB_MIN_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-GAL_US")
    GM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM")
    DEGREE_API = URIRef("http://qudt.org/vocab/unit/DEGREE_API")
    MilliGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-HR")
    K_PER_T = URIRef("http://qudt.org/vocab/unit/K-PER-T")
    IN2_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN2-PER-SEC")
    IN_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC2")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    FATH = URIRef("http://qudt.org/vocab/unit/FATH")
    MegaOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-BAR")
    LB_PER_FT_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-HR")
    GT = URIRef("http://qudt.org/vocab/unit/GT")
    OZ_HR_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-GAL_US")
    ExaJ = URIRef("http://qudt.org/vocab/unit/ExaJ")
    MilliGAL = URIRef("http://qudt.org/vocab/unit/MilliGAL")
    KiloGM_F = URIRef("http://qudt.org/vocab/unit/KiloGM_F")
    ERG_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM2-SEC")
    GM_PER_MilliM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM-BAR")
    PK_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-DAY")
    YR_Common = URIRef("http://qudt.org/vocab/unit/YR_Common")
    BBL = URIRef("http://qudt.org/vocab/unit/BBL")
    GAL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-DAY")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    MicroIN = URIRef("http://qudt.org/vocab/unit/MicroIN")
    GibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M3")
    REV_PER_HR = URIRef("http://qudt.org/vocab/unit/REV-PER-HR")
    V_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Ab-PER-CentiM")
    CentiN_M = URIRef("http://qudt.org/vocab/unit/CentiN-M")
    MilliGM = URIRef("http://qudt.org/vocab/unit/MilliGM")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    BTU_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC")
    PERCENT_PER_OHM = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-OHM")
    MegaPA = URIRef("http://qudt.org/vocab/unit/MegaPA")
    ROD = URIRef("http://qudt.org/vocab/unit/ROD")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    TeraW_HR = URIRef("http://qudt.org/vocab/unit/TeraW-HR")
    V2_PER_K2 = URIRef("http://qudt.org/vocab/unit/V2-PER-K2")
    N_M_PER_ARCMIN = URIRef("http://qudt.org/vocab/unit/N-M-PER-ARCMIN")
    PicoMOL_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L-DAY")
    MilliBAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-M3-PER-SEC")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PER-M3-SEC")
    KiloGM_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM2")
    POISE_PER_K = URIRef("http://qudt.org/vocab/unit/POISE-PER-K")
    EV_PER_T = URIRef("http://qudt.org/vocab/unit/EV-PER-T")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    M2_PER_M2 = URIRef("http://qudt.org/vocab/unit/M2-PER-M2")
    GM_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/GM-PER-DEG_C")
    DeciBAR = URIRef("http://qudt.org/vocab/unit/DeciBAR")
    GM_PER_K = URIRef("http://qudt.org/vocab/unit/GM-PER-K")
    FT3 = URIRef("http://qudt.org/vocab/unit/FT3")
    V_Stat_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-CentiM")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    H = URIRef("http://qudt.org/vocab/unit/H")
    GRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/GRAY-PER-HR")
    MegaW_HR = URIRef("http://qudt.org/vocab/unit/MegaW-HR")
    CAL_TH = URIRef("http://qudt.org/vocab/unit/CAL_TH")
    CentiM3_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-CentiM3")
    GM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/GM-PER-HR-K")
    OERSTED_CentiM = URIRef("http://qudt.org/vocab/unit/OERSTED-CentiM")
    TON_Metric_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    EV_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/EV-M2-PER-KiloGM")
    LB = URIRef("http://qudt.org/vocab/unit/LB")
    PER_EV2 = URIRef("http://qudt.org/vocab/unit/PER-EV2")
    PER_GM = URIRef("http://qudt.org/vocab/unit/PER-GM")
    DEG_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG-PER-MIN")
    PK_US_DRY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY")
    V_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V-PER-CentiM")
    MilliV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliV-PER-MIN")
    TeraW = URIRef("http://qudt.org/vocab/unit/TeraW")
    KiloGM_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-PA")
    KiloGM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-CentiM2")
    MI_UK3 = URIRef("http://qudt.org/vocab/unit/MI_UK3")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    FT_LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2")
    MIN_Sidereal = URIRef("http://qudt.org/vocab/unit/MIN_Sidereal")
    FemtoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-KiloGM")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    MegaPA = URIRef("http://qudt.org/vocab/unit/MegaPA")
    KiloN_M_PER_DEG_M = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-DEG-M")
    PlanckMomentum = URIRef("http://qudt.org/vocab/unit/PlanckMomentum")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    AttoJ_SEC = URIRef("http://qudt.org/vocab/unit/AttoJ-SEC")
    MegaJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-KiloGM")
    MilliGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    MI_N_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI_N-PER-MIN")
    W_PER_SR = URIRef("http://qudt.org/vocab/unit/W-PER-SR")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    K_SEC = URIRef("http://qudt.org/vocab/unit/K-SEC")
    MicroFARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-KiloM")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    GM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2")
    ST = URIRef("http://qudt.org/vocab/unit/ST")
    FARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/FARAD-PER-KiloM")
    T_Ab = URIRef("http://qudt.org/vocab/unit/T_Ab")
    OZ_M = URIRef("http://qudt.org/vocab/unit/OZ_M")
    ARCSEC = URIRef("http://qudt.org/vocab/unit/ARCSEC")
    HectoBAR = URIRef("http://qudt.org/vocab/unit/HectoBAR")
    MegaGM = URIRef("http://qudt.org/vocab/unit/MegaGM")
    GM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciL")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    EV_M2 = URIRef("http://qudt.org/vocab/unit/EV-M2")
    LB_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC-DEG_F")
    MilliGM_MIN_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L-M3")
    J = URIRef("http://qudt.org/vocab/unit/J")
    DEGREE_PLATO = URIRef("http://qudt.org/vocab/unit/DEGREE_PLATO")
    GM = URIRef("http://qudt.org/vocab/unit/GM")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    DEATHS_PER_KiloINDIV_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-KiloINDIV-YR")
    WB_M = URIRef("http://qudt.org/vocab/unit/WB-M")
    KiloHZ_M = URIRef("http://qudt.org/vocab/unit/KiloHZ-M")
    NanoGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M3")
    PCA = URIRef("http://qudt.org/vocab/unit/PCA")
    MilliV = URIRef("http://qudt.org/vocab/unit/MilliV")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    BBL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-DAY")
    MOL_PER_M2_SEC_M = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-M")
    MilliL_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-BAR")
    LB_MIN_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-YD3")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    KiloLB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-FT")
    GM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR-BAR")
    PER_SEC_M3 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M3")
    M_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-K")
    OZ_PER_GAL = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL")
    KiloC_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M2")
    KiloR = URIRef("http://qudt.org/vocab/unit/KiloR")
    RAD_PER_HR = URIRef("http://qudt.org/vocab/unit/RAD-PER-HR")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    LB_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-SEC")
    TONNE_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN-K")
    MilliL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    FemtoSEC = URIRef("http://qudt.org/vocab/unit/FemtoSEC")
    GRAIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-M3")
    GM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloM")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    BAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/BAR-PER-BAR")
    LB_SEC_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-YD3")
    FT_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT-PER-DAY")
    ATM_T = URIRef("http://qudt.org/vocab/unit/ATM_T")
    KiloCAL_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-HR")
    N_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-RAD")
    PicoV_A_Reactive = URIRef("http://qudt.org/vocab/unit/PicoV-A_Reactive")
    KiloJ_PER_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-K")
    MilliL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN")
    BU_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-HR")
    DeciM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-DAY")
    TON_Metric = URIRef("http://qudt.org/vocab/unit/TON_Metric")
    LB_F_PER_IN2_DEG_F = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-DEG_F")
    MilliGM_PER_L = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L")
    MilliMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-L")
    MilliGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-DAY")
    BTU_IT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_F")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    BTU_TH_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2")
    BTU_TH_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB")
    C_Ab = URIRef("http://qudt.org/vocab/unit/C_Ab")
    PERM_Metric_0DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_Metric_0DEG_C")
    LB_MIN_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT6")
    THM_US = URIRef("http://qudt.org/vocab/unit/THM_US")
    MegaPA = URIRef("http://qudt.org/vocab/unit/MegaPA")
    N_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM2")
    BTU_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC")
    LB_PER_FT3_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3-DEG_F")
    PER_M_NanoM = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    BTU_IT_PER_LB_F_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_F")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    TON_SHORT = URIRef("http://qudt.org/vocab/unit/TON_SHORT")
    FRACTION = URIRef("http://qudt.org/vocab/unit/FRACTION")
    HR_PER_FT2 = URIRef("http://qudt.org/vocab/unit/HR-PER-FT2")
    OZ_PER_GAL = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL")
    CentiM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY")
    DeciB_PER_M = URIRef("http://qudt.org/vocab/unit/DeciB-PER-M")
    DEG_F_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC2")
    BQ_PER_L = URIRef("http://qudt.org/vocab/unit/BQ-PER-L")
    LB_SEC_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-FT3")
    M_PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PA-PER-SEC")
    HectoPA_PER_HR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-HR")
    SEC_PER_M3_RAD = URIRef("http://qudt.org/vocab/unit/SEC-PER-M3-RAD")
    MilliMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3")
    A_M2 = URIRef("http://qudt.org/vocab/unit/A-M2")
    MIL = URIRef("http://qudt.org/vocab/unit/MIL")
    MicroMOL_PER_MicroMOL_DAY = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MicroMOL-DAY")
    KiloM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC")
    FM = URIRef("http://qudt.org/vocab/unit/FM")
    MilliGM_SEC_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M3-L")
    PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-PER-SEC")
    CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-GM")
    KiloCAL_Mean = URIRef("http://qudt.org/vocab/unit/KiloCAL_Mean")
    PER_BAR = URIRef("http://qudt.org/vocab/unit/PER-BAR")
    MI_US_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/MI_US-PER-SEC2")
    CentiM_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-K")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    MOL_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB")
    M3_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-BAR")
    NanoBQ_PER_L = URIRef("http://qudt.org/vocab/unit/NanoBQ-PER-L")
    SUSCEPTIBILITY_MAG = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_MAG")
    MegaHZ = URIRef("http://qudt.org/vocab/unit/MegaHZ")
    PicoA_PER_MicroMOL_L = URIRef("http://qudt.org/vocab/unit/PicoA-PER-MicroMOL-L")
    MilliGM_HR_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M3-CentiM3")
    KN_PER_SEC = URIRef("http://qudt.org/vocab/unit/KN-PER-SEC")
    PER_SEC_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR")
    KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    EV_PER_K = URIRef("http://qudt.org/vocab/unit/EV-PER-K")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    KiloGM_PER_GigaJ = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-GigaJ")
    BTU_TH_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-SEC")
    CentiM_HG = URIRef("http://qudt.org/vocab/unit/CentiM_HG")
    RichterMagnitude = URIRef("http://qudt.org/vocab/unit/RichterMagnitude")
    PER_T_SEC = URIRef("http://qudt.org/vocab/unit/PER-T-SEC")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    V_Ab = URIRef("http://qudt.org/vocab/unit/V_Ab")
    M_K_PER_W = URIRef("http://qudt.org/vocab/unit/M-K-PER-W")
    KiloOHM = URIRef("http://qudt.org/vocab/unit/KiloOHM")
    MilliR_man = URIRef("http://qudt.org/vocab/unit/MilliR_man")
    SLUG_PER_HR = URIRef("http://qudt.org/vocab/unit/SLUG-PER-HR")
    GI = URIRef("http://qudt.org/vocab/unit/GI")
    SPIN_QUANTUM_NUMBER = URIRef("http://qudt.org/vocab/unit/SPIN_QUANTUM_NUMBER")
    MOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-DAY")
    PA_SEC_PER_K = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-K")
    V = URIRef("http://qudt.org/vocab/unit/V")
    KiloMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    KiloGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-BAR")
    MicroMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM")
    OZ_MIN_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-FT3")
    IN_HG_32DEG_F = URIRef("http://qudt.org/vocab/unit/IN_HG_32DEG_F")
    BBL_UK_PET_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-MIN")
    DeciTON_Metric = URIRef("http://qudt.org/vocab/unit/DeciTON_Metric")
    RAD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC2")
    YR = URIRef("http://qudt.org/vocab/unit/YR")
    W_PER_M2_PA = URIRef("http://qudt.org/vocab/unit/W-PER-M2-PA")
    KiloMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-SEC")
    YD = URIRef("http://qudt.org/vocab/unit/YD")
    FT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-DEG_F")
    C_PER_MOL = URIRef("http://qudt.org/vocab/unit/C-PER-MOL")
    KiloTONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloTONNE-PER-YR")
    HectoBAR = URIRef("http://qudt.org/vocab/unit/HectoBAR")
    PERCENT_HR_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-GAL_US")
    MicroM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroM-PER-SEC")
    KiloM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC-BAR")
    DeciB_MilliW_PER_MegaHZ = URIRef("http://qudt.org/vocab/unit/DeciB-MilliW-PER-MegaHZ")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    MicroL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroL-PER-L")
    J = URIRef("http://qudt.org/vocab/unit/J")
    S_Stat = URIRef("http://qudt.org/vocab/unit/S_Stat")
    A2_SEC = URIRef("http://qudt.org/vocab/unit/A2-SEC")
    SolarMass = URIRef("http://qudt.org/vocab/unit/SolarMass")
    MilliGM_MIN_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L2")
    KiloGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-K")
    KiloMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-KiloGM")
    DEG_F_HR_FT2_PER_BTU_TH_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH-IN")
    PERCENT_PER_DAY = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DAY")
    HART_PER_SEC = URIRef("http://qudt.org/vocab/unit/HART-PER-SEC")
    IN_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN-PER-MIN")
    PER_GigaEV2 = URIRef("http://qudt.org/vocab/unit/PER-GigaEV2")
    MicroM_PER_K = URIRef("http://qudt.org/vocab/unit/MicroM-PER-K")
    J = URIRef("http://qudt.org/vocab/unit/J")
    PERM_Metric_23DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_Metric_23DEG_C")
    MilliJ = URIRef("http://qudt.org/vocab/unit/MilliJ")
    QT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-HR")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    MegaOHM = URIRef("http://qudt.org/vocab/unit/MegaOHM")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    L_PER_MIN = URIRef("http://qudt.org/vocab/unit/L-PER-MIN")
    SLUG_PER_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-SEC")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    MilliPA = URIRef("http://qudt.org/vocab/unit/MilliPA")
    CentiM3_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY-BAR")
    MicroW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroW-PER-M2")
    MicroGM = URIRef("http://qudt.org/vocab/unit/MicroGM")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    MilliMOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2-SEC")
    J_PER_M = URIRef("http://qudt.org/vocab/unit/J-PER-M")
    CentiM6 = URIRef("http://qudt.org/vocab/unit/CentiM6")
    C = URIRef("http://qudt.org/vocab/unit/C")
    MilliM3 = URIRef("http://qudt.org/vocab/unit/MilliM3")
    CAL_IT_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM")
    LB_HR_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-YD3")
    M2_PER_GM = URIRef("http://qudt.org/vocab/unit/M2-PER-GM")
    DeciB_MilliW = URIRef("http://qudt.org/vocab/unit/DeciB-MilliW")
    BTU_IT_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_R")
    M4 = URIRef("http://qudt.org/vocab/unit/M4")
    CASES_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-1000I-YR")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    KiloGM_PER_M3_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-PA")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    GM_PER_DeciM3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3-K")
    MilliGRAY = URIRef("http://qudt.org/vocab/unit/MilliGRAY")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    DYN_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM2")
    Kilo_FT3 = URIRef("http://qudt.org/vocab/unit/Kilo-FT3")
    SEC_PER_M = URIRef("http://qudt.org/vocab/unit/SEC-PER-M")
    A_SEC = URIRef("http://qudt.org/vocab/unit/A-SEC")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    EV_PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/EV-PER-ANGSTROM")
    PERCENT_SEC_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-GAL_US")
    LM_PER_W = URIRef("http://qudt.org/vocab/unit/LM-PER-W")
    V_Ab = URIRef("http://qudt.org/vocab/unit/V_Ab")
    M2_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-V-SEC")
    LB_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT2")
    PA_SEC_PER_L = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-L")
    ANGSTROM = URIRef("http://qudt.org/vocab/unit/ANGSTROM")
    DIOPTER = URIRef("http://qudt.org/vocab/unit/DIOPTER")
    KiloJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-SEC")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    FT_SEC_PER_IN3 = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-IN3")
    HZ_PER_T = URIRef("http://qudt.org/vocab/unit/HZ-PER-T")
    PER_YR = URIRef("http://qudt.org/vocab/unit/PER-YR")
    NanoS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/NanoS-PER-CentiM")
    LB_HR_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-YD3")
    DeciGM = URIRef("http://qudt.org/vocab/unit/DeciGM")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    QT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-SEC")
    DEG_PER_M = URIRef("http://qudt.org/vocab/unit/DEG-PER-M")
    KiloPA_M2_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloPA-M2-PER-GM")
    MilliR = URIRef("http://qudt.org/vocab/unit/MilliR")
    MegaHZ = URIRef("http://qudt.org/vocab/unit/MegaHZ")
    PSI_IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-IN3-PER-SEC")
    MegaC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M2")
    LB_MOL = URIRef("http://qudt.org/vocab/unit/LB-MOL")
    MilliGM = URIRef("http://qudt.org/vocab/unit/MilliGM")
    MicroMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L-HR")
    MilliM_HG = URIRef("http://qudt.org/vocab/unit/MilliM_HG")
    KiloCAL_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM-SEC-DEG_C")
    M3_PER_HR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR")
    KiloCAL_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM-SEC-DEG_C")
    MilliDEG_C = URIRef("http://qudt.org/vocab/unit/MilliDEG_C")
    GM_PER_L = URIRef("http://qudt.org/vocab/unit/GM-PER-L")
    CentiM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC")
    MilliMOL_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3-DAY")
    MilliV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MilliV-A_Reactive")
    MilliGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-SEC")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    DecaARE = URIRef("http://qudt.org/vocab/unit/DecaARE")
    GM_PER_MIN = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN")
    DeciM3 = URIRef("http://qudt.org/vocab/unit/DeciM3")
    MicroBAR = URIRef("http://qudt.org/vocab/unit/MicroBAR")
    M3_PER_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-BAR")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    DEG_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG-PER-HR")
    KiloV_PER_M = URIRef("http://qudt.org/vocab/unit/KiloV-PER-M")
    IN_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC-PSI")
    M_K = URIRef("http://qudt.org/vocab/unit/M-K")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    MOL_PER_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-HR")
    PERMITTIVITY_REL = URIRef("http://qudt.org/vocab/unit/PERMITTIVITY_REL")
    GM_PER_L_PA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-L-PA-SEC")
    KiloBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBYTE-PER-SEC")
    KiloBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT")
    GM_MIN_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L2")
    GigaEV = URIRef("http://qudt.org/vocab/unit/GigaEV")
    J_PER_M = URIRef("http://qudt.org/vocab/unit/J-PER-M")
    J_PER_KiloGM_K_PA = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-PA")
    OHM_M2_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-M2-PER-M")
    HectoPA_PER_K = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-K")
    KiloGM_F_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-MilliM2")
    BTU_IT_PER_LB_F_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_F")
    MegaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-HR")
    Flight = URIRef("http://qudt.org/vocab/unit/Flight")
    MilliM_HG = URIRef("http://qudt.org/vocab/unit/MilliM_HG")
    NanoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-KiloGM")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    MIN_Sidereal = URIRef("http://qudt.org/vocab/unit/MIN_Sidereal")
    TON = URIRef("http://qudt.org/vocab/unit/TON")
    PetaW = URIRef("http://qudt.org/vocab/unit/PetaW")
    PicoGM_PER_GM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-GM")
    PicoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-MilliL")
    MegaV = URIRef("http://qudt.org/vocab/unit/MegaV")
    MilliL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliL-PER-L")
    FT3_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT3-PER-SEC")
    GM = URIRef("http://qudt.org/vocab/unit/GM")
    AttoA = URIRef("http://qudt.org/vocab/unit/AttoA")
    YD3_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD3-PER-MIN")
    PERCENT_HR_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-L")
    MicroGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-MilliL")
    A_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-PER-DEG_C")
    PINT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-DAY")
    GM_PER_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY")
    IN3_PER_LB = URIRef("http://qudt.org/vocab/unit/IN3-PER-LB")
    GM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-L-BAR")
    MilliW_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-MilliGM")
    CentiM3_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY-K")
    KibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M2")
    PER_KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/PER-KiloV-A-HR")
    FT_LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2")
    CFU = URIRef("http://qudt.org/vocab/unit/CFU")
    KiloR = URIRef("http://qudt.org/vocab/unit/KiloR")
    PER_L = URIRef("http://qudt.org/vocab/unit/PER-L")
    MicroGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2")
    MicroV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MicroV-A_Reactive")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    V_PER_IN = URIRef("http://qudt.org/vocab/unit/V-PER-IN")
    TeraW_HR = URIRef("http://qudt.org/vocab/unit/TeraW-HR")
    KiloHZ = URIRef("http://qudt.org/vocab/unit/KiloHZ")
    V_A_Reactive = URIRef("http://qudt.org/vocab/unit/V-A_Reactive")
    TON_SHIPPING_UK = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_UK")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    OZ_PER_IN2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN2")
    PER_DEG_C = URIRef("http://qudt.org/vocab/unit/PER-DEG_C")
    CentiMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-KiloGM")
    C = URIRef("http://qudt.org/vocab/unit/C")
    PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/PER-ANGSTROM")
    MIN = URIRef("http://qudt.org/vocab/unit/MIN")
    DEG_C_CentiM = URIRef("http://qudt.org/vocab/unit/DEG_C-CentiM")
    Hundredweight_UK = URIRef("http://qudt.org/vocab/unit/Hundredweight_UK")
    ATM = URIRef("http://qudt.org/vocab/unit/ATM")
    FemtoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-KiloGM")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    BTU_IT_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_R")
    PicoS = URIRef("http://qudt.org/vocab/unit/PicoS")
    M2_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-BAR")
    J_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2")
    KiloCAL_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM")
    MESH = URIRef("http://qudt.org/vocab/unit/MESH")
    MI_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI-PER-MIN")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    PA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-BAR")
    OZ_FT = URIRef("http://qudt.org/vocab/unit/OZ-FT")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    SLUG_PER_FT = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT")
    SV_PER_MIN = URIRef("http://qudt.org/vocab/unit/SV-PER-MIN")
    J_M2 = URIRef("http://qudt.org/vocab/unit/J-M2")
    QT_US_DRY = URIRef("http://qudt.org/vocab/unit/QT_US_DRY")
    W_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/W-PER-CentiM2")
    OZ_PER_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD3")
    BARN_PER_SR = URIRef("http://qudt.org/vocab/unit/BARN-PER-SR")
    MilliW_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-MilliGM")
    DeciM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MIN")
    PicoW_PER_CentiM2_L = URIRef("http://qudt.org/vocab/unit/PicoW-PER-CentiM2-L")
    KiloGM_PER_M_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC")
    M_K_PER_W = URIRef("http://qudt.org/vocab/unit/M-K-PER-W")
    LB_PER_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-HR")
    HectoPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-L-PER-SEC")
    LB_IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN-PER-SEC")
    KiloM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-HR")
    KiloJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    SEC2 = URIRef("http://qudt.org/vocab/unit/SEC2")
    KiloGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-BAR")
    W_PER_GM = URIRef("http://qudt.org/vocab/unit/W-PER-GM")
    MilliGM_SEC_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M6")
    A_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Stat-PER-CentiM2")
    MegaGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-M3")
    J_PER_MIN = URIRef("http://qudt.org/vocab/unit/J-PER-MIN")
    MOL_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB")
    BTU_IT_PER_SEC_FT_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT-DEG_R")
    KiloGM_M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M2-PER-SEC")
    FemtoMOL = URIRef("http://qudt.org/vocab/unit/FemtoMOL")
    MX = URIRef("http://qudt.org/vocab/unit/MX")
    LB_PER_MIN_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN-PSI")
    OZ_F = URIRef("http://qudt.org/vocab/unit/OZ_F")
    LB_DEG_R = URIRef("http://qudt.org/vocab/unit/LB-DEG_R")
    GM_MIN_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L-CentiM3")
    LB_PER_FT3_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3-PSI")
    PA_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M")
    A_SEC = URIRef("http://qudt.org/vocab/unit/A-SEC")
    HP = URIRef("http://qudt.org/vocab/unit/HP")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    KiloM3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM3-PER-SEC2")
    TON_FG_HR = URIRef("http://qudt.org/vocab/unit/TON_FG-HR")
    DeciC = URIRef("http://qudt.org/vocab/unit/DeciC")
    BTU_IT_PER_LB_F_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_R")
    BTU_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC")
    FemtoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-L")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    PER_LB = URIRef("http://qudt.org/vocab/unit/PER-LB")
    LB_F_IN_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN-PER-IN")
    MicroMOL_PER_GM_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM-HR")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    TON_Metric_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC-K")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    T_SEC = URIRef("http://qudt.org/vocab/unit/T-SEC")
    M4_PER_SEC = URIRef("http://qudt.org/vocab/unit/M4-PER-SEC")
    MilliL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-SEC")
    GigaHZ = URIRef("http://qudt.org/vocab/unit/GigaHZ")
    DEG_F_HR_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_TH")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    BTU_TH_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-SEC")
    SUSCEPTIBILITY_ELEC = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_ELEC")
    M_K_PER_W = URIRef("http://qudt.org/vocab/unit/M-K-PER-W")
    SH = URIRef("http://qudt.org/vocab/unit/SH")
    BTU_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-MIN")
    MilliPA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-BAR")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    MIN = URIRef("http://qudt.org/vocab/unit/MIN")
    FemtoFARAD = URIRef("http://qudt.org/vocab/unit/FemtoFARAD")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    KiloCi = URIRef("http://qudt.org/vocab/unit/KiloCi")
    BTU_MEAN = URIRef("http://qudt.org/vocab/unit/BTU_MEAN")
    PlanckForce = URIRef("http://qudt.org/vocab/unit/PlanckForce")
    T_SEC = URIRef("http://qudt.org/vocab/unit/T-SEC")
    NanoL = URIRef("http://qudt.org/vocab/unit/NanoL")
    N_M_PER_MIN_Angle = URIRef("http://qudt.org/vocab/unit/N-M-PER-MIN_Angle")
    PDL_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/PDL-SEC-PER-IN2")
    MicroM3_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-MilliL")
    M3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC2")
    MilliW_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM-SR")
    KiloGM_PER_KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloMOL")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    SV_PER_SEC = URIRef("http://qudt.org/vocab/unit/SV-PER-SEC")
    K2 = URIRef("http://qudt.org/vocab/unit/K2")
    FUR = URIRef("http://qudt.org/vocab/unit/FUR")
    KiloGM_PER_L = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L")
    KiloM3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM3-PER-SEC2")
    KY = URIRef("http://qudt.org/vocab/unit/KY")
    ElementaryCharge = URIRef("http://qudt.org/vocab/unit/ElementaryCharge")
    FARAD_Stat = URIRef("http://qudt.org/vocab/unit/FARAD_Stat")
    DARCY = URIRef("http://qudt.org/vocab/unit/DARCY")
    YD3 = URIRef("http://qudt.org/vocab/unit/YD3")
    PPQ = URIRef("http://qudt.org/vocab/unit/PPQ")
    MicroH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-KiloOHM")
    PERCENT_PER_DAY = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DAY")
    REM_PER_SEC = URIRef("http://qudt.org/vocab/unit/REM-PER-SEC")
    PINT_UK = URIRef("http://qudt.org/vocab/unit/PINT_UK")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    MOL_PER_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-HR")
    MicroL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroL-PER-L")
    LB_MIN_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-IN3")
    KIP_F = URIRef("http://qudt.org/vocab/unit/KIP_F")
    MI_N_PER_HR = URIRef("http://qudt.org/vocab/unit/MI_N-PER-HR")
    CentiM2_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-CentiM3")
    GI_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-HR")
    MI_UK3 = URIRef("http://qudt.org/vocab/unit/MI_UK3")
    PER_HR = URIRef("http://qudt.org/vocab/unit/PER-HR")
    CentiMOL_PER_L = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-L")
    J_PER_HR = URIRef("http://qudt.org/vocab/unit/J-PER-HR")
    MilliL = URIRef("http://qudt.org/vocab/unit/MilliL")
    MilliW_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM")
    N_M2_PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/N-M2-PER-KiloGM2")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    PER_GigaEV2 = URIRef("http://qudt.org/vocab/unit/PER-GigaEV2")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    Kilo_FT3 = URIRef("http://qudt.org/vocab/unit/Kilo-FT3")
    GM_MIN_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L-M3")
    HZ_M = URIRef("http://qudt.org/vocab/unit/HZ-M")
    PicoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-KiloGM")
    SV_PER_SEC = URIRef("http://qudt.org/vocab/unit/SV-PER-SEC")
    BARN = URIRef("http://qudt.org/vocab/unit/BARN")
    J_M_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-M-PER-MOL")
    KiloW_PER_M_K = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M-K")
    MilliGM_SEC_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M3-L")
    M_PER_RAD = URIRef("http://qudt.org/vocab/unit/M-PER-RAD")
    KiloM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloM-PER-DAY")
    ERLANG = URIRef("http://qudt.org/vocab/unit/ERLANG")
    KiloGM_PER_MegaBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MegaBTU_IT")
    TONNE_PER_DAY = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY")
    W_PER_M2_PA = URIRef("http://qudt.org/vocab/unit/W-PER-M2-PA")
    NUM_PER_M = URIRef("http://qudt.org/vocab/unit/NUM-PER-M")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    CentiM3_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY-BAR")
    CentiMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-KiloGM")
    MilliGM_PER_L = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L")
    MilliGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-BAR")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    LB_F_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-IN2")
    L_PER_HR_K = URIRef("http://qudt.org/vocab/unit/L-PER-HR-K")
    MicroH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-KiloOHM")
    FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-SEC-DEG_F")
    MilliGM_PER_L_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-MilliPA-SEC")
    FT_LA = URIRef("http://qudt.org/vocab/unit/FT-LA")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    PicoSEC = URIRef("http://qudt.org/vocab/unit/PicoSEC")
    MI_PER_HR = URIRef("http://qudt.org/vocab/unit/MI-PER-HR")
    MilliJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-SEC")
    DEATHS_PER_1000000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000000I-YR")
    KiloGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC")
    LB_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN2")
    KN = URIRef("http://qudt.org/vocab/unit/KN")
    BBL_US = URIRef("http://qudt.org/vocab/unit/BBL_US")
    CD_PER_LM = URIRef("http://qudt.org/vocab/unit/CD-PER-LM")
    GI_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-HR")
    PicoPA_PER_KiloM = URIRef("http://qudt.org/vocab/unit/PicoPA-PER-KiloM")
    V_PER_M2 = URIRef("http://qudt.org/vocab/unit/V-PER-M2")
    KiloGM_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM2")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    PSI_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-L-PER-SEC")
    PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-PSI")
    M_PER_MIN = URIRef("http://qudt.org/vocab/unit/M-PER-MIN")
    GI_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_US-PER-MIN")
    NanoBQ = URIRef("http://qudt.org/vocab/unit/NanoBQ")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    GM_PER_M3_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-MilliPA-SEC")
    PK_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-DAY")
    PERM_23DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_23DEG_C")
    DeciM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-DAY")
    TONNE_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN-BAR")
    LB_PER_FT = URIRef("http://qudt.org/vocab/unit/LB-PER-FT")
    MilliMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2-DAY")
    POISE_PER_K = URIRef("http://qudt.org/vocab/unit/POISE-PER-K")
    BBL_UK_PET_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-MIN")
    M_PER_K = URIRef("http://qudt.org/vocab/unit/M-PER-K")
    LB_FT2 = URIRef("http://qudt.org/vocab/unit/LB-FT2")
    PicoMOL_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M3-SEC")
    KiloA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloA-PER-K")
    KiloJ_PER_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-K")
    A_Stat = URIRef("http://qudt.org/vocab/unit/A_Stat")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    NanoMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L-HR")
    MilliMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-L")
    BU_UK = URIRef("http://qudt.org/vocab/unit/BU_UK")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    MegaEV_PER_SpeedOfLight = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-SpeedOfLight")
    J_PER_M4 = URIRef("http://qudt.org/vocab/unit/J-PER-M4")
    PA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-BAR")
    MicroBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-KiloGM")
    MegaBIT = URIRef("http://qudt.org/vocab/unit/MegaBIT")
    MicroGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2")
    CentiM_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-K")
    EV_PER_T = URIRef("http://qudt.org/vocab/unit/EV-PER-T")
    PER_MilliL = URIRef("http://qudt.org/vocab/unit/PER-MilliL")
    A_PER_RAD = URIRef("http://qudt.org/vocab/unit/A-PER-RAD")
    KiloJ_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM-K")
    PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/PER-KiloGM-SEC")
    CD_PER_M2 = URIRef("http://qudt.org/vocab/unit/CD-PER-M2")
    PebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M")
    MicroM_PER_K = URIRef("http://qudt.org/vocab/unit/MicroM-PER-K")
    MilliM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM2-PER-SEC")
    TON_US_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_US-PER-HR")
    R = URIRef("http://qudt.org/vocab/unit/R")
    MilliGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2")
    H = URIRef("http://qudt.org/vocab/unit/H")
    MOHM = URIRef("http://qudt.org/vocab/unit/MOHM")
    L_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-M2")
    L_PER_K = URIRef("http://qudt.org/vocab/unit/L-PER-K")
    PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PER-M3-SEC")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CentiM2-MIN")
    MilliW_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM")
    A_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-M3")
    GM_MIN_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L-M3")
    BAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/BAR-PER-BAR")
    M2_PER_J = URIRef("http://qudt.org/vocab/unit/M2-PER-J")
    CentiMOL = URIRef("http://qudt.org/vocab/unit/CentiMOL")
    SLUG_PER_FT = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT")
    MilliGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-BAR")
    CAL_TH_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM2-K")
    TONNE_PER_HA_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA-YR")
    YD3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD3-PER-DEG_F")
    KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A-HR")
    HZ_PER_T = URIRef("http://qudt.org/vocab/unit/HZ-PER-T")
    BEAT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BEAT-PER-MIN")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    THM_US_PER_HR = URIRef("http://qudt.org/vocab/unit/THM_US-PER-HR")
    LB_PER_FT3 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3")
    KiloGM_PER_GigaJ = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-GigaJ")
    MilliL_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-K")
    MilliW_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-MilliGM")
    TON_Metric_PER_HA = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HA")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    CHAIN_US = URIRef("http://qudt.org/vocab/unit/CHAIN_US")
    MilliT = URIRef("http://qudt.org/vocab/unit/MilliT")
    A_PER_MilliM = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM")
    W_PER_M2_M_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M-SR")
    MegaHZ = URIRef("http://qudt.org/vocab/unit/MegaHZ")
    EUR_PER_M2 = URIRef("http://qudt.org/vocab/unit/EUR-PER-M2")
    OZ_F_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ_F-PER-IN3")
    MicroBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-L")
    ZOLL = URIRef("http://qudt.org/vocab/unit/ZOLL")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    LB_PER_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-HR")
    DEG_F_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-HR")
    BTU_TH_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-SEC-DEG_F")
    MilliS_PER_M = URIRef("http://qudt.org/vocab/unit/MilliS-PER-M")
    MilliGM_MIN_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L-CentiM3")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    PER_J_M3 = URIRef("http://qudt.org/vocab/unit/PER-J-M3")
    DecaPA = URIRef("http://qudt.org/vocab/unit/DecaPA")
    A = URIRef("http://qudt.org/vocab/unit/A")
    MegaTOE = URIRef("http://qudt.org/vocab/unit/MegaTOE")
    AC = URIRef("http://qudt.org/vocab/unit/AC")
    V_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/V-A_Reactive-HR")
    NanoM = URIRef("http://qudt.org/vocab/unit/NanoM")
    A_SEC = URIRef("http://qudt.org/vocab/unit/A-SEC")
    E = URIRef("http://qudt.org/vocab/unit/E")
    PicoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-KiloGM")
    M3_PER_HR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR")
    IN_PER_PSI = URIRef("http://qudt.org/vocab/unit/IN-PER-PSI")
    CentiM2_PER_SR_ERG = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SR-ERG")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    CentiM3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-K")
    T_SEC = URIRef("http://qudt.org/vocab/unit/T-SEC")
    MicroV = URIRef("http://qudt.org/vocab/unit/MicroV")
    MilliIN = URIRef("http://qudt.org/vocab/unit/MilliIN")
    ARCMIN = URIRef("http://qudt.org/vocab/unit/ARCMIN")
    NanoSEC = URIRef("http://qudt.org/vocab/unit/NanoSEC")
    KiloN = URIRef("http://qudt.org/vocab/unit/KiloN")
    PPTR_VOL = URIRef("http://qudt.org/vocab/unit/PPTR_VOL")
    KiloS = URIRef("http://qudt.org/vocab/unit/KiloS")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    MOL_PER_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-HR")
    DecaM = URIRef("http://qudt.org/vocab/unit/DecaM")
    OZ_VOL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-MIN")
    PERM_Metric = URIRef("http://qudt.org/vocab/unit/PERM_Metric")
    MegaBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaBQ-PER-KiloGM")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    N_PER_C = URIRef("http://qudt.org/vocab/unit/N-PER-C")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    BAUD = URIRef("http://qudt.org/vocab/unit/BAUD")
    GM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciL")
    KiloJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM")
    GM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC-K")
    PERCENT_PER_V = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-V")
    DEG_F_HR_FT2_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH")
    M3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC2")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    PER_L = URIRef("http://qudt.org/vocab/unit/PER-L")
    L_PER_MIN = URIRef("http://qudt.org/vocab/unit/L-PER-MIN")
    PER_J2 = URIRef("http://qudt.org/vocab/unit/PER-J2")
    GM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-M2-DAY")
    PicoGM_PER_GM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-GM")
    DYN_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM")
    TeraC = URIRef("http://qudt.org/vocab/unit/TeraC")
    YD2 = URIRef("http://qudt.org/vocab/unit/YD2")
    PPT = URIRef("http://qudt.org/vocab/unit/PPT")
    K_PER_MIN = URIRef("http://qudt.org/vocab/unit/K-PER-MIN")
    SON = URIRef("http://qudt.org/vocab/unit/SON")
    PlanckCurrentDensity = URIRef("http://qudt.org/vocab/unit/PlanckCurrentDensity")
    KiloGM_PER_CentiM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-BAR")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    DEGREE_BAUME_US_LIGHT = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_LIGHT")
    FBM = URIRef("http://qudt.org/vocab/unit/FBM")
    QT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-MIN")
    KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A-HR")
    L_PER_MIN = URIRef("http://qudt.org/vocab/unit/L-PER-MIN")
    MOL_PER_M3_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-PA")
    W_PER_IN2 = URIRef("http://qudt.org/vocab/unit/W-PER-IN2")
    M2_PER_HZ = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ")
    GigaV_A = URIRef("http://qudt.org/vocab/unit/GigaV-A")
    KiloM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-HR")
    KiloGM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-BAR")
    BYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/BYTE-PER-SEC")
    MegaS_PER_M = URIRef("http://qudt.org/vocab/unit/MegaS-PER-M")
    MilliL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC")
    GM_PER_L = URIRef("http://qudt.org/vocab/unit/GM-PER-L")
    GAL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-MIN")
    FT3_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT3-PER-SEC")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    KiloGM_PER_GigaJ = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-GigaJ")
    NanoSEC = URIRef("http://qudt.org/vocab/unit/NanoSEC")
    PERCENT_PER_DecaKiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaKiloCount")
    GM_PER_M3 = URIRef("http://qudt.org/vocab/unit/GM-PER-M3")
    TeraJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/TeraJ-PER-SEC")
    DAY_Sidereal = URIRef("http://qudt.org/vocab/unit/DAY_Sidereal")
    MicroGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-MIN")
    KiloCAL_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM-DEG_C")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    SH = URIRef("http://qudt.org/vocab/unit/SH")
    BTU_IT_PER_HR_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2")
    MilliRAD = URIRef("http://qudt.org/vocab/unit/MilliRAD")
    BTU_TH_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_F")
    GigaW_HR = URIRef("http://qudt.org/vocab/unit/GigaW-HR")
    IN_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC-DEG_F")
    MicroG_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroG-PER-CentiM2")
    BTU_IT_PER_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL-DEG_F")
    MOL_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-DeciM3")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    GigaW_HR = URIRef("http://qudt.org/vocab/unit/GigaW-HR")
    N_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-PER-RAD")
    MilliGM_SEC_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L2")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    KiloPA_M2_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloPA-M2-PER-GM")
    FemtoSEC = URIRef("http://qudt.org/vocab/unit/FemtoSEC")
    ExbiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M")
    M3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-BAR")
    MilliGM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-BAR")
    GM_Carbon_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Carbon-PER-M2-DAY")
    T_SEC = URIRef("http://qudt.org/vocab/unit/T-SEC")
    NanoH = URIRef("http://qudt.org/vocab/unit/NanoH")
    SON = URIRef("http://qudt.org/vocab/unit/SON")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    LB_MOL = URIRef("http://qudt.org/vocab/unit/LB-MOL")
    C_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-CentiM2")
    TON_US = URIRef("http://qudt.org/vocab/unit/TON_US")
    FT_HG = URIRef("http://qudt.org/vocab/unit/FT_HG")
    LB_SEC_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-IN3")
    PER_K = URIRef("http://qudt.org/vocab/unit/PER-K")
    PicoMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L-HR")
    M2_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-PA")
    DEGREE_API = URIRef("http://qudt.org/vocab/unit/DEGREE_API")
    L = URIRef("http://qudt.org/vocab/unit/L")
    THM_US = URIRef("http://qudt.org/vocab/unit/THM_US")
    TONNE_PER_DAY = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY")
    HP_Boiler = URIRef("http://qudt.org/vocab/unit/HP_Boiler")
    M2_PER_N = URIRef("http://qudt.org/vocab/unit/M2-PER-N")
    M2_HZ3 = URIRef("http://qudt.org/vocab/unit/M2-HZ3")
    SV_PER_MIN = URIRef("http://qudt.org/vocab/unit/SV-PER-MIN")
    W_PER_M2_PA = URIRef("http://qudt.org/vocab/unit/W-PER-M2-PA")
    TeraHZ = URIRef("http://qudt.org/vocab/unit/TeraHZ")
    PlanckPower = URIRef("http://qudt.org/vocab/unit/PlanckPower")
    MegaJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-KiloGM")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    KiloBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT")
    PERCENT_SEC_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-YD3")
    M2_PER_SR = URIRef("http://qudt.org/vocab/unit/M2-PER-SR")
    FARAD_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/FARAD_Ab-PER-CentiM")
    V_PER_MicroSEC = URIRef("http://qudt.org/vocab/unit/V-PER-MicroSEC")
    NanoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/NanoFARAD-PER-M")
    NUM_PER_SEC = URIRef("http://qudt.org/vocab/unit/NUM-PER-SEC")
    PA_M0pt5 = URIRef("http://qudt.org/vocab/unit/PA-M0pt5")
    BTU_IT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC")
    KiloCAL_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM-SEC-DEG_C")
    T_SEC = URIRef("http://qudt.org/vocab/unit/T-SEC")
    DeciB_C = URIRef("http://qudt.org/vocab/unit/DeciB_C")
    MI_US2 = URIRef("http://qudt.org/vocab/unit/MI_US2")
    MilliGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN")
    EUR_PER_KiloW = URIRef("http://qudt.org/vocab/unit/EUR-PER-KiloW")
    TeraHZ = URIRef("http://qudt.org/vocab/unit/TeraHZ")
    M3_PER_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-M2")
    THM_US = URIRef("http://qudt.org/vocab/unit/THM_US")
    KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloGM-K")
    PERCENT_PER_PA_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-PA-SEC")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    LB_HR_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-GAL_UK")
    ENZ = URIRef("http://qudt.org/vocab/unit/ENZ")
    MicroFARAD = URIRef("http://qudt.org/vocab/unit/MicroFARAD")
    FT_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC2")
    KiloHZ_M = URIRef("http://qudt.org/vocab/unit/KiloHZ-M")
    BTU_IT_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_R")
    BU_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-DAY")
    BTU_IT_IN_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-SEC-FT2-DEG_F")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    W_HR_PER_L = URIRef("http://qudt.org/vocab/unit/W-HR-PER-L")
    ExaBIT_PER_M = URIRef("http://qudt.org/vocab/unit/ExaBIT-PER-M")
    DecaARE = URIRef("http://qudt.org/vocab/unit/DecaARE")
    KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT")
    TONNE_PER_DAY = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY")
    KiloMOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-MIN")
    BARAD = URIRef("http://qudt.org/vocab/unit/BARAD")
    NanoBQ = URIRef("http://qudt.org/vocab/unit/NanoBQ")
    M_PER_RAD = URIRef("http://qudt.org/vocab/unit/M-PER-RAD")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    BBL_UK_PET_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-DAY")
    MilliJ = URIRef("http://qudt.org/vocab/unit/MilliJ")
    FT3_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN")
    KiloPA = URIRef("http://qudt.org/vocab/unit/KiloPA")
    L_PER_DAY = URIRef("http://qudt.org/vocab/unit/L-PER-DAY")
    PPT = URIRef("http://qudt.org/vocab/unit/PPT")
    W_PER_IN2 = URIRef("http://qudt.org/vocab/unit/W-PER-IN2")
    A = URIRef("http://qudt.org/vocab/unit/A")
    J_PER_M = URIRef("http://qudt.org/vocab/unit/J-PER-M")
    MOMME_Textile = URIRef("http://qudt.org/vocab/unit/MOMME_Textile")
    A_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM2")
    FT2_HR_DEG_F_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F-PER-BTU_IT")
    DeciB_C = URIRef("http://qudt.org/vocab/unit/DeciB_C")
    MicroM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroM-PER-SEC")
    W = URIRef("http://qudt.org/vocab/unit/W")
    TON_Metric_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY-BAR")
    PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/PER-M2-SEC")
    MilliJ = URIRef("http://qudt.org/vocab/unit/MilliJ")
    PER_SEC_M2_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2-SR")
    SUSCEPTIBILITY_MAG = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_MAG")
    AT_PER_M = URIRef("http://qudt.org/vocab/unit/AT-PER-M")
    N_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M3")
    MI_US2 = URIRef("http://qudt.org/vocab/unit/MI_US2")
    PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/PER-MilliM3")
    ExaJ = URIRef("http://qudt.org/vocab/unit/ExaJ")
    PicoGM_PER_GM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-GM")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    PPB = URIRef("http://qudt.org/vocab/unit/PPB")
    BTU_MEAN = URIRef("http://qudt.org/vocab/unit/BTU_MEAN")
    BTU_TH_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-FT2-HR-DEG_F")
    M3_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-BAR")
    PicoS_PER_M = URIRef("http://qudt.org/vocab/unit/PicoS-PER-M")
    LB_SEC_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-IN3")
    FBM = URIRef("http://qudt.org/vocab/unit/FBM")
    FT_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-PER-MIN")
    OZ_VOL_UK = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK")
    TOE = URIRef("http://qudt.org/vocab/unit/TOE")
    KiloYR = URIRef("http://qudt.org/vocab/unit/KiloYR")
    MilliG = URIRef("http://qudt.org/vocab/unit/MilliG")
    KiloM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloM-PER-DAY")
    AU = URIRef("http://qudt.org/vocab/unit/AU")
    CentiPOISE_PER_K = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-K")
    MOL_LB_PER_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-LB")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    ERLANG = URIRef("http://qudt.org/vocab/unit/ERLANG")
    C_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-M2-PER-KiloGM")
    BBL_UK_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-HR")
    L_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/L-PER-MicroMOL")
    PlanckPower = URIRef("http://qudt.org/vocab/unit/PlanckPower")
    GM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-M2-DAY")
    KiloGAUSS = URIRef("http://qudt.org/vocab/unit/KiloGAUSS")
    MilliJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-M2")
    MilliJ = URIRef("http://qudt.org/vocab/unit/MilliJ")
    LB_F_PER_LB = URIRef("http://qudt.org/vocab/unit/LB_F-PER-LB")
    PER_IN3 = URIRef("http://qudt.org/vocab/unit/PER-IN3")
    PER_WK = URIRef("http://qudt.org/vocab/unit/PER-WK")
    QT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_US-PER-MIN")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    OHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/OHM-PER-BAR")
    CAL_20DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_20DEG_C")
    BTU_IT_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC-DEG_F")
    MicroH = URIRef("http://qudt.org/vocab/unit/MicroH")
    POISE = URIRef("http://qudt.org/vocab/unit/POISE")
    YD3_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD3-PER-MIN")
    W_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-PER-M3")
    A2_SEC = URIRef("http://qudt.org/vocab/unit/A2-SEC")
    OHM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/OHM-PER-KiloM")
    BAR_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/BAR-PER-DEG_C")
    MicroPA = URIRef("http://qudt.org/vocab/unit/MicroPA")
    AttoJ_SEC = URIRef("http://qudt.org/vocab/unit/AttoJ-SEC")
    M3_PER_HR_K = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-K")
    TeraW = URIRef("http://qudt.org/vocab/unit/TeraW")
    PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PER-CentiM3")
    NanoFARAD = URIRef("http://qudt.org/vocab/unit/NanoFARAD")
    W_PER_M2_K = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K")
    PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/PER-KiloGM-SEC")
    C_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-M2-PER-KiloGM")
    C_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM3")
    MilliGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN")
    NUM_PER_CentiM_KiloYR = URIRef("http://qudt.org/vocab/unit/NUM-PER-CentiM-KiloYR")
    NanoGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DAY")
    PER_TONNE = URIRef("http://qudt.org/vocab/unit/PER-TONNE")
    LB_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-MOL-DEG_F")
    PicoGM_PER_L = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-L")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    M3_PER_C = URIRef("http://qudt.org/vocab/unit/M3-PER-C")
    KiloGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-BAR")
    MicroBAR = URIRef("http://qudt.org/vocab/unit/MicroBAR")
    MilliGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DeciL")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    PDL_PER_IN2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-IN2")
    GRAIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-M3")
    YR_Sidereal = URIRef("http://qudt.org/vocab/unit/YR_Sidereal")
    FT_HR_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-GAL_US")
    GM_PER_MOL = URIRef("http://qudt.org/vocab/unit/GM-PER-MOL")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    KiloJ_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-DAY")
    ARE = URIRef("http://qudt.org/vocab/unit/ARE")
    PicoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/PicoW-PER-M2")
    A_M2_PER_J_SEC = URIRef("http://qudt.org/vocab/unit/A-M2-PER-J-SEC")
    TON_US_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_US-PER-HR")
    KiloGM_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM2")
    K_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/K-PER-SEC2")
    TON_SHORT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-DEG_F")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    MegaOHM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-KiloM")
    PetaBIT = URIRef("http://qudt.org/vocab/unit/PetaBIT")
    MicroGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-DeciL")
    MilliGM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-K")
    L_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-BAR")
    C_Stat_PER_MOL = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-MOL")
    KiloTONNE = URIRef("http://qudt.org/vocab/unit/KiloTONNE")
    MicroJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroJ-PER-SEC")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    LB_PER_IN = URIRef("http://qudt.org/vocab/unit/LB-PER-IN")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    EV = URIRef("http://qudt.org/vocab/unit/EV")
    CAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-K")
    DYN_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    LB_PER_YD3 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD3")
    NUM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NUM-PER-M3")
    MicroBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-L")
    MilliGM_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-DAY")
    MOL_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-K")
    CH = URIRef("http://qudt.org/vocab/unit/CH")
    MicroM3_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-MilliL")
    TON_Assay = URIRef("http://qudt.org/vocab/unit/TON_Assay")
    LB_F_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-FT2")
    KiloGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY")
    KiloWB = URIRef("http://qudt.org/vocab/unit/KiloWB")
    LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC")
    HectoBAR = URIRef("http://qudt.org/vocab/unit/HectoBAR")
    LUX_SEC = URIRef("http://qudt.org/vocab/unit/LUX-SEC")
    N_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM2")
    V_M = URIRef("http://qudt.org/vocab/unit/V-M")
    MegaPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-L-PER-SEC")
    FT3 = URIRef("http://qudt.org/vocab/unit/FT3")
    M2_HZ3 = URIRef("http://qudt.org/vocab/unit/M2-HZ3")
    PA_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC2")
    EV_PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/EV-PER-ANGSTROM")
    KibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M")
    KiloBQ = URIRef("http://qudt.org/vocab/unit/KiloBQ")
    BTU_IT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR-DEG_F")
    NanoS_PER_M = URIRef("http://qudt.org/vocab/unit/NanoS-PER-M")
    OHM_PER_MI = URIRef("http://qudt.org/vocab/unit/OHM-PER-MI")
    TeraJ = URIRef("http://qudt.org/vocab/unit/TeraJ")
    PA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-BAR")
    PARSEC = URIRef("http://qudt.org/vocab/unit/PARSEC")
    KiloBTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-FT2")
    K_PER_PA = URIRef("http://qudt.org/vocab/unit/K-PER-PA")
    MicroBQ = URIRef("http://qudt.org/vocab/unit/MicroBQ")
    M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/M2-PER-MOL")
    FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-DEG_F")
    MicroFARAD = URIRef("http://qudt.org/vocab/unit/MicroFARAD")
    HeartBeat = URIRef("http://qudt.org/vocab/unit/HeartBeat")
    MicroS_PER_M = URIRef("http://qudt.org/vocab/unit/MicroS-PER-M")
    PERCENT_PER_OHM = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-OHM")
    B = URIRef("http://qudt.org/vocab/unit/B")
    CentiM_H20_4DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_H20_4DEG_C")
    C2_M2_PER_J = URIRef("http://qudt.org/vocab/unit/C2-M2-PER-J")
    GM_PER_M3 = URIRef("http://qudt.org/vocab/unit/GM-PER-M3")
    SLUG_PER_FT2 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT2")
    CD_PER_LM = URIRef("http://qudt.org/vocab/unit/CD-PER-LM")
    PER_SEC_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR")
    DEG_F_SEC_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-SEC-PER-BTU_IT")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    KiloGM_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-YR")
    MOL_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-DeciM3")
    KiloGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    K = URIRef("http://qudt.org/vocab/unit/K")
    BBL_US = URIRef("http://qudt.org/vocab/unit/BBL_US")
    MilliL = URIRef("http://qudt.org/vocab/unit/MilliL")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    NUM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NUM-PER-MicroL")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    NUM_PER_HectoGM = URIRef("http://qudt.org/vocab/unit/NUM-PER-HectoGM")
    BTU_IT_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-SEC-DEG_F")
    MilliDARCY = URIRef("http://qudt.org/vocab/unit/MilliDARCY")
    AttoA = URIRef("http://qudt.org/vocab/unit/AttoA")
    PER_J2 = URIRef("http://qudt.org/vocab/unit/PER-J2")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    KiloEV_PER_MicroM = URIRef("http://qudt.org/vocab/unit/KiloEV-PER-MicroM")
    PERCENT_FT_HR_PER_LB = URIRef("http://qudt.org/vocab/unit/PERCENT-FT-HR-PER-LB")
    GAL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-HR")
    YR_Sidereal = URIRef("http://qudt.org/vocab/unit/YR_Sidereal")
    NUM_PER_M2 = URIRef("http://qudt.org/vocab/unit/NUM-PER-M2")
    PSI_YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-YD3-PER-SEC")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    N_M_PER_M_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-M-RAD")
    KiloM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloM-PER-DAY")
    MicroMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MOL")
    C_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM2")
    GigaBIT = URIRef("http://qudt.org/vocab/unit/GigaBIT")
    MilliGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MilliL")
    FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC")
    DeciB_Z = URIRef("http://qudt.org/vocab/unit/DeciB_Z")
    KiloGM_PER_KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloMOL")
    J_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2-DAY")
    LB_DEG_R = URIRef("http://qudt.org/vocab/unit/LB-DEG_R")
    MilliPA_SEC_PER_K = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-K")
    K = URIRef("http://qudt.org/vocab/unit/K")
    OZ_HR_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-YD3")
    KiloGM_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-YR")
    MilliL_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-BAR")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    MilliGM_PER_L_PA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-PA-SEC")
    YR = URIRef("http://qudt.org/vocab/unit/YR")
    FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-SEC-DEG_F")
    FT_US = URIRef("http://qudt.org/vocab/unit/FT_US")
    GigaBIT_PER_M = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-M")
    LB_HR_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-GAL_US")
    MilliCi = URIRef("http://qudt.org/vocab/unit/MilliCi")
    CM_H2O = URIRef("http://qudt.org/vocab/unit/CM_H2O")
    KiloGM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM2-PER-SEC2")
    MegaGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-HA")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    MilliMOL = URIRef("http://qudt.org/vocab/unit/MilliMOL")
    KiloPA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-MilliM")
    FARAD_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/FARAD_Ab-PER-CentiM")
    ERG_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM2-SEC")
    PERCENT_SEC_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-GAL_UK")
    YoctoC = URIRef("http://qudt.org/vocab/unit/YoctoC")
    J_PER_MIN = URIRef("http://qudt.org/vocab/unit/J-PER-MIN")
    BTU_IT_PER_LB_F_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_F")
    PicoV = URIRef("http://qudt.org/vocab/unit/PicoV")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    DeciM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-M3")
    PicoJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/PicoJ-PER-SEC")
    GM_MIN_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L-CentiM3")
    MilliS = URIRef("http://qudt.org/vocab/unit/MilliS")
    N_M_PER_A = URIRef("http://qudt.org/vocab/unit/N-M-PER-A")
    C_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM2")
    IU_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliGM")
    CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-SEC")
    C_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM3")
    MegaOHM_KiloM = URIRef("http://qudt.org/vocab/unit/MegaOHM-KiloM")
    NP_PER_SEC = URIRef("http://qudt.org/vocab/unit/NP-PER-SEC")
    FemtoC = URIRef("http://qudt.org/vocab/unit/FemtoC")
    MicroM = URIRef("http://qudt.org/vocab/unit/MicroM")
    MilliGM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR")
    TONNE_PER_HA_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA-YR")
    PK_US_DRY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY")
    PER_MILLE_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PSI")
    CFU = URIRef("http://qudt.org/vocab/unit/CFU")
    MilliCD = URIRef("http://qudt.org/vocab/unit/MilliCD")
    MegaPA_M0dot5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0dot5")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    DeciM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MIN")
    KiloL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloL-PER-HR")
    CAL_IT_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM2-K")
    MilliGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-GM")
    CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-SEC")
    PER_IN = URIRef("http://qudt.org/vocab/unit/PER-IN")
    A_Ab_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-CentiM2")
    DeciM3 = URIRef("http://qudt.org/vocab/unit/DeciM3")
    GigaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/GigaC-PER-M3")
    KiloYR = URIRef("http://qudt.org/vocab/unit/KiloYR")
    MegaV_A_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A-HR")
    MicroMOL_PER_GM_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM-HR")
    MicroM = URIRef("http://qudt.org/vocab/unit/MicroM")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    NanoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-KiloGM")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    KIP_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KIP_F-PER-IN2")
    HectoL = URIRef("http://qudt.org/vocab/unit/HectoL")
    QT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_US-PER-DAY")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    TON_Metric_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY")
    MilliGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-GM")
    N = URIRef("http://qudt.org/vocab/unit/N")
    DecaPA = URIRef("http://qudt.org/vocab/unit/DecaPA")
    PER_J_M3 = URIRef("http://qudt.org/vocab/unit/PER-J-M3")
    FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    BU_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-DAY")
    KiloGM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3")
    HectoPA_PER_M = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-M")
    M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/M2-PER-MOL")
    KiloGM_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-M2")
    MilliA_HR_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliA-HR-PER-GM")
    J_PER_T2 = URIRef("http://qudt.org/vocab/unit/J-PER-T2")
    PERCENT_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-M3")
    MicroS = URIRef("http://qudt.org/vocab/unit/MicroS")
    LB_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-DEG_F")
    M2_PER_K = URIRef("http://qudt.org/vocab/unit/M2-PER-K")
    GigaBasePair = URIRef("http://qudt.org/vocab/unit/GigaBasePair")
    K = URIRef("http://qudt.org/vocab/unit/K")
    KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloGM-K")
    M3_PER_HA = URIRef("http://qudt.org/vocab/unit/M3-PER-HA")
    PHOT = URIRef("http://qudt.org/vocab/unit/PHOT")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    KiloM3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM3-PER-SEC2")
    MicroFARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-KiloM")
    IN_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN-PER-MIN")
    DYN_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-CentiM")
    DecaM = URIRef("http://qudt.org/vocab/unit/DecaM")
    DEG2 = URIRef("http://qudt.org/vocab/unit/DEG2")
    PINT_US_DRY = URIRef("http://qudt.org/vocab/unit/PINT_US_DRY")
    MegaEV_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-CentiM")
    MicroGAL_PER_M = URIRef("http://qudt.org/vocab/unit/MicroGAL-PER-M")
    MicroMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L")
    PER_DAY = URIRef("http://qudt.org/vocab/unit/PER-DAY")
    RAD_R = URIRef("http://qudt.org/vocab/unit/RAD_R")
    DEG_F_HR_FT2_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH")
    MilliGM_PER_M3_CentiPOISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-CentiPOISE")
    MicroV = URIRef("http://qudt.org/vocab/unit/MicroV")
    M_KiloGM = URIRef("http://qudt.org/vocab/unit/M-KiloGM")
    M2_PER_SR = URIRef("http://qudt.org/vocab/unit/M2-PER-SR")
    BTU_IT_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-HR-DEG_F")
    CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM-SEC-DEG_C")
    TebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M3")
    BBL_US_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-HR")
    POISE_PER_K = URIRef("http://qudt.org/vocab/unit/POISE-PER-K")
    DeciB_MilliW_PER_MegaHZ = URIRef("http://qudt.org/vocab/unit/DeciB-MilliW-PER-MegaHZ")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    GM_PER_MIN = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN")
    NanoJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoJ-PER-SEC")
    YottaC = URIRef("http://qudt.org/vocab/unit/YottaC")
    TON_Metric_PER_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-BAR")
    LB_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN2")
    GALILEO = URIRef("http://qudt.org/vocab/unit/GALILEO")
    H = URIRef("http://qudt.org/vocab/unit/H")
    TONNE_PER_DAY = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY")
    SLUG_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT-SEC")
    BTU_TH_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC-FT2-DEG_F")
    PERCENT_PER_MO = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MO")
    FT2 = URIRef("http://qudt.org/vocab/unit/FT2")
    N_M_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-M")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    GigaPA_CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/GigaPA-CentiM3-PER-GM")
    NanoS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/NanoS-PER-CentiM")
    TON_US_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_US-PER-HR")
    BTU_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-MIN")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    SV_PER_MIN = URIRef("http://qudt.org/vocab/unit/SV-PER-MIN")
    GI_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-HR")
    LB_MIN_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-GAL_UK")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    PlanckForce = URIRef("http://qudt.org/vocab/unit/PlanckForce")
    MilliL_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-K")
    ExaC = URIRef("http://qudt.org/vocab/unit/ExaC")
    MOL_LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-SEC")
    FUR_Long = URIRef("http://qudt.org/vocab/unit/FUR_Long")
    M = URIRef("http://qudt.org/vocab/unit/M")
    BTU_IT_IN_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-SEC-FT2-DEG_F")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    MilliA_PER_IN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-IN")
    PicoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-MilliL")
    DPI = URIRef("http://qudt.org/vocab/unit/DPI")
    GM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-BAR")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    A_PER_CentiM = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM")
    A_PER_GM = URIRef("http://qudt.org/vocab/unit/A-PER-GM")
    CentiM_HG = URIRef("http://qudt.org/vocab/unit/CentiM_HG")
    FT_LB_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-M2")
    KiloLB_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloLB-PER-HR")
    KiloJ_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MOL")
    MegaPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-BAR")
    PlanckFrequency = URIRef("http://qudt.org/vocab/unit/PlanckFrequency")
    ERG_PER_G = URIRef("http://qudt.org/vocab/unit/ERG-PER-G")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    R = URIRef("http://qudt.org/vocab/unit/R")
    LB_HR_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-FT3")
    KiloCAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-MIN")
    HectoL = URIRef("http://qudt.org/vocab/unit/HectoL")
    BTU_IT = URIRef("http://qudt.org/vocab/unit/BTU_IT")
    KiloGM_PER_L = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L")
    MilliMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-KiloGM")
    BTU_TH_FT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-HR-FT2-DEG_F")
    LB_PER_FT_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-MIN")
    MicroGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-DeciL")
    PER_MilliSEC = URIRef("http://qudt.org/vocab/unit/PER-MilliSEC")
    PER_SEC_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR")
    R_man = URIRef("http://qudt.org/vocab/unit/R_man")
    MicroIN = URIRef("http://qudt.org/vocab/unit/MicroIN")
    S_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/S-M2-PER-MOL")
    MicroL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroL-PER-L")
    DeciM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MOL")
    TON_Metric_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR")
    J_PER_GM = URIRef("http://qudt.org/vocab/unit/J-PER-GM")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    GAL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-SEC")
    IN_HG_60DEG_F = URIRef("http://qudt.org/vocab/unit/IN_HG_60DEG_F")
    CFU = URIRef("http://qudt.org/vocab/unit/CFU")
    BTU_TH_PER_FT2_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-HR")
    MilliC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M3")
    M_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-BAR")
    LB_SEC_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-IN3")
    CAL_TH = URIRef("http://qudt.org/vocab/unit/CAL_TH")
    MilliA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/MilliA-PER-MilliM")
    N_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M3")
    LB_HR_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-IN3")
    PA2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA2-PER-SEC2")
    BTU_IT_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT-PER-FT2-HR-DEG_F")
    IN3 = URIRef("http://qudt.org/vocab/unit/IN3")
    GM_PER_CentiM_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM-SEC")
    GI_UK = URIRef("http://qudt.org/vocab/unit/GI_UK")
    EV_PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/EV-PER-ANGSTROM")
    LB_F_PER_LB = URIRef("http://qudt.org/vocab/unit/LB_F-PER-LB")
    FT3 = URIRef("http://qudt.org/vocab/unit/FT3")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    PERCENT_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEG_C")
    KiloBTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH-PER-HR")
    AttoSEC = URIRef("http://qudt.org/vocab/unit/AttoSEC")
    V = URIRef("http://qudt.org/vocab/unit/V")
    YD3_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD3-PER-MIN")
    MilliMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2-DAY")
    CD_PER_FT2 = URIRef("http://qudt.org/vocab/unit/CD-PER-FT2")
    DEG_PER_M = URIRef("http://qudt.org/vocab/unit/DEG-PER-M")
    KiloGAUSS = URIRef("http://qudt.org/vocab/unit/KiloGAUSS")
    LB_F_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-IN2")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    PA_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-PER-BAR")
    PicoGM_PER_L = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-L")
    PSI_IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-IN3-PER-SEC")
    NanoGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DAY")
    BTU_TH_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_R")
    CentiM_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-BAR")
    CAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-K")
    CD_PER_IN2 = URIRef("http://qudt.org/vocab/unit/CD-PER-IN2")
    GibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M2")
    KiloGM_M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M2-PER-SEC")
    LANGLEY = URIRef("http://qudt.org/vocab/unit/LANGLEY")
    MilliM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-BAR")
    OHM_M2_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-M2-PER-M")
    KiloSEC = URIRef("http://qudt.org/vocab/unit/KiloSEC")
    CAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-MIN")
    LB_FT2 = URIRef("http://qudt.org/vocab/unit/LB-FT2")
    PERCENT_PER_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MilliPA-SEC")
    PINT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-DAY")
    MIN_Angle = URIRef("http://qudt.org/vocab/unit/MIN_Angle")
    L_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-BAR")
    CAL_15_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_15_DEG_C")
    CentiM_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-HR")
    MicroTORR = URIRef("http://qudt.org/vocab/unit/MicroTORR")
    MicroV_A = URIRef("http://qudt.org/vocab/unit/MicroV-A")
    MilliHZ = URIRef("http://qudt.org/vocab/unit/MilliHZ")
    C_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM-SEC")
    PlanckPressure = URIRef("http://qudt.org/vocab/unit/PlanckPressure")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    BBL_UK_PET_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-DAY")
    GigaBasePair = URIRef("http://qudt.org/vocab/unit/GigaBasePair")
    PA_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC2")
    MicroOHM_M = URIRef("http://qudt.org/vocab/unit/MicroOHM-M")
    PA_SEC_PER_L = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-L")
    ZettaC = URIRef("http://qudt.org/vocab/unit/ZettaC")
    KiloJ_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-DAY")
    GigaBIT = URIRef("http://qudt.org/vocab/unit/GigaBIT")
    MegaGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-M3")
    M3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC2")
    A_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-PER-DEG_C")
    EUR_PER_W_SEC = URIRef("http://qudt.org/vocab/unit/EUR-PER-W-SEC")
    V_PER_V = URIRef("http://qudt.org/vocab/unit/V-PER-V")
    GM_PER_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY")
    MilliBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-L")
    OZ_VOL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-HR")
    STILB = URIRef("http://qudt.org/vocab/unit/STILB")
    YR_TROPICAL = URIRef("http://qudt.org/vocab/unit/YR_TROPICAL")
    IU = URIRef("http://qudt.org/vocab/unit/IU")
    OZ_HR_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-FT3")
    MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/MOL-DEG_C")
    MilliM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM2-PER-SEC")
    CAL_20DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_20DEG_C")
    MilliL_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-BAR")
    L_PER_MOL = URIRef("http://qudt.org/vocab/unit/L-PER-MOL")
    IN_HG = URIRef("http://qudt.org/vocab/unit/IN_HG")
    MI = URIRef("http://qudt.org/vocab/unit/MI")
    MOL_PER_L_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-L-K")
    EV = URIRef("http://qudt.org/vocab/unit/EV")
    W_SEC = URIRef("http://qudt.org/vocab/unit/W-SEC")
    PER_MilliL = URIRef("http://qudt.org/vocab/unit/PER-MilliL")
    KiloBAR = URIRef("http://qudt.org/vocab/unit/KiloBAR")
    MegaBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaBTU_IT-PER-HR")
    KiloCAL_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM-DEG_C")
    PER_T_SEC = URIRef("http://qudt.org/vocab/unit/PER-T-SEC")
    GM = URIRef("http://qudt.org/vocab/unit/GM")
    PFUND = URIRef("http://qudt.org/vocab/unit/PFUND")
    BTU_IT_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-IN2-SEC")
    KiloGM_PER_M_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-HR")
    MIL_Circ = URIRef("http://qudt.org/vocab/unit/MIL_Circ")
    MebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M2")
    KiloCAL_IT_PER_HR_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-HR-M-DEG_C")
    GM_PER_L_POISE = URIRef("http://qudt.org/vocab/unit/GM-PER-L-POISE")
    CentiM4 = URIRef("http://qudt.org/vocab/unit/CentiM4")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    GI_UK = URIRef("http://qudt.org/vocab/unit/GI_UK")
    FT_LB_F_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-HR")
    FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-SEC")
    PA_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC2")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    KY = URIRef("http://qudt.org/vocab/unit/KY")
    BU_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-DAY")
    IN2 = URIRef("http://qudt.org/vocab/unit/IN2")
    CAL_TH_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2")
    DEG_F_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC2")
    M3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM")
    DEG_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC")
    PERCENT_PER_MilliM = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MilliM")
    MilliV = URIRef("http://qudt.org/vocab/unit/MilliV")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    PERCENT_MIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-GAL_US")
    DEGREE_BAUME_US_HEAVY = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_HEAVY")
    NanoGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M2-PA-SEC")
    TONNE_PER_HR_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR-K")
    PicoW_PER_CentiM2_L = URIRef("http://qudt.org/vocab/unit/PicoW-PER-CentiM2-L")
    KiloL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloL-PER-HR")
    KiloN_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M2")
    MOL_PER_KiloGM_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-BAR")
    J_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2-DAY")
    BTU_IT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MIN")
    EUR_PER_KiloW_HR = URIRef("http://qudt.org/vocab/unit/EUR-PER-KiloW-HR")
    KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloMOL")
    PERCENT_PER_PA_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-PA-SEC")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    V_A_Reactive = URIRef("http://qudt.org/vocab/unit/V-A_Reactive")
    GAL_IMP = URIRef("http://qudt.org/vocab/unit/GAL_IMP")
    MilliM_PER_DEG_C_M = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DEG_C-M")
    A = URIRef("http://qudt.org/vocab/unit/A")
    MHO_Stat = URIRef("http://qudt.org/vocab/unit/MHO_Stat")
    MicroGRAY = URIRef("http://qudt.org/vocab/unit/MicroGRAY")
    PERCENT_PER_CentiPOISE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-CentiPOISE")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    LA_FT = URIRef("http://qudt.org/vocab/unit/LA_FT")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    OZ_VOL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-DAY")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    PER_BAR = URIRef("http://qudt.org/vocab/unit/PER-BAR")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    KiloBTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH-PER-HR")
    DYN_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM3")
    W_PER_M2_K4 = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K4")
    KiloGM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM2-PER-SEC2")
    FUR_Long = URIRef("http://qudt.org/vocab/unit/FUR_Long")
    FT3_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN")
    STR = URIRef("http://qudt.org/vocab/unit/STR")
    KiloBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT")
    GM_PER_L_PA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-L-PA-SEC")
    MilliMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-L")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    AttoSEC = URIRef("http://qudt.org/vocab/unit/AttoSEC")
    NanoH_PER_M = URIRef("http://qudt.org/vocab/unit/NanoH-PER-M")
    MicroBQ = URIRef("http://qudt.org/vocab/unit/MicroBQ")
    FT_PDL = URIRef("http://qudt.org/vocab/unit/FT-PDL")
    KiloJ_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-HR")
    NanoV_A = URIRef("http://qudt.org/vocab/unit/NanoV-A")
    PIXEL = URIRef("http://qudt.org/vocab/unit/PIXEL")
    BU_US = URIRef("http://qudt.org/vocab/unit/BU_US")
    FT_LA = URIRef("http://qudt.org/vocab/unit/FT-LA")
    MegaHZ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-K")
    PA_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-PER-BAR")
    CentiM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-M3")
    HectoPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-BAR")
    KiloGM_M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M2-PER-SEC")
    GM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3-BAR")
    T = URIRef("http://qudt.org/vocab/unit/T")
    V_PER_MicroSEC = URIRef("http://qudt.org/vocab/unit/V-PER-MicroSEC")
    BTU_IT_PER_LB_F_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_R")
    KiloGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC")
    MilliC = URIRef("http://qudt.org/vocab/unit/MilliC")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    MOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MOL-PER-MOL")
    FT_LB_F_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-HR")
    NanoGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-SEC")
    NanoC = URIRef("http://qudt.org/vocab/unit/NanoC")
    NanoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/NanoFARAD-PER-M")
    BARN_PER_EV = URIRef("http://qudt.org/vocab/unit/BARN-PER-EV")
    CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-SEC")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    MilliM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM2-PER-SEC")
    PER_J2 = URIRef("http://qudt.org/vocab/unit/PER-J2")
    MicroBAR = URIRef("http://qudt.org/vocab/unit/MicroBAR")
    MegaJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-KiloGM")
    PicoMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M3")
    GM_PER_MIN = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN")
    M2_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-K")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    CentiM_HG = URIRef("http://qudt.org/vocab/unit/CentiM_HG")
    YD3_PER_PSI = URIRef("http://qudt.org/vocab/unit/YD3-PER-PSI")
    MegaV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive")
    BTU_TH_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB")
    MilliGM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    PDL_FT = URIRef("http://qudt.org/vocab/unit/PDL-FT")
    PPM = URIRef("http://qudt.org/vocab/unit/PPM")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    ZettaC = URIRef("http://qudt.org/vocab/unit/ZettaC")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    MilliL_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-BAR")
    IN_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN-PER-MIN")
    LB_M = URIRef("http://qudt.org/vocab/unit/LB_M")
    MilliG = URIRef("http://qudt.org/vocab/unit/MilliG")
    BIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BIT-PER-SEC")
    LB_IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN-PER-SEC")
    OZ_PER_FT2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-FT2")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    MegaGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-HA")
    KiloGM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR")
    UNKNOWN = URIRef("http://qudt.org/vocab/unit/UNKNOWN")
    ST = URIRef("http://qudt.org/vocab/unit/ST")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    FT2_PER_HR = URIRef("http://qudt.org/vocab/unit/FT2-PER-HR")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    LB_PER_YD2 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD2")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    GALILEO = URIRef("http://qudt.org/vocab/unit/GALILEO")
    M3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL-SEC")
    KiloCAL = URIRef("http://qudt.org/vocab/unit/KiloCAL")
    KiloGM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    FA = URIRef("http://qudt.org/vocab/unit/FA")
    MicroM_PER_N = URIRef("http://qudt.org/vocab/unit/MicroM-PER-N")
    HectoL = URIRef("http://qudt.org/vocab/unit/HectoL")
    KiloJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM")
    ST = URIRef("http://qudt.org/vocab/unit/ST")
    MOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL-PER-MIN")
    N = URIRef("http://qudt.org/vocab/unit/N")
    KiloMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    MilliM_HGA = URIRef("http://qudt.org/vocab/unit/MilliM_HGA")
    BAUD = URIRef("http://qudt.org/vocab/unit/BAUD")
    RAD_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-KiloGM")
    KiloGM_PER_HA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HA")
    LB_PER_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-PSI")
    LB_MOL = URIRef("http://qudt.org/vocab/unit/LB-MOL")
    MilliL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC")
    MilliGM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-K")
    L_PER_L = URIRef("http://qudt.org/vocab/unit/L-PER-L")
    GM_PER_CentiM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM-BAR")
    PER_J = URIRef("http://qudt.org/vocab/unit/PER-J")
    PPM_PER_K = URIRef("http://qudt.org/vocab/unit/PPM-PER-K")
    NanoGM_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2-DAY")
    L_PER_DAY = URIRef("http://qudt.org/vocab/unit/L-PER-DAY")
    MicroL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroL-PER-L")
    CentiM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL")
    MilliSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-HR")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    BTU_TH_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_R")
    MilliGM_PER_L_POISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-POISE")
    TON_LONG = URIRef("http://qudt.org/vocab/unit/TON_LONG")
    N_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM2")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    ZettaC = URIRef("http://qudt.org/vocab/unit/ZettaC")
    MilliL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-KiloGM")
    GM_PER_CentiM3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3-BAR")
    GAL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-DAY")
    KiloBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloBQ-PER-KiloGM")
    MicroS = URIRef("http://qudt.org/vocab/unit/MicroS")
    PA_M0pt5 = URIRef("http://qudt.org/vocab/unit/PA-M0pt5")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    DARCY = URIRef("http://qudt.org/vocab/unit/DARCY")
    DecaGM = URIRef("http://qudt.org/vocab/unit/DecaGM")
    PlanckMomentum = URIRef("http://qudt.org/vocab/unit/PlanckMomentum")
    MilliBQ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-GM")
    DecaM = URIRef("http://qudt.org/vocab/unit/DecaM")
    IN3 = URIRef("http://qudt.org/vocab/unit/IN3")
    LB_HR_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-GAL_US")
    TONNE_PER_HA = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA")
    MilliMOL_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3-DAY")
    MilliKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MilliKAT-PER-L")
    PSU = URIRef("http://qudt.org/vocab/unit/PSU")
    N_PER_C = URIRef("http://qudt.org/vocab/unit/N-PER-C")
    MebiBYTE = URIRef("http://qudt.org/vocab/unit/MebiBYTE")
    V_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V-PER-CentiM")
    W_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M3")
    V_IN2_PER_LB_F = URIRef("http://qudt.org/vocab/unit/V-IN2-PER-LB_F")
    K_M_PER_W = URIRef("http://qudt.org/vocab/unit/K-M-PER-W")
    KiloOHM_PER_K = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-K")
    CentiM3_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY-BAR")
    KiloV_A = URIRef("http://qudt.org/vocab/unit/KiloV-A")
    PK_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-HR")
    NanoGM_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2-DAY")
    GM_MIN_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M6")
    IN3 = URIRef("http://qudt.org/vocab/unit/IN3")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    LB_F_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-FT2")
    OZ_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ-PER-SEC")
    TON_SHIPPING_US = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_US")
    KiloGM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MilliM")
    LB_PER_IN3 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3")
    failures_in_time = URIRef("http://qudt.org/vocab/unit/failures-in-time")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    DeciS = URIRef("http://qudt.org/vocab/unit/DeciS")
    MicroGM_PER_CentiM2_WK = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2-WK")
    LA_FT = URIRef("http://qudt.org/vocab/unit/LA_FT")
    LB_SEC_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-YD3")
    POISE = URIRef("http://qudt.org/vocab/unit/POISE")
    PER_V_A_SEC = URIRef("http://qudt.org/vocab/unit/PER-V-A-SEC")
    IN2 = URIRef("http://qudt.org/vocab/unit/IN2")
    IN2_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN2-PER-SEC")
    PicoA = URIRef("http://qudt.org/vocab/unit/PicoA")
    CentiM2_PER_ERG = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-ERG")
    DecaGM = URIRef("http://qudt.org/vocab/unit/DecaGM")
    KiloT = URIRef("http://qudt.org/vocab/unit/KiloT")
    PA_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC2")
    MilliSV = URIRef("http://qudt.org/vocab/unit/MilliSV")
    MicroM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-M3")
    FemtoJ = URIRef("http://qudt.org/vocab/unit/FemtoJ")
    J_SEC_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-SEC-PER-MOL")
    CI_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CI-PER-KiloGM")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    FemtoSEC = URIRef("http://qudt.org/vocab/unit/FemtoSEC")
    ST_PER_PA = URIRef("http://qudt.org/vocab/unit/ST-PER-PA")
    TON_SHORT_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR")
    DEG_C_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-SEC")
    MicroGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-MIN")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    YD_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD-PER-MIN")
    V_Ab = URIRef("http://qudt.org/vocab/unit/V_Ab")
    MegaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M2")
    OZ_MIN_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN6")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    DYN_SEC_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM")
    DYN = URIRef("http://qudt.org/vocab/unit/DYN")
    LB_MIN_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-FT3")
    TON_Metric_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY")
    KAT_PER_L = URIRef("http://qudt.org/vocab/unit/KAT-PER-L")
    QUAD = URIRef("http://qudt.org/vocab/unit/QUAD")
    CentiM_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-K")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    CWT_SHORT = URIRef("http://qudt.org/vocab/unit/CWT_SHORT")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    W_PER_M2_M = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M")
    DEG_PER_M = URIRef("http://qudt.org/vocab/unit/DEG-PER-M")
    KiloGM_F_M = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M")
    BARAD = URIRef("http://qudt.org/vocab/unit/BARAD")
    CAL_TH_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-DEG_C")
    PER_YD3 = URIRef("http://qudt.org/vocab/unit/PER-YD3")
    MilliJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-M2")
    CentiC = URIRef("http://qudt.org/vocab/unit/CentiC")
    PER_MilliGM = URIRef("http://qudt.org/vocab/unit/PER-MilliGM")
    DRAM_UK = URIRef("http://qudt.org/vocab/unit/DRAM_UK")
    MilliM3 = URIRef("http://qudt.org/vocab/unit/MilliM3")
    NUM_PER_M2 = URIRef("http://qudt.org/vocab/unit/NUM-PER-M2")
    BTU_IT_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC")
    LB_HR_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US2")
    OZ_HR_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-GAL_UK")
    V_PER_M2 = URIRef("http://qudt.org/vocab/unit/V-PER-M2")
    PERCENT_PER_KiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-KiloCount")
    MilliL_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-K")
    BTU_TH = URIRef("http://qudt.org/vocab/unit/BTU_TH")
    LB_FT2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-IN3-LB_F-SEC")
    PER_MIN = URIRef("http://qudt.org/vocab/unit/PER-MIN")
    M2_HR_DEG_C_PER_KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/M2-HR-DEG_C-PER-KiloCAL_IT")
    MilliL_PER_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-K")
    PDL_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-SEC-PER-FT2")
    LB_SEC_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT6")
    MACH = URIRef("http://qudt.org/vocab/unit/MACH")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    KiloGM_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-PA")
    KiloJ_PER_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-K")
    KiloJ_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM-K")
    PER_M_K = URIRef("http://qudt.org/vocab/unit/PER-M-K")
    KiloBTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-FT2")
    MicroMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L")
    KIP_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KIP_F-PER-IN2")
    KiloCAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-GM-K")
    MHO = URIRef("http://qudt.org/vocab/unit/MHO")
    GM_PER_M3_CentiPOISE = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-CentiPOISE")
    GAUSS = URIRef("http://qudt.org/vocab/unit/GAUSS")
    PER_OZ = URIRef("http://qudt.org/vocab/unit/PER-OZ")
    PERCENT_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-CentiM3")
    M3_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-BAR")
    A = URIRef("http://qudt.org/vocab/unit/A")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    NanoGM = URIRef("http://qudt.org/vocab/unit/NanoGM")
    RPK = URIRef("http://qudt.org/vocab/unit/RPK")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    PERCENT_PER_PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-PERCENT")
    KiloPA = URIRef("http://qudt.org/vocab/unit/KiloPA")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    GM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3-BAR")
    TONNE_PER_HR_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR-K")
    NUM_PER_HectoGM = URIRef("http://qudt.org/vocab/unit/NUM-PER-HectoGM")
    KiloCAL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MIN")
    PicoW = URIRef("http://qudt.org/vocab/unit/PicoW")
    GigaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-SEC")
    TON_Metric_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR")
    FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-SEC")
    M3_PER_HR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    BTU_IT_FT = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT")
    TONNE_PER_HR_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR-K")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    LB_MIN_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-YD3")
    BTU_TH_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_F")
    MegaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-M")
    KiloN_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M3")
    OZ_IN = URIRef("http://qudt.org/vocab/unit/OZ-IN")
    ANGSTROM = URIRef("http://qudt.org/vocab/unit/ANGSTROM")
    IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC")
    TON_Metric_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN-BAR")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    KiloGM_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC2")
    KiloCAL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-SEC")
    KiloW = URIRef("http://qudt.org/vocab/unit/KiloW")
    GM_PER_L_K = URIRef("http://qudt.org/vocab/unit/GM-PER-L-K")
    OZ_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ-PER-DAY")
    V_Ab = URIRef("http://qudt.org/vocab/unit/V_Ab")
    CAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-K")
    CentiM2_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-CentiM3")
    CAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-MIN")
    KiloGM_PER_GigaJ = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-GigaJ")
    PicoSEC = URIRef("http://qudt.org/vocab/unit/PicoSEC")
    MilliGM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-BAR")
    IN_HG_32DEG_F = URIRef("http://qudt.org/vocab/unit/IN_HG_32DEG_F")
    KiloEV_PER_MicroM = URIRef("http://qudt.org/vocab/unit/KiloEV-PER-MicroM")
    M_PER_HR = URIRef("http://qudt.org/vocab/unit/M-PER-HR")
    MicroC = URIRef("http://qudt.org/vocab/unit/MicroC")
    ARCSEC = URIRef("http://qudt.org/vocab/unit/ARCSEC")
    PERCENT_PER_PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-PERCENT")
    LB_FT2 = URIRef("http://qudt.org/vocab/unit/LB-FT2")
    CAL_IT_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-DEG_C")
    MicroBAR = URIRef("http://qudt.org/vocab/unit/MicroBAR")
    CentiM3_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR")
    MX = URIRef("http://qudt.org/vocab/unit/MX")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    TOE = URIRef("http://qudt.org/vocab/unit/TOE")
    MicroN_M = URIRef("http://qudt.org/vocab/unit/MicroN-M")
    L_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-K")
    MicroW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroW-PER-M2")
    KiloV_A = URIRef("http://qudt.org/vocab/unit/KiloV-A")
    FUR_Long = URIRef("http://qudt.org/vocab/unit/FUR_Long")
    K = URIRef("http://qudt.org/vocab/unit/K")
    M = URIRef("http://qudt.org/vocab/unit/M")
    KiloV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive-PER-K")
    YR = URIRef("http://qudt.org/vocab/unit/YR")
    SolarMass = URIRef("http://qudt.org/vocab/unit/SolarMass")
    GM_MilliM = URIRef("http://qudt.org/vocab/unit/GM-MilliM")
    LB_MOL = URIRef("http://qudt.org/vocab/unit/LB-MOL")
    MicroFARAD = URIRef("http://qudt.org/vocab/unit/MicroFARAD")
    FT2_HR_DEG_F_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F-PER-BTU_IT")
    YD2 = URIRef("http://qudt.org/vocab/unit/YD2")
    NanoGM = URIRef("http://qudt.org/vocab/unit/NanoGM")
    STR = URIRef("http://qudt.org/vocab/unit/STR")
    GM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM_F-PER-CentiM2")
    BAUD = URIRef("http://qudt.org/vocab/unit/BAUD")
    M3_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-PA")
    TON_UK_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-YD3")
    IU_PER_L = URIRef("http://qudt.org/vocab/unit/IU-PER-L")
    LB_FT2 = URIRef("http://qudt.org/vocab/unit/LB-FT2")
    MilliL_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    FT_LB_F_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2-SEC")
    BTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR")
    MilliGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3")
    GM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-BAR")
    M_PER_PA = URIRef("http://qudt.org/vocab/unit/M-PER-PA")
    M2_PER_M2 = URIRef("http://qudt.org/vocab/unit/M2-PER-M2")
    KiloP = URIRef("http://qudt.org/vocab/unit/KiloP")
    QT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_US-PER-MIN")
    MegaV_A = URIRef("http://qudt.org/vocab/unit/MegaV-A")
    KiloGM_PER_GigaJ = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-GigaJ")
    CAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-MIN")
    OZ_VOL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-DAY")
    PER_YR = URIRef("http://qudt.org/vocab/unit/PER-YR")
    MilliV_PER_M = URIRef("http://qudt.org/vocab/unit/MilliV-PER-M")
    MicroMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    J_PER_M = URIRef("http://qudt.org/vocab/unit/J-PER-M")
    YD_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD-PER-DEG_F")
    GRAIN = URIRef("http://qudt.org/vocab/unit/GRAIN")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    WB_M = URIRef("http://qudt.org/vocab/unit/WB-M")
    H_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/H-PER-KiloOHM")
    ExaBYTE = URIRef("http://qudt.org/vocab/unit/ExaBYTE")
    L_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-BAR")
    S_Stat = URIRef("http://qudt.org/vocab/unit/S_Stat")
    MicroH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-KiloOHM")
    NanoMOL_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-GM-SEC")
    BTU_IT_PER_SEC_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_R")
    NanoM = URIRef("http://qudt.org/vocab/unit/NanoM")
    AC_FT_US = URIRef("http://qudt.org/vocab/unit/AC-FT_US")
    DEGREE_OECHSLE = URIRef("http://qudt.org/vocab/unit/DEGREE_OECHSLE")
    TSP = URIRef("http://qudt.org/vocab/unit/TSP")
    M6 = URIRef("http://qudt.org/vocab/unit/M6")
    BU_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-DAY")
    BTU_IT_PER_LB_F_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_F")
    BTU_IT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_F")
    OZ_PER_GAL = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL")
    BTU_TH_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-FT2-HR-DEG_F")
    GM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY-K")
    KiloJ = URIRef("http://qudt.org/vocab/unit/KiloJ")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    PlanckMomentum = URIRef("http://qudt.org/vocab/unit/PlanckMomentum")
    KiloGM_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-M2")
    BTU_IT_PER_MOL_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB")
    MicroM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroM-PER-SEC")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    KiloGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-SEC")
    MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC")
    MegaOHM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-KiloM")
    PlanckEnergy = URIRef("http://qudt.org/vocab/unit/PlanckEnergy")
    PERCENT_RH = URIRef("http://qudt.org/vocab/unit/PERCENT_RH")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    PER_YR = URIRef("http://qudt.org/vocab/unit/PER-YR")
    FARAD_Ab = URIRef("http://qudt.org/vocab/unit/FARAD_Ab")
    LB_MIN_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-GAL_UK")
    OZ_IN2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/OZ-IN2-PER-IN3-LB_F-SEC")
    PER_KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/PER-KiloV-A-HR")
    C = URIRef("http://qudt.org/vocab/unit/C")
    KiloGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-BAR")
    BU_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-MIN")
    FC = URIRef("http://qudt.org/vocab/unit/FC")
    KiloPA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-K")
    MilliBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-L")
    OHM_Stat = URIRef("http://qudt.org/vocab/unit/OHM_Stat")
    PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PER-CentiM3")
    V_PER_PA = URIRef("http://qudt.org/vocab/unit/V-PER-PA")
    GI_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-SEC")
    PINT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-SEC")
    TON_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_US-PER-DAY")
    W_PER_FT2 = URIRef("http://qudt.org/vocab/unit/W-PER-FT2")
    MegaOHM = URIRef("http://qudt.org/vocab/unit/MegaOHM")
    MilLength = URIRef("http://qudt.org/vocab/unit/MilLength")
    NUM_PER_GM = URIRef("http://qudt.org/vocab/unit/NUM-PER-GM")
    NanoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L")
    PERCENT_HR_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-CentiM3")
    LM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LM-PER-FT2")
    ERG_PER_G = URIRef("http://qudt.org/vocab/unit/ERG-PER-G")
    PER_PA_SEC = URIRef("http://qudt.org/vocab/unit/PER-PA-SEC")
    TONNE_PER_HA = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA")
    TON_FG = URIRef("http://qudt.org/vocab/unit/TON_FG")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/MOL_LB-DEG_F")
    KiloGM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3")
    DeciM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MOL")
    CAL_IT_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-DEG_C")
    GM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3")
    PebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M2")
    KiloOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-BAR")
    PDL_PER_IN = URIRef("http://qudt.org/vocab/unit/PDL-PER-IN")
    MilliGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-K")
    LB_SEC_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-YD3")
    N = URIRef("http://qudt.org/vocab/unit/N")
    MilliV = URIRef("http://qudt.org/vocab/unit/MilliV")
    MilliOHM = URIRef("http://qudt.org/vocab/unit/MilliOHM")
    MilliM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliM-PER-M")
    BTU_TH_FT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-HR-FT2-DEG_F")
    FT3_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT3-PER-DAY")
    GI_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-HR")
    GM_MilliM = URIRef("http://qudt.org/vocab/unit/GM-MilliM")
    KiloCAL_IT_PER_HR_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-HR-M-DEG_C")
    MicroIN = URIRef("http://qudt.org/vocab/unit/MicroIN")
    PA2_SEC = URIRef("http://qudt.org/vocab/unit/PA2-SEC")
    CAL_MEAN = URIRef("http://qudt.org/vocab/unit/CAL_MEAN")
    DYN_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM3")
    J_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-M2-PER-KiloGM")
    KiloV = URIRef("http://qudt.org/vocab/unit/KiloV")
    MicroH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-KiloOHM")
    OZ_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ-PER-SEC")
    PA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-L-PER-SEC")
    FT_H2O_39dot2DEG_F = URIRef("http://qudt.org/vocab/unit/FT_H2O_39dot2DEG_F")
    PERCENT_HR_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-L")
    PERCENT_PER_DecaK = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaK")
    DEG_F_HR_FT2_PER_BTU_TH_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH-IN")
    KiloPA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-MilliM")
    MilliGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-BAR")
    KiloA_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M2")
    PetaFLOPS = URIRef("http://qudt.org/vocab/unit/PetaFLOPS")
    KiloV_A = URIRef("http://qudt.org/vocab/unit/KiloV-A")
    TON_LONG_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_LONG-PER-YD3")
    TON_US = URIRef("http://qudt.org/vocab/unit/TON_US")
    J_PER_GM_K = URIRef("http://qudt.org/vocab/unit/J-PER-GM-K")
    YD_PER_PSI = URIRef("http://qudt.org/vocab/unit/YD-PER-PSI")
    GM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3-K")
    PERCENT_HR_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-GAL_US")
    FT_LB_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-M2")
    CAL_TH_PER_G = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-G")
    MilliMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-L")
    LA = URIRef("http://qudt.org/vocab/unit/LA")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    PSI_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-L-PER-SEC")
    KiloPOND = URIRef("http://qudt.org/vocab/unit/KiloPOND")
    MegaL = URIRef("http://qudt.org/vocab/unit/MegaL")
    MegaHZ = URIRef("http://qudt.org/vocab/unit/MegaHZ")
    CentiM_HG_0DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_HG_0DEG_C")
    PA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M3-PER-SEC")
    MilliL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliL-PER-L")
    SHANNON_PER_SEC = URIRef("http://qudt.org/vocab/unit/SHANNON-PER-SEC")
    DeciB_M = URIRef("http://qudt.org/vocab/unit/DeciB_M")
    REV_PER_MIN = URIRef("http://qudt.org/vocab/unit/REV-PER-MIN")
    S = URIRef("http://qudt.org/vocab/unit/S")
    W_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-PER-M3")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    GM_PER_L = URIRef("http://qudt.org/vocab/unit/GM-PER-L")
    CentiM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL")
    K_PER_BAR = URIRef("http://qudt.org/vocab/unit/K-PER-BAR")
    HectoPA_PER_HR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-HR")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    MilliGM_SEC_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L2")
    OCTET = URIRef("http://qudt.org/vocab/unit/OCTET")
    MilliIN = URIRef("http://qudt.org/vocab/unit/MilliIN")
    PA_M0dot5 = URIRef("http://qudt.org/vocab/unit/PA-M0dot5")
    KiloMOL_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3-BAR")
    TONNE_PER_SEC = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC")
    HK = URIRef("http://qudt.org/vocab/unit/HK")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    ExaBYTE = URIRef("http://qudt.org/vocab/unit/ExaBYTE")
    PSI_PER_IN = URIRef("http://qudt.org/vocab/unit/PSI-PER-IN")
    V = URIRef("http://qudt.org/vocab/unit/V")
    NanoSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-MIN")
    PebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M")
    BTU_IT_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC")
    MilliA_PER_IN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-IN")
    MegaHZ_M = URIRef("http://qudt.org/vocab/unit/MegaHZ-M")
    PINT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-HR")
    BTU_IT_PER_LB_MOL = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-MOL")
    BQ_PER_M2 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M2")
    FT3_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN")
    KiloGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-K")
    YR_TROPICAL = URIRef("http://qudt.org/vocab/unit/YR_TROPICAL")
    TONNE_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC-K")
    CLO = URIRef("http://qudt.org/vocab/unit/CLO")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    DeciM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MOL")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    A = URIRef("http://qudt.org/vocab/unit/A")
    MicroC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M2")
    A_Ab = URIRef("http://qudt.org/vocab/unit/A_Ab")
    C_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM2")
    A_PER_CentiM = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM")
    J = URIRef("http://qudt.org/vocab/unit/J")
    MOL_PER_M2_SEC_SR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-SR")
    W_PER_M2_M_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M-SR")
    FemtoSEC = URIRef("http://qudt.org/vocab/unit/FemtoSEC")
    PlanckCharge = URIRef("http://qudt.org/vocab/unit/PlanckCharge")
    W_PER_IN2 = URIRef("http://qudt.org/vocab/unit/W-PER-IN2")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    HART_PER_SEC = URIRef("http://qudt.org/vocab/unit/HART-PER-SEC")
    CentiPOISE_PER_K = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-K")
    NUM_PER_SEC = URIRef("http://qudt.org/vocab/unit/NUM-PER-SEC")
    FemtoFARAD = URIRef("http://qudt.org/vocab/unit/FemtoFARAD")
    TONNE_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN-BAR")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    MilliM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-HR")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    MilliOHM_M = URIRef("http://qudt.org/vocab/unit/MilliOHM-M")
    MegaN = URIRef("http://qudt.org/vocab/unit/MegaN")
    GM_SEC_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M6")
    M_K_PER_W = URIRef("http://qudt.org/vocab/unit/M-K-PER-W")
    PSI_YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-YD3-PER-SEC")
    FemtoGM_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-L")
    BTU_IT_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT-PER-FT2-HR-DEG_F")
    S_Ab = URIRef("http://qudt.org/vocab/unit/S_Ab")
    BQ_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-SEC-PER-M3")
    MicroC = URIRef("http://qudt.org/vocab/unit/MicroC")
    KiloGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloGM")
    KiloGM_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-YR")
    ERG = URIRef("http://qudt.org/vocab/unit/ERG")
    MilliGM = URIRef("http://qudt.org/vocab/unit/MilliGM")
    MilliGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-K")
    MicroBAR = URIRef("http://qudt.org/vocab/unit/MicroBAR")
    NP = URIRef("http://qudt.org/vocab/unit/NP")
    FT2_HR_DEG_F_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F-PER-BTU_IT")
    OZ_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ-PER-SEC")
    PER_M_NanoM_SR = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM-SR")
    MilliM_HGA = URIRef("http://qudt.org/vocab/unit/MilliM_HGA")
    KiloMOL_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3-BAR")
    Da = URIRef("http://qudt.org/vocab/unit/Da")
    BTU_TH = URIRef("http://qudt.org/vocab/unit/BTU_TH")
    PSI_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-M3-PER-SEC")
    MicroGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M2-DAY")
    MilliGM_MIN_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L2")
    SEC2 = URIRef("http://qudt.org/vocab/unit/SEC2")
    H_PER_OHM = URIRef("http://qudt.org/vocab/unit/H-PER-OHM")
    OZ_VOL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-MIN")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    LB_F_PER_IN2_DEG_F = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-DEG_F")
    DeciB_Z = URIRef("http://qudt.org/vocab/unit/DeciB_Z")
    M_SEC = URIRef("http://qudt.org/vocab/unit/M-SEC")
    CentiM3_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-BAR")
    BBL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-MIN")
    MebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M2")
    GM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY-BAR")
    LB_F_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN")
    LB_F_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN")
    MegaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M2")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    FemtoGM = URIRef("http://qudt.org/vocab/unit/FemtoGM")
    DeciM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MOL")
    BTU_IT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR-DEG_F")
    RAD_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-MOL")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    PA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M3-PER-SEC")
    J_M2 = URIRef("http://qudt.org/vocab/unit/J-M2")
    S_Stat = URIRef("http://qudt.org/vocab/unit/S_Stat")
    GM_HR_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L2")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    GM_PER_DeciM3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3-K")
    PERCENT_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-M3")
    M2_PER_HA = URIRef("http://qudt.org/vocab/unit/M2-PER-HA")
    IN4 = URIRef("http://qudt.org/vocab/unit/IN4")
    DecaM = URIRef("http://qudt.org/vocab/unit/DecaM")
    PPTH_PER_HR = URIRef("http://qudt.org/vocab/unit/PPTH-PER-HR")
    DecaGM = URIRef("http://qudt.org/vocab/unit/DecaGM")
    DecaPA = URIRef("http://qudt.org/vocab/unit/DecaPA")
    LB_PER_FT3_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3-PSI")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    GM_PER_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-BAR")
    YD_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD-PER-DEG_F")
    MilliPA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-BAR")
    SON = URIRef("http://qudt.org/vocab/unit/SON")
    NanoM = URIRef("http://qudt.org/vocab/unit/NanoM")
    RT = URIRef("http://qudt.org/vocab/unit/RT")
    MicroMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM")
    ARE = URIRef("http://qudt.org/vocab/unit/ARE")
    KiloCAL_PER_MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL-DEG_C")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    PlanckCharge = URIRef("http://qudt.org/vocab/unit/PlanckCharge")
    J_PER_MOL_K = URIRef("http://qudt.org/vocab/unit/J-PER-MOL-K")
    MilliGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-SEC")
    KiloM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloM-PER-DAY")
    CentiM_HG = URIRef("http://qudt.org/vocab/unit/CentiM_HG")
    KiloMOL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-HR")
    DEG_R_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-MIN")
    YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD3-PER-SEC")
    TON_SHORT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-DEG_F")
    MilliV_A_PER_K = URIRef("http://qudt.org/vocab/unit/MilliV-A-PER-K")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    MegaDOLLAR_US_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MegaDOLLAR_US-PER-FLIGHT")
    LB_SEC_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US2")
    MilliKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MilliKAT-PER-L")
    PERCENT_RH = URIRef("http://qudt.org/vocab/unit/PERCENT_RH")
    FemtoGM = URIRef("http://qudt.org/vocab/unit/FemtoGM")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    MicroG_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroG-PER-CentiM2")
    IU_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliGM")
    MicroRAD = URIRef("http://qudt.org/vocab/unit/MicroRAD")
    FT_SEC_PER_IN3 = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-IN3")
    MIL_Circ = URIRef("http://qudt.org/vocab/unit/MIL_Circ")
    GM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC")
    T = URIRef("http://qudt.org/vocab/unit/T")
    CUP = URIRef("http://qudt.org/vocab/unit/CUP")
    THERM_EC = URIRef("http://qudt.org/vocab/unit/THERM_EC")
    M2_PER_K = URIRef("http://qudt.org/vocab/unit/M2-PER-K")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    CentiM2_PER_SR_ERG = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SR-ERG")
    LB_MIN_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-YD3")
    KiloM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloM-PER-DAY")
    TON_SHORT_PER_PSI = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-PSI")
    PERCENT_RH = URIRef("http://qudt.org/vocab/unit/PERCENT_RH")
    GRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/GRAY-PER-SEC")
    FT2_PER_HR = URIRef("http://qudt.org/vocab/unit/FT2-PER-HR")
    MilliPA = URIRef("http://qudt.org/vocab/unit/MilliPA")
    BARN_PER_EV = URIRef("http://qudt.org/vocab/unit/BARN-PER-EV")
    OZ_SEC_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-GAL_UK")
    PINT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-MIN")
    KiloM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM2-PER-SEC2")
    LB_MIN_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-FT3")
    GAL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-DAY")
    KiloGM_PER_M_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC2")
    BARYE = URIRef("http://qudt.org/vocab/unit/BARYE")
    MilliGM_PER_M3_POISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-POISE")
    MilliSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-HR")
    C_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM3")
    DEG_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG-PER-HR")
    MDOLLAR_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MDOLLAR-PER-FLIGHT")
    CAL_MEAN = URIRef("http://qudt.org/vocab/unit/CAL_MEAN")
    MicroGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-DeciL")
    WB_M = URIRef("http://qudt.org/vocab/unit/WB-M")
    OHM_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-PER-M")
    KiloW_HR = URIRef("http://qudt.org/vocab/unit/KiloW-HR")
    CentiM_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-HR")
    PERM_Metric_23DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_Metric_23DEG_C")
    KiloPA_M2_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloPA-M2-PER-GM")
    NanoFARAD = URIRef("http://qudt.org/vocab/unit/NanoFARAD")
    M3_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-BAR")
    A = URIRef("http://qudt.org/vocab/unit/A")
    V_A_HR = URIRef("http://qudt.org/vocab/unit/V-A-HR")
    PlanckMass = URIRef("http://qudt.org/vocab/unit/PlanckMass")
    A_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-PER-DEG_C")
    S = URIRef("http://qudt.org/vocab/unit/S")
    MilliR = URIRef("http://qudt.org/vocab/unit/MilliR")
    W_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM")
    KiloBAR = URIRef("http://qudt.org/vocab/unit/KiloBAR")
    BIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/BIT-PER-M2")
    PPTR = URIRef("http://qudt.org/vocab/unit/PPTR")
    PINT_US_DRY = URIRef("http://qudt.org/vocab/unit/PINT_US_DRY")
    KiloGM_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-YR")
    TONNE_PER_HR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR")
    C_PER_MOL = URIRef("http://qudt.org/vocab/unit/C-PER-MOL")
    GM_SEC_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M6")
    GAL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-HR")
    GAL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-MIN")
    LB_SEC_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-IN3")
    HART = URIRef("http://qudt.org/vocab/unit/HART")
    MegaPA_M0pt5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0pt5")
    A_Ab = URIRef("http://qudt.org/vocab/unit/A_Ab")
    K_PER_K = URIRef("http://qudt.org/vocab/unit/K-PER-K")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    PicoC = URIRef("http://qudt.org/vocab/unit/PicoC")
    V_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/V-A_Reactive-PER-K")
    TONNE_PER_HR_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR-K")
    GibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M2")
    MilliGM_PER_L_CentiPOISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-CentiPOISE")
    NanoMOL_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL")
    PSU = URIRef("http://qudt.org/vocab/unit/PSU")
    ERG_PER_CentiM = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM")
    MilliGM_MIN_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L-M3")
    DEATHS_PER_MegaINDIV_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-MegaINDIV-YR")
    GM_PER_L_CentiPOISE = URIRef("http://qudt.org/vocab/unit/GM-PER-L-CentiPOISE")
    KiloN_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-DEG")
    MegaA = URIRef("http://qudt.org/vocab/unit/MegaA")
    HectoPA_PER_HR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-HR")
    GM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-L-BAR")
    MicroM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-M3")
    KiloSEC = URIRef("http://qudt.org/vocab/unit/KiloSEC")
    M_PER_HR = URIRef("http://qudt.org/vocab/unit/M-PER-HR")
    KiloGM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR")
    PH = URIRef("http://qudt.org/vocab/unit/PH")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    EUR_PER_M2 = URIRef("http://qudt.org/vocab/unit/EUR-PER-M2")
    NanoSEC = URIRef("http://qudt.org/vocab/unit/NanoSEC")
    FT4 = URIRef("http://qudt.org/vocab/unit/FT4")
    MegaL = URIRef("http://qudt.org/vocab/unit/MegaL")
    PK_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-MIN")
    CentiM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN")
    L_PER_HR = URIRef("http://qudt.org/vocab/unit/L-PER-HR")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    CentiM = URIRef("http://qudt.org/vocab/unit/CentiM")
    QT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_US-PER-MIN")
    CWT_SHORT = URIRef("http://qudt.org/vocab/unit/CWT_SHORT")
    LB_HR_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US2")
    KiloPA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-MilliM")
    failures_in_time = URIRef("http://qudt.org/vocab/unit/failures-in-time")
    KiloGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC")
    T = URIRef("http://qudt.org/vocab/unit/T")
    KiloL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloL-PER-HR")
    KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-SEC2")
    MegaEV_PER_SpeedOfLight = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-SpeedOfLight")
    M3_PER_HR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR")
    PINT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-DAY")
    HK = URIRef("http://qudt.org/vocab/unit/HK")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    M2_PER_HZ_DEG = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ-DEG")
    DeciM3_PER_HR = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-HR")
    KiloN_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M2")
    LB_PER_MIN_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN-PSI")
    PicoV_A = URIRef("http://qudt.org/vocab/unit/PicoV-A")
    GigaN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaN-M-PER-M2")
    M2_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/M2-SEC-PER-RAD")
    S_Stat = URIRef("http://qudt.org/vocab/unit/S_Stat")
    PERCENT_MIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-GAL_US")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    PERCENT_PER_CentiPOISE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-CentiPOISE")
    MicroN_M = URIRef("http://qudt.org/vocab/unit/MicroN-M")
    LB_PER_LB = URIRef("http://qudt.org/vocab/unit/LB-PER-LB")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    MilliMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2-DAY")
    NanoGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M3")
    KiloGM_F_M = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M")
    TONNE_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY-BAR")
    NanoMOL_PER_CentiM3_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-CentiM3-HR")
    KiloM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-HR")
    KiloGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-PA-SEC")
    GigaHZ = URIRef("http://qudt.org/vocab/unit/GigaHZ")
    KiloMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-SEC")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    DEG_F_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-K")
    IN3_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN3-PER-MIN")
    MilliKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MilliKAT-PER-L")
    SEC_PER_RAD_M3 = URIRef("http://qudt.org/vocab/unit/SEC-PER-RAD-M3")
    REV_PER_MIN = URIRef("http://qudt.org/vocab/unit/REV-PER-MIN")
    KiloM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC-BAR")
    FemtoL = URIRef("http://qudt.org/vocab/unit/FemtoL")
    IU_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliGM")
    BAN = URIRef("http://qudt.org/vocab/unit/BAN")
    MegaJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-KiloGM")
    PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/PER-MilliM3")
    MilliGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-CentiM2")
    PER_SEC_M3 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M3")
    KiloSEC = URIRef("http://qudt.org/vocab/unit/KiloSEC")
    M2_SR = URIRef("http://qudt.org/vocab/unit/M2-SR")
    NUM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NUM-PER-M3")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    MilliW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2")
    MicroGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-GM")
    M3_PER_DAY = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY")
    MilliV_PER_V = URIRef("http://qudt.org/vocab/unit/MilliV-PER-V")
    CAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC")
    BU_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-MIN")
    PERCENT_HR_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-CentiM3")
    MicroMHO = URIRef("http://qudt.org/vocab/unit/MicroMHO")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    MilliGM_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-DAY")
    CentiM_HG_0DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_HG_0DEG_C")
    H = URIRef("http://qudt.org/vocab/unit/H")
    RAD_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-KiloGM")
    PicoM = URIRef("http://qudt.org/vocab/unit/PicoM")
    MegaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBIT-PER-SEC")
    M2_PER_SR_J = URIRef("http://qudt.org/vocab/unit/M2-PER-SR-J")
    TonEnergy = URIRef("http://qudt.org/vocab/unit/TonEnergy")
    NP_PER_SEC = URIRef("http://qudt.org/vocab/unit/NP-PER-SEC")
    LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    AU = URIRef("http://qudt.org/vocab/unit/AU")
    PERCENT_PER_K = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-K")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    KiloC_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M3")
    MilliGM_HR_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M3-L")
    MilliH = URIRef("http://qudt.org/vocab/unit/MilliH")
    PINT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-SEC")
    PlanckPower = URIRef("http://qudt.org/vocab/unit/PlanckPower")
    PetaC = URIRef("http://qudt.org/vocab/unit/PetaC")
    GM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN-BAR")
    Quarter_UK = URIRef("http://qudt.org/vocab/unit/Quarter_UK")
    SLUG_PER_FT2 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT2")
    J_PER_GM = URIRef("http://qudt.org/vocab/unit/J-PER-GM")
    MilliGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HA")
    FemtoJ = URIRef("http://qudt.org/vocab/unit/FemtoJ")
    OZ_VOL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-HR")
    PER_H = URIRef("http://qudt.org/vocab/unit/PER-H")
    MI_PER_SEC = URIRef("http://qudt.org/vocab/unit/MI-PER-SEC")
    M3_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-BAR")
    AC_FT = URIRef("http://qudt.org/vocab/unit/AC-FT")
    GigaJ = URIRef("http://qudt.org/vocab/unit/GigaJ")
    NanoGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2")
    BIT_PER_M = URIRef("http://qudt.org/vocab/unit/BIT-PER-M")
    MicroGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-HR")
    MilliGM = URIRef("http://qudt.org/vocab/unit/MilliGM")
    PicoPA_PER_KiloM = URIRef("http://qudt.org/vocab/unit/PicoPA-PER-KiloM")
    PPTM_PER_K = URIRef("http://qudt.org/vocab/unit/PPTM-PER-K")
    KiloP = URIRef("http://qudt.org/vocab/unit/KiloP")
    PA_SEC_PER_K = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-K")
    S_PER_CentiM = URIRef("http://qudt.org/vocab/unit/S-PER-CentiM")
    K_PER_MIN = URIRef("http://qudt.org/vocab/unit/K-PER-MIN")
    MilliGM_SEC_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M3-CentiM3")
    ST_PER_BAR = URIRef("http://qudt.org/vocab/unit/ST-PER-BAR")
    CARAT = URIRef("http://qudt.org/vocab/unit/CARAT")
    OZ_MIN_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-YD3")
    PER_GigaEV2 = URIRef("http://qudt.org/vocab/unit/PER-GigaEV2")
    B = URIRef("http://qudt.org/vocab/unit/B")
    MilliSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-MIN")
    A_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-M2")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    LB_PER_FT3_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3-PSI")
    J_PER_M4 = URIRef("http://qudt.org/vocab/unit/J-PER-M4")
    DeciSEC = URIRef("http://qudt.org/vocab/unit/DeciSEC")
    C_Ab = URIRef("http://qudt.org/vocab/unit/C_Ab")
    MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC")
    NanoGM = URIRef("http://qudt.org/vocab/unit/NanoGM")
    NanoGM_PER_L = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-L")
    DeciTONNE = URIRef("http://qudt.org/vocab/unit/DeciTONNE")
    QT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_US-PER-SEC")
    MilliGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3")
    OZ_MIN_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-FT3")
    DeciM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-M3")
    M3_PER_HR_K = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-K")
    GM_PER_MOL = URIRef("http://qudt.org/vocab/unit/GM-PER-MOL")
    MilliGM = URIRef("http://qudt.org/vocab/unit/MilliGM")
    MicroGM = URIRef("http://qudt.org/vocab/unit/MicroGM")
    LB_PER_FT_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-HR")
    OZ_SEC_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN6")
    MilliL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M2-DAY")
    CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3")
    OZ_VOL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-HR")
    PA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M3-PER-SEC")
    PA_M0dot5 = URIRef("http://qudt.org/vocab/unit/PA-M0dot5")
    W_M_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-M-PER-M2-SR")
    H_PER_M = URIRef("http://qudt.org/vocab/unit/H-PER-M")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    C_Stat_PER_MOL = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-MOL")
    MicroGM_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L-HR")
    MilliMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-KiloGM")
    GAL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-SEC")
    TONNE_PER_M3 = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3")
    MI_N_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI_N-PER-MIN")
    PER_MILLE_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PSI")
    M2_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-V-SEC")
    MegaPA_PER_K = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-K")
    KiloGM_PER_M_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC")
    GM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY-K")
    MilliGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-SEC")
    LB_PER_FT_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-MIN")
    OHM_PER_MI = URIRef("http://qudt.org/vocab/unit/OHM-PER-MI")
    BTU_IT_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_F")
    ElementaryCharge = URIRef("http://qudt.org/vocab/unit/ElementaryCharge")
    CLO = URIRef("http://qudt.org/vocab/unit/CLO")
    C = URIRef("http://qudt.org/vocab/unit/C")
    M_PER_HR = URIRef("http://qudt.org/vocab/unit/M-PER-HR")
    MicroOHM = URIRef("http://qudt.org/vocab/unit/MicroOHM")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    PlanckCurrent = URIRef("http://qudt.org/vocab/unit/PlanckCurrent")
    MI2 = URIRef("http://qudt.org/vocab/unit/MI2")
    GM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3")
    CentiM3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL-SEC")
    MegaBQ = URIRef("http://qudt.org/vocab/unit/MegaBQ")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    MOL_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-K")
    QT_US = URIRef("http://qudt.org/vocab/unit/QT_US")
    GI_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-DAY")
    M3_PER_MIN = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN")
    FT_LB_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-SEC")
    POND = URIRef("http://qudt.org/vocab/unit/POND")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    MilliGM_SEC_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L-CentiM3")
    PSI_YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-YD3-PER-SEC")
    M_K = URIRef("http://qudt.org/vocab/unit/M-K")
    FT_LB_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-M2")
    MilliJ = URIRef("http://qudt.org/vocab/unit/MilliJ")
    PA2_SEC = URIRef("http://qudt.org/vocab/unit/PA2-SEC")
    MilliGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/FT2-PER-BTU_IT-IN")
    PSI_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-M3-PER-SEC")
    KiloW_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloW-HR-PER-M2")
    LB_PER_FT_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-HR")
    W = URIRef("http://qudt.org/vocab/unit/W")
    DEG_F_HR_FT2_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH")
    PER_IN3 = URIRef("http://qudt.org/vocab/unit/PER-IN3")
    ROD = URIRef("http://qudt.org/vocab/unit/ROD")
    MilliGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3")
    ERLANG = URIRef("http://qudt.org/vocab/unit/ERLANG")
    N_M2 = URIRef("http://qudt.org/vocab/unit/N-M2")
    FT2 = URIRef("http://qudt.org/vocab/unit/FT2")
    MicroGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-GM")
    DEATHS_PER_KiloINDIV_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-KiloINDIV-YR")
    N_M2_PER_A = URIRef("http://qudt.org/vocab/unit/N-M2-PER-A")
    FT3_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT3-PER-DAY")
    V_PER_SEC = URIRef("http://qudt.org/vocab/unit/V-PER-SEC")
    MilliL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M3")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    PERM_Metric = URIRef("http://qudt.org/vocab/unit/PERM_Metric")
    MI3 = URIRef("http://qudt.org/vocab/unit/MI3")
    PINT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-HR")
    MegaS_PER_M = URIRef("http://qudt.org/vocab/unit/MegaS-PER-M")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    MicroGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M2-DAY")
    W_HR_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-HR-PER-KiloGM")
    MilliGM_MIN_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L-CentiM3")
    KiloYR = URIRef("http://qudt.org/vocab/unit/KiloYR")
    BU_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-SEC")
    PicoL = URIRef("http://qudt.org/vocab/unit/PicoL")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    ST_PER_PA = URIRef("http://qudt.org/vocab/unit/ST-PER-PA")
    CentiM3_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN-K")
    BTU_IT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MIN")
    KiloCi = URIRef("http://qudt.org/vocab/unit/KiloCi")
    BTU_TH_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2")
    M3_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-PA")
    PINT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-MIN")
    MicroMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MOL")
    GI_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-SEC")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    MegaTONNE = URIRef("http://qudt.org/vocab/unit/MegaTONNE")
    PetaC = URIRef("http://qudt.org/vocab/unit/PetaC")
    LB_PER_FT_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-DAY")
    LB_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN2")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    PERCENT_IN2_PER_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-IN2-PER-LB_F-SEC")
    PPQ = URIRef("http://qudt.org/vocab/unit/PPQ")
    A_HR_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/A-HR-PER-KiloGM")
    NanoW = URIRef("http://qudt.org/vocab/unit/NanoW")
    ExaBYTE = URIRef("http://qudt.org/vocab/unit/ExaBYTE")
    M2_PER_SR_J = URIRef("http://qudt.org/vocab/unit/M2-PER-SR-J")
    A_PER_RAD = URIRef("http://qudt.org/vocab/unit/A-PER-RAD")
    V_PER_M2 = URIRef("http://qudt.org/vocab/unit/V-PER-M2")
    MilliMOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2-SEC")
    GI = URIRef("http://qudt.org/vocab/unit/GI")
    C_M2 = URIRef("http://qudt.org/vocab/unit/C-M2")
    ERG_PER_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-SEC")
    MegaPA_M0pt5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0pt5")
    A = URIRef("http://qudt.org/vocab/unit/A")
    MicroT = URIRef("http://qudt.org/vocab/unit/MicroT")
    NanoMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-M2-DAY")
    BTU_IT_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-HR-DEG_F")
    DecaC = URIRef("http://qudt.org/vocab/unit/DecaC")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    KiloGM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-CentiM2")
    MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/MOL-DEG_C")
    GI_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_US-PER-SEC")
    PER_TON = URIRef("http://qudt.org/vocab/unit/PER-TON")
    MOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MOL-PER-MOL")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    MilliS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MilliS-PER-CentiM")
    MegaA = URIRef("http://qudt.org/vocab/unit/MegaA")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    CentiM2_PER_SR_ERG = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SR-ERG")
    EV_PER_K = URIRef("http://qudt.org/vocab/unit/EV-PER-K")
    DEG_PER_M = URIRef("http://qudt.org/vocab/unit/DEG-PER-M")
    DeciL = URIRef("http://qudt.org/vocab/unit/DeciL")
    MilliL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-KiloGM")
    L_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-BAR")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    M2_K = URIRef("http://qudt.org/vocab/unit/M2-K")
    KiloGM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3")
    MicroSV = URIRef("http://qudt.org/vocab/unit/MicroSV")
    DeciSEC = URIRef("http://qudt.org/vocab/unit/DeciSEC")
    CUP_US = URIRef("http://qudt.org/vocab/unit/CUP_US")
    BARN_PER_SR = URIRef("http://qudt.org/vocab/unit/BARN-PER-SR")
    DEG_C_GROWING_CEREAL_DAY = URIRef("http://qudt.org/vocab/unit/DEG_C_GROWING_CEREAL-DAY")
    MilliGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-KiloGM")
    PERM_Metric = URIRef("http://qudt.org/vocab/unit/PERM_Metric")
    J_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-M2-PER-KiloGM")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    PlanckCharge = URIRef("http://qudt.org/vocab/unit/PlanckCharge")
    MegaV_A = URIRef("http://qudt.org/vocab/unit/MegaV-A")
    V_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/V-SEC-PER-M")
    LB_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN2")
    V_PER_SEC = URIRef("http://qudt.org/vocab/unit/V-PER-SEC")
    PERCENT_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-M3")
    PicoW = URIRef("http://qudt.org/vocab/unit/PicoW")
    KiloJ_PER_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-K")
    FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/FT2-PER-BTU_IT-IN")
    LB_HR_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-YD3")
    MHO = URIRef("http://qudt.org/vocab/unit/MHO")
    MilliBAR = URIRef("http://qudt.org/vocab/unit/MilliBAR")
    PHON = URIRef("http://qudt.org/vocab/unit/PHON")
    PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PER-KiloGM")
    KiloGM_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-MilliM2")
    SLUG_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT-SEC")
    LB_MIN_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN6")
    MilliCD = URIRef("http://qudt.org/vocab/unit/MilliCD")
    MegaFLOPS = URIRef("http://qudt.org/vocab/unit/MegaFLOPS")
    KiloT = URIRef("http://qudt.org/vocab/unit/KiloT")
    M4_PER_SEC = URIRef("http://qudt.org/vocab/unit/M4-PER-SEC")
    REV_PER_HR = URIRef("http://qudt.org/vocab/unit/REV-PER-HR")
    MilliA_PER_LB_F_IN2 = URIRef("http://qudt.org/vocab/unit/MilliA-PER-LB_F-IN2")
    W = URIRef("http://qudt.org/vocab/unit/W")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    MegaTON = URIRef("http://qudt.org/vocab/unit/MegaTON")
    PERM_0DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_0DEG_C")
    NP = URIRef("http://qudt.org/vocab/unit/NP")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    LM_HR = URIRef("http://qudt.org/vocab/unit/LM-HR")
    AU = URIRef("http://qudt.org/vocab/unit/AU")
    KiloW_HR = URIRef("http://qudt.org/vocab/unit/KiloW-HR")
    LB_PER_FT_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-HR")
    PK_US_DRY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY")
    MilliGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-HR")
    PicoSEC = URIRef("http://qudt.org/vocab/unit/PicoSEC")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    MilliSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-MIN")
    MegaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M3")
    CentiM_PER_YR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-YR")
    EV_PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/EV-PER-ANGSTROM")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    ERG_PER_G = URIRef("http://qudt.org/vocab/unit/ERG-PER-G")
    GM_PER_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-BAR")
    ATM_M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/ATM-M3-PER-MOL")
    N_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M3")
    N_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M2")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    LB_SEC_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-GAL_US")
    DYN_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-CentiM")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    BTU_IT_FT = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT")
    SAMPLE_PER_SEC = URIRef("http://qudt.org/vocab/unit/SAMPLE-PER-SEC")
    PicoM = URIRef("http://qudt.org/vocab/unit/PicoM")
    MilliL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-MIN")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    MOL_PER_KiloGM_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-PA")
    LB_F_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-IN2")
    MilliA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/MilliA-PER-MilliM")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    DEGREE_OECHSLE = URIRef("http://qudt.org/vocab/unit/DEGREE_OECHSLE")
    W_PER_SR = URIRef("http://qudt.org/vocab/unit/W-PER-SR")
    PebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M2")
    GM_PER_M2 = URIRef("http://qudt.org/vocab/unit/GM-PER-M2")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    GM_PER_HZ = URIRef("http://qudt.org/vocab/unit/GM-PER-HZ")
    EarthMass = URIRef("http://qudt.org/vocab/unit/EarthMass")
    POISE = URIRef("http://qudt.org/vocab/unit/POISE")
    M3_PER_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-M2")
    MicroV_A = URIRef("http://qudt.org/vocab/unit/MicroV-A")
    PicoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/PicoFARAD-PER-M")
    TONNE_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR-BAR")
    A_PER_MilliM = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    MilliJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-M2")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    GAL_US = URIRef("http://qudt.org/vocab/unit/GAL_US")
    Gs = URIRef("http://qudt.org/vocab/unit/Gs")
    K_PER_M = URIRef("http://qudt.org/vocab/unit/K-PER-M")
    W_PER_M_DEG_C = URIRef("http://qudt.org/vocab/unit/W-PER-M-DEG_C")
    BTU_IT_PER_MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB-DEG_F")
    KAT_PER_MicroL = URIRef("http://qudt.org/vocab/unit/KAT-PER-MicroL")
    FT_H2O = URIRef("http://qudt.org/vocab/unit/FT_H2O")
    N_M2_PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/N-M2-PER-KiloGM2")
    KiloN_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M3")
    L_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-K")
    TeraC = URIRef("http://qudt.org/vocab/unit/TeraC")
    KY = URIRef("http://qudt.org/vocab/unit/KY")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    GM_PER_MilliL_K = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL-K")
    BTU_TH_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_F")
    M = URIRef("http://qudt.org/vocab/unit/M")
    N_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-RAD")
    C_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM-SEC")
    GI_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_US-PER-SEC")
    CentiM_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-HR")
    KiloGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC")
    LB_SEC_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-YD3")
    PERCENT_FT_HR_PER_LB = URIRef("http://qudt.org/vocab/unit/PERCENT-FT-HR-PER-LB")
    OZ_HR_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-GAL_UK")
    MOL_LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-SEC")
    NanoBQ = URIRef("http://qudt.org/vocab/unit/NanoBQ")
    PER_M2 = URIRef("http://qudt.org/vocab/unit/PER-M2")
    MicroGM_PER_CentiM2_WK = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2-WK")
    MegaFLOPS = URIRef("http://qudt.org/vocab/unit/MegaFLOPS")
    KiloGM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM-PER-SEC")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    CentiN = URIRef("http://qudt.org/vocab/unit/CentiN")
    BIOT = URIRef("http://qudt.org/vocab/unit/BIOT")
    DEGREE_BALLING = URIRef("http://qudt.org/vocab/unit/DEGREE_BALLING")
    V_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/V-SEC-PER-M")
    MicroM3_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-MilliL")
    M2_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-V-SEC")
    KiloCAL = URIRef("http://qudt.org/vocab/unit/KiloCAL")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    GM_MIN_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L2")
    MegaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-M")
    HectoPA = URIRef("http://qudt.org/vocab/unit/HectoPA")
    SEC_PER_RAD_M3 = URIRef("http://qudt.org/vocab/unit/SEC-PER-RAD-M3")
    A_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-M3")
    TON_LONG_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_LONG-PER-YD3")
    MilliN_M = URIRef("http://qudt.org/vocab/unit/MilliN-M")
    A_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-PER-CentiM2")
    MicroSV = URIRef("http://qudt.org/vocab/unit/MicroSV")
    KiloPA_M2_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloPA-M2-PER-GM")
    DEGREE_BRIX = URIRef("http://qudt.org/vocab/unit/DEGREE_BRIX")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    C_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM2")
    GigaN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaN-M-PER-M2")
    OZ_VOL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-HR")
    WB_PER_MilliM = URIRef("http://qudt.org/vocab/unit/WB-PER-MilliM")
    MilliGM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-BAR")
    PER_T_SEC = URIRef("http://qudt.org/vocab/unit/PER-T-SEC")
    B_PER_M = URIRef("http://qudt.org/vocab/unit/B-PER-M")
    GM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL")
    MilliV_PER_V = URIRef("http://qudt.org/vocab/unit/MilliV-PER-V")
    MicroN_M = URIRef("http://qudt.org/vocab/unit/MicroN-M")
    ERLANG = URIRef("http://qudt.org/vocab/unit/ERLANG")
    DeciM3 = URIRef("http://qudt.org/vocab/unit/DeciM3")
    FT_SEC_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-GAL_UK")
    M3_PER_K = URIRef("http://qudt.org/vocab/unit/M3-PER-K")
    KiloCAL_TH = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH")
    MicroS = URIRef("http://qudt.org/vocab/unit/MicroS")
    MilliL_PER_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-K")
    KiloBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-HR")
    MilliGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-BAR")
    K_PER_BAR = URIRef("http://qudt.org/vocab/unit/K-PER-BAR")
    A_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-M2")
    NanoS = URIRef("http://qudt.org/vocab/unit/NanoS")
    A_M2_PER_J_SEC = URIRef("http://qudt.org/vocab/unit/A-M2-PER-J-SEC")
    PERCENT_PER_10KiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-10KiloCount")
    GM_SEC_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M3-CentiM3")
    M3_PER_M3 = URIRef("http://qudt.org/vocab/unit/M3-PER-M3")
    J_PER_MOL_K = URIRef("http://qudt.org/vocab/unit/J-PER-MOL-K")
    QT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_US-PER-SEC")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    CAL_TH_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM2-K")
    MicroM_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/MicroM-PER-L-DAY")
    PK_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-SEC")
    PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3")
    AttoJ = URIRef("http://qudt.org/vocab/unit/AttoJ")
    KiloGM_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-PA")
    M3_PER_MIN = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN")
    FT3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT3-PER-DEG_F")
    KiloWB = URIRef("http://qudt.org/vocab/unit/KiloWB")
    MilliMOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2-SEC")
    M3_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-BAR")
    TON_Metric_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY")
    TON_US_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_US-PER-HR")
    MOL_PER_GM_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-GM-HR")
    MilliGM_SEC_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M6")
    MegaC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M2")
    PSI_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-M3-PER-SEC")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    KiloGM_PER_M_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-MIN")
    ARCMIN = URIRef("http://qudt.org/vocab/unit/ARCMIN")
    M_K_PER_W = URIRef("http://qudt.org/vocab/unit/M-K-PER-W")
    KiloPA_A = URIRef("http://qudt.org/vocab/unit/KiloPA_A")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    PA_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PA-M2-PER-KiloGM")
    A_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-PER-CentiM2")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    M3_PER_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-M2")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    OZ_MIN_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-GAL_US")
    BTU_IT_IN_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-HR-FT2-DEG_F")
    PER_DEG_C = URIRef("http://qudt.org/vocab/unit/PER-DEG_C")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    MI_PER_SEC = URIRef("http://qudt.org/vocab/unit/MI-PER-SEC")
    MicroG = URIRef("http://qudt.org/vocab/unit/MicroG")
    OZ_VOL_UK = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK")
    CentiPOISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-BAR")
    MicroA = URIRef("http://qudt.org/vocab/unit/MicroA")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    ExbiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M3")
    GAL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-SEC")
    L_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-BAR")
    KiloMOL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-HR")
    L = URIRef("http://qudt.org/vocab/unit/L")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    MicroSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-MIN")
    REV_PER_SEC = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC")
    BTU_IT_PER_LB_MOL = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-MOL")
    PDL = URIRef("http://qudt.org/vocab/unit/PDL")
    MilliGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN")
    W_PER_M2_K = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K")
    ONE_PER_ONE = URIRef("http://qudt.org/vocab/unit/ONE-PER-ONE")
    K_M = URIRef("http://qudt.org/vocab/unit/K-M")
    MilliL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-MIN")
    MilliM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-HR")
    KiloCAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-MIN")
    TeraJ = URIRef("http://qudt.org/vocab/unit/TeraJ")
    GAL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-SEC")
    GM_PER_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-BAR")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    TeraC = URIRef("http://qudt.org/vocab/unit/TeraC")
    HectoPA_PER_K = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-K")
    FT_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-PER-MIN")
    MilliGM_MIN_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M3-CentiM3")
    V_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V-PER-CentiM")
    PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/PER-KiloGM2")
    NanoS = URIRef("http://qudt.org/vocab/unit/NanoS")
    PERCENT_PER_MilliM = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MilliM")
    KiloGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-PA-SEC")
    IN = URIRef("http://qudt.org/vocab/unit/IN")
    SLUG_PER_FT = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT")
    KiloGAUSS = URIRef("http://qudt.org/vocab/unit/KiloGAUSS")
    MegaBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaBQ-PER-KiloGM")
    MilliOHM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-M")
    TON_SHORT_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR")
    ERG_PER_G = URIRef("http://qudt.org/vocab/unit/ERG-PER-G")
    M2_PER_K = URIRef("http://qudt.org/vocab/unit/M2-PER-K")
    W_PER_M2_K4 = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K4")
    GAL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-MIN")
    KiloMOL_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3-BAR")
    KiloN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-M2")
    MicroIN = URIRef("http://qudt.org/vocab/unit/MicroIN")
    CORD = URIRef("http://qudt.org/vocab/unit/CORD")
    GRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/GRAY-PER-HR")
    PebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M2")
    MilliL_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR")
    C_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM-SEC")
    GI_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_US-PER-MIN")
    MicroMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-KiloGM")
    M3_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-K")
    MicroV_A = URIRef("http://qudt.org/vocab/unit/MicroV-A")
    TONNE_PER_SEC = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC")
    FT2_PER_HR = URIRef("http://qudt.org/vocab/unit/FT2-PER-HR")
    STR = URIRef("http://qudt.org/vocab/unit/STR")
    EU_PER_L = URIRef("http://qudt.org/vocab/unit/EU-PER-L")
    BTU_IT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MIN")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    FATH = URIRef("http://qudt.org/vocab/unit/FATH")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    M = URIRef("http://qudt.org/vocab/unit/M")
    L_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-MOL-SEC")
    DeciM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-KiloGM")
    OHM_CIRC_MIL_PER_FT = URIRef("http://qudt.org/vocab/unit/OHM_CIRC-MIL-PER-FT")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    BTU_IT_PER_LB_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F")
    L_PER_MOL = URIRef("http://qudt.org/vocab/unit/L-PER-MOL")
    M_H2O = URIRef("http://qudt.org/vocab/unit/M_H2O")
    OZ_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_UK")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    GigaPA = URIRef("http://qudt.org/vocab/unit/GigaPA")
    KiloPA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-K")
    T = URIRef("http://qudt.org/vocab/unit/T")
    DEG_F_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-K")
    MicroKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MicroKAT-PER-L")
    PER_OZ = URIRef("http://qudt.org/vocab/unit/PER-OZ")
    PA_PER_HR = URIRef("http://qudt.org/vocab/unit/PA-PER-HR")
    GibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M")
    LB_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-SEC")
    NanoC = URIRef("http://qudt.org/vocab/unit/NanoC")
    V_PER_MicroSEC = URIRef("http://qudt.org/vocab/unit/V-PER-MicroSEC")
    PERCENT_SEC_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-GAL_US")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    MegaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBIT-PER-SEC")
    GAL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-MIN")
    KiloN_M_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-M")
    PicoW = URIRef("http://qudt.org/vocab/unit/PicoW")
    CentiM3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-K")
    BTU_TH_PER_FT2_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-HR")
    LB_PER_YD = URIRef("http://qudt.org/vocab/unit/LB-PER-YD")
    MOL_PER_KiloGM_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-PA")
    MegaPA_M0dot5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0dot5")
    L_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-K")
    MicroH = URIRef("http://qudt.org/vocab/unit/MicroH")
    TONNE_PER_MIN = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN")
    DEG_C_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-HR")
    PA_PER_MIN = URIRef("http://qudt.org/vocab/unit/PA-PER-MIN")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    PicoM = URIRef("http://qudt.org/vocab/unit/PicoM")
    TONNE_PER_M3 = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3")
    MilliGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-MIN")
    OZ_F_IN = URIRef("http://qudt.org/vocab/unit/OZ_F-IN")
    KiloW_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloW-HR-PER-M2")
    MicroGM_PER_IN2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-IN2")
    MegaW_HR = URIRef("http://qudt.org/vocab/unit/MegaW-HR")
    BAUD = URIRef("http://qudt.org/vocab/unit/BAUD")
    N_PER_MilliM = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM")
    LB_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC-PSI")
    FT2 = URIRef("http://qudt.org/vocab/unit/FT2")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    BU_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-DAY")
    KiloCAL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-SEC")
    C_PER_MOL = URIRef("http://qudt.org/vocab/unit/C-PER-MOL")
    KY = URIRef("http://qudt.org/vocab/unit/KY")
    MicroL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroL-PER-L")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    GM_PER_MIN = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN")
    KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloMOL")
    NanoC = URIRef("http://qudt.org/vocab/unit/NanoC")
    DeciM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MIN")
    MicroGRAY = URIRef("http://qudt.org/vocab/unit/MicroGRAY")
    MicroM_PER_M = URIRef("http://qudt.org/vocab/unit/MicroM-PER-M")
    KiloBTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-FT2")
    MilliW_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM-SR")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    M3_PER_C = URIRef("http://qudt.org/vocab/unit/M3-PER-C")
    QT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-HR")
    MicroS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MicroS-PER-CentiM")
    TONNE_PER_M3 = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    DEG_C_GROWING_CEREAL_DAY = URIRef("http://qudt.org/vocab/unit/DEG_C_GROWING_CEREAL-DAY")
    MegaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBYTE-PER-SEC")
    CentiM3_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-K")
    KiloCAL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MIN")
    KiloN_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M2")
    MegaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M2")
    MicroGM = URIRef("http://qudt.org/vocab/unit/MicroGM")
    LB_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-DEG_F")
    OERSTED_CentiM = URIRef("http://qudt.org/vocab/unit/OERSTED-CentiM")
    MOL_PER_L = URIRef("http://qudt.org/vocab/unit/MOL-PER-L")
    AC_FT_US = URIRef("http://qudt.org/vocab/unit/AC-FT_US")
    BTU_IT_PER_LB_F_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_R")
    GM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-K")
    Megahertz_KiloM = URIRef("http://qudt.org/vocab/unit/Megahertz-KiloM")
    MegaBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaBTU_IT-PER-HR")
    HectoBAR = URIRef("http://qudt.org/vocab/unit/HectoBAR")
    DeciB_MilliW = URIRef("http://qudt.org/vocab/unit/DeciB-MilliW")
    CI_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CI-PER-KiloGM")
    PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2")
    BTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR")
    MilliA_HR = URIRef("http://qudt.org/vocab/unit/MilliA-HR")
    YR_TROPICAL = URIRef("http://qudt.org/vocab/unit/YR_TROPICAL")
    PSI_PER_PSI = URIRef("http://qudt.org/vocab/unit/PSI-PER-PSI")
    MilliL_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-K")
    CentiM_H2O_4DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_H2O_4DEG_C")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    LB_F_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN")
    PicoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-MilliL")
    GM_MilliM = URIRef("http://qudt.org/vocab/unit/GM-MilliM")
    MicroPOISE = URIRef("http://qudt.org/vocab/unit/MicroPOISE")
    M2_PER_KiloW = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloW")
    OZ_F = URIRef("http://qudt.org/vocab/unit/OZ_F")
    FARAD_Ab = URIRef("http://qudt.org/vocab/unit/FARAD_Ab")
    W_PER_SR = URIRef("http://qudt.org/vocab/unit/W-PER-SR")
    C_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM")
    MilliBQ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-GM")
    N_M_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-RAD")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    CD_PER_FT2 = URIRef("http://qudt.org/vocab/unit/CD-PER-FT2")
    OZ_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN3")
    DEG_F_HR_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_IT")
    N_M2_PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/N-M2-PER-KiloGM2")
    M2_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-K")
    IN_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC-DEG_F")
    IN_HG = URIRef("http://qudt.org/vocab/unit/IN_HG")
    A_Ab = URIRef("http://qudt.org/vocab/unit/A_Ab")
    CentiM3_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-CentiM3")
    CH = URIRef("http://qudt.org/vocab/unit/CH")
    PERCENT_SEC_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-L")
    ERG_PER_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-SEC")
    S = URIRef("http://qudt.org/vocab/unit/S")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    KiloHZ_M = URIRef("http://qudt.org/vocab/unit/KiloHZ-M")
    EV_PER_M = URIRef("http://qudt.org/vocab/unit/EV-PER-M")
    LM_SEC = URIRef("http://qudt.org/vocab/unit/LM-SEC")
    PlanckVolt = URIRef("http://qudt.org/vocab/unit/PlanckVolt")
    MilliGRAY = URIRef("http://qudt.org/vocab/unit/MilliGRAY")
    M3_PER_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-BAR")
    MegaJ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-K")
    FR = URIRef("http://qudt.org/vocab/unit/FR")
    YD3 = URIRef("http://qudt.org/vocab/unit/YD3")
    BTU_TH_PER_FT2_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-MIN")
    DEG_R_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-HR")
    KiloGM_PER_M_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC")
    EV = URIRef("http://qudt.org/vocab/unit/EV")
    Stone_UK = URIRef("http://qudt.org/vocab/unit/Stone_UK")
    LB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT")
    LB_MIN_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-IN3")
    MilliM_HGA = URIRef("http://qudt.org/vocab/unit/MilliM_HGA")
    BAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/BAR-PER-BAR")
    KiloGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-BAR")
    BARN_PER_EV = URIRef("http://qudt.org/vocab/unit/BARN-PER-EV")
    MOMME_Pearl = URIRef("http://qudt.org/vocab/unit/MOMME_Pearl")
    MilliGM_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-HR")
    LB_F = URIRef("http://qudt.org/vocab/unit/LB_F")
    M2_SR = URIRef("http://qudt.org/vocab/unit/M2-SR")
    M2_HR_DEG_C_PER_KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/M2-HR-DEG_C-PER-KiloCAL_IT")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    CentiMOL_PER_L = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-L")
    PER_FT3 = URIRef("http://qudt.org/vocab/unit/PER-FT3")
    FemtoMOL = URIRef("http://qudt.org/vocab/unit/FemtoMOL")
    KiloGM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM")
    PlanckImpedance = URIRef("http://qudt.org/vocab/unit/PlanckImpedance")
    DeciB_PER_KiloM = URIRef("http://qudt.org/vocab/unit/DeciB-PER-KiloM")
    N_M2_PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/N-M2-PER-KiloGM2")
    MegaTOE = URIRef("http://qudt.org/vocab/unit/MegaTOE")
    PlanckEnergy = URIRef("http://qudt.org/vocab/unit/PlanckEnergy")
    GI_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-SEC")
    BTU_IT_FT = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT")
    KiloGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-PA-SEC")
    LB_SEC_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-FT3")
    PlanckImpedance = URIRef("http://qudt.org/vocab/unit/PlanckImpedance")
    W_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-SEC-PER-M2")
    LB_HR_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US2")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    FUR = URIRef("http://qudt.org/vocab/unit/FUR")
    TonEnergy = URIRef("http://qudt.org/vocab/unit/TonEnergy")
    ONE_PER_ONE = URIRef("http://qudt.org/vocab/unit/ONE-PER-ONE")
    J_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-M2-PER-KiloGM")
    KiloCAL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MIN")
    YD = URIRef("http://qudt.org/vocab/unit/YD")
    PicoFARAD = URIRef("http://qudt.org/vocab/unit/PicoFARAD")
    K_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PER-SEC")
    PicoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-MilliL")
    W_M2 = URIRef("http://qudt.org/vocab/unit/W-M2")
    W_PER_SR_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-SR-M2")
    PERCENT_MIN_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-IN3")
    MilliDEG_C = URIRef("http://qudt.org/vocab/unit/MilliDEG_C")
    GigaV_A = URIRef("http://qudt.org/vocab/unit/GigaV-A")
    MicroA = URIRef("http://qudt.org/vocab/unit/MicroA")
    DeciL_PER_GM = URIRef("http://qudt.org/vocab/unit/DeciL-PER-GM")
    MegaHZ_M = URIRef("http://qudt.org/vocab/unit/MegaHZ-M")
    REV_PER_MIN = URIRef("http://qudt.org/vocab/unit/REV-PER-MIN")
    PA2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA2-PER-SEC2")
    DeciBAR = URIRef("http://qudt.org/vocab/unit/DeciBAR")
    KiloCi = URIRef("http://qudt.org/vocab/unit/KiloCi")
    PER_MILLE_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PSI")
    LM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LM-PER-FT2")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    N_M_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-RAD")
    LB_PER_YD = URIRef("http://qudt.org/vocab/unit/LB-PER-YD")
    LB_PER_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-HR")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    MicroSEC = URIRef("http://qudt.org/vocab/unit/MicroSEC")
    KiloGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-SEC")
    IN2 = URIRef("http://qudt.org/vocab/unit/IN2")
    MilliBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-L")
    PERMEABILITY_EM_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_EM_REL")
    H = URIRef("http://qudt.org/vocab/unit/H")
    MilliN_M = URIRef("http://qudt.org/vocab/unit/MilliN-M")
    ExaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/ExaJ-PER-SEC")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    MicroA = URIRef("http://qudt.org/vocab/unit/MicroA")
    KiloGM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM")
    N_M_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-M")
    KiloW_PER_M2_K = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M2-K")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    M3_PER_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-M2")
    GAL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-HR")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    GM_HR_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M3-L")
    PERCENT_PER_DEGREE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEGREE")
    MOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2")
    GM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL")
    TON_SHORT_PER_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR-DEG_F")
    MI_UK3 = URIRef("http://qudt.org/vocab/unit/MI_UK3")
    N_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-PER-M3")
    MegaLB_F = URIRef("http://qudt.org/vocab/unit/MegaLB_F")
    MilliGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-SEC")
    PlanckMass = URIRef("http://qudt.org/vocab/unit/PlanckMass")
    M_SEC2 = URIRef("http://qudt.org/vocab/unit/M-SEC2")
    KiloPA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-MilliM")
    PK_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-MIN")
    H_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/H_Stat-PER-CentiM")
    PERCENT_PER_MO = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MO")
    KiloGM_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-M2")
    GM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN-BAR")
    CentiN_M = URIRef("http://qudt.org/vocab/unit/CentiN-M")
    NanoGM_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2-DAY")
    ERG = URIRef("http://qudt.org/vocab/unit/ERG")
    MicroFARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-KiloM")
    KiloC = URIRef("http://qudt.org/vocab/unit/KiloC")
    PERCENT_MIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-M3")
    CentiM3_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-BAR")
    M = URIRef("http://qudt.org/vocab/unit/M")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    V_Stat = URIRef("http://qudt.org/vocab/unit/V_Stat")
    EUR_PER_W_HR = URIRef("http://qudt.org/vocab/unit/EUR-PER-W-HR")
    MegaPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-M3-PER-SEC")
    M_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-PA")
    KiloPA = URIRef("http://qudt.org/vocab/unit/KiloPA")
    M2_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/M2-SEC-PER-RAD")
    NanoJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoJ-PER-SEC")
    W_PER_M = URIRef("http://qudt.org/vocab/unit/W-PER-M")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    BAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/BAR-PER-BAR")
    MicroH_PER_M = URIRef("http://qudt.org/vocab/unit/MicroH-PER-M")
    M3_PER_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-M2")
    CentiM3_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY-BAR")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloGM-K")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    K2 = URIRef("http://qudt.org/vocab/unit/K2")
    M2_PER_M2 = URIRef("http://qudt.org/vocab/unit/M2-PER-M2")
    MilliA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliA-PER-BAR")
    SEC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/SEC-PER-KiloGM")
    MilliS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MilliS-PER-CentiM")
    J_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K")
    FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-SEC-DEG_F")
    PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2")
    W_PER_GM = URIRef("http://qudt.org/vocab/unit/W-PER-GM")
    NanoM2 = URIRef("http://qudt.org/vocab/unit/NanoM2")
    NanoH = URIRef("http://qudt.org/vocab/unit/NanoH")
    DeciGM = URIRef("http://qudt.org/vocab/unit/DeciGM")
    Pennyweight = URIRef("http://qudt.org/vocab/unit/Pennyweight")
    GM_PER_HR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR")
    PERCENT_PER_MilliM = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MilliM")
    A = URIRef("http://qudt.org/vocab/unit/A")
    GM_MIN_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M3-L")
    OZ_VOL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-MIN")
    BTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    KiloCAL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-SEC")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    LB_F_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN")
    TeraV = URIRef("http://qudt.org/vocab/unit/TeraV")
    TONNE_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC-K")
    MilliGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-K")
    RAD_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-MOL")
    MegaEV_FemtoM = URIRef("http://qudt.org/vocab/unit/MegaEV-FemtoM")
    NanoMOL_PER_MicroGM_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroGM-HR")
    MegaW = URIRef("http://qudt.org/vocab/unit/MegaW")
    CAL_IT_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM")
    KiloHZ_M = URIRef("http://qudt.org/vocab/unit/KiloHZ-M")
    KiloJ_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM-K")
    IN = URIRef("http://qudt.org/vocab/unit/IN")
    MicroGM_PER_IN2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-IN2")
    M2_SR = URIRef("http://qudt.org/vocab/unit/M2-SR")
    C = URIRef("http://qudt.org/vocab/unit/C")
    LB_F_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-FT2")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    MicroGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    PERCENT_PER_DecaCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaCount")
    LB_PER_IN3 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3")
    CAL_IT_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-DEG_C")
    OZ_MIN_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-YD3")
    H_PER_M = URIRef("http://qudt.org/vocab/unit/H-PER-M")
    MOL_PER_GM_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-GM-HR")
    MilliGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    MicroGM = URIRef("http://qudt.org/vocab/unit/MicroGM")
    KiloMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3")
    E = URIRef("http://qudt.org/vocab/unit/E")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    MegaW_HR = URIRef("http://qudt.org/vocab/unit/MegaW-HR")
    MilliV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/MilliV-A_Reactive-PER-K")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    TeraBQ = URIRef("http://qudt.org/vocab/unit/TeraBQ")
    GM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM_F-PER-CentiM2")
    FemtoM = URIRef("http://qudt.org/vocab/unit/FemtoM")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    V_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V-PER-CentiM")
    YR = URIRef("http://qudt.org/vocab/unit/YR")
    DEG_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC")
    KiloCAL_PER_MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL-DEG_C")
    M3_PER_KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM-SEC2")
    MOL_PER_M2_SEC_M = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-M")
    RAYL = URIRef("http://qudt.org/vocab/unit/RAYL")
    DEG_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG-PER-MIN")
    ARCMIN = URIRef("http://qudt.org/vocab/unit/ARCMIN")
    SPIN_QUANTUM_NUMBER = URIRef("http://qudt.org/vocab/unit/SPIN_QUANTUM_NUMBER")
    FRACTION = URIRef("http://qudt.org/vocab/unit/FRACTION")
    GAUSS = URIRef("http://qudt.org/vocab/unit/GAUSS")
    KiloM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC2")
    BTU_IT_PER_LB_F_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_R")
    OZ = URIRef("http://qudt.org/vocab/unit/OZ")
    PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-PER-SEC")
    DEG_C_PER_M = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-M")
    PINT_US_DRY = URIRef("http://qudt.org/vocab/unit/PINT_US_DRY")
    FT_PER_PSI = URIRef("http://qudt.org/vocab/unit/FT-PER-PSI")
    LB_HR_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN6")
    YR_Sidereal = URIRef("http://qudt.org/vocab/unit/YR_Sidereal")
    V = URIRef("http://qudt.org/vocab/unit/V")
    J_SEC_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-SEC-PER-MOL")
    PER_LB = URIRef("http://qudt.org/vocab/unit/PER-LB")
    SLUG_PER_FT2 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT2")
    MicroH_PER_M = URIRef("http://qudt.org/vocab/unit/MicroH-PER-M")
    GigaHZ = URIRef("http://qudt.org/vocab/unit/GigaHZ")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    SUSCEPTIBILITY_ELEC = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_ELEC")
    YR_TROPICAL = URIRef("http://qudt.org/vocab/unit/YR_TROPICAL")
    KiloGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-BAR")
    W_PER_M_DEG_C = URIRef("http://qudt.org/vocab/unit/W-PER-M-DEG_C")
    J_PER_HR = URIRef("http://qudt.org/vocab/unit/J-PER-HR")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    MicroV = URIRef("http://qudt.org/vocab/unit/MicroV")
    NanoOHM = URIRef("http://qudt.org/vocab/unit/NanoOHM")
    CASES_PER_KiloINDIV_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-KiloINDIV-YR")
    Gs = URIRef("http://qudt.org/vocab/unit/Gs")
    KiloGM_PER_M2_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC2")
    OZ_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN3")
    GM_PER_MilliM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM-BAR")
    OCTET_PER_SEC = URIRef("http://qudt.org/vocab/unit/OCTET-PER-SEC")
    PlanckMass = URIRef("http://qudt.org/vocab/unit/PlanckMass")
    KiloC = URIRef("http://qudt.org/vocab/unit/KiloC")
    ARCSEC = URIRef("http://qudt.org/vocab/unit/ARCSEC")
    RPK = URIRef("http://qudt.org/vocab/unit/RPK")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    MilliGM_HR_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L-M3")
    MIL = URIRef("http://qudt.org/vocab/unit/MIL")
    MilliM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliM-PER-MIN")
    DeciB_MilliW = URIRef("http://qudt.org/vocab/unit/DeciB-MilliW")
    KiloM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC")
    NanoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-KiloGM")
    GM_PER_L_K = URIRef("http://qudt.org/vocab/unit/GM-PER-L-K")
    PK_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-DAY")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    MilliN_PER_M = URIRef("http://qudt.org/vocab/unit/MilliN-PER-M")
    GM_PER_CentiM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM-BAR")
    KiloBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloBQ-PER-KiloGM")
    MegaBQ = URIRef("http://qudt.org/vocab/unit/MegaBQ")
    M2_PER_SR = URIRef("http://qudt.org/vocab/unit/M2-PER-SR")
    PINT_US_DRY = URIRef("http://qudt.org/vocab/unit/PINT_US_DRY")
    GM_MIN_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M3-L")
    YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD3-PER-SEC")
    DEG_C_CentiM = URIRef("http://qudt.org/vocab/unit/DEG_C-CentiM")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    CORD = URIRef("http://qudt.org/vocab/unit/CORD")
    MilliL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliL-PER-L")
    BTU_IT_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_R")
    M2_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-K")
    OZ_VOL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-MIN")
    Stone_UK = URIRef("http://qudt.org/vocab/unit/Stone_UK")
    PicoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    PicoGM = URIRef("http://qudt.org/vocab/unit/PicoGM")
    MilliGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-K")
    GigaBIT_PER_M = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-M")
    ERG_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM-SEC")
    DEGREE_OECHSLE = URIRef("http://qudt.org/vocab/unit/DEGREE_OECHSLE")
    MilliM2 = URIRef("http://qudt.org/vocab/unit/MilliM2")
    GM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL")
    LM_SEC = URIRef("http://qudt.org/vocab/unit/LM-SEC")
    PA_M0pt5 = URIRef("http://qudt.org/vocab/unit/PA-M0pt5")
    L_PER_HR_K = URIRef("http://qudt.org/vocab/unit/L-PER-HR-K")
    BARYE = URIRef("http://qudt.org/vocab/unit/BARYE")
    MicroGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-K")
    KiloBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-HR")
    MilliBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-L")
    MilliGRAY = URIRef("http://qudt.org/vocab/unit/MilliGRAY")
    PicoV_A = URIRef("http://qudt.org/vocab/unit/PicoV-A")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    A_HR = URIRef("http://qudt.org/vocab/unit/A-HR")
    TeraW = URIRef("http://qudt.org/vocab/unit/TeraW")
    GRAIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-M3")
    BTU_IT_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB")
    CentiMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-KiloGM")
    GM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM")
    KiloGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-K")
    GigaV_A_Reactive = URIRef("http://qudt.org/vocab/unit/GigaV-A_Reactive")
    PERCENT_MIN_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-FT3")
    W_PER_GM = URIRef("http://qudt.org/vocab/unit/W-PER-GM")
    A_HR_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-DeciM3")
    DPI = URIRef("http://qudt.org/vocab/unit/DPI")
    HP = URIRef("http://qudt.org/vocab/unit/HP")
    PERCENT_PER_POISE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-POISE")
    LB_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_US")
    MOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-DAY")
    KiloJ_PER_KiloV = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloV")
    TeraOHM = URIRef("http://qudt.org/vocab/unit/TeraOHM")
    V_PER_SEC = URIRef("http://qudt.org/vocab/unit/V-PER-SEC")
    J_PER_GM = URIRef("http://qudt.org/vocab/unit/J-PER-GM")
    SUSCEPTIBILITY_ELEC = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_ELEC")
    MilliPA = URIRef("http://qudt.org/vocab/unit/MilliPA")
    TeraW = URIRef("http://qudt.org/vocab/unit/TeraW")
    LB_MIN_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-YD3")
    MilliM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliM-PER-MIN")
    L_PER_L = URIRef("http://qudt.org/vocab/unit/L-PER-L")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    PINT_US = URIRef("http://qudt.org/vocab/unit/PINT_US")
    NanoGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M2-PA-SEC")
    GM_PER_M3_CentiPOISE = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-CentiPOISE")
    PK_US_DRY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY")
    KiloH = URIRef("http://qudt.org/vocab/unit/KiloH")
    LB_F_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-IN2")
    BTU_IT_PER_FT2_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR")
    KiloGM_M = URIRef("http://qudt.org/vocab/unit/KiloGM-M")
    FT_PER_PSI = URIRef("http://qudt.org/vocab/unit/FT-PER-PSI")
    MicroBQ = URIRef("http://qudt.org/vocab/unit/MicroBQ")
    GAL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-MIN")
    TON_US = URIRef("http://qudt.org/vocab/unit/TON_US")
    M2_PER_HA = URIRef("http://qudt.org/vocab/unit/M2-PER-HA")
    N_PER_MilliM = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM")
    TONNE_PER_M3_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3-K")
    LB_F_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN")
    PERM_23DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_23DEG_C")
    QT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-DAY")
    A_Ab = URIRef("http://qudt.org/vocab/unit/A_Ab")
    PER_DEG_F = URIRef("http://qudt.org/vocab/unit/PER-DEG_F")
    MebiBYTE = URIRef("http://qudt.org/vocab/unit/MebiBYTE")
    LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN")
    GM_PER_M3_PA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-PA-SEC")
    K_PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PA-PER-SEC")
    TebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M")
    MicroGM_PER_IN2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-IN2")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    MilliL_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY")
    MicroA = URIRef("http://qudt.org/vocab/unit/MicroA")
    MilliL_PER_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-K")
    W_PER_M2_M = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M")
    H = URIRef("http://qudt.org/vocab/unit/H")
    KiloGM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM-PER-SEC")
    PER_M_SR = URIRef("http://qudt.org/vocab/unit/PER-M-SR")
    GAL_UK = URIRef("http://qudt.org/vocab/unit/GAL_UK")
    MilliM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliM-PER-MIN")
    SUSCEPTIBILITY_ELEC = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_ELEC")
    GM_PER_MilliL_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL-BAR")
    LB_PER_GAL = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL")
    CentiL = URIRef("http://qudt.org/vocab/unit/CentiL")
    L_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-K")
    FARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/FARAD-PER-KiloM")
    MilliBAR_PER_K = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-K")
    GigaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-HR")
    PSI_PER_PSI = URIRef("http://qudt.org/vocab/unit/PSI-PER-PSI")
    N_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-PER-KiloGM")
    MicroH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-OHM")
    PER_DAY = URIRef("http://qudt.org/vocab/unit/PER-DAY")
    M3_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-M2")
    MicroV_PER_M = URIRef("http://qudt.org/vocab/unit/MicroV-PER-M")
    BTU_TH_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_F")
    BU_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-HR")
    M_KiloGM = URIRef("http://qudt.org/vocab/unit/M-KiloGM")
    M_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-PA")
    DEG_F_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-HR")
    MicroATM = URIRef("http://qudt.org/vocab/unit/MicroATM")
    PicoH = URIRef("http://qudt.org/vocab/unit/PicoH")
    PER_M_SR = URIRef("http://qudt.org/vocab/unit/PER-M-SR")
    L_PER_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-SEC")
    MilliV_PER_V = URIRef("http://qudt.org/vocab/unit/MilliV-PER-V")
    MegaBQ = URIRef("http://qudt.org/vocab/unit/MegaBQ")
    KiloGM_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MOL")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    KiloGAUSS = URIRef("http://qudt.org/vocab/unit/KiloGAUSS")
    MilliGM_PER_M3_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-MilliPA-SEC")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3")
    MilliL_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-BAR")
    SLUG = URIRef("http://qudt.org/vocab/unit/SLUG")
    PA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M3-PER-SEC")
    MilliH = URIRef("http://qudt.org/vocab/unit/MilliH")
    TONNE_PER_M3 = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3")
    MACH = URIRef("http://qudt.org/vocab/unit/MACH")
    KiloGM_PER_GigaJ = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-GigaJ")
    MilliN = URIRef("http://qudt.org/vocab/unit/MilliN")
    GM_SEC_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L-CentiM3")
    PA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-L-PER-SEC")
    MegaEV = URIRef("http://qudt.org/vocab/unit/MegaEV")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    YoctoC = URIRef("http://qudt.org/vocab/unit/YoctoC")
    BU_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-HR")
    NanoM2 = URIRef("http://qudt.org/vocab/unit/NanoM2")
    PER_MegaK = URIRef("http://qudt.org/vocab/unit/PER-MegaK")
    DEGREE_API = URIRef("http://qudt.org/vocab/unit/DEGREE_API")
    KiloGM_F_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-SEC")
    MegaV_PER_M = URIRef("http://qudt.org/vocab/unit/MegaV-PER-M")
    PER_K = URIRef("http://qudt.org/vocab/unit/PER-K")
    PER_PA_SEC = URIRef("http://qudt.org/vocab/unit/PER-PA-SEC")
    GigaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-PER-M")
    M3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-K")
    LB_M = URIRef("http://qudt.org/vocab/unit/LB_M")
    MicroGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-KiloGM")
    TONNE_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY-K")
    TON_UK_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-YD3")
    ERLANG = URIRef("http://qudt.org/vocab/unit/ERLANG")
    MilliW_PER_CentiM2_MicroM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-CentiM2-MicroM-SR")
    GigaOHM = URIRef("http://qudt.org/vocab/unit/GigaOHM")
    MicroOHM = URIRef("http://qudt.org/vocab/unit/MicroOHM")
    THM_EEC = URIRef("http://qudt.org/vocab/unit/THM_EEC")
    DeciL_PER_GM = URIRef("http://qudt.org/vocab/unit/DeciL-PER-GM")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    MilliDARCY = URIRef("http://qudt.org/vocab/unit/MilliDARCY")
    MegaJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-KiloGM")
    LB_HR_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-GAL_UK")
    PlanckVolume = URIRef("http://qudt.org/vocab/unit/PlanckVolume")
    M3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC2")
    MicroH = URIRef("http://qudt.org/vocab/unit/MicroH")
    MilliBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-KiloGM")
    LB_HR_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK2")
    LB_MIN_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-GAL_US")
    MilliL_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-BAR")
    N_M_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-RAD")
    YD_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD-PER-DEG_F")
    SEC_PER_M = URIRef("http://qudt.org/vocab/unit/SEC-PER-M")
    PPTR_VOL = URIRef("http://qudt.org/vocab/unit/PPTR_VOL")
    BTU_59DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_59DEG_F")
    TON_Metric_PER_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-K")
    MicroMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L")
    MilliBAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-M3-PER-SEC")
    PER_M2 = URIRef("http://qudt.org/vocab/unit/PER-M2")
    PERCENT_PER_DEGREE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEGREE")
    W_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/W-PER-CentiM2")
    KiloCAL_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL")
    TON_Metric_PER_M3 = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3")
    N_M_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-M")
    C_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM3")
    PER_K = URIRef("http://qudt.org/vocab/unit/PER-K")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    A_M2_PER_J_SEC = URIRef("http://qudt.org/vocab/unit/A-M2-PER-J-SEC")
    NanoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-KiloGM")
    PERCENT_PER_KiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-KiloCount")
    OZ_FT_HR_PER_IN3_LB = URIRef("http://qudt.org/vocab/unit/OZ-FT-HR-PER-IN3-LB")
    DEGREE_BAUME = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    LB_PER_YD3 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD3")
    MegaDOLLAR_US_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MegaDOLLAR_US-PER-FLIGHT")
    LB_PER_IN3_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3-PSI")
    PER_PERCENT = URIRef("http://qudt.org/vocab/unit/PER-PERCENT")
    MilliGM_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-DAY")
    H = URIRef("http://qudt.org/vocab/unit/H")
    KiloGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-K")
    M3_PER_KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM-SEC2")
    SEC_PER_RAD_M3 = URIRef("http://qudt.org/vocab/unit/SEC-PER-RAD-M3")
    PA_PER_MIN = URIRef("http://qudt.org/vocab/unit/PA-PER-MIN")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    CWT_LONG = URIRef("http://qudt.org/vocab/unit/CWT_LONG")
    MicroOHM = URIRef("http://qudt.org/vocab/unit/MicroOHM")
    M3_PER_K = URIRef("http://qudt.org/vocab/unit/M3-PER-K")
    MicroM_PER_M = URIRef("http://qudt.org/vocab/unit/MicroM-PER-M")
    QT_UK = URIRef("http://qudt.org/vocab/unit/QT_UK")
    MicroSEC = URIRef("http://qudt.org/vocab/unit/MicroSEC")
    DEG_C2_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C2-PER-SEC")
    BTU_IT_PER_MOL_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB")
    LB_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-DEG_F")
    BTU_IT_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC-DEG_F")
    BTU_IT_PER_MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB-DEG_F")
    MicroGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-K")
    ST = URIRef("http://qudt.org/vocab/unit/ST")
    GM_PER_L_PA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-L-PA-SEC")
    W = URIRef("http://qudt.org/vocab/unit/W")
    W_PER_M_DEG_C = URIRef("http://qudt.org/vocab/unit/W-PER-M-DEG_C")
    CAL_IT_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-DEG_C")
    MicroOHM = URIRef("http://qudt.org/vocab/unit/MicroOHM")
    KiloEV_PER_MicroM = URIRef("http://qudt.org/vocab/unit/KiloEV-PER-MicroM")
    MegaV = URIRef("http://qudt.org/vocab/unit/MegaV")
    KiloGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-BAR")
    W_HR = URIRef("http://qudt.org/vocab/unit/W-HR")
    BTU_IT_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-HR-DEG_F")
    LB_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-MOL-DEG_F")
    KiloLB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-FT")
    BIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/BIT-PER-M2")
    DEG_C_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-K")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    MilliN_M = URIRef("http://qudt.org/vocab/unit/MilliN-M")
    FUR = URIRef("http://qudt.org/vocab/unit/FUR")
    DeciM3_PER_HR = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-HR")
    KiloN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-M2")
    LB_PER_MIN_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN-PSI")
    MilliH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-KiloOHM")
    MegaEV_FemtoM = URIRef("http://qudt.org/vocab/unit/MegaEV-FemtoM")
    BTU_IT_PER_LB_F_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_R")
    ExaJ = URIRef("http://qudt.org/vocab/unit/ExaJ")
    PlanckPower = URIRef("http://qudt.org/vocab/unit/PlanckPower")
    MilliMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-KiloGM")
    REV_PER_HR = URIRef("http://qudt.org/vocab/unit/REV-PER-HR")
    KiloMOL_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3-K")
    TONNE_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN-K")
    CAL_15_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_15_DEG_C")
    GI_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-DAY")
    C_Ab = URIRef("http://qudt.org/vocab/unit/C_Ab")
    MilliGM_SEC_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M3-CentiM3")
    NanoA_PER_K = URIRef("http://qudt.org/vocab/unit/NanoA-PER-K")
    N_PER_A = URIRef("http://qudt.org/vocab/unit/N-PER-A")
    MilliMOL = URIRef("http://qudt.org/vocab/unit/MilliMOL")
    PT_BIG = URIRef("http://qudt.org/vocab/unit/PT_BIG")
    M3_PER_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-M2")
    THM_US_PER_HR = URIRef("http://qudt.org/vocab/unit/THM_US-PER-HR")
    KiloOHM_M = URIRef("http://qudt.org/vocab/unit/KiloOHM-M")
    BBL_US = URIRef("http://qudt.org/vocab/unit/BBL_US")
    V_PER_BAR = URIRef("http://qudt.org/vocab/unit/V-PER-BAR")
    TeraW_HR = URIRef("http://qudt.org/vocab/unit/TeraW-HR")
    DEG_F_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-K")
    MilliM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DAY")
    BTU_IT_PER_LB_MOL = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-MOL")
    DeciB_M = URIRef("http://qudt.org/vocab/unit/DeciB_M")
    NanoGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M2-PA-SEC")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    KiloGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC")
    OHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/OHM-PER-BAR")
    PlanckImpedance = URIRef("http://qudt.org/vocab/unit/PlanckImpedance")
    OZ_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ-PER-HR")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    MOHM = URIRef("http://qudt.org/vocab/unit/MOHM")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    MilliK_PER_K = URIRef("http://qudt.org/vocab/unit/MilliK-PER-K")
    LB_F_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-FT2")
    LB_HR_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-GAL_US")
    MI_N = URIRef("http://qudt.org/vocab/unit/MI_N")
    PlanckDensity = URIRef("http://qudt.org/vocab/unit/PlanckDensity")
    OHM_CIRC_MIL_PER_FT = URIRef("http://qudt.org/vocab/unit/OHM_CIRC-MIL-PER-FT")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    LA = URIRef("http://qudt.org/vocab/unit/LA")
    PA_PER_M = URIRef("http://qudt.org/vocab/unit/PA-PER-M")
    J = URIRef("http://qudt.org/vocab/unit/J")
    CentiM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SEC")
    PicoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/PicoW-PER-M2")
    PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/PER-M2-SEC")
    TeraOHM = URIRef("http://qudt.org/vocab/unit/TeraOHM")
    KiloCAL_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL")
    MilliV_A = URIRef("http://qudt.org/vocab/unit/MilliV-A")
    PER_HR = URIRef("http://qudt.org/vocab/unit/PER-HR")
    PPTR_VOL = URIRef("http://qudt.org/vocab/unit/PPTR_VOL")
    M2_PER_SEC2_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2-K")
    KiloA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M")
    ARCMIN = URIRef("http://qudt.org/vocab/unit/ARCMIN")
    KiloBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT")
    DYN_SEC_PER_CentiM5 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM5")
    KiloGM_F_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-MilliM2")
    PDL = URIRef("http://qudt.org/vocab/unit/PDL")
    MicroGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-HR")
    BAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-L-PER-SEC")
    KiloLB_F_FT_PER_A = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-A")
    MebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M3")
    M_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-V-SEC")
    FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/FT2-PER-BTU_IT-IN")
    KiloGM_F = URIRef("http://qudt.org/vocab/unit/KiloGM_F")
    TORR = URIRef("http://qudt.org/vocab/unit/TORR")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    MilliJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-M2")
    W_M2 = URIRef("http://qudt.org/vocab/unit/W-M2")
    MOL_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-DeciM3")
    LB_PER_LB = URIRef("http://qudt.org/vocab/unit/LB-PER-LB")
    J_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K")
    FT_LB_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-SEC")
    LB_PER_FT = URIRef("http://qudt.org/vocab/unit/LB-PER-FT")
    GigaPA_CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/GigaPA-CentiM3-PER-GM")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    DecaM = URIRef("http://qudt.org/vocab/unit/DecaM")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    V_PER_K = URIRef("http://qudt.org/vocab/unit/V-PER-K")
    FT2_PER_HR = URIRef("http://qudt.org/vocab/unit/FT2-PER-HR")
    HectoPA_PER_HR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-HR")
    STILB = URIRef("http://qudt.org/vocab/unit/STILB")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    PA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-BAR")
    W_PER_M_DEG_C = URIRef("http://qudt.org/vocab/unit/W-PER-M-DEG_C")
    DEGREE_BAUME = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME")
    DYN_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM3")
    DEG_R_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-SEC")
    QT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-DAY")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    IN_PER_PSI = URIRef("http://qudt.org/vocab/unit/IN-PER-PSI")
    J_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-GM-DEG_C")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    N_M2_PER_A = URIRef("http://qudt.org/vocab/unit/N-M2-PER-A")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    KiloGAUSS = URIRef("http://qudt.org/vocab/unit/KiloGAUSS")
    MilliOHM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-K")
    MicroGM_PER_CentiM2_WK = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2-WK")
    K_PER_M = URIRef("http://qudt.org/vocab/unit/K-PER-M")
    NUM_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/NUM-PER-MilliGM")
    KiloM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC")
    LB_SEC_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN6")
    L_PER_L = URIRef("http://qudt.org/vocab/unit/L-PER-L")
    CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CentiM2-MIN")
    M2_PER_HZ_DEG = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ-DEG")
    OZ_PER_IN2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN2")
    V_PER_SEC = URIRef("http://qudt.org/vocab/unit/V-PER-SEC")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    NanoM_PER_CentiM_PSI = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-PSI")
    SUSCEPTIBILITY_MAG = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_MAG")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    MilliPA = URIRef("http://qudt.org/vocab/unit/MilliPA")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    M_PER_BAR = URIRef("http://qudt.org/vocab/unit/M-PER-BAR")
    MilliM_PER_YR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-YR")
    OZ_HR_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-FT3")
    PPB = URIRef("http://qudt.org/vocab/unit/PPB")
    PER_EV_M3 = URIRef("http://qudt.org/vocab/unit/PER-EV-M3")
    NanoGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-SEC")
    FemtoGM_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-L")
    MicroCi = URIRef("http://qudt.org/vocab/unit/MicroCi")
    MI2 = URIRef("http://qudt.org/vocab/unit/MI2")
    PER_PlanckMass2 = URIRef("http://qudt.org/vocab/unit/PER-PlanckMass2")
    W = URIRef("http://qudt.org/vocab/unit/W")
    TON_US_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_US-PER-YD3")
    AMU = URIRef("http://qudt.org/vocab/unit/AMU")
    MegaHZ = URIRef("http://qudt.org/vocab/unit/MegaHZ")
    OZ_MIN_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN6")
    PER_GM = URIRef("http://qudt.org/vocab/unit/PER-GM")
    C2_M2_PER_J = URIRef("http://qudt.org/vocab/unit/C2-M2-PER-J")
    TONNE = URIRef("http://qudt.org/vocab/unit/TONNE")
    BTU_IT_PER_SEC_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_R")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    MegaBQ = URIRef("http://qudt.org/vocab/unit/MegaBQ")
    NanoMOL_PER_MicroMOL_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL-DAY")
    F = URIRef("http://qudt.org/vocab/unit/F")
    NUM_PER_HA = URIRef("http://qudt.org/vocab/unit/NUM-PER-HA")
    OERSTED = URIRef("http://qudt.org/vocab/unit/OERSTED")
    MicroFARAD = URIRef("http://qudt.org/vocab/unit/MicroFARAD")
    KiloCAL_PER_MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL-DEG_C")
    KiloGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-BAR")
    PlanckCurrentDensity = URIRef("http://qudt.org/vocab/unit/PlanckCurrentDensity")
    ZeptoC = URIRef("http://qudt.org/vocab/unit/ZeptoC")
    NanoC = URIRef("http://qudt.org/vocab/unit/NanoC")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    MegaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-SEC")
    PER_TONNE = URIRef("http://qudt.org/vocab/unit/PER-TONNE")
    NUM_PER_M = URIRef("http://qudt.org/vocab/unit/NUM-PER-M")
    CP = URIRef("http://qudt.org/vocab/unit/CP")
    PlanckFrequency_Ang = URIRef("http://qudt.org/vocab/unit/PlanckFrequency_Ang")
    YD3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD3-PER-DEG_F")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    PicoGM = URIRef("http://qudt.org/vocab/unit/PicoGM")
    KiloGM_PER_M_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC")
    KiloCAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-SEC")
    DEG_F_SEC_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-SEC-PER-BTU_TH")
    FT3_PER_MIN_FT2 = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN-FT2")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    LB_MIN_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-IN3")
    MicroM = URIRef("http://qudt.org/vocab/unit/MicroM")
    N = URIRef("http://qudt.org/vocab/unit/N")
    DYN = URIRef("http://qudt.org/vocab/unit/DYN")
    MicroGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-KiloGM")
    MegaPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-M3-PER-SEC")
    DEG_F_HR_FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT-IN")
    MilliM3_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-GM")
    FT_US = URIRef("http://qudt.org/vocab/unit/FT_US")
    GAL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-MIN")
    PA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-L-PER-SEC")
    PSI_PER_PSI = URIRef("http://qudt.org/vocab/unit/PSI-PER-PSI")
    M3_PER_MIN = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    CentiM3_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN-BAR")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    GM_MIN_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M3-CentiM3")
    MicroGRAY = URIRef("http://qudt.org/vocab/unit/MicroGRAY")
    MOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-DAY")
    NanoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-KiloGM")
    PK_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-HR")
    PDL_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-FT2")
    MilliBAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-BAR")
    TON_Metric_PER_MIN = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN")
    QT_US = URIRef("http://qudt.org/vocab/unit/QT_US")
    MilliWB = URIRef("http://qudt.org/vocab/unit/MilliWB")
    EV_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/EV-M2-PER-KiloGM")
    AC_FT_US = URIRef("http://qudt.org/vocab/unit/AC-FT_US")
    MOL_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-K")
    BTU_IT_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-IN2-SEC")
    MicroN = URIRef("http://qudt.org/vocab/unit/MicroN")
    GigaOHM = URIRef("http://qudt.org/vocab/unit/GigaOHM")
    S = URIRef("http://qudt.org/vocab/unit/S")
    TON_Metric_PER_M3 = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3")
    MicroGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2")
    POISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/POISE-PER-BAR")
    KiloGM_F_M = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M")
    LB_F_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN")
    LB_FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT-PER-SEC")
    M3_PER_C = URIRef("http://qudt.org/vocab/unit/M3-PER-C")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    TONNE_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC-BAR")
    BTU_IT_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC-DEG_F")
    CAL_TH_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM2-K")
    CARAT = URIRef("http://qudt.org/vocab/unit/CARAT")
    CentiM3_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN-K")
    ExaBYTE = URIRef("http://qudt.org/vocab/unit/ExaBYTE")
    STR = URIRef("http://qudt.org/vocab/unit/STR")
    MicroMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-KiloGM")
    M3_PER_HR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR")
    AttoJ_SEC = URIRef("http://qudt.org/vocab/unit/AttoJ-SEC")
    LB_SEC_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-YD3")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    IN_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-DEG_F")
    PlanckDensity = URIRef("http://qudt.org/vocab/unit/PlanckDensity")
    W_PER_K = URIRef("http://qudt.org/vocab/unit/W-PER-K")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    PicoJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/PicoJ-PER-SEC")
    PERCENT_PER_DektoKiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DektoKiloCount")
    NAT_PER_SEC = URIRef("http://qudt.org/vocab/unit/NAT-PER-SEC")
    GM_PER_MilliL_K = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL-K")
    DYN = URIRef("http://qudt.org/vocab/unit/DYN")
    V_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/V-SEC-PER-M")
    J_SEC_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-SEC-PER-MOL")
    KiloGM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC2")
    W_PER_M2_K = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K")
    CAL_TH_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM2-K")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    MilliW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2")
    MegaBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaBTU_IT-PER-HR")
    MegaGM = URIRef("http://qudt.org/vocab/unit/MegaGM")
    FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-SEC")
    Debye = URIRef("http://qudt.org/vocab/unit/Debye")
    MilliV_PER_M = URIRef("http://qudt.org/vocab/unit/MilliV-PER-M")
    MilliMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3")
    MilliGM_MIN_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L-M3")
    KiloBQ = URIRef("http://qudt.org/vocab/unit/KiloBQ")
    PER_MO = URIRef("http://qudt.org/vocab/unit/PER-MO")
    MIL_Circ = URIRef("http://qudt.org/vocab/unit/MIL_Circ")
    MilliGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-K")
    MicroMOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-SEC")
    N = URIRef("http://qudt.org/vocab/unit/N")
    ARCMIN = URIRef("http://qudt.org/vocab/unit/ARCMIN")
    MicroS_PER_M = URIRef("http://qudt.org/vocab/unit/MicroS-PER-M")
    MilliH = URIRef("http://qudt.org/vocab/unit/MilliH")
    KiloCAL_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2")
    TON_SHORT_PER_PSI = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-PSI")
    DecaM3 = URIRef("http://qudt.org/vocab/unit/DecaM3")
    LB_IN2_PER_FT3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-FT3-LB_F-SEC")
    HectoPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-BAR")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    GM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM")
    V = URIRef("http://qudt.org/vocab/unit/V")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    CAL_TH_PER_G = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-G")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    PERCENT_HR_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-L")
    KiloW_HR = URIRef("http://qudt.org/vocab/unit/KiloW-HR")
    MegaBQ = URIRef("http://qudt.org/vocab/unit/MegaBQ")
    V_Ab = URIRef("http://qudt.org/vocab/unit/V_Ab")
    FT_PDL = URIRef("http://qudt.org/vocab/unit/FT-PDL")
    GM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM_F-PER-CentiM2")
    KiloC_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M3")
    TeraW = URIRef("http://qudt.org/vocab/unit/TeraW")
    DeciM3_PER_HR = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-HR")
    PINT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-HR")
    FARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/FARAD-PER-KiloM")
    N_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-RAD")
    BTU_IT_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    BU_UK = URIRef("http://qudt.org/vocab/unit/BU_UK")
    FT3_PER_PSI = URIRef("http://qudt.org/vocab/unit/FT3-PER-PSI")
    KN = URIRef("http://qudt.org/vocab/unit/KN")
    FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC")
    GM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-K")
    KiloCAL_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL")
    MegaPA_M0pt5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0pt5")
    MicroM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM-PER-MilliL")
    KiloGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM2")
    YR_Sidereal = URIRef("http://qudt.org/vocab/unit/YR_Sidereal")
    PER_PERCENT = URIRef("http://qudt.org/vocab/unit/PER-PERCENT")
    IN2_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN2-PER-SEC")
    LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN")
    MilliM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-HR")
    LB_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC-DEG_F")
    M = URIRef("http://qudt.org/vocab/unit/M")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    PK_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-DAY")
    BTU_TH_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-SEC-DEG_F")
    KiloGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-BAR")
    OZ_VOL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-HR")
    PicoA_PER_HectoPA = URIRef("http://qudt.org/vocab/unit/PicoA-PER-HectoPA")
    H = URIRef("http://qudt.org/vocab/unit/H")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    IN4 = URIRef("http://qudt.org/vocab/unit/IN4")
    GM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3")
    KiloGM_PER_L_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-K")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    CentiM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL")
    MicroV_PER_M = URIRef("http://qudt.org/vocab/unit/MicroV-PER-M")
    FARAD_Ab = URIRef("http://qudt.org/vocab/unit/FARAD_Ab")
    FemtoL = URIRef("http://qudt.org/vocab/unit/FemtoL")
    MilliR_man = URIRef("http://qudt.org/vocab/unit/MilliR_man")
    NanoT = URIRef("http://qudt.org/vocab/unit/NanoT")
    NanoS = URIRef("http://qudt.org/vocab/unit/NanoS")
    KiloGM_PER_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA")
    PSI_IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-IN3-PER-SEC")
    CAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-K")
    KiloW_PER_M_K = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M-K")
    TSP = URIRef("http://qudt.org/vocab/unit/TSP")
    HR_FT2 = URIRef("http://qudt.org/vocab/unit/HR-FT2")
    MIL_Circ = URIRef("http://qudt.org/vocab/unit/MIL_Circ")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    ExbiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M")
    MilliGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DeciL")
    PebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M")
    M4_PER_SEC = URIRef("http://qudt.org/vocab/unit/M4-PER-SEC")
    TeraBIT = URIRef("http://qudt.org/vocab/unit/TeraBIT")
    PERCENT_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEG_C")
    IU_PER_L = URIRef("http://qudt.org/vocab/unit/IU-PER-L")
    W_M2_PER_SR = URIRef("http://qudt.org/vocab/unit/W-M2-PER-SR")
    MicroM2 = URIRef("http://qudt.org/vocab/unit/MicroM2")
    SLUG_PER_FT3 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT3")
    YD3_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD3-PER-MIN")
    MilliL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-GM")
    MilliL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-MIN")
    EV_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/EV-M2-PER-KiloGM")
    MilliTORR = URIRef("http://qudt.org/vocab/unit/MilliTORR")
    ExaBIT_PER_M = URIRef("http://qudt.org/vocab/unit/ExaBIT-PER-M")
    N_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG")
    MOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-DAY")
    W_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM")
    GigaW_HR = URIRef("http://qudt.org/vocab/unit/GigaW-HR")
    KiloCAL = URIRef("http://qudt.org/vocab/unit/KiloCAL")
    TeraV = URIRef("http://qudt.org/vocab/unit/TeraV")
    MilliGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-K")
    ExaBYTE = URIRef("http://qudt.org/vocab/unit/ExaBYTE")
    GALILEO = URIRef("http://qudt.org/vocab/unit/GALILEO")
    MicroS_PER_M = URIRef("http://qudt.org/vocab/unit/MicroS-PER-M")
    PERCENT_PER_IN = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-IN")
    J_PER_MOL_K = URIRef("http://qudt.org/vocab/unit/J-PER-MOL-K")
    TON_Metric_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY-BAR")
    CAL_IT_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM")
    DeciM = URIRef("http://qudt.org/vocab/unit/DeciM")
    LB_T = URIRef("http://qudt.org/vocab/unit/LB_T")
    PA_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PA-M2-PER-KiloGM")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    KiloGM_PER_M_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-HR")
    PER_PlanckMass2 = URIRef("http://qudt.org/vocab/unit/PER-PlanckMass2")
    QT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_US-PER-MIN")
    PPM_PER_K = URIRef("http://qudt.org/vocab/unit/PPM-PER-K")
    PSI_YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-YD3-PER-SEC")
    MilliA_IN2_PER_LB_F = URIRef("http://qudt.org/vocab/unit/MilliA-IN2-PER-LB_F")
    WB_M = URIRef("http://qudt.org/vocab/unit/WB-M")
    YD3_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD3-PER-MIN")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    HeartBeat = URIRef("http://qudt.org/vocab/unit/HeartBeat")
    M3_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-M2")
    BAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/BAR-PER-BAR")
    GM_PER_L_POISE = URIRef("http://qudt.org/vocab/unit/GM-PER-L-POISE")
    MilliGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-HR")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    MIN_Angle = URIRef("http://qudt.org/vocab/unit/MIN_Angle")
    ERLANG = URIRef("http://qudt.org/vocab/unit/ERLANG")
    TeraJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/TeraJ-PER-SEC")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    KiloGM_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MOL")
    KiloCAL_IT_PER_HR_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-HR-M-DEG_C")
    KiloGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloGM")
    MilliSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-SEC")
    PER_SR = URIRef("http://qudt.org/vocab/unit/PER-SR")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    LM_PER_W = URIRef("http://qudt.org/vocab/unit/LM-PER-W")
    OZ_HR_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-GAL_US")
    LB_F_FT = URIRef("http://qudt.org/vocab/unit/LB_F-FT")
    CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3")
    LB_PER_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-HR-DEG_F")
    Denier = URIRef("http://qudt.org/vocab/unit/Denier")
    MilliBAR = URIRef("http://qudt.org/vocab/unit/MilliBAR")
    EUR_PER_W = URIRef("http://qudt.org/vocab/unit/EUR-PER-W")
    KiloN_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M2")
    ST_PER_BAR = URIRef("http://qudt.org/vocab/unit/ST-PER-BAR")
    BTU_IT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC")
    PPTM = URIRef("http://qudt.org/vocab/unit/PPTM")
    MicroSV = URIRef("http://qudt.org/vocab/unit/MicroSV")
    MilliV = URIRef("http://qudt.org/vocab/unit/MilliV")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    OZ_TROY = URIRef("http://qudt.org/vocab/unit/OZ_TROY")
    PER_KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/PER-KiloV-A-HR")
    E = URIRef("http://qudt.org/vocab/unit/E")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    W_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-PER-KiloGM")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    W_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-PER-KiloGM")
    CAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC")
    KiloN_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M2")
    YD2 = URIRef("http://qudt.org/vocab/unit/YD2")
    LB_PER_LB = URIRef("http://qudt.org/vocab/unit/LB-PER-LB")
    MO_MeanGREGORIAN = URIRef("http://qudt.org/vocab/unit/MO_MeanGREGORIAN")
    LM_PER_M2 = URIRef("http://qudt.org/vocab/unit/LM-PER-M2")
    HP_Electric = URIRef("http://qudt.org/vocab/unit/HP_Electric")
    DecaM3 = URIRef("http://qudt.org/vocab/unit/DecaM3")
    L_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-M2")
    V_PER_K = URIRef("http://qudt.org/vocab/unit/V-PER-K")
    MilliGAL = URIRef("http://qudt.org/vocab/unit/MilliGAL")
    PER_OZ = URIRef("http://qudt.org/vocab/unit/PER-OZ")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    GM_MIN_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L2")
    MI_PER_SEC = URIRef("http://qudt.org/vocab/unit/MI-PER-SEC")
    TON_Metric_PER_MIN = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    PetaBQ = URIRef("http://qudt.org/vocab/unit/PetaBQ")
    DRAM_US = URIRef("http://qudt.org/vocab/unit/DRAM_US")
    PER_IN2 = URIRef("http://qudt.org/vocab/unit/PER-IN2")
    KiloGM_PER_M2_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC2")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    M2_HZ3 = URIRef("http://qudt.org/vocab/unit/M2-HZ3")
    MicroPOISE = URIRef("http://qudt.org/vocab/unit/MicroPOISE")
    NanoA = URIRef("http://qudt.org/vocab/unit/NanoA")
    MilliBAR_PER_K = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-K")
    GM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3")
    A_PER_CentiM = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM")
    GigaJ = URIRef("http://qudt.org/vocab/unit/GigaJ")
    BU_UK = URIRef("http://qudt.org/vocab/unit/BU_UK")
    KiloA_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M2")
    C = URIRef("http://qudt.org/vocab/unit/C")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    TeraV = URIRef("http://qudt.org/vocab/unit/TeraV")
    PlanckFrequency = URIRef("http://qudt.org/vocab/unit/PlanckFrequency")
    BTU_IT_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT-PER-FT2-HR-DEG_F")
    MilliPA_SEC_PER_K = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-K")
    KN = URIRef("http://qudt.org/vocab/unit/KN")
    ZettaC = URIRef("http://qudt.org/vocab/unit/ZettaC")
    DRAM_UK = URIRef("http://qudt.org/vocab/unit/DRAM_UK")
    PicoMOL_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M3-SEC")
    PARSEC = URIRef("http://qudt.org/vocab/unit/PARSEC")
    LB_IN2 = URIRef("http://qudt.org/vocab/unit/LB-IN2")
    KiloWB_PER_M = URIRef("http://qudt.org/vocab/unit/KiloWB-PER-M")
    MicroATM = URIRef("http://qudt.org/vocab/unit/MicroATM")
    FT2 = URIRef("http://qudt.org/vocab/unit/FT2")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    PER_CentiM = URIRef("http://qudt.org/vocab/unit/PER-CentiM")
    BTU_TH_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_F")
    MilliM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-HR")
    IN_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC2")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    PlanckMomentum = URIRef("http://qudt.org/vocab/unit/PlanckMomentum")
    M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/M2-PER-MOL")
    AttoSEC = URIRef("http://qudt.org/vocab/unit/AttoSEC")
    DecaM3 = URIRef("http://qudt.org/vocab/unit/DecaM3")
    MilliM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-BAR")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    PERCENT_MIN_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-L")
    GRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/GRAY-PER-SEC")
    M3_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-M2")
    NanoS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/NanoS-PER-CentiM")
    PK_US_DRY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY")
    MegaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-M")
    DeciGM = URIRef("http://qudt.org/vocab/unit/DeciGM")
    PK_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-MIN")
    KiloW_HR = URIRef("http://qudt.org/vocab/unit/KiloW-HR")
    PCA = URIRef("http://qudt.org/vocab/unit/PCA")
    TON_Metric_PER_MIN = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN")
    MilliR = URIRef("http://qudt.org/vocab/unit/MilliR")
    PERCENT_PER_DEG = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEG")
    GM_PER_GM = URIRef("http://qudt.org/vocab/unit/GM-PER-GM")
    KiloGM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM-PER-SEC")
    GRAIN = URIRef("http://qudt.org/vocab/unit/GRAIN")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    HectoPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-M3-PER-SEC")
    DEG_R_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-MIN")
    MegaV = URIRef("http://qudt.org/vocab/unit/MegaV")
    MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/MOL-DEG_C")
    LM_PER_M2 = URIRef("http://qudt.org/vocab/unit/LM-PER-M2")
    MicroM = URIRef("http://qudt.org/vocab/unit/MicroM")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    STILB = URIRef("http://qudt.org/vocab/unit/STILB")
    LB_FT2_PER_GAL_US_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-GAL_US-LB_F-SEC")
    MilliA_SEC = URIRef("http://qudt.org/vocab/unit/MilliA-SEC")
    LB_F_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-SEC")
    GI_US = URIRef("http://qudt.org/vocab/unit/GI_US")
    BTU_TH_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-SEC-DEG_F")
    RPK = URIRef("http://qudt.org/vocab/unit/RPK")
    KiloGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-BAR")
    PK_UK = URIRef("http://qudt.org/vocab/unit/PK_UK")
    NanoJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoJ-PER-SEC")
    MilliM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM2-PER-SEC")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    CAL_IT_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM2-K")
    YoctoC = URIRef("http://qudt.org/vocab/unit/YoctoC")
    PINT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-SEC")
    FemtoL = URIRef("http://qudt.org/vocab/unit/FemtoL")
    MilliL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-KiloGM")
    CentiM3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL-SEC")
    OZ_MIN_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-GAL_UK")
    MOL_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-SEC")
    TeraW_HR = URIRef("http://qudt.org/vocab/unit/TeraW-HR")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    M2_HZ4 = URIRef("http://qudt.org/vocab/unit/M2-HZ4")
    PINT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-MIN")
    MegaV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive")
    HectoM = URIRef("http://qudt.org/vocab/unit/HectoM")
    PHON = URIRef("http://qudt.org/vocab/unit/PHON")
    MOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2")
    T_M = URIRef("http://qudt.org/vocab/unit/T-M")
    MicroV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MicroV-A_Reactive")
    MicroM = URIRef("http://qudt.org/vocab/unit/MicroM")
    MilliGM_PER_M3_PA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-PA-SEC")
    KiloGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-K")
    PER_MILLE_PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PER-PSI")
    TONNE_PER_HA_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA-YR")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    DIOPTER = URIRef("http://qudt.org/vocab/unit/DIOPTER")
    GI_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-SEC")
    DEATHS_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000I-YR")
    OZ_FT2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/OZ-FT2-PER-IN3-LB_F-SEC")
    BEAT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BEAT-PER-MIN")
    GM_MilliM = URIRef("http://qudt.org/vocab/unit/GM-MilliM")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    DeciB_PER_KiloM = URIRef("http://qudt.org/vocab/unit/DeciB-PER-KiloM")
    PA_PER_M = URIRef("http://qudt.org/vocab/unit/PA-PER-M")
    MicroGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-BAR")
    M_PER_PA = URIRef("http://qudt.org/vocab/unit/M-PER-PA")
    N_PER_MilliM = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM")
    PK_UK = URIRef("http://qudt.org/vocab/unit/PK_UK")
    MI_US2 = URIRef("http://qudt.org/vocab/unit/MI_US2")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    PlanckCharge = URIRef("http://qudt.org/vocab/unit/PlanckCharge")
    Z = URIRef("http://qudt.org/vocab/unit/Z")
    SH = URIRef("http://qudt.org/vocab/unit/SH")
    BTU_IT_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_R")
    M5 = URIRef("http://qudt.org/vocab/unit/M5")
    NanoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-KiloGM")
    DeciB_MilliW = URIRef("http://qudt.org/vocab/unit/DeciB-MilliW")
    MilliHZ = URIRef("http://qudt.org/vocab/unit/MilliHZ")
    A_SEC = URIRef("http://qudt.org/vocab/unit/A-SEC")
    NanoGM_PER_L = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-L")
    PicoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/PicoKAT-PER-L")
    FT_HG = URIRef("http://qudt.org/vocab/unit/FT_HG")
    OHM_CentiM = URIRef("http://qudt.org/vocab/unit/OHM-CentiM")
    PPTM = URIRef("http://qudt.org/vocab/unit/PPTM")
    NanoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MilliL")
    MOL_PER_M2_SEC_M_SR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-M-SR")
    IN = URIRef("http://qudt.org/vocab/unit/IN")
    PlanckEnergy = URIRef("http://qudt.org/vocab/unit/PlanckEnergy")
    KiloCAL_PER_MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL-DEG_C")
    PER_SEC_M3 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M3")
    V_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/V-SEC-PER-M")
    J_SEC_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-SEC-PER-MOL")
    POISE_PER_K = URIRef("http://qudt.org/vocab/unit/POISE-PER-K")
    T = URIRef("http://qudt.org/vocab/unit/T")
    NanoW = URIRef("http://qudt.org/vocab/unit/NanoW")
    MilliGM_SEC_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L2")
    PERMEABILITY_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_REL")
    PicoSEC = URIRef("http://qudt.org/vocab/unit/PicoSEC")
    IN_PER_PSI = URIRef("http://qudt.org/vocab/unit/IN-PER-PSI")
    KiloGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-K")
    ElementaryCharge = URIRef("http://qudt.org/vocab/unit/ElementaryCharge")
    GM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR-BAR")
    KiloMOL_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3-K")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    MicroPOISE = URIRef("http://qudt.org/vocab/unit/MicroPOISE")
    MilliGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-BAR")
    NanoGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DeciL")
    TeraJ = URIRef("http://qudt.org/vocab/unit/TeraJ")
    PERM_US = URIRef("http://qudt.org/vocab/unit/PERM_US")
    DYN_SEC_PER_CentiM5 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM5")
    YD3 = URIRef("http://qudt.org/vocab/unit/YD3")
    N_M_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-M")
    LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC")
    KiloCAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-GM-K")
    KiloGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-BAR")
    Megahertz_KiloM = URIRef("http://qudt.org/vocab/unit/Megahertz-KiloM")
    N_M_PER_M_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-M-RAD")
    GM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    MegaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBIT-PER-SEC")
    PER_M_SEC = URIRef("http://qudt.org/vocab/unit/PER-M-SEC")
    MilliMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    DeciBAR_PER_YR = URIRef("http://qudt.org/vocab/unit/DeciBAR-PER-YR")
    TeraC = URIRef("http://qudt.org/vocab/unit/TeraC")
    OZ_VOL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-DAY")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    NUM_PER_HectoGM = URIRef("http://qudt.org/vocab/unit/NUM-PER-HectoGM")
    HectoPA_PER_K = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-K")
    MI_PER_SEC = URIRef("http://qudt.org/vocab/unit/MI-PER-SEC")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    PA_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-PER-BAR")
    TON_US_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_US-PER-YD3")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    MilliJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-M2")
    MilliM4 = URIRef("http://qudt.org/vocab/unit/MilliM4")
    C_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-CentiM2")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    KiloGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-BAR")
    PERCENT_SEC_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-L")
    W = URIRef("http://qudt.org/vocab/unit/W")
    NP = URIRef("http://qudt.org/vocab/unit/NP")
    PDL_PER_IN = URIRef("http://qudt.org/vocab/unit/PDL-PER-IN")
    PER_YD3 = URIRef("http://qudt.org/vocab/unit/PER-YD3")
    KiloPA_A = URIRef("http://qudt.org/vocab/unit/KiloPA_A")
    MilliGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-DAY")
    LB_PER_FT_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-MIN")
    MegaW = URIRef("http://qudt.org/vocab/unit/MegaW")
    ANGSTROM = URIRef("http://qudt.org/vocab/unit/ANGSTROM")
    MilliSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-MIN")
    E_h = URIRef("http://qudt.org/vocab/unit/E_h")
    TON_Metric_PER_M3 = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3")
    KiloCAL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-SEC")
    W_SEC = URIRef("http://qudt.org/vocab/unit/W-SEC")
    IN3 = URIRef("http://qudt.org/vocab/unit/IN3")
    MilliC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M3")
    MegaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-M")
    H_PER_M = URIRef("http://qudt.org/vocab/unit/H-PER-M")
    C3_M_PER_J2 = URIRef("http://qudt.org/vocab/unit/C3-M-PER-J2")
    LA_FT = URIRef("http://qudt.org/vocab/unit/LA_FT")
    OZ_HR_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-YD3")
    BYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/BYTE-PER-SEC")
    K_M2_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/K-M2-PER-KiloGM-SEC")
    PicoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-MilliL")
    MegaS = URIRef("http://qudt.org/vocab/unit/MegaS")
    HP_Brake = URIRef("http://qudt.org/vocab/unit/HP_Brake")
    MilliGRAY = URIRef("http://qudt.org/vocab/unit/MilliGRAY")
    MilliA = URIRef("http://qudt.org/vocab/unit/MilliA")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    Megahertz_KiloM = URIRef("http://qudt.org/vocab/unit/Megahertz-KiloM")
    PDL_FT = URIRef("http://qudt.org/vocab/unit/PDL-FT")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    FARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/FARAD-PER-KiloM")
    LB_SEC_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-GAL_US")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    M_PER_K = URIRef("http://qudt.org/vocab/unit/M-PER-K")
    KiloGM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3")
    DeciBAR_PER_YR = URIRef("http://qudt.org/vocab/unit/DeciBAR-PER-YR")
    KiloCAL_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM")
    KiloGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN")
    MIN_Angle = URIRef("http://qudt.org/vocab/unit/MIN_Angle")
    QT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_US-PER-HR")
    MegaC = URIRef("http://qudt.org/vocab/unit/MegaC")
    M_PER_PA = URIRef("http://qudt.org/vocab/unit/M-PER-PA")
    TONNE_PER_M3 = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3")
    AttoSEC = URIRef("http://qudt.org/vocab/unit/AttoSEC")
    NUM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/NUM-PER-M2-DAY")
    LB_FT2 = URIRef("http://qudt.org/vocab/unit/LB-FT2")
    CentiM2_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-CentiM3")
    IN_PER_YR = URIRef("http://qudt.org/vocab/unit/IN-PER-YR")
    GigaW_HR = URIRef("http://qudt.org/vocab/unit/GigaW-HR")
    OZ_IN = URIRef("http://qudt.org/vocab/unit/OZ-IN")
    EarthMass = URIRef("http://qudt.org/vocab/unit/EarthMass")
    K_PER_K = URIRef("http://qudt.org/vocab/unit/K-PER-K")
    YD_PER_PSI = URIRef("http://qudt.org/vocab/unit/YD-PER-PSI")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    KiloJ_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MIN")
    MegaSEC = URIRef("http://qudt.org/vocab/unit/MegaSEC")
    KiloC_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M2")
    MilliGM_PER_M3_CentiPOISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-CentiPOISE")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    SV_PER_HR = URIRef("http://qudt.org/vocab/unit/SV-PER-HR")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    PicoA = URIRef("http://qudt.org/vocab/unit/PicoA")
    DEG_C_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-SEC")
    L = URIRef("http://qudt.org/vocab/unit/L")
    L_PER_HR_K = URIRef("http://qudt.org/vocab/unit/L-PER-HR-K")
    MOL_PER_KiloGM_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-PA")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    MI_N_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI_N-PER-MIN")
    KiloGM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-BAR")
    MicroN_M = URIRef("http://qudt.org/vocab/unit/MicroN-M")
    M_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-PA")
    LB_PER_FT_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-HR")
    N = URIRef("http://qudt.org/vocab/unit/N")
    MilliM2 = URIRef("http://qudt.org/vocab/unit/MilliM2")
    HectoM = URIRef("http://qudt.org/vocab/unit/HectoM")
    LB_MIN_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-GAL_US")
    EarthMass = URIRef("http://qudt.org/vocab/unit/EarthMass")
    OHM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/OHM-PER-KiloM")
    FATH = URIRef("http://qudt.org/vocab/unit/FATH")
    GM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3-BAR")
    ATM = URIRef("http://qudt.org/vocab/unit/ATM")
    CD_PER_IN2 = URIRef("http://qudt.org/vocab/unit/CD-PER-IN2")
    MegaC = URIRef("http://qudt.org/vocab/unit/MegaC")
    PetaBQ = URIRef("http://qudt.org/vocab/unit/PetaBQ")
    A_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-PER-CentiM2")
    PINT_UK = URIRef("http://qudt.org/vocab/unit/PINT_UK")
    KiloGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-K")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    N_M_PER_ARCMIN = URIRef("http://qudt.org/vocab/unit/N-M-PER-ARCMIN")
    DEG_F_PER_BAR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-BAR")
    J_PER_T2 = URIRef("http://qudt.org/vocab/unit/J-PER-T2")
    DEG_C_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-K")
    LM_SEC = URIRef("http://qudt.org/vocab/unit/LM-SEC")
    BQ_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-SEC-PER-M3")
    M3_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-BAR")
    PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-PSI")
    A_SEC2 = URIRef("http://qudt.org/vocab/unit/A-SEC2")
    MilliSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-SEC")
    MACH = URIRef("http://qudt.org/vocab/unit/MACH")
    A_PER_GM = URIRef("http://qudt.org/vocab/unit/A-PER-GM")
    J = URIRef("http://qudt.org/vocab/unit/J")
    CAL_TH_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-K")
    MilliM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-KiloGM")
    MilliA_PER_LB_F_IN2 = URIRef("http://qudt.org/vocab/unit/MilliA-PER-LB_F-IN2")
    FemtoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-KiloGM")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    MOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-SEC")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    LB_IN2 = URIRef("http://qudt.org/vocab/unit/LB-IN2")
    SH = URIRef("http://qudt.org/vocab/unit/SH")
    BTU_IT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC")
    DEG_C_KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/DEG_C-KiloGM-PER-M2")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    MilliGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-K")
    LUX_HR = URIRef("http://qudt.org/vocab/unit/LUX-HR")
    DeciN_M = URIRef("http://qudt.org/vocab/unit/DeciN-M")
    LB_F_PER_LB = URIRef("http://qudt.org/vocab/unit/LB_F-PER-LB")
    UNKNOWN = URIRef("http://qudt.org/vocab/unit/UNKNOWN")
    MilliL_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-BAR")
    PER_DEG_C = URIRef("http://qudt.org/vocab/unit/PER-DEG_C")
    MilliGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-SEC")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    MilliM_HGA = URIRef("http://qudt.org/vocab/unit/MilliM_HGA")
    M2_PER_J = URIRef("http://qudt.org/vocab/unit/M2-PER-J")
    GM_SEC_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M6")
    DYN_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM2")
    BEAT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BEAT-PER-MIN")
    NUM_PER_CentiM_KiloYR = URIRef("http://qudt.org/vocab/unit/NUM-PER-CentiM-KiloYR")
    MegaV = URIRef("http://qudt.org/vocab/unit/MegaV")
    MilliC = URIRef("http://qudt.org/vocab/unit/MilliC")
    CAL_TH_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM2-K")
    GAL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-MIN")
    M2_K_PER_W = URIRef("http://qudt.org/vocab/unit/M2-K-PER-W")
    MicroW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroW-PER-M2")
    FT_LB_F_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2-SEC")
    LB_IN2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-IN3-LB_F-SEC")
    PINT = URIRef("http://qudt.org/vocab/unit/PINT")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    BAR_PER_K = URIRef("http://qudt.org/vocab/unit/BAR-PER-K")
    M2_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-V-SEC")
    MicroFARAD = URIRef("http://qudt.org/vocab/unit/MicroFARAD")
    GigaBIT = URIRef("http://qudt.org/vocab/unit/GigaBIT")
    MilliM_HG = URIRef("http://qudt.org/vocab/unit/MilliM_HG")
    GAL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-HR")
    KiloCAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-SEC")
    MilliA_PER_L_MIN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-L-MIN")
    W_PER_GM = URIRef("http://qudt.org/vocab/unit/W-PER-GM")
    CentiM = URIRef("http://qudt.org/vocab/unit/CentiM")
    KiloBTU_TH = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH")
    KiloBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBIT-PER-SEC")
    MilliA = URIRef("http://qudt.org/vocab/unit/MilliA")
    YD3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD3-PER-DEG_F")
    LB_MIN_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-FT3")
    MilliL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-SEC")
    PicoW_PER_CentiM2_L = URIRef("http://qudt.org/vocab/unit/PicoW-PER-CentiM2-L")
    PlanckArea = URIRef("http://qudt.org/vocab/unit/PlanckArea")
    FR = URIRef("http://qudt.org/vocab/unit/FR")
    KiloGM_PER_M2_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC2")
    MI_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI-PER-MIN")
    MebiBYTE = URIRef("http://qudt.org/vocab/unit/MebiBYTE")
    CHAIN_US = URIRef("http://qudt.org/vocab/unit/CHAIN_US")
    CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CentiM2-MIN")
    V_Ab = URIRef("http://qudt.org/vocab/unit/V_Ab")
    MilliOHM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-K")
    NanoGM_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2-DAY")
    PER_MilliL = URIRef("http://qudt.org/vocab/unit/PER-MilliL")
    GM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3")
    PER_EV2 = URIRef("http://qudt.org/vocab/unit/PER-EV2")
    BAR = URIRef("http://qudt.org/vocab/unit/BAR")
    M5 = URIRef("http://qudt.org/vocab/unit/M5")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    PPB = URIRef("http://qudt.org/vocab/unit/PPB")
    TONNE_PER_SEC = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC")
    AttoJ = URIRef("http://qudt.org/vocab/unit/AttoJ")
    PA_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC2")
    V_A_Reactive = URIRef("http://qudt.org/vocab/unit/V-A_Reactive")
    A = URIRef("http://qudt.org/vocab/unit/A")
    M3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC2")
    MegaV = URIRef("http://qudt.org/vocab/unit/MegaV")
    MilliARCSEC = URIRef("http://qudt.org/vocab/unit/MilliARCSEC")
    ARCMIN = URIRef("http://qudt.org/vocab/unit/ARCMIN")
    J_PER_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-DAY")
    S_Stat = URIRef("http://qudt.org/vocab/unit/S_Stat")
    L_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-BAR")
    NanoV_A = URIRef("http://qudt.org/vocab/unit/NanoV-A")
    M4 = URIRef("http://qudt.org/vocab/unit/M4")
    PlanckMass = URIRef("http://qudt.org/vocab/unit/PlanckMass")
    A_Ab = URIRef("http://qudt.org/vocab/unit/A_Ab")
    PlanckTime = URIRef("http://qudt.org/vocab/unit/PlanckTime")
    HectoPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-BAR")
    MegaGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-M3")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    N_PER_C = URIRef("http://qudt.org/vocab/unit/N-PER-C")
    MilliGM_PER_M3_PA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-PA-SEC")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    NanoT = URIRef("http://qudt.org/vocab/unit/NanoT")
    ATM_T = URIRef("http://qudt.org/vocab/unit/ATM_T")
    MilliGM_MIN_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L2")
    CAL_MEAN = URIRef("http://qudt.org/vocab/unit/CAL_MEAN")
    W_PER_M2_M = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    V_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/V-SEC-PER-M")
    W_PER_K = URIRef("http://qudt.org/vocab/unit/W-PER-K")
    BEAT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BEAT-PER-MIN")
    NanoW = URIRef("http://qudt.org/vocab/unit/NanoW")
    OZ_SEC_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN6")
    MegaBAUD = URIRef("http://qudt.org/vocab/unit/MegaBAUD")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    MicroMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L")
    MilliM2 = URIRef("http://qudt.org/vocab/unit/MilliM2")
    FT3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT3-PER-DEG_F")
    TOE = URIRef("http://qudt.org/vocab/unit/TOE")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    FUR = URIRef("http://qudt.org/vocab/unit/FUR")
    GM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM_F-PER-CentiM2")
    KiloCAL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-SEC")
    DEG_PER_M = URIRef("http://qudt.org/vocab/unit/DEG-PER-M")
    J = URIRef("http://qudt.org/vocab/unit/J")
    MOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-SEC")
    LB_HR_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-FT3")
    GAL_UK = URIRef("http://qudt.org/vocab/unit/GAL_UK")
    PER_SR = URIRef("http://qudt.org/vocab/unit/PER-SR")
    Da = URIRef("http://qudt.org/vocab/unit/Da")
    PINT = URIRef("http://qudt.org/vocab/unit/PINT")
    OZ_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ-PER-DAY")
    PERCENT_HR_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-GAL_US")
    MilliH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-KiloOHM")
    BBL_UK_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-SEC")
    FT2 = URIRef("http://qudt.org/vocab/unit/FT2")
    PERCENT_HR_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-FT3")
    HectoPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-L-PER-SEC")
    C_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM-SEC")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    MicroGM = URIRef("http://qudt.org/vocab/unit/MicroGM")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    V_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-PER-CentiM")
    BBL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-DAY")
    BBL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-DAY")
    OZ_FT_HR_PER_IN3_LB = URIRef("http://qudt.org/vocab/unit/OZ-FT-HR-PER-IN3-LB")
    BTU_IT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_F")
    PSI_PER_PSI = URIRef("http://qudt.org/vocab/unit/PSI-PER-PSI")
    KiloJ = URIRef("http://qudt.org/vocab/unit/KiloJ")
    KiloJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-SEC")
    KiloCAL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-MIN")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/PER-KiloGM2")
    MicroM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroM-PER-SEC")
    PT_BIG = URIRef("http://qudt.org/vocab/unit/PT_BIG")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    CentiM3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL-SEC")
    DeciGM = URIRef("http://qudt.org/vocab/unit/DeciGM")
    LB_PER_FT3 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3")
    IN3_PER_HR = URIRef("http://qudt.org/vocab/unit/IN3-PER-HR")
    MI = URIRef("http://qudt.org/vocab/unit/MI")
    GAL_IMP = URIRef("http://qudt.org/vocab/unit/GAL_IMP")
    K_PER_W = URIRef("http://qudt.org/vocab/unit/K-PER-W")
    TON_US = URIRef("http://qudt.org/vocab/unit/TON_US")
    MegaN_M = URIRef("http://qudt.org/vocab/unit/MegaN-M")
    PA_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC")
    NanoBQ_PER_L = URIRef("http://qudt.org/vocab/unit/NanoBQ-PER-L")
    LB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT")
    FemtoC = URIRef("http://qudt.org/vocab/unit/FemtoC")
    ERG_SEC = URIRef("http://qudt.org/vocab/unit/ERG-SEC")
    W_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-PER-KiloGM")
    EV = URIRef("http://qudt.org/vocab/unit/EV")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    BTU_IT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC")
    PetaW = URIRef("http://qudt.org/vocab/unit/PetaW")
    KiloV_PER_M = URIRef("http://qudt.org/vocab/unit/KiloV-PER-M")
    PA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M3-PER-SEC")
    GigaW_HR = URIRef("http://qudt.org/vocab/unit/GigaW-HR")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    CentiM_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-K")
    GI_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_US-PER-HR")
    MicroSEC = URIRef("http://qudt.org/vocab/unit/MicroSEC")
    NanoN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/NanoN-M-PER-M2")
    DARCY = URIRef("http://qudt.org/vocab/unit/DARCY")
    NanoH = URIRef("http://qudt.org/vocab/unit/NanoH")
    ROD = URIRef("http://qudt.org/vocab/unit/ROD")
    KIP_F = URIRef("http://qudt.org/vocab/unit/KIP_F")
    MegaTOE = URIRef("http://qudt.org/vocab/unit/MegaTOE")
    M3_PER_KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM-SEC2")
    BBL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-DAY")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT2")
    FT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-DEG_F")
    MicroOHM = URIRef("http://qudt.org/vocab/unit/MicroOHM")
    S_Stat = URIRef("http://qudt.org/vocab/unit/S_Stat")
    FT2_HR_DEG_F_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F-PER-BTU_IT")
    LB_FT2_PER_GAL_US_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-GAL_US-LB_F-SEC")
    CentiBAR = URIRef("http://qudt.org/vocab/unit/CentiBAR")
    CentiM3_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR")
    REM_PER_SEC = URIRef("http://qudt.org/vocab/unit/REM-PER-SEC")
    N_M2_PER_A = URIRef("http://qudt.org/vocab/unit/N-M2-PER-A")
    RAD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC2")
    KiloA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M")
    SEC2 = URIRef("http://qudt.org/vocab/unit/SEC2")
    MI_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI-PER-MIN")
    DEGREE_TWADDELL = URIRef("http://qudt.org/vocab/unit/DEGREE_TWADDELL")
    GM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloGM")
    CentiM_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-HR")
    MilliH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-KiloOHM")
    TONNE_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR-BAR")
    M_PER_MIN = URIRef("http://qudt.org/vocab/unit/M-PER-MIN")
    W_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-PER-KiloGM")
    S_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/S-M2-PER-MOL")
    MilliMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-GM")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    KiloC_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M2")
    KiloN_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    HectoM = URIRef("http://qudt.org/vocab/unit/HectoM")
    PicoV = URIRef("http://qudt.org/vocab/unit/PicoV")
    LB = URIRef("http://qudt.org/vocab/unit/LB")
    KiloGM_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM2")
    NUM_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/NUM-PER-MilliGM")
    MegaOHM_KiloM = URIRef("http://qudt.org/vocab/unit/MegaOHM-KiloM")
    N_M_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-RAD")
    KiloPA = URIRef("http://qudt.org/vocab/unit/KiloPA")
    M_PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PA-PER-SEC")
    TeraV_A = URIRef("http://qudt.org/vocab/unit/TeraV-A")
    DecaC = URIRef("http://qudt.org/vocab/unit/DecaC")
    PicoMOL_PER_M_W_SEC = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M-W-SEC")
    LB_HR_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-FT3")
    ONE = URIRef("http://qudt.org/vocab/unit/ONE")
    LB_MIN_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-YD3")
    GM_PER_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    TON_Metric_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY-K")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    FBM = URIRef("http://qudt.org/vocab/unit/FBM")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    OZ_F_IN = URIRef("http://qudt.org/vocab/unit/OZ_F-IN")
    KiloGM_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-PA")
    MilLength = URIRef("http://qudt.org/vocab/unit/MilLength")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    AC = URIRef("http://qudt.org/vocab/unit/AC")
    M2_PER_SEC2_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2-K")
    FBM = URIRef("http://qudt.org/vocab/unit/FBM")
    BBL = URIRef("http://qudt.org/vocab/unit/BBL")
    PetaBIT = URIRef("http://qudt.org/vocab/unit/PetaBIT")
    FT_HR_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-GAL_UK")
    MegaGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-HA")
    DYN = URIRef("http://qudt.org/vocab/unit/DYN")
    TONNE_PER_M3_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3-K")
    AttoC = URIRef("http://qudt.org/vocab/unit/AttoC")
    DYN_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-CentiM")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    MicroM3 = URIRef("http://qudt.org/vocab/unit/MicroM3")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    DEG_C_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-HR")
    MilliV_A_PER_K = URIRef("http://qudt.org/vocab/unit/MilliV-A-PER-K")
    MilliM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC2")
    BTU_TH_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-FT2-HR-DEG_F")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    M_PER_RAD = URIRef("http://qudt.org/vocab/unit/M-PER-RAD")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    ERG_PER_G = URIRef("http://qudt.org/vocab/unit/ERG-PER-G")
    FT_H2O_39dot2DEG_F = URIRef("http://qudt.org/vocab/unit/FT_H2O_39dot2DEG_F")
    M3_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-K")
    IN_PDL = URIRef("http://qudt.org/vocab/unit/IN-PDL")
    TON_Metric_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR")
    GM_PER_MilliL_K = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL-K")
    H_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/H-PER-KiloOHM")
    NanoM_PER_CentiM_PSI = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-PSI")
    LB_F_PER_IN2_DEG_F = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-DEG_F")
    PicoV_A_Reactive = URIRef("http://qudt.org/vocab/unit/PicoV-A_Reactive")
    BTU_IT_PER_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL-DEG_F")
    M2_HZ = URIRef("http://qudt.org/vocab/unit/M2-HZ")
    GM_PER_CentiM2_YR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2-YR")
    RAD_PER_MIN = URIRef("http://qudt.org/vocab/unit/RAD-PER-MIN")
    LB_SEC_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-YD3")
    NanoM2 = URIRef("http://qudt.org/vocab/unit/NanoM2")
    J_PER_MOL_K = URIRef("http://qudt.org/vocab/unit/J-PER-MOL-K")
    M3_PER_DAY = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY")
    BBL_US_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-SEC")
    BTU_MEAN = URIRef("http://qudt.org/vocab/unit/BTU_MEAN")
    CentiBAR = URIRef("http://qudt.org/vocab/unit/CentiBAR")
    KiloJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM")
    A_PER_GM = URIRef("http://qudt.org/vocab/unit/A-PER-GM")
    DEG_R_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-HR")
    KiloS = URIRef("http://qudt.org/vocab/unit/KiloS")
    FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F")
    V_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/V-SEC-PER-M")
    BU_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-HR")
    PetaBQ = URIRef("http://qudt.org/vocab/unit/PetaBQ")
    HectoM = URIRef("http://qudt.org/vocab/unit/HectoM")
    AttoJ = URIRef("http://qudt.org/vocab/unit/AttoJ")
    NP = URIRef("http://qudt.org/vocab/unit/NP")
    Gs = URIRef("http://qudt.org/vocab/unit/Gs")
    MicroGAL_PER_M = URIRef("http://qudt.org/vocab/unit/MicroGAL-PER-M")
    B = URIRef("http://qudt.org/vocab/unit/B")
    KiloGM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-FT2")
    IU_PER_MilliL = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliL")
    KiloGM_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC2")
    LB_IN = URIRef("http://qudt.org/vocab/unit/LB-IN")
    IN_H2O_60DEG_F = URIRef("http://qudt.org/vocab/unit/IN_H2O_60DEG_F")
    MegaPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-L-PER-SEC")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A-HR")
    N_PER_CentiM = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM")
    MilliPA_SEC_PER_K = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-K")
    BTU_IT_PER_HR_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_R")
    M_PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PA-PER-SEC")
    KiloN_M = URIRef("http://qudt.org/vocab/unit/KiloN-M")
    LB_SEC_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-FT3")
    DEG2 = URIRef("http://qudt.org/vocab/unit/DEG2")
    CAL_TH_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-K")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    KiloHZ_M = URIRef("http://qudt.org/vocab/unit/KiloHZ-M")
    GM_PER_M3_CentiPOISE = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-CentiPOISE")
    MilliM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-HR")
    MicroJ = URIRef("http://qudt.org/vocab/unit/MicroJ")
    PlanckMass = URIRef("http://qudt.org/vocab/unit/PlanckMass")
    MilliM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-KiloGM")
    MicroMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-DAY")
    KiloCAL_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL")
    GT = URIRef("http://qudt.org/vocab/unit/GT")
    KiloGM_PER_M_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-DAY")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    ERG_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM2-SEC")
    GR = URIRef("http://qudt.org/vocab/unit/GR")
    ExbiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M2")
    DeciTON_Metric = URIRef("http://qudt.org/vocab/unit/DeciTON_Metric")
    M2_PER_J = URIRef("http://qudt.org/vocab/unit/M2-PER-J")
    AC_FT = URIRef("http://qudt.org/vocab/unit/AC-FT")
    V_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Ab-PER-CentiM")
    MilliMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-L")
    MilliG = URIRef("http://qudt.org/vocab/unit/MilliG")
    MegaHZ_M = URIRef("http://qudt.org/vocab/unit/MegaHZ-M")
    NUM_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/NUM-PER-MilliGM")
    PER_J = URIRef("http://qudt.org/vocab/unit/PER-J")
    BTU_TH_PER_FT2_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-HR")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    DEG_C_KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/DEG_C-KiloGM-PER-M2")
    MI_PER_HR = URIRef("http://qudt.org/vocab/unit/MI-PER-HR")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    NanoT = URIRef("http://qudt.org/vocab/unit/NanoT")
    PER_SEC_M2_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2-SR")
    MicroV_PER_M = URIRef("http://qudt.org/vocab/unit/MicroV-PER-M")
    LB_PER_FT3_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3-DEG_F")
    U = URIRef("http://qudt.org/vocab/unit/U")
    PER_SEC_M2_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2-SR")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    GM_PER_M2 = URIRef("http://qudt.org/vocab/unit/GM-PER-M2")
    CentiM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN")
    MicroMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L-HR")
    CentiM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC")
    MilliS_PER_M = URIRef("http://qudt.org/vocab/unit/MilliS-PER-M")
    YR_Sidereal = URIRef("http://qudt.org/vocab/unit/YR_Sidereal")
    MicroM_PER_N = URIRef("http://qudt.org/vocab/unit/MicroM-PER-N")
    CAL_TH_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM-SEC-DEG_C")
    BTU_TH = URIRef("http://qudt.org/vocab/unit/BTU_TH")
    LB_FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT-PER-SEC")
    ERG = URIRef("http://qudt.org/vocab/unit/ERG")
    AT_PER_IN = URIRef("http://qudt.org/vocab/unit/AT-PER-IN")
    KiloYR = URIRef("http://qudt.org/vocab/unit/KiloYR")
    NanoS_PER_M = URIRef("http://qudt.org/vocab/unit/NanoS-PER-M")
    CentiM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY")
    LB_PER_FT3_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3-PSI")
    PicoW_PER_CentiM2_L = URIRef("http://qudt.org/vocab/unit/PicoW-PER-CentiM2-L")
    CASES_PER_KiloINDIV_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-KiloINDIV-YR")
    MilliGM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M")
    MOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-SEC")
    M2_HZ3 = URIRef("http://qudt.org/vocab/unit/M2-HZ3")
    MicroPOISE = URIRef("http://qudt.org/vocab/unit/MicroPOISE")
    PER_SEC_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR")
    PicoS = URIRef("http://qudt.org/vocab/unit/PicoS")
    W_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M3")
    TONNE_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN-K")
    MilliPA_PER_M = URIRef("http://qudt.org/vocab/unit/MilliPA-PER-M")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    SEC2 = URIRef("http://qudt.org/vocab/unit/SEC2")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    MilliBQ = URIRef("http://qudt.org/vocab/unit/MilliBQ")
    KiloGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-K")
    RAYL = URIRef("http://qudt.org/vocab/unit/RAYL")
    KiloBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBYTE-PER-SEC")
    M2_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-K")
    PicoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/PicoFARAD-PER-M")
    CentiM3_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-CentiM3")
    LB_FT2_PER_GAL_UK_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-GAL_UK-LB_F-SEC")
    MegaBIT = URIRef("http://qudt.org/vocab/unit/MegaBIT")
    PK_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-SEC")
    TONNE_PER_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-K")
    PK_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-DAY")
    M_PER_RAD = URIRef("http://qudt.org/vocab/unit/M-PER-RAD")
    CentiM3_PER_HR_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR-K")
    PDL_PER_IN2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-IN2")
    ARE = URIRef("http://qudt.org/vocab/unit/ARE")
    M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/M2-PER-MOL")
    BTU_MEAN = URIRef("http://qudt.org/vocab/unit/BTU_MEAN")
    N_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-PER-RAD")
    S_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/S-M2-PER-MOL")
    LUX_SEC = URIRef("http://qudt.org/vocab/unit/LUX-SEC")
    M2_HZ3 = URIRef("http://qudt.org/vocab/unit/M2-HZ3")
    KibiBYTE = URIRef("http://qudt.org/vocab/unit/KibiBYTE")
    CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM-SEC-DEG_C")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    GM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3")
    KiloS = URIRef("http://qudt.org/vocab/unit/KiloS")
    CentiM6 = URIRef("http://qudt.org/vocab/unit/CentiM6")
    DEGREE_TWADDELL = URIRef("http://qudt.org/vocab/unit/DEGREE_TWADDELL")
    TONNE_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3-BAR")
    GM_PER_L_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-L-MilliPA-SEC")
    BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN")
    KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloM2")
    PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2")
    CentiC = URIRef("http://qudt.org/vocab/unit/CentiC")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    GigaBQ = URIRef("http://qudt.org/vocab/unit/GigaBQ")
    PERCENT_MIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-GAL_US")
    EV_PER_M = URIRef("http://qudt.org/vocab/unit/EV-PER-M")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    KiloC_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M2")
    FemtoC = URIRef("http://qudt.org/vocab/unit/FemtoC")
    MilliL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-MIN")
    PER_M2 = URIRef("http://qudt.org/vocab/unit/PER-M2")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    PK_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-SEC")
    W_M2_PER_SR = URIRef("http://qudt.org/vocab/unit/W-M2-PER-SR")
    MicroGM_PER_L = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L")
    GigaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-SEC")
    KiloGRAY = URIRef("http://qudt.org/vocab/unit/KiloGRAY")
    BBL_US_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-HR")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    PCA = URIRef("http://qudt.org/vocab/unit/PCA")
    IN3_PER_HR = URIRef("http://qudt.org/vocab/unit/IN3-PER-HR")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    HR_Sidereal = URIRef("http://qudt.org/vocab/unit/HR_Sidereal")
    PicoM = URIRef("http://qudt.org/vocab/unit/PicoM")
    GigaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBYTE-PER-SEC")
    L_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/L-PER-KiloGM")
    PER_M_NanoM_SR = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM-SR")
    M2_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/M2-SEC-PER-RAD")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    PlanckTemperature = URIRef("http://qudt.org/vocab/unit/PlanckTemperature")
    TON_FG_HR = URIRef("http://qudt.org/vocab/unit/TON_FG-HR")
    KiloP = URIRef("http://qudt.org/vocab/unit/KiloP")
    KiloV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive-HR")
    RAD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC2")
    PERCENT_MIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-M3")
    M_PER_DEG_C_M = URIRef("http://qudt.org/vocab/unit/M-PER-DEG_C-M")
    PetaFLOPS = URIRef("http://qudt.org/vocab/unit/PetaFLOPS")
    KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT")
    DeciB_C = URIRef("http://qudt.org/vocab/unit/DeciB_C")
    GRAIN_PER_GAL = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL")
    BTU_IT_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-SEC-DEG_F")
    MegaPA = URIRef("http://qudt.org/vocab/unit/MegaPA")
    TeraW_HR = URIRef("http://qudt.org/vocab/unit/TeraW-HR")
    LA = URIRef("http://qudt.org/vocab/unit/LA")
    MilliGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    PINT_US = URIRef("http://qudt.org/vocab/unit/PINT_US")
    DEG_R = URIRef("http://qudt.org/vocab/unit/DEG_R")
    PER_SEC_M2_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2-SR")
    LB_HR_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-IN3")
    OZ_VOL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-DAY")
    BU_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-DAY")
    K_PER_W = URIRef("http://qudt.org/vocab/unit/K-PER-W")
    SEC_PER_RAD_M3 = URIRef("http://qudt.org/vocab/unit/SEC-PER-RAD-M3")
    TEX = URIRef("http://qudt.org/vocab/unit/TEX")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    DEG_F_SEC_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-SEC-PER-BTU_TH")
    LB_PER_IN = URIRef("http://qudt.org/vocab/unit/LB-PER-IN")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    LB_F_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-SEC")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    NanoH_PER_M = URIRef("http://qudt.org/vocab/unit/NanoH-PER-M")
    C3_M_PER_J2 = URIRef("http://qudt.org/vocab/unit/C3-M-PER-J2")
    PetaFLOPS = URIRef("http://qudt.org/vocab/unit/PetaFLOPS")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    BBL_UK_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-HR")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    BTU_TH_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2")
    PER_M_K = URIRef("http://qudt.org/vocab/unit/PER-M-K")
    GM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciL")
    KiloGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC")
    QT_UK = URIRef("http://qudt.org/vocab/unit/QT_UK")
    A_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM2")
    HectoC = URIRef("http://qudt.org/vocab/unit/HectoC")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    REV_PER_MIN = URIRef("http://qudt.org/vocab/unit/REV-PER-MIN")
    AttoSEC = URIRef("http://qudt.org/vocab/unit/AttoSEC")
    ARE = URIRef("http://qudt.org/vocab/unit/ARE")
    LB_PER_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-HR-DEG_F")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    GigaV = URIRef("http://qudt.org/vocab/unit/GigaV")
    BU_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-SEC")
    FT = URIRef("http://qudt.org/vocab/unit/FT")
    PERCENT_PER_IN = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-IN")
    ERG_PER_CentiM = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    ARCMIN = URIRef("http://qudt.org/vocab/unit/ARCMIN")
    CentiM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN")
    LB_F_PER_LB = URIRef("http://qudt.org/vocab/unit/LB_F-PER-LB")
    BTU_TH = URIRef("http://qudt.org/vocab/unit/BTU_TH")
    M_PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PA-PER-SEC")
    BTU_IT_PER_HR_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_R")
    MicroJ = URIRef("http://qudt.org/vocab/unit/MicroJ")
    KiloCAL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-SEC")
    TONNE_PER_M3_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3-K")
    MicroM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM-PER-MilliL")
    S_PER_CentiM = URIRef("http://qudt.org/vocab/unit/S-PER-CentiM")
    OZ = URIRef("http://qudt.org/vocab/unit/OZ")
    GM_PER_CentiM2_YR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2-YR")
    YD = URIRef("http://qudt.org/vocab/unit/YD")
    KAT_PER_MicroL = URIRef("http://qudt.org/vocab/unit/KAT-PER-MicroL")
    BREATH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BREATH-PER-MIN")
    SLUG_PER_DAY = URIRef("http://qudt.org/vocab/unit/SLUG-PER-DAY")
    FT_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC2")
    M_PER_MIN = URIRef("http://qudt.org/vocab/unit/M-PER-MIN")
    MOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL-PER-MIN")
    MegaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M3")
    MilliBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-KiloGM")
    MicroL = URIRef("http://qudt.org/vocab/unit/MicroL")
    LB_PER_GAL = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL")
    MegaJ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-K")
    TON_SHORT_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR")
    KiloHZ = URIRef("http://qudt.org/vocab/unit/KiloHZ")
    A_PER_K = URIRef("http://qudt.org/vocab/unit/A-PER-K")
    MegaPSI = URIRef("http://qudt.org/vocab/unit/MegaPSI")
    DeciN = URIRef("http://qudt.org/vocab/unit/DeciN")
    MOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-DAY")
    MegaN_M = URIRef("http://qudt.org/vocab/unit/MegaN-M")
    GM_PER_M3_PA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-PA-SEC")
    TON_US_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_US-PER-YD3")
    MillionUSD_PER_YR = URIRef("http://qudt.org/vocab/unit/MillionUSD-PER-YR")
    THERM_EC = URIRef("http://qudt.org/vocab/unit/THERM_EC")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    PER_PERCENT = URIRef("http://qudt.org/vocab/unit/PER-PERCENT")
    KiloV = URIRef("http://qudt.org/vocab/unit/KiloV")
    GigaBasePair = URIRef("http://qudt.org/vocab/unit/GigaBasePair")
    GM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-L-BAR")
    KiloGM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR")
    FemtoV = URIRef("http://qudt.org/vocab/unit/FemtoV")
    KiloM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-HR")
    PSI = URIRef("http://qudt.org/vocab/unit/PSI")
    C_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM3")
    GigaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-PER-M")
    KiloN = URIRef("http://qudt.org/vocab/unit/KiloN")
    KiloBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloBQ-PER-KiloGM")
    KiloCAL_Mean = URIRef("http://qudt.org/vocab/unit/KiloCAL_Mean")
    BTU_TH = URIRef("http://qudt.org/vocab/unit/BTU_TH")
    BTU_TH_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR-FT2-DEG_F")
    PARSEC = URIRef("http://qudt.org/vocab/unit/PARSEC")
    TON_FG = URIRef("http://qudt.org/vocab/unit/TON_FG")
    FT_LA = URIRef("http://qudt.org/vocab/unit/FT-LA")
    BTU_IT_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_R")
    DEG_C_WK = URIRef("http://qudt.org/vocab/unit/DEG_C-WK")
    MegaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M3")
    FT_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT-PER-DAY")
    KiloC = URIRef("http://qudt.org/vocab/unit/KiloC")
    PERCENT_SEC_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-L")
    PicoPA = URIRef("http://qudt.org/vocab/unit/PicoPA")
    MicroV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/MicroV-A_Reactive-PER-K")
    T = URIRef("http://qudt.org/vocab/unit/T")
    BU_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-SEC")
    L_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/L-PER-MicroMOL")
    PicoFARAD = URIRef("http://qudt.org/vocab/unit/PicoFARAD")
    NanoOHM = URIRef("http://qudt.org/vocab/unit/NanoOHM")
    KiloA_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M2")
    G = URIRef("http://qudt.org/vocab/unit/G")
    NP = URIRef("http://qudt.org/vocab/unit/NP")
    MegaHZ_PER_T = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-T")
    PA2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA2-PER-SEC2")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    AT_PER_IN = URIRef("http://qudt.org/vocab/unit/AT-PER-IN")
    PicoW = URIRef("http://qudt.org/vocab/unit/PicoW")
    GM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL")
    TONNE_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC-K")
    MilliV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MilliV-A_Reactive")
    MilliS = URIRef("http://qudt.org/vocab/unit/MilliS")
    DYN_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM2")
    LB_MIN_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-GAL_UK")
    NanoL = URIRef("http://qudt.org/vocab/unit/NanoL")
    LB_HR_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-GAL_UK")
    BTU_TH_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT3")
    NUM_PER_SEC = URIRef("http://qudt.org/vocab/unit/NUM-PER-SEC")
    IN_H2O_60DEG_F = URIRef("http://qudt.org/vocab/unit/IN_H2O_60DEG_F")
    PER_MicroMOL_L = URIRef("http://qudt.org/vocab/unit/PER-MicroMOL-L")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    KiloGM_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-M2")
    BIT_PER_M = URIRef("http://qudt.org/vocab/unit/BIT-PER-M")
    BTU_TH_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB")
    KiloWB_PER_M = URIRef("http://qudt.org/vocab/unit/KiloWB-PER-M")
    MegaOHM_PER_K = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-K")
    PA_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PA-M2-PER-KiloGM")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    DEATHS_PER_KiloINDIV_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-KiloINDIV-YR")
    A_SEC2 = URIRef("http://qudt.org/vocab/unit/A-SEC2")
    ATM = URIRef("http://qudt.org/vocab/unit/ATM")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    MilliSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-HR")
    A_M2 = URIRef("http://qudt.org/vocab/unit/A-M2")
    LB_F_FT = URIRef("http://qudt.org/vocab/unit/LB_F-FT")
    GM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloGM")
    GM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN-K")
    PlanckCurrent = URIRef("http://qudt.org/vocab/unit/PlanckCurrent")
    MegaW_HR = URIRef("http://qudt.org/vocab/unit/MegaW-HR")
    MegaBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaBQ-PER-KiloGM")
    KiloW_PER_M2_K = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M2-K")
    LB_MIN_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-IN3")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    C_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM2")
    KiloN = URIRef("http://qudt.org/vocab/unit/KiloN")
    A_PER_MilliM = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM")
    TONNE_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC-K")
    NanoSEC = URIRef("http://qudt.org/vocab/unit/NanoSEC")
    MilliV_PER_M = URIRef("http://qudt.org/vocab/unit/MilliV-PER-M")
    POND = URIRef("http://qudt.org/vocab/unit/POND")
    FT3_PER_LB = URIRef("http://qudt.org/vocab/unit/FT3-PER-LB")
    KAT_PER_L = URIRef("http://qudt.org/vocab/unit/KAT-PER-L")
    KiloPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-BAR")
    KiloM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-HR")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    GigaC = URIRef("http://qudt.org/vocab/unit/GigaC")
    PERCENT_PER_DecaKiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaKiloCount")
    MegaPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-L-PER-SEC")
    PHOT = URIRef("http://qudt.org/vocab/unit/PHOT")
    KiloM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC2")
    DARCY = URIRef("http://qudt.org/vocab/unit/DARCY")
    FT_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC2")
    CentiM_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-BAR")
    KiloN_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-DEG")
    CAL_IT_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM2-K")
    MilliSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-MIN")
    LB_SEC_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-GAL_UK")
    CentiM3_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR-BAR")
    TONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-YR")
    LB_PER_M3 = URIRef("http://qudt.org/vocab/unit/LB-PER-M3")
    MicroMOL_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-HR")
    W_PER_GM = URIRef("http://qudt.org/vocab/unit/W-PER-GM")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    MegaJ_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M3")
    V_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V-PER-CentiM")
    PER_OZ = URIRef("http://qudt.org/vocab/unit/PER-OZ")
    PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/PER-ANGSTROM")
    KiloCAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-MIN")
    PlanckLength = URIRef("http://qudt.org/vocab/unit/PlanckLength")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    LB_SEC_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-YD3")
    PERCENT_PER_IN = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-IN")
    GM_HR_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M3-L")
    PER_RAD = URIRef("http://qudt.org/vocab/unit/PER-RAD")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    CAL_TH_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    KiloN_M = URIRef("http://qudt.org/vocab/unit/KiloN-M")
    PSU = URIRef("http://qudt.org/vocab/unit/PSU")
    M_PER_HR = URIRef("http://qudt.org/vocab/unit/M-PER-HR")
    GigaC = URIRef("http://qudt.org/vocab/unit/GigaC")
    A_PER_M2_K2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2-K2")
    J_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    M3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC2")
    ROD = URIRef("http://qudt.org/vocab/unit/ROD")
    KiloGM_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC2")
    PetaV_A = URIRef("http://qudt.org/vocab/unit/PetaV-A")
    FT_LB_F = URIRef("http://qudt.org/vocab/unit/FT-LB_F")
    E_h = URIRef("http://qudt.org/vocab/unit/E_h")
    SLUG_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT-SEC")
    KiloGM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-BAR")
    K_DAY = URIRef("http://qudt.org/vocab/unit/K-DAY")
    DeciL = URIRef("http://qudt.org/vocab/unit/DeciL")
    EV = URIRef("http://qudt.org/vocab/unit/EV")
    M3_PER_MIN = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    MilliN = URIRef("http://qudt.org/vocab/unit/MilliN")
    BTU_TH_PER_FT2_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-MIN")
    BAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-M3-PER-SEC")
    M2_PER_HA = URIRef("http://qudt.org/vocab/unit/M2-PER-HA")
    PERCENT_SEC_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-YD3")
    RAYL = URIRef("http://qudt.org/vocab/unit/RAYL")
    TON_SHIPPING_UK = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_UK")
    PicoW = URIRef("http://qudt.org/vocab/unit/PicoW")
    IN_PER_YR = URIRef("http://qudt.org/vocab/unit/IN-PER-YR")
    KAT_PER_L = URIRef("http://qudt.org/vocab/unit/KAT-PER-L")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    GM_PER_GM = URIRef("http://qudt.org/vocab/unit/GM-PER-GM")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    MilliA_HR = URIRef("http://qudt.org/vocab/unit/MilliA-HR")
    Gamma = URIRef("http://qudt.org/vocab/unit/Gamma")
    LB_MIN_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT6")
    KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloGM-K")
    C_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM-SEC")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    HectoPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-L-PER-SEC")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    ANGSTROM = URIRef("http://qudt.org/vocab/unit/ANGSTROM")
    H_Stat = URIRef("http://qudt.org/vocab/unit/H_Stat")
    PERCENT_MIN_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-YD3")
    MicroV = URIRef("http://qudt.org/vocab/unit/MicroV")
    KiloCAL_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2")
    PER_M_SR = URIRef("http://qudt.org/vocab/unit/PER-M-SR")
    BTU_TH_PER_FT2_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-MIN")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    LunarMass = URIRef("http://qudt.org/vocab/unit/LunarMass")
    PetaBIT = URIRef("http://qudt.org/vocab/unit/PetaBIT")
    ZettaC = URIRef("http://qudt.org/vocab/unit/ZettaC")
    AC_FT = URIRef("http://qudt.org/vocab/unit/AC-FT")
    MilliGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY")
    LB_HR_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN6")
    PERCENT_MIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-GAL_US")
    MilliA_IN2_PER_LB_F = URIRef("http://qudt.org/vocab/unit/MilliA-IN2-PER-LB_F")
    DeciL_PER_GM = URIRef("http://qudt.org/vocab/unit/DeciL-PER-GM")
    MilliH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-OHM")
    GRAIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL_US")
    MilliBQ_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-M2-DAY")
    REM_PER_SEC = URIRef("http://qudt.org/vocab/unit/REM-PER-SEC")
    KiloN_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M2")
    CAL_20DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_20DEG_C")
    PER_M2 = URIRef("http://qudt.org/vocab/unit/PER-M2")
    PERCENT_FT2_PER_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-FT2-PER-LB_F-SEC")
    W_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-PER-KiloGM")
    KiloGM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MilliM")
    NanoH = URIRef("http://qudt.org/vocab/unit/NanoH")
    PINT_UK = URIRef("http://qudt.org/vocab/unit/PINT_UK")
    TOE = URIRef("http://qudt.org/vocab/unit/TOE")
    NanoBQ_PER_L = URIRef("http://qudt.org/vocab/unit/NanoBQ-PER-L")
    B = URIRef("http://qudt.org/vocab/unit/B")
    GM_PER_L_PA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-L-PA-SEC")
    MicroJ = URIRef("http://qudt.org/vocab/unit/MicroJ")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    KiloGM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM2-PER-SEC2")
    PebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M3")
    GM_PER_GM = URIRef("http://qudt.org/vocab/unit/GM-PER-GM")
    MegaV_A_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A-HR")
    PER_T_SEC = URIRef("http://qudt.org/vocab/unit/PER-T-SEC")
    M2_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-K")
    RT = URIRef("http://qudt.org/vocab/unit/RT")
    EV = URIRef("http://qudt.org/vocab/unit/EV")
    KiloTON_Metric = URIRef("http://qudt.org/vocab/unit/KiloTON_Metric")
    N = URIRef("http://qudt.org/vocab/unit/N")
    BTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR")
    CentiL = URIRef("http://qudt.org/vocab/unit/CentiL")
    KiloHZ_M = URIRef("http://qudt.org/vocab/unit/KiloHZ-M")
    GM_MIN_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L-M3")
    MilliGM_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-DAY")
    C_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM3")
    M_K_PER_W = URIRef("http://qudt.org/vocab/unit/M-K-PER-W")
    J_PER_GM_K = URIRef("http://qudt.org/vocab/unit/J-PER-GM-K")
    LB_PER_FT3_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3-DEG_F")
    LB_HR_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-FT3")
    GM_PER_L_K = URIRef("http://qudt.org/vocab/unit/GM-PER-L-K")
    PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/PER-KiloGM2")
    M2_PER_SR_J = URIRef("http://qudt.org/vocab/unit/M2-PER-SR-J")
    GI_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-HR")
    MegaTOE = URIRef("http://qudt.org/vocab/unit/MegaTOE")
    AU = URIRef("http://qudt.org/vocab/unit/AU")
    KiloGM_PER_M3_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-PA")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    M_PER_DEG_C_M = URIRef("http://qudt.org/vocab/unit/M-PER-DEG_C-M")
    DEG_R_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-HR")
    IN_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC2")
    BTU_TH_FT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-HR-FT2-DEG_F")
    KiloOHM = URIRef("http://qudt.org/vocab/unit/KiloOHM")
    M3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    EV_M2 = URIRef("http://qudt.org/vocab/unit/EV-M2")
    PER_MicroMOL_L = URIRef("http://qudt.org/vocab/unit/PER-MicroMOL-L")
    FT_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-PER-MIN")
    MilliSV = URIRef("http://qudt.org/vocab/unit/MilliSV")
    DEG_C_WK = URIRef("http://qudt.org/vocab/unit/DEG_C-WK")
    MilliS = URIRef("http://qudt.org/vocab/unit/MilliS")
    B = URIRef("http://qudt.org/vocab/unit/B")
    MI = URIRef("http://qudt.org/vocab/unit/MI")
    MicroJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroJ-PER-SEC")
    DEG_C_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-K")
    W_M_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-M-PER-M2-SR")
    REM = URIRef("http://qudt.org/vocab/unit/REM")
    BTU_IT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_F")
    PA_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PA-M2-PER-KiloGM")
    M2_K_PER_W = URIRef("http://qudt.org/vocab/unit/M2-K-PER-W")
    A_PER_A_HR = URIRef("http://qudt.org/vocab/unit/A-PER-A-HR")
    PINT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-MIN")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    GAL_IMP = URIRef("http://qudt.org/vocab/unit/GAL_IMP")
    CAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-MIN")
    DEG_C_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-K")
    N = URIRef("http://qudt.org/vocab/unit/N")
    MicroH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-KiloOHM")
    BTU_IT_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-HR-DEG_F")
    FT_HG = URIRef("http://qudt.org/vocab/unit/FT_HG")
    KiloTON_Metric = URIRef("http://qudt.org/vocab/unit/KiloTON_Metric")
    DeciM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MIN")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    BTU_TH_PER_FT2_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-HR")
    MegaDOLLAR_US_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MegaDOLLAR_US-PER-FLIGHT")
    BAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/BAR-PER-BAR")
    CAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-K")
    MilliC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliC-PER-KiloGM")
    DEG_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC2")
    N = URIRef("http://qudt.org/vocab/unit/N")
    TONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-YR")
    HA = URIRef("http://qudt.org/vocab/unit/HA")
    NanoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-KiloGM")
    MicroMHO = URIRef("http://qudt.org/vocab/unit/MicroMHO")
    TON_SHORT_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR")
    V_A_Reactive = URIRef("http://qudt.org/vocab/unit/V-A_Reactive")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    MilliGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-KiloGM")
    KiloGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-K")
    KiloGM_F_M_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-CentiM2")
    K_PER_K = URIRef("http://qudt.org/vocab/unit/K-PER-K")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    PER_IN3 = URIRef("http://qudt.org/vocab/unit/PER-IN3")
    KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-SEC2")
    MegaV_PER_M = URIRef("http://qudt.org/vocab/unit/MegaV-PER-M")
    IU_PER_MilliL = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliL")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/PER-ANGSTROM")
    NUM_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/NUM-PER-MilliM3")
    IN_H2O_39dot2DEG_F = URIRef("http://qudt.org/vocab/unit/IN_H2O_39dot2DEG_F")
    KiloPA = URIRef("http://qudt.org/vocab/unit/KiloPA")
    MegaGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-HA")
    LB_PER_IN3 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3")
    K_SEC = URIRef("http://qudt.org/vocab/unit/K-SEC")
    PetaBQ = URIRef("http://qudt.org/vocab/unit/PetaBQ")
    BTU_TH_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-SEC")
    LB_SEC_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-GAL_UK")
    DEGREE_TWADDELL = URIRef("http://qudt.org/vocab/unit/DEGREE_TWADDELL")
    PlanckMass = URIRef("http://qudt.org/vocab/unit/PlanckMass")
    TON_Metric_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN-BAR")
    MilliS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MilliS-PER-CentiM")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    MicroGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-KiloGM")
    SPIN_QUANTUM_NUMBER = URIRef("http://qudt.org/vocab/unit/SPIN_QUANTUM_NUMBER")
    NanoL = URIRef("http://qudt.org/vocab/unit/NanoL")
    DeciN_M = URIRef("http://qudt.org/vocab/unit/DeciN-M")
    NanoS_PER_M = URIRef("http://qudt.org/vocab/unit/NanoS-PER-M")
    MilliBQ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-GM")
    NanoV = URIRef("http://qudt.org/vocab/unit/NanoV")
    MicroV_A_PER_K = URIRef("http://qudt.org/vocab/unit/MicroV-A-PER-K")
    KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloM2")
    PlanckDensity = URIRef("http://qudt.org/vocab/unit/PlanckDensity")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    MilliGM_PER_M3_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-MilliPA-SEC")
    PK_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-MIN")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    AC_FT = URIRef("http://qudt.org/vocab/unit/AC-FT")
    MicroT = URIRef("http://qudt.org/vocab/unit/MicroT")
    M2_HZ = URIRef("http://qudt.org/vocab/unit/M2-HZ")
    M3_PER_M3 = URIRef("http://qudt.org/vocab/unit/M3-PER-M3")
    W_PER_M2_PA = URIRef("http://qudt.org/vocab/unit/W-PER-M2-PA")
    GM = URIRef("http://qudt.org/vocab/unit/GM")
    PA_PER_MIN = URIRef("http://qudt.org/vocab/unit/PA-PER-MIN")
    LB_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-SEC")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    PicoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/PicoFARAD-PER-M")
    GI_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_US-PER-DAY")
    Gs = URIRef("http://qudt.org/vocab/unit/Gs")
    MilliGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-MIN")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-SEC-DEG_F")
    BTU_IT_PER_SEC_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2")
    PetaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/PetaJ-PER-SEC")
    BTU_TH_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-HR-DEG_F")
    M2_PER_SR = URIRef("http://qudt.org/vocab/unit/M2-PER-SR")
    B = URIRef("http://qudt.org/vocab/unit/B")
    LB_F_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN")
    DeciBAR = URIRef("http://qudt.org/vocab/unit/DeciBAR")
    BAR_PER_K = URIRef("http://qudt.org/vocab/unit/BAR-PER-K")
    PERCENT_PER_DektoKiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DektoKiloCount")
    FemtoJ = URIRef("http://qudt.org/vocab/unit/FemtoJ")
    MDOLLAR_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MDOLLAR-PER-FLIGHT")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    M2_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-HZ2")
    PER_TONNE = URIRef("http://qudt.org/vocab/unit/PER-TONNE")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    LB_PER_IN = URIRef("http://qudt.org/vocab/unit/LB-PER-IN")
    MOL_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-DeciM3")
    MicroGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-SEC")
    PER_T_M = URIRef("http://qudt.org/vocab/unit/PER-T-M")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    M_PER_YR = URIRef("http://qudt.org/vocab/unit/M-PER-YR")
    J_PER_GM_K = URIRef("http://qudt.org/vocab/unit/J-PER-GM-K")
    J_PER_KiloGM_K_PA = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-PA")
    MilliGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-BAR")
    OHM_PER_K = URIRef("http://qudt.org/vocab/unit/OHM-PER-K")
    MOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3")
    LB_MIN_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-YD3")
    A_Ab = URIRef("http://qudt.org/vocab/unit/A_Ab")
    NanoSEC = URIRef("http://qudt.org/vocab/unit/NanoSEC")
    TONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-YR")
    CentiMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-KiloGM")
    TON_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_US-PER-DAY")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    MilliM4 = URIRef("http://qudt.org/vocab/unit/MilliM4")
    CentiL = URIRef("http://qudt.org/vocab/unit/CentiL")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    KiloHZ_M = URIRef("http://qudt.org/vocab/unit/KiloHZ-M")
    KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT")
    N_M_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-RAD")
    T = URIRef("http://qudt.org/vocab/unit/T")
    KiloJ_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-HR")
    KibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M2")
    CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-SEC")
    YD3 = URIRef("http://qudt.org/vocab/unit/YD3")
    A_PER_CentiM = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM")
    GM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3")
    MicroS_PER_M = URIRef("http://qudt.org/vocab/unit/MicroS-PER-M")
    DeciB_W = URIRef("http://qudt.org/vocab/unit/DeciB-W")
    PERCENT_PER_BAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-BAR")
    PlanckMomentum = URIRef("http://qudt.org/vocab/unit/PlanckMomentum")
    A_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM2")
    MicroKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MicroKAT-PER-L")
    MilliM3_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-GM")
    DEG_C2_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C2-PER-SEC")
    MicroM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-M3")
    KiloGM_PER_M_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC")
    CentiM_H2O = URIRef("http://qudt.org/vocab/unit/CentiM_H2O")
    MilliPA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-BAR")
    OZ_VOL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-HR")
    MilliBAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-M3-PER-SEC")
    MicroW = URIRef("http://qudt.org/vocab/unit/MicroW")
    J_M2 = URIRef("http://qudt.org/vocab/unit/J-M2")
    LB_MOL = URIRef("http://qudt.org/vocab/unit/LB-MOL")
    PK_US_DRY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY")
    KibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M3")
    FT3_PER_HR = URIRef("http://qudt.org/vocab/unit/FT3-PER-HR")
    HectoGM = URIRef("http://qudt.org/vocab/unit/HectoGM")
    M2_PER_HZ = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ")
    LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT2")
    K_DAY = URIRef("http://qudt.org/vocab/unit/K-DAY")
    HR_PER_FT2 = URIRef("http://qudt.org/vocab/unit/HR-PER-FT2")
    MOL_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-SEC")
    NUM_PER_CentiM_KiloYR = URIRef("http://qudt.org/vocab/unit/NUM-PER-CentiM-KiloYR")
    LB_SEC_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-IN3")
    WK = URIRef("http://qudt.org/vocab/unit/WK")
    KiloGM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-BAR")
    TON_SHORT_PER_HR_PSI = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR-PSI")
    W_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M3")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    DAY_Sidereal = URIRef("http://qudt.org/vocab/unit/DAY_Sidereal")
    LB_PER_IN3_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3-DEG_F")
    U = URIRef("http://qudt.org/vocab/unit/U")
    MilliDEG_C = URIRef("http://qudt.org/vocab/unit/MilliDEG_C")
    PINT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-SEC")
    V_IN2_PER_LB_F = URIRef("http://qudt.org/vocab/unit/V-IN2-PER-LB_F")
    FT3_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT3-PER-SEC")
    KiloGM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MilliM")
    MI_US2 = URIRef("http://qudt.org/vocab/unit/MI_US2")
    MicroM2 = URIRef("http://qudt.org/vocab/unit/MicroM2")
    PK_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-HR")
    MicroIN = URIRef("http://qudt.org/vocab/unit/MicroIN")
    PPT = URIRef("http://qudt.org/vocab/unit/PPT")
    TON_SHORT_PER_PSI = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-PSI")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    KiloMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-KiloGM")
    MilliV_PER_M = URIRef("http://qudt.org/vocab/unit/MilliV-PER-M")
    MilliMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3")
    BBL = URIRef("http://qudt.org/vocab/unit/BBL")
    KiloPA_M2_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloPA-M2-PER-GM")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    CD_IN = URIRef("http://qudt.org/vocab/unit/CD_IN")
    GM_SEC_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M3-CentiM3")
    DEG_F_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-HR")
    AttoFARAD = URIRef("http://qudt.org/vocab/unit/AttoFARAD")
    MilliL_PER_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-K")
    PER_WB = URIRef("http://qudt.org/vocab/unit/PER-WB")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    MicroATM = URIRef("http://qudt.org/vocab/unit/MicroATM")
    MicroGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2")
    GM_SEC_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L2")
    W_PER_M2_M = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M")
    MegaN = URIRef("http://qudt.org/vocab/unit/MegaN")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    KiloCAL_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM-SEC-DEG_C")
    H_Ab = URIRef("http://qudt.org/vocab/unit/H_Ab")
    N_PER_A = URIRef("http://qudt.org/vocab/unit/N-PER-A")
    MicroSEC = URIRef("http://qudt.org/vocab/unit/MicroSEC")
    M2_PER_K = URIRef("http://qudt.org/vocab/unit/M2-PER-K")
    MicroSV = URIRef("http://qudt.org/vocab/unit/MicroSV")
    FT3 = URIRef("http://qudt.org/vocab/unit/FT3")
    PER_M_K = URIRef("http://qudt.org/vocab/unit/PER-M-K")
    DeciM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MOL")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    V_PER_K = URIRef("http://qudt.org/vocab/unit/V-PER-K")
    OZ_HR_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-FT3")
    DYN_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM")
    KiloMOL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-HR")
    FemtoGM_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-L")
    HectoPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-BAR")
    DEG_C_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-HR")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    ATM_PER_M = URIRef("http://qudt.org/vocab/unit/ATM-PER-M")
    KibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M2")
    MilliL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN")
    KiloJ_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MIN")
    PDL_FT = URIRef("http://qudt.org/vocab/unit/PDL-FT")
    KiloGM_PER_HA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HA")
    HZ_PER_V = URIRef("http://qudt.org/vocab/unit/HZ-PER-V")
    ERG_PER_G = URIRef("http://qudt.org/vocab/unit/ERG-PER-G")
    GAL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-HR")
    Hundredweight_UK = URIRef("http://qudt.org/vocab/unit/Hundredweight_UK")
    MilliGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-HR")
    QT_US_DRY = URIRef("http://qudt.org/vocab/unit/QT_US_DRY")
    M2_PER_N = URIRef("http://qudt.org/vocab/unit/M2-PER-N")
    HP_Metric = URIRef("http://qudt.org/vocab/unit/HP_Metric")
    KiloCAL_TH = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH")
    L_PER_MIN = URIRef("http://qudt.org/vocab/unit/L-PER-MIN")
    MicroGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-BAR")
    MilliGM_PER_L = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L")
    W_HR_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-HR-PER-KiloGM")
    TeraA = URIRef("http://qudt.org/vocab/unit/TeraA")
    KiloGM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MilliM")
    MilliV_A_PER_K = URIRef("http://qudt.org/vocab/unit/MilliV-A-PER-K")
    MegaGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-M3")
    BAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-L-PER-SEC")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    MOL_PER_M2_SEC_M_SR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-M-SR")
    KiloN = URIRef("http://qudt.org/vocab/unit/KiloN")
    MilliGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-KiloGM")
    MOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-SEC")
    MilliTORR = URIRef("http://qudt.org/vocab/unit/MilliTORR")
    MicroFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-M")
    DecaARE = URIRef("http://qudt.org/vocab/unit/DecaARE")
    MicroBQ = URIRef("http://qudt.org/vocab/unit/MicroBQ")
    MO_MeanJulian = URIRef("http://qudt.org/vocab/unit/MO_MeanJulian")
    ERG_PER_CentiM = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM")
    TON_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-DAY")
    MilliGM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M")
    FT_HR_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-GAL_US")
    BU_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-MIN")
    N_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-M-PER-M2")
    MilliGM_PER_M3_POISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-POISE")
    MegaBAR = URIRef("http://qudt.org/vocab/unit/MegaBAR")
    KiloC_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M2")
    YD_PER_HR = URIRef("http://qudt.org/vocab/unit/YD-PER-HR")
    L_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-BAR")
    PA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-BAR")
    MilliM_HG = URIRef("http://qudt.org/vocab/unit/MilliM_HG")
    CentiMOL = URIRef("http://qudt.org/vocab/unit/CentiMOL")
    KiloGM_PER_J = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-J")
    CentiN_M = URIRef("http://qudt.org/vocab/unit/CentiN-M")
    DeciM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MOL")
    T = URIRef("http://qudt.org/vocab/unit/T")
    LB_SEC_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-FT3")
    KiloTON_Metric = URIRef("http://qudt.org/vocab/unit/KiloTON_Metric")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    MilliH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-OHM")
    MilliM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-HR")
    PPTR_VOL = URIRef("http://qudt.org/vocab/unit/PPTR_VOL")
    N_M2_PER_A = URIRef("http://qudt.org/vocab/unit/N-M2-PER-A")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    ERG = URIRef("http://qudt.org/vocab/unit/ERG")
    CAL_TH_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-K")
    GAL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-HR")
    MI2 = URIRef("http://qudt.org/vocab/unit/MI2")
    MicroS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MicroS-PER-CentiM")
    MilliGM_SEC_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M3-L")
    AttoC = URIRef("http://qudt.org/vocab/unit/AttoC")
    GM_F = URIRef("http://qudt.org/vocab/unit/GM_F")
    PPT = URIRef("http://qudt.org/vocab/unit/PPT")
    MicroMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-DAY")
    BTU_IT_PER_HR_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2")
    PINT_US = URIRef("http://qudt.org/vocab/unit/PINT_US")
    KiloL = URIRef("http://qudt.org/vocab/unit/KiloL")
    PSI_IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-IN3-PER-SEC")
    FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/FT2-PER-BTU_IT-IN")
    DeciB_C = URIRef("http://qudt.org/vocab/unit/DeciB_C")
    MicroJ = URIRef("http://qudt.org/vocab/unit/MicroJ")
    OZ_MIN_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN6")
    LB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT")
    HectoPA = URIRef("http://qudt.org/vocab/unit/HectoPA")
    A = URIRef("http://qudt.org/vocab/unit/A")
    MilliS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MilliS-PER-CentiM")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    MilliM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM2-PER-SEC")
    MilloMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilloMOL-PER-L")
    MegaOHM_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-M")
    DeciSEC = URIRef("http://qudt.org/vocab/unit/DeciSEC")
    TEX = URIRef("http://qudt.org/vocab/unit/TEX")
    KiloJ = URIRef("http://qudt.org/vocab/unit/KiloJ")
    DEG_F_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC2")
    KiloBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-HR")
    M3_PER_KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM-SEC2")
    LB_FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT-PER-SEC")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    MilliH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-OHM")
    MilliMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-GM")
    MegaS_PER_M = URIRef("http://qudt.org/vocab/unit/MegaS-PER-M")
    DEGREE_BRIX = URIRef("http://qudt.org/vocab/unit/DEGREE_BRIX")
    EV_PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/EV-PER-ANGSTROM")
    MilliM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM2-PER-SEC")
    TON_Metric_PER_M3 = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3")
    PlanckLength = URIRef("http://qudt.org/vocab/unit/PlanckLength")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    KiloGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-BAR")
    MilliGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-DAY")
    KiloJ_PER_KiloV = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloV")
    LB_MIN_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-GAL_UK")
    TON_SHORT_PER_HR_PSI = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR-PSI")
    YD_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD-PER-SEC")
    ERG_PER_CentiM = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM")
    L_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-K")
    J_PER_T2 = URIRef("http://qudt.org/vocab/unit/J-PER-T2")
    DeciM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-DAY")
    TeraW_HR = URIRef("http://qudt.org/vocab/unit/TeraW-HR")
    DEG_F_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-K")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    M3_PER_M3 = URIRef("http://qudt.org/vocab/unit/M3-PER-M3")
    PlanckVolt = URIRef("http://qudt.org/vocab/unit/PlanckVolt")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    M = URIRef("http://qudt.org/vocab/unit/M")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    M2_K = URIRef("http://qudt.org/vocab/unit/M2-K")
    N_M2_PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/N-M2-PER-KiloGM2")
    MilliL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M3")
    DeciB_PER_M = URIRef("http://qudt.org/vocab/unit/DeciB-PER-M")
    KiloGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-SEC")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    CAL_TH_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM-SEC-DEG_C")
    L_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-M2")
    PERCENT_MIN_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-GAL_UK")
    KiloM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC2")
    BTU_IT_PER_LB_MOL = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-MOL")
    LB_M = URIRef("http://qudt.org/vocab/unit/LB_M")
    YD3_PER_HR = URIRef("http://qudt.org/vocab/unit/YD3-PER-HR")
    FT3_PER_MIN_FT2 = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN-FT2")
    M = URIRef("http://qudt.org/vocab/unit/M")
    PlanckMass = URIRef("http://qudt.org/vocab/unit/PlanckMass")
    BAUD = URIRef("http://qudt.org/vocab/unit/BAUD")
    BTU_IT_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT-PER-FT2-HR-DEG_F")
    LunarMass = URIRef("http://qudt.org/vocab/unit/LunarMass")
    J_PER_KiloGM_K_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-M3")
    M2_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-HZ2")
    DeciN = URIRef("http://qudt.org/vocab/unit/DeciN")
    PERCENT_PER_M = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-M")
    MilliFARAD = URIRef("http://qudt.org/vocab/unit/MilliFARAD")
    MilliS_PER_M = URIRef("http://qudt.org/vocab/unit/MilliS-PER-M")
    CAL_TH = URIRef("http://qudt.org/vocab/unit/CAL_TH")
    LB_PER_FT_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-HR")
    FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC")
    OZ_MIN_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-YD3")
    MegaN = URIRef("http://qudt.org/vocab/unit/MegaN")
    GigaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-SEC")
    LB_HR_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-GAL_UK")
    J_PER_KiloGM_K_PA = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-PA")
    PK_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-SEC")
    GigaW = URIRef("http://qudt.org/vocab/unit/GigaW")
    MilliGM_MIN_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M6")
    A_Stat = URIRef("http://qudt.org/vocab/unit/A_Stat")
    NanoOHM_M = URIRef("http://qudt.org/vocab/unit/NanoOHM-M")
    M = URIRef("http://qudt.org/vocab/unit/M")
    YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD3-PER-SEC")
    MicroM_PER_M = URIRef("http://qudt.org/vocab/unit/MicroM-PER-M")
    AC_FT = URIRef("http://qudt.org/vocab/unit/AC-FT")
    CentiM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    PPM_PER_K = URIRef("http://qudt.org/vocab/unit/PPM-PER-K")
    YD3_PER_DAY = URIRef("http://qudt.org/vocab/unit/YD3-PER-DAY")
    NanoH = URIRef("http://qudt.org/vocab/unit/NanoH")
    OZ_VOL_UK = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK")
    KiloBTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH-PER-HR")
    PER_PA_SEC = URIRef("http://qudt.org/vocab/unit/PER-PA-SEC")
    NanoL = URIRef("http://qudt.org/vocab/unit/NanoL")
    DecaM = URIRef("http://qudt.org/vocab/unit/DecaM")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    CORD = URIRef("http://qudt.org/vocab/unit/CORD")
    LB_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-SEC")
    C = URIRef("http://qudt.org/vocab/unit/C")
    MilliCD = URIRef("http://qudt.org/vocab/unit/MilliCD")
    PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/PER-MilliM3")
    M_PER_K = URIRef("http://qudt.org/vocab/unit/M-PER-K")
    MilliM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliM-PER-K")
    PERCENT_PER_DektoKiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DektoKiloCount")
    YD_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD-PER-MIN")
    MilliGM_PER_M3_CentiPOISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-CentiPOISE")
    N_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM2")
    KiloCAL_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM")
    A_HR_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/A-HR-PER-KiloGM")
    REM_PER_SEC = URIRef("http://qudt.org/vocab/unit/REM-PER-SEC")
    V_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/V-A_Reactive-HR")
    M6 = URIRef("http://qudt.org/vocab/unit/M6")
    LB_HR_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-YD3")
    KiloGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-BAR")
    GigaBasePair = URIRef("http://qudt.org/vocab/unit/GigaBasePair")
    KiloMIL_Circ = URIRef("http://qudt.org/vocab/unit/KiloMIL_Circ")
    TONNE_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN-BAR")
    LB_MIN_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-GAL_US")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    M3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-K")
    KiloN_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M3")
    PER_CentiM = URIRef("http://qudt.org/vocab/unit/PER-CentiM")
    GigaBQ = URIRef("http://qudt.org/vocab/unit/GigaBQ")
    MicroMOL = URIRef("http://qudt.org/vocab/unit/MicroMOL")
    MilliH = URIRef("http://qudt.org/vocab/unit/MilliH")
    C_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM2")
    PicoA = URIRef("http://qudt.org/vocab/unit/PicoA")
    ERG_PER_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-SEC")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    KY = URIRef("http://qudt.org/vocab/unit/KY")
    PER_T_M = URIRef("http://qudt.org/vocab/unit/PER-T-M")
    KiloGM_PER_M_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-HR")
    MebiBIT = URIRef("http://qudt.org/vocab/unit/MebiBIT")
    ARCMIN = URIRef("http://qudt.org/vocab/unit/ARCMIN")
    SLUG_PER_HR = URIRef("http://qudt.org/vocab/unit/SLUG-PER-HR")
    M2_PER_GM = URIRef("http://qudt.org/vocab/unit/M2-PER-GM")
    ExaW = URIRef("http://qudt.org/vocab/unit/ExaW")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    PER_GigaEV2 = URIRef("http://qudt.org/vocab/unit/PER-GigaEV2")
    KiloTONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloTONNE-PER-YR")
    DYN_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM3")
    GM_PER_M3_CentiPOISE = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-CentiPOISE")
    GM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR-BAR")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    DeciM2 = URIRef("http://qudt.org/vocab/unit/DeciM2")
    BTU_IT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC")
    DEG_F_HR_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_IT")
    AttoFARAD = URIRef("http://qudt.org/vocab/unit/AttoFARAD")
    A_MIN = URIRef("http://qudt.org/vocab/unit/A-MIN")
    KiloC = URIRef("http://qudt.org/vocab/unit/KiloC")
    CAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    DEATHS_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000I-YR")
    K_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-M-PER-SEC")
    GigaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBYTE-PER-SEC")
    ST = URIRef("http://qudt.org/vocab/unit/ST")
    NanoC = URIRef("http://qudt.org/vocab/unit/NanoC")
    CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-GM")
    FT_PDL = URIRef("http://qudt.org/vocab/unit/FT-PDL")
    TON_Metric_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY-K")
    ERG_SEC = URIRef("http://qudt.org/vocab/unit/ERG-SEC")
    MilliGAL = URIRef("http://qudt.org/vocab/unit/MilliGAL")
    A_PER_MilliM = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM")
    MegaPA_M0pt5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0pt5")
    DPI = URIRef("http://qudt.org/vocab/unit/DPI")
    CentiGM = URIRef("http://qudt.org/vocab/unit/CentiGM")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    C_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM2")
    KiloGM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-BAR")
    BTU_IT_PER_LB_F_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_R")
    PER_L = URIRef("http://qudt.org/vocab/unit/PER-L")
    KiloN_M_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-M")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    IN4 = URIRef("http://qudt.org/vocab/unit/IN4")
    MOL_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-SEC")
    MilliH = URIRef("http://qudt.org/vocab/unit/MilliH")
    N_M_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-M")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    AttoA = URIRef("http://qudt.org/vocab/unit/AttoA")
    CentiM3_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR-BAR")
    PDL_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-FT2")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    MilliA_PER_IN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-IN")
    TeraJ = URIRef("http://qudt.org/vocab/unit/TeraJ")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    KiloGM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3")
    GM_PER_M3 = URIRef("http://qudt.org/vocab/unit/GM-PER-M3")
    NanoM_PER_CentiM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-MegaPA")
    HZ_PER_V = URIRef("http://qudt.org/vocab/unit/HZ-PER-V")
    STILB = URIRef("http://qudt.org/vocab/unit/STILB")
    PicoPA = URIRef("http://qudt.org/vocab/unit/PicoPA")
    GAL_US_DRY = URIRef("http://qudt.org/vocab/unit/GAL_US_DRY")
    PER_DAY = URIRef("http://qudt.org/vocab/unit/PER-DAY")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    TON_SHORT = URIRef("http://qudt.org/vocab/unit/TON_SHORT")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    MilliFARAD = URIRef("http://qudt.org/vocab/unit/MilliFARAD")
    DeciB_C = URIRef("http://qudt.org/vocab/unit/DeciB_C")
    MilliWB = URIRef("http://qudt.org/vocab/unit/MilliWB")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    DeciM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-M3")
    LB_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN2")
    ST_PER_BAR = URIRef("http://qudt.org/vocab/unit/ST-PER-BAR")
    W_PER_M2_M = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M")
    GAL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-HR")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    FT_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-PER-MIN")
    DeciM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-SEC")
    ERG_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM3")
    FT = URIRef("http://qudt.org/vocab/unit/FT")
    NUM_PER_HA = URIRef("http://qudt.org/vocab/unit/NUM-PER-HA")
    MegaGM = URIRef("http://qudt.org/vocab/unit/MegaGM")
    KiloGM_PER_GigaJ = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-GigaJ")
    MegaPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-BAR")
    DeciS_PER_M = URIRef("http://qudt.org/vocab/unit/DeciS-PER-M")
    FT3_PER_MIN_FT2 = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN-FT2")
    AttoJ = URIRef("http://qudt.org/vocab/unit/AttoJ")
    LB_SEC_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-FT3")
    KiloCAL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MIN")
    MegaN = URIRef("http://qudt.org/vocab/unit/MegaN")
    N_M_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-M")
    NanoM2 = URIRef("http://qudt.org/vocab/unit/NanoM2")
    C4_M4_PER_J3 = URIRef("http://qudt.org/vocab/unit/C4-M4-PER-J3")
    ExbiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M3")
    CAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-MIN")
    GM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM")
    MegaPSI = URIRef("http://qudt.org/vocab/unit/MegaPSI")
    PicoS = URIRef("http://qudt.org/vocab/unit/PicoS")
    PER_PlanckMass2 = URIRef("http://qudt.org/vocab/unit/PER-PlanckMass2")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    KiloJ = URIRef("http://qudt.org/vocab/unit/KiloJ")
    PlanckFrequency = URIRef("http://qudt.org/vocab/unit/PlanckFrequency")
    N_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM2")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    MilliGM_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-DAY")
    CentiM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC")
    MilliM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliM-PER-M")
    V_PER_MicroSEC = URIRef("http://qudt.org/vocab/unit/V-PER-MicroSEC")
    MilliL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-SEC")
    DeciBAR = URIRef("http://qudt.org/vocab/unit/DeciBAR")
    GM_SEC_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L-M3")
    PER_H = URIRef("http://qudt.org/vocab/unit/PER-H")
    MillionUSD_PER_YR = URIRef("http://qudt.org/vocab/unit/MillionUSD-PER-YR")
    L_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/L-PER-KiloGM")
    MilliH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-OHM")
    MilliPA_SEC_PER_K = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-K")
    DecaPA = URIRef("http://qudt.org/vocab/unit/DecaPA")
    KiloMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-KiloGM")
    N_M2_PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/N-M2-PER-KiloGM2")
    OZ_VOL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-DAY")
    PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PER-CentiM3")
    MilliW_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM")
    DEGREE_BRIX = URIRef("http://qudt.org/vocab/unit/DEGREE_BRIX")
    KiloBIT = URIRef("http://qudt.org/vocab/unit/KiloBIT")
    L_PER_DAY = URIRef("http://qudt.org/vocab/unit/L-PER-DAY")
    HART_PER_SEC = URIRef("http://qudt.org/vocab/unit/HART-PER-SEC")
    KiloV_A = URIRef("http://qudt.org/vocab/unit/KiloV-A")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    DEGREE_API = URIRef("http://qudt.org/vocab/unit/DEGREE_API")
    MicroM_PER_K = URIRef("http://qudt.org/vocab/unit/MicroM-PER-K")
    CAL_TH_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2-MIN")
    KiloGM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM2")
    PlanckForce = URIRef("http://qudt.org/vocab/unit/PlanckForce")
    BU_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-MIN")
    KiloT = URIRef("http://qudt.org/vocab/unit/KiloT")
    PERCENT_PER_V = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-V")
    H_Ab = URIRef("http://qudt.org/vocab/unit/H_Ab")
    M2_PER_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ2")
    MegaV = URIRef("http://qudt.org/vocab/unit/MegaV")
    TONNE_PER_HA = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    M3_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-BAR")
    PER_CentiM = URIRef("http://qudt.org/vocab/unit/PER-CentiM")
    NUM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/NUM-PER-M2-DAY")
    T = URIRef("http://qudt.org/vocab/unit/T")
    CentiM3_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR-BAR")
    C2_M2_PER_J = URIRef("http://qudt.org/vocab/unit/C2-M2-PER-J")
    TON_Metric_PER_SEC = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC")
    EUR_PER_W_SEC = URIRef("http://qudt.org/vocab/unit/EUR-PER-W-SEC")
    N_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M2")
    PERCENT_PER_DEGREE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEGREE")
    HZ_PER_T = URIRef("http://qudt.org/vocab/unit/HZ-PER-T")
    MilliGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-DAY")
    M_KiloGM = URIRef("http://qudt.org/vocab/unit/M-KiloGM")
    MicroFARAD = URIRef("http://qudt.org/vocab/unit/MicroFARAD")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    RAD_PER_HR = URIRef("http://qudt.org/vocab/unit/RAD-PER-HR")
    MicroMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-KiloGM")
    NanoW = URIRef("http://qudt.org/vocab/unit/NanoW")
    MilliGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2")
    CentiMOL_PER_L = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-L")
    ERG_CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-CentiM2-PER-GM")
    MilliGM_SEC_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M3-L")
    A_M2 = URIRef("http://qudt.org/vocab/unit/A-M2")
    S = URIRef("http://qudt.org/vocab/unit/S")
    TONNE_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY-BAR")
    FT_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-PER-HR")
    WB_PER_MilliM = URIRef("http://qudt.org/vocab/unit/WB-PER-MilliM")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2")
    W_PER_M2_K = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K")
    TON_Metric_PER_HR_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR-K")
    KiloS_PER_M = URIRef("http://qudt.org/vocab/unit/KiloS-PER-M")
    RAD_PER_MIN = URIRef("http://qudt.org/vocab/unit/RAD-PER-MIN")
    C = URIRef("http://qudt.org/vocab/unit/C")
    MilliJ = URIRef("http://qudt.org/vocab/unit/MilliJ")
    FT_LA = URIRef("http://qudt.org/vocab/unit/FT-LA")
    FT_SEC_PER_IN3 = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-IN3")
    TebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M")
    GI_US = URIRef("http://qudt.org/vocab/unit/GI_US")
    GM_PER_M3 = URIRef("http://qudt.org/vocab/unit/GM-PER-M3")
    A_PER_RAD = URIRef("http://qudt.org/vocab/unit/A-PER-RAD")
    MicroMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM")
    CAL_IT_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM")
    CentiM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL")
    PicoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-MilliL")
    W_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-PER-KiloGM")
    ERG_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM3")
    Stone_UK = URIRef("http://qudt.org/vocab/unit/Stone_UK")
    NanoT = URIRef("http://qudt.org/vocab/unit/NanoT")
    MilliL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-KiloGM")
    NanoC = URIRef("http://qudt.org/vocab/unit/NanoC")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    BU_US = URIRef("http://qudt.org/vocab/unit/BU_US")
    FemtoGM_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-L")
    AT = URIRef("http://qudt.org/vocab/unit/AT")
    MegaC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M2")
    N_M_PER_MIN_Angle = URIRef("http://qudt.org/vocab/unit/N-M-PER-MIN_Angle")
    CAL_15_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_15_DEG_C")
    KiloGM_PER_L = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L")
    LB_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_US")
    PER_EV2 = URIRef("http://qudt.org/vocab/unit/PER-EV2")
    V_IN2_PER_LB_F = URIRef("http://qudt.org/vocab/unit/V-IN2-PER-LB_F")
    DeciN_M = URIRef("http://qudt.org/vocab/unit/DeciN-M")
    A_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Stat-PER-CentiM2")
    KiloL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloL-PER-HR")
    MI_US = URIRef("http://qudt.org/vocab/unit/MI_US")
    YD3 = URIRef("http://qudt.org/vocab/unit/YD3")
    DEGREE_BAUME_US_HEAVY = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_HEAVY")
    MegaJ = URIRef("http://qudt.org/vocab/unit/MegaJ")
    MilliA_SEC = URIRef("http://qudt.org/vocab/unit/MilliA-SEC")
    FT_LB_F_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2-SEC")
    KiloW = URIRef("http://qudt.org/vocab/unit/KiloW")
    MilliGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC")
    NUM_PER_HA = URIRef("http://qudt.org/vocab/unit/NUM-PER-HA")
    KiloGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-K")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    FC = URIRef("http://qudt.org/vocab/unit/FC")
    MIL = URIRef("http://qudt.org/vocab/unit/MIL")
    YD3_PER_DAY = URIRef("http://qudt.org/vocab/unit/YD3-PER-DAY")
    PlanckLength = URIRef("http://qudt.org/vocab/unit/PlanckLength")
    MilliL_PER_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-K")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    YR_Sidereal = URIRef("http://qudt.org/vocab/unit/YR_Sidereal")
    M_PER_HR = URIRef("http://qudt.org/vocab/unit/M-PER-HR")
    AU = URIRef("http://qudt.org/vocab/unit/AU")
    MI_PER_SEC = URIRef("http://qudt.org/vocab/unit/MI-PER-SEC")
    H_Ab = URIRef("http://qudt.org/vocab/unit/H_Ab")
    MHO_Stat = URIRef("http://qudt.org/vocab/unit/MHO_Stat")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    DYN_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM3")
    NanoGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-MIN")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    GI_UK = URIRef("http://qudt.org/vocab/unit/GI_UK")
    MicroV_A_PER_K = URIRef("http://qudt.org/vocab/unit/MicroV-A-PER-K")
    N_M_PER_ARCMIN = URIRef("http://qudt.org/vocab/unit/N-M-PER-ARCMIN")
    PicoGM_PER_L = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-L")
    GRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/GRAY-PER-SEC")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    FT_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC-DEG_F")
    PebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M2")
    S_Ab = URIRef("http://qudt.org/vocab/unit/S_Ab")
    YD3_PER_PSI = URIRef("http://qudt.org/vocab/unit/YD3-PER-PSI")
    OZ_VOL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-HR")
    CAL_IT = URIRef("http://qudt.org/vocab/unit/CAL_IT")
    BTU_IT_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_F")
    KAT_PER_MicroL = URIRef("http://qudt.org/vocab/unit/KAT-PER-MicroL")
    M3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-K")
    FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F")
    PlanckVolt = URIRef("http://qudt.org/vocab/unit/PlanckVolt")
    KiloCAL_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM")
    MI3 = URIRef("http://qudt.org/vocab/unit/MI3")
    MicroGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-MIN")
    PlanckPower = URIRef("http://qudt.org/vocab/unit/PlanckPower")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    IN_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC-DEG_F")
    MIN_Sidereal = URIRef("http://qudt.org/vocab/unit/MIN_Sidereal")
    J_PER_KiloGM_K_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-M3")
    REV_PER_MIN = URIRef("http://qudt.org/vocab/unit/REV-PER-MIN")
    OZ_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ-PER-HR")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    KiloGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-K")
    PPTM = URIRef("http://qudt.org/vocab/unit/PPTM")
    YD3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD3-PER-DEG_F")
    EV_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/EV-M2-PER-KiloGM")
    FARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/FARAD-PER-KiloM")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    A_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/A-PER-KiloGM")
    TON_SHORT_PER_PSI = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-PSI")
    MicroV_A_PER_K = URIRef("http://qudt.org/vocab/unit/MicroV-A-PER-K")
    HA = URIRef("http://qudt.org/vocab/unit/HA")
    MOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MOL-PER-MOL")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    V_PER_BAR = URIRef("http://qudt.org/vocab/unit/V-PER-BAR")
    KiloCAL_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM-SEC-DEG_C")
    MicroM_PER_M = URIRef("http://qudt.org/vocab/unit/MicroM-PER-M")
    PA_SEC_PER_K = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-K")
    PPTR = URIRef("http://qudt.org/vocab/unit/PPTR")
    CAL_TH_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM-K")
    ExaBYTE = URIRef("http://qudt.org/vocab/unit/ExaBYTE")
    KiloGM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR")
    CentiM3_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR-BAR")
    DEG_R = URIRef("http://qudt.org/vocab/unit/DEG_R")
    KiloA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M")
    FT_SEC_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-GAL_US")
    IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC")
    KiloGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloGM")
    DEATHS_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000I-YR")
    OZ_SEC_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-FT3")
    GigaOHM_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-M")
    KiloM = URIRef("http://qudt.org/vocab/unit/KiloM")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    PER_YR = URIRef("http://qudt.org/vocab/unit/PER-YR")
    MicroV_PER_M = URIRef("http://qudt.org/vocab/unit/MicroV-PER-M")
    PDL_PER_IN = URIRef("http://qudt.org/vocab/unit/PDL-PER-IN")
    TON_Metric_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN-BAR")
    K_PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PA-PER-SEC")
    MilliMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2")
    M_PER_FARAD = URIRef("http://qudt.org/vocab/unit/M-PER-FARAD")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    M3_PER_HR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR")
    OHM_Stat = URIRef("http://qudt.org/vocab/unit/OHM_Stat")
    GM_PER_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-BAR")
    DeciTON_Metric = URIRef("http://qudt.org/vocab/unit/DeciTON_Metric")
    OZ_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ-PER-MIN")
    LB_PER_YD3 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD3")
    MilliGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-K")
    ERG_PER_G = URIRef("http://qudt.org/vocab/unit/ERG-PER-G")
    N_M2_PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/N-M2-PER-KiloGM2")
    KiloGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-BAR")
    T = URIRef("http://qudt.org/vocab/unit/T")
    KiloGM_PER_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-K")
    MicroMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM")
    LB_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC-PSI")
    MegaOHM = URIRef("http://qudt.org/vocab/unit/MegaOHM")
    C_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM")
    FRAME_PER_SEC = URIRef("http://qudt.org/vocab/unit/FRAME-PER-SEC")
    GigaEV = URIRef("http://qudt.org/vocab/unit/GigaEV")
    MebiBYTE = URIRef("http://qudt.org/vocab/unit/MebiBYTE")
    PlanckTime = URIRef("http://qudt.org/vocab/unit/PlanckTime")
    THERM_EC = URIRef("http://qudt.org/vocab/unit/THERM_EC")
    DeciM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-SEC")
    PDL_IN = URIRef("http://qudt.org/vocab/unit/PDL-IN")
    KiloGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC")
    MicroGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-MIN")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    OZ_VOL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-DAY")
    BTU_IT_PER_LB_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F")
    K_DAY = URIRef("http://qudt.org/vocab/unit/K-DAY")
    PetaJ = URIRef("http://qudt.org/vocab/unit/PetaJ")
    NanoGM_PER_L = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-L")
    PlanckEnergy = URIRef("http://qudt.org/vocab/unit/PlanckEnergy")
    L_PER_DAY = URIRef("http://qudt.org/vocab/unit/L-PER-DAY")
    MilliJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-M2")
    MilliV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliV-PER-MIN")
    V_PER_MilliM = URIRef("http://qudt.org/vocab/unit/V-PER-MilliM")
    MilliGM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-BAR")
    MOL_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB")
    N_M_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-M")
    YD_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD-PER-DEG_F")
    N_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM2")
    DECADE = URIRef("http://qudt.org/vocab/unit/DECADE")
    IN_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC-DEG_F")
    DEG_F_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-K")
    KiloV_PER_M = URIRef("http://qudt.org/vocab/unit/KiloV-PER-M")
    TON_SHORT_PER_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR-DEG_F")
    GRAIN = URIRef("http://qudt.org/vocab/unit/GRAIN")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    Denier = URIRef("http://qudt.org/vocab/unit/Denier")
    REV_PER_MIN = URIRef("http://qudt.org/vocab/unit/REV-PER-MIN")
    TeraFLOPS = URIRef("http://qudt.org/vocab/unit/TeraFLOPS")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    A_HR = URIRef("http://qudt.org/vocab/unit/A-HR")
    TeraW = URIRef("http://qudt.org/vocab/unit/TeraW")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    OZ_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ-PER-HR")
    SLUG_PER_MIN = URIRef("http://qudt.org/vocab/unit/SLUG-PER-MIN")
    TON_F_US = URIRef("http://qudt.org/vocab/unit/TON_F_US")
    KiloL = URIRef("http://qudt.org/vocab/unit/KiloL")
    MilliC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M3")
    KiloCD = URIRef("http://qudt.org/vocab/unit/KiloCD")
    OZ_VOL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-MIN")
    FT_LB_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-M2")
    MilliA_PER_LB_F_IN2 = URIRef("http://qudt.org/vocab/unit/MilliA-PER-LB_F-IN2")
    CD_PER_LM = URIRef("http://qudt.org/vocab/unit/CD-PER-LM")
    W_M_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-M-PER-M2-SR")
    KAT_PER_MicroL = URIRef("http://qudt.org/vocab/unit/KAT-PER-MicroL")
    CAL_IT_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM")
    GM_SEC_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M3-L")
    STR = URIRef("http://qudt.org/vocab/unit/STR")
    EUR_PER_KiloW = URIRef("http://qudt.org/vocab/unit/EUR-PER-KiloW")
    PSI_PER_PSI = URIRef("http://qudt.org/vocab/unit/PSI-PER-PSI")
    LB_F_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN")
    PERCENT_PER_DEG = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEG")
    MOL_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-SEC")
    NUM_PER_PicoL = URIRef("http://qudt.org/vocab/unit/NUM-PER-PicoL")
    IN_PER_YR = URIRef("http://qudt.org/vocab/unit/IN-PER-YR")
    A_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-PER-CentiM2")
    FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F")
    BAR = URIRef("http://qudt.org/vocab/unit/BAR")
    M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/M2-PER-MOL")
    MilliRAD = URIRef("http://qudt.org/vocab/unit/MilliRAD")
    MicroGAL_PER_M = URIRef("http://qudt.org/vocab/unit/MicroGAL-PER-M")
    J_PER_M4 = URIRef("http://qudt.org/vocab/unit/J-PER-M4")
    W_PER_M = URIRef("http://qudt.org/vocab/unit/W-PER-M")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    MilliS = URIRef("http://qudt.org/vocab/unit/MilliS")
    N_M_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-M")
    OZ_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_US")
    TON_Metric_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC-BAR")
    M2_K_PER_W = URIRef("http://qudt.org/vocab/unit/M2-K-PER-W")
    PSU = URIRef("http://qudt.org/vocab/unit/PSU")
    MilliL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-GM")
    BU_US = URIRef("http://qudt.org/vocab/unit/BU_US")
    N = URIRef("http://qudt.org/vocab/unit/N")
    LA = URIRef("http://qudt.org/vocab/unit/LA")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    MilliOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-BAR")
    PER_WB = URIRef("http://qudt.org/vocab/unit/PER-WB")
    KiloGM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-K")
    OZ_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ-PER-MIN")
    PERCENT_PER_MO = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MO")
    KAT_PER_M3 = URIRef("http://qudt.org/vocab/unit/KAT-PER-M3")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    PA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M3-PER-SEC")
    QT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-MIN")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    BAR_PER_K = URIRef("http://qudt.org/vocab/unit/BAR-PER-K")
    LB_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-DEG_F")
    KiloR = URIRef("http://qudt.org/vocab/unit/KiloR")
    CentiM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY")
    KiloGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-BAR")
    TON_LONG_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_LONG-PER-YD3")
    NanoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/NanoKAT-PER-L")
    KiloGM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC2")
    HR_Sidereal = URIRef("http://qudt.org/vocab/unit/HR_Sidereal")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    ZettaC = URIRef("http://qudt.org/vocab/unit/ZettaC")
    YD_PER_PSI = URIRef("http://qudt.org/vocab/unit/YD-PER-PSI")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    PicoW = URIRef("http://qudt.org/vocab/unit/PicoW")
    BTU_IT_IN_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-HR-FT2-DEG_F")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    QT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-SEC")
    MegaGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-M3")
    KiloM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC-BAR")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    GM_PER_M3_POISE = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-POISE")
    MilliW_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-MilliGM")
    EV_SEC = URIRef("http://qudt.org/vocab/unit/EV-SEC")
    MilliL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-SEC")
    KiloPOND = URIRef("http://qudt.org/vocab/unit/KiloPOND")
    L_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/L-PER-KiloGM")
    MicroM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroM-PER-SEC")
    LB_MIN_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-FT3")
    W_PER_M = URIRef("http://qudt.org/vocab/unit/W-PER-M")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    GI_US = URIRef("http://qudt.org/vocab/unit/GI_US")
    DeciB_M = URIRef("http://qudt.org/vocab/unit/DeciB_M")
    DeciSEC = URIRef("http://qudt.org/vocab/unit/DeciSEC")
    GigaA = URIRef("http://qudt.org/vocab/unit/GigaA")
    M4 = URIRef("http://qudt.org/vocab/unit/M4")
    MilliL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-KiloGM")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    KiloV_PER_M = URIRef("http://qudt.org/vocab/unit/KiloV-PER-M")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    MicroMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L")
    EV_M2 = URIRef("http://qudt.org/vocab/unit/EV-M2")
    TON_Metric_PER_SEC = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC")
    ATM_PER_M = URIRef("http://qudt.org/vocab/unit/ATM-PER-M")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    MOL_K = URIRef("http://qudt.org/vocab/unit/MOL-K")
    PERCENT_PER_KiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-KiloCount")
    V_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Ab-PER-CentiM")
    TONNE_PER_SEC = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC")
    CentiM3_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR")
    DecaPA = URIRef("http://qudt.org/vocab/unit/DecaPA")
    DeciB_M = URIRef("http://qudt.org/vocab/unit/DeciB_M")
    LB_F_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-IN2")
    KiloGM_PER_CentiM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-BAR")
    KiloJ_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM-K")
    GM_PER_M3_CentiPOISE = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-CentiPOISE")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    ERG_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM-SEC")
    FT_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC2")
    A_Stat = URIRef("http://qudt.org/vocab/unit/A_Stat")
    M2_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-V-SEC")
    PicoC = URIRef("http://qudt.org/vocab/unit/PicoC")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    CORD = URIRef("http://qudt.org/vocab/unit/CORD")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    BTU_IT_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-IN2-SEC")
    KiloGM_PER_HA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HA")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    CWT_LONG = URIRef("http://qudt.org/vocab/unit/CWT_LONG")
    S = URIRef("http://qudt.org/vocab/unit/S")
    OHM_Ab = URIRef("http://qudt.org/vocab/unit/OHM_Ab")
    GM_PER_L_CentiPOISE = URIRef("http://qudt.org/vocab/unit/GM-PER-L-CentiPOISE")
    GAL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-MIN")
    Gs = URIRef("http://qudt.org/vocab/unit/Gs")
    MIL = URIRef("http://qudt.org/vocab/unit/MIL")
    CAL_TH_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-DEG_C")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    MegaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-HR")
    KiloGM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM2")
    K2 = URIRef("http://qudt.org/vocab/unit/K2")
    MegaC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M2")
    J_PER_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-DAY")
    NanoGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2")
    YR_Common = URIRef("http://qudt.org/vocab/unit/YR_Common")
    BTU_IT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_F")
    V2_PER_K2 = URIRef("http://qudt.org/vocab/unit/V2-PER-K2")
    MilliM3 = URIRef("http://qudt.org/vocab/unit/MilliM3")
    KiloGM_F_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-MilliM2")
    A_PER_A_HR = URIRef("http://qudt.org/vocab/unit/A-PER-A-HR")
    W_PER_M_DEG_C = URIRef("http://qudt.org/vocab/unit/W-PER-M-DEG_C")
    J_PER_SEC = URIRef("http://qudt.org/vocab/unit/J-PER-SEC")
    PDL = URIRef("http://qudt.org/vocab/unit/PDL")
    DeciBAR_PER_YR = URIRef("http://qudt.org/vocab/unit/DeciBAR-PER-YR")
    LY = URIRef("http://qudt.org/vocab/unit/LY")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    PERCENT_PER_DAY = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DAY")
    GAL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-MIN")
    GM_Carbon_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Carbon-PER-M2-DAY")
    NAT = URIRef("http://qudt.org/vocab/unit/NAT")
    IN = URIRef("http://qudt.org/vocab/unit/IN")
    C_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM-SEC")
    KiloA = URIRef("http://qudt.org/vocab/unit/KiloA")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    DECADE = URIRef("http://qudt.org/vocab/unit/DECADE")
    MilliMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-KiloGM")
    E_h = URIRef("http://qudt.org/vocab/unit/E_h")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    PER_PlanckMass2 = URIRef("http://qudt.org/vocab/unit/PER-PlanckMass2")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    MilliGM_PER_L_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-MilliPA-SEC")
    MebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M3")
    CentiL = URIRef("http://qudt.org/vocab/unit/CentiL")
    N_M2 = URIRef("http://qudt.org/vocab/unit/N-M2")
    FT_LB_F_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-HR")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    KiloGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-K")
    PetaW = URIRef("http://qudt.org/vocab/unit/PetaW")
    V_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Ab-PER-CentiM")
    W_PER_M2_K4 = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K4")
    LB_F_FT_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-FT-PER-IN")
    FT_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC2")
    TeraBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/TeraBIT-PER-SEC")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    PPQ = URIRef("http://qudt.org/vocab/unit/PPQ")
    V = URIRef("http://qudt.org/vocab/unit/V")
    KiloLB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-IN2")
    MegaV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive-HR")
    PERCENT_PER_M = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-M")
    FemtoGM_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-L")
    EUR_PER_M2 = URIRef("http://qudt.org/vocab/unit/EUR-PER-M2")
    KiloS_PER_M = URIRef("http://qudt.org/vocab/unit/KiloS-PER-M")
    FemtoJ = URIRef("http://qudt.org/vocab/unit/FemtoJ")
    LB_PER_M3 = URIRef("http://qudt.org/vocab/unit/LB-PER-M3")
    MilliL_PER_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-K")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    MilliGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-SEC")
    LB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT")
    KiloLB_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloLB-PER-HR")
    MOL_PER_L_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-L-K")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    M3_PER_MIN = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN")
    BTU_TH_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_F")
    MIN_Sidereal = URIRef("http://qudt.org/vocab/unit/MIN_Sidereal")
    MicroFARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-KiloM")
    BTU_IT_PER_SEC_FT_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT-DEG_R")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    GM_MIN_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M3-CentiM3")
    FT3_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT3-PER-DAY")
    HP_H2O = URIRef("http://qudt.org/vocab/unit/HP_H2O")
    MicroN_M = URIRef("http://qudt.org/vocab/unit/MicroN-M")
    PER_DEG_C = URIRef("http://qudt.org/vocab/unit/PER-DEG_C")
    REV_PER_HR = URIRef("http://qudt.org/vocab/unit/REV-PER-HR")
    KiloGM_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-YR")
    MilliS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MilliS-PER-CentiM")
    PicoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L")
    BU_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-HR")
    J_PER_GM = URIRef("http://qudt.org/vocab/unit/J-PER-GM")
    CentiN_M = URIRef("http://qudt.org/vocab/unit/CentiN-M")
    BTU_IT_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-SEC-DEG_F")
    LB_SEC_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-FT3")
    J_PER_GM = URIRef("http://qudt.org/vocab/unit/J-PER-GM")
    TON_FG = URIRef("http://qudt.org/vocab/unit/TON_FG")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    Debye = URIRef("http://qudt.org/vocab/unit/Debye")
    BQ_PER_M2 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M2")
    MegaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBYTE-PER-SEC")
    N_M2_PER_A = URIRef("http://qudt.org/vocab/unit/N-M2-PER-A")
    SLUG_PER_MIN = URIRef("http://qudt.org/vocab/unit/SLUG-PER-MIN")
    PA_M = URIRef("http://qudt.org/vocab/unit/PA-M")
    KiloLB_F = URIRef("http://qudt.org/vocab/unit/KiloLB_F")
    N = URIRef("http://qudt.org/vocab/unit/N")
    LB_F_FT_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-FT-PER-IN")
    MicroGM_PER_L = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L")
    MicroH = URIRef("http://qudt.org/vocab/unit/MicroH")
    MicroGM_PER_L = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L")
    KiloM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC")
    LB_HR_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-GAL_US")
    PK_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-SEC")
    YR_Metrology = URIRef("http://qudt.org/vocab/unit/YR_Metrology")
    MilliT = URIRef("http://qudt.org/vocab/unit/MilliT")
    BTU_TH_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT3")
    MI_PER_HR = URIRef("http://qudt.org/vocab/unit/MI-PER-HR")
    MicroGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-KiloGM")
    HectoPA = URIRef("http://qudt.org/vocab/unit/HectoPA")
    GigaOHM_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-M")
    W_PER_M = URIRef("http://qudt.org/vocab/unit/W-PER-M")
    KiloBAR = URIRef("http://qudt.org/vocab/unit/KiloBAR")
    Gs = URIRef("http://qudt.org/vocab/unit/Gs")
    PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/PER-KiloGM-SEC")
    MilliBQ_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-M2-DAY")
    BTU_IT_PER_MOL_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB")
    ARE = URIRef("http://qudt.org/vocab/unit/ARE")
    OHM_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-PER-M")
    A_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Stat-PER-CentiM2")
    M3_PER_MIN = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN")
    MilliGM_MIN_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M3-L")
    KiloCAL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-MIN")
    GigaOHM_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-M")
    MilliGM_HR_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L-M3")
    MilliL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-KiloGM")
    KiloGM_PER_CentiM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-BAR")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    MicroSEC = URIRef("http://qudt.org/vocab/unit/MicroSEC")
    LM_PER_W = URIRef("http://qudt.org/vocab/unit/LM-PER-W")
    PA_PER_K = URIRef("http://qudt.org/vocab/unit/PA-PER-K")
    GM_PER_L_POISE = URIRef("http://qudt.org/vocab/unit/GM-PER-L-POISE")
    FT_LA = URIRef("http://qudt.org/vocab/unit/FT-LA")
    LB_MIN_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-YD3")
    M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/M2-PER-MOL")
    SLUG_PER_HR = URIRef("http://qudt.org/vocab/unit/SLUG-PER-HR")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    PPTM_PER_K = URIRef("http://qudt.org/vocab/unit/PPTM-PER-K")
    MicroV_PER_M = URIRef("http://qudt.org/vocab/unit/MicroV-PER-M")
    FT_LB_F_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2-SEC")
    ST = URIRef("http://qudt.org/vocab/unit/ST")
    DEATHS_PER_1000000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000000I-YR")
    CAL_IT_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM")
    DEG_R = URIRef("http://qudt.org/vocab/unit/DEG_R")
    NanoSEC = URIRef("http://qudt.org/vocab/unit/NanoSEC")
    CentiM_PER_YR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-YR")
    DeciTON_Metric = URIRef("http://qudt.org/vocab/unit/DeciTON_Metric")
    IN_PDL = URIRef("http://qudt.org/vocab/unit/IN-PDL")
    M3_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-PA")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    BTU_IT = URIRef("http://qudt.org/vocab/unit/BTU_IT")
    PER_MilliGM = URIRef("http://qudt.org/vocab/unit/PER-MilliGM")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    CentiM_HG_0DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_HG_0DEG_C")
    KiloGM_PER_GigaJ = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-GigaJ")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    DRAM_US = URIRef("http://qudt.org/vocab/unit/DRAM_US")
    GAL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-HR")
    N_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-PER-KiloGM")
    NUM_PER_L = URIRef("http://qudt.org/vocab/unit/NUM-PER-L")
    NanoGM = URIRef("http://qudt.org/vocab/unit/NanoGM")
    OZ_HR_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN6")
    BBL_UK_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-HR")
    MilliL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-KiloGM")
    BIT_PER_M = URIRef("http://qudt.org/vocab/unit/BIT-PER-M")
    GM_PER_M3_PA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-PA-SEC")
    DECADE = URIRef("http://qudt.org/vocab/unit/DECADE")
    H = URIRef("http://qudt.org/vocab/unit/H")
    YD3_PER_PSI = URIRef("http://qudt.org/vocab/unit/YD3-PER-PSI")
    OZ_VOL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-SEC")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    MegaLB_F = URIRef("http://qudt.org/vocab/unit/MegaLB_F")
    GALILEO = URIRef("http://qudt.org/vocab/unit/GALILEO")
    PPTR_VOL = URIRef("http://qudt.org/vocab/unit/PPTR_VOL")
    DEG_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC2")
    KiloGM_PER_L = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L")
    IN3_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN3-PER-MIN")
    KiloCAL_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-HR")
    GibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M2")
    HectoPA_PER_K = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-K")
    MilliM2 = URIRef("http://qudt.org/vocab/unit/MilliM2")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    M3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-K")
    PER_J_M3 = URIRef("http://qudt.org/vocab/unit/PER-J-M3")
    KiloN_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M2")
    FT3_PER_LB = URIRef("http://qudt.org/vocab/unit/FT3-PER-LB")
    BTU_TH_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_F")
    M_PER_DEG_C_M = URIRef("http://qudt.org/vocab/unit/M-PER-DEG_C-M")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    CASES_PER_KiloINDIV_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-KiloINDIV-YR")
    PERCENT_MIN_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-YD3")
    LB_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-DEG_F")
    TON_SHORT_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR")
    MilliGM_HR_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L-M3")
    MilliL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-GM")
    GM_SEC_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M3-L")
    HR_Sidereal = URIRef("http://qudt.org/vocab/unit/HR_Sidereal")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    PHOT = URIRef("http://qudt.org/vocab/unit/PHOT")
    CAL_TH_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2-MIN")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    TON_UK = URIRef("http://qudt.org/vocab/unit/TON_UK")
    CAL_TH_PER_G = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-G")
    OZ_SEC_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-FT3")
    DEGREE_TWADDELL = URIRef("http://qudt.org/vocab/unit/DEGREE_TWADDELL")
    GM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3-K")
    KiloBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBYTE-PER-SEC")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    MilliGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-HR")
    EV_SEC = URIRef("http://qudt.org/vocab/unit/EV-SEC")
    MicroGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-HR")
    M3_PER_HR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    CentiN = URIRef("http://qudt.org/vocab/unit/CentiN")
    PER_SEC_M3 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M3")
    NP_PER_SEC = URIRef("http://qudt.org/vocab/unit/NP-PER-SEC")
    GM_SEC_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M3-L")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    PERCENT_MIN_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-IN3")
    OERSTED_CentiM = URIRef("http://qudt.org/vocab/unit/OERSTED-CentiM")
    MilliRAD = URIRef("http://qudt.org/vocab/unit/MilliRAD")
    W_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/W-PER-CentiM2")
    PERCENT_MIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-M3")
    ERG_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM")
    KiloCAL_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL")
    KiloPA = URIRef("http://qudt.org/vocab/unit/KiloPA")
    MilliSV = URIRef("http://qudt.org/vocab/unit/MilliSV")
    C3_M_PER_J2 = URIRef("http://qudt.org/vocab/unit/C3-M-PER-J2")
    BTU_TH_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-SEC-DEG_F")
    FA = URIRef("http://qudt.org/vocab/unit/FA")
    GM_MIN_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L2")
    OZ_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ-PER-SEC")
    PA_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M")
    BARYE = URIRef("http://qudt.org/vocab/unit/BARYE")
    BTU_IT_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT-PER-FT2-HR-DEG_F")
    KiloGM_PER_L = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L")
    KiloBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloBQ-PER-KiloGM")
    TON_SHIPPING_UK = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_UK")
    FT_PDL = URIRef("http://qudt.org/vocab/unit/FT-PDL")
    HART = URIRef("http://qudt.org/vocab/unit/HART")
    MilliA_PER_LB_F_IN2 = URIRef("http://qudt.org/vocab/unit/MilliA-PER-LB_F-IN2")
    N_M_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-M")
    SLUG_PER_FT3 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT3")
    BTU_IT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_F")
    TON_Metric_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC-BAR")
    WB_PER_MilliM = URIRef("http://qudt.org/vocab/unit/WB-PER-MilliM")
    MESH = URIRef("http://qudt.org/vocab/unit/MESH")
    ZOLL = URIRef("http://qudt.org/vocab/unit/ZOLL")
    BU_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-HR")
    CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-GM")
    DEG_R = URIRef("http://qudt.org/vocab/unit/DEG_R")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    DeciM3 = URIRef("http://qudt.org/vocab/unit/DeciM3")
    BU_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-DAY")
    M2_PER_SR_J = URIRef("http://qudt.org/vocab/unit/M2-PER-SR-J")
    PERCENT_PER_DEG = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEG")
    CentiM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY")
    LB_PER_IN3 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3")
    N_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-M-PER-M2")
    A_M2_PER_J_SEC = URIRef("http://qudt.org/vocab/unit/A-M2-PER-J-SEC")
    MOL_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-K")
    GM_PER_CentiM_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM-SEC")
    TONNE_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY-K")
    MicroM_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/MicroM-PER-L-DAY")
    NanoGM_PER_L = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-L")
    DARCY = URIRef("http://qudt.org/vocab/unit/DARCY")
    DEG_C_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-HR")
    YottaC = URIRef("http://qudt.org/vocab/unit/YottaC")
    PicoGM_PER_L = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-L")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    DeciB_PER_M = URIRef("http://qudt.org/vocab/unit/DeciB-PER-M")
    M_PER_YR = URIRef("http://qudt.org/vocab/unit/M-PER-YR")
    ExbiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M3")
    TON = URIRef("http://qudt.org/vocab/unit/TON")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    GigaV_A = URIRef("http://qudt.org/vocab/unit/GigaV-A")
    OZ_IN2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/OZ-IN2-PER-IN3-LB_F-SEC")
    M2_PER_HA = URIRef("http://qudt.org/vocab/unit/M2-PER-HA")
    M4 = URIRef("http://qudt.org/vocab/unit/M4")
    LB_MIN_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-YD3")
    MilliM_HG = URIRef("http://qudt.org/vocab/unit/MilliM_HG")
    ZettaC = URIRef("http://qudt.org/vocab/unit/ZettaC")
    LB_HR_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-IN3")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    KiloGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-K")
    KiloGM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-CentiM2")
    N_PER_CentiM = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM")
    BBL_US = URIRef("http://qudt.org/vocab/unit/BBL_US")
    PicoMOL = URIRef("http://qudt.org/vocab/unit/PicoMOL")
    DecaC = URIRef("http://qudt.org/vocab/unit/DecaC")
    ERLANG = URIRef("http://qudt.org/vocab/unit/ERLANG")
    MilliL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-SEC")
    MilliOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-BAR")
    N_M_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-M-PER-KiloGM")
    PicoMOL_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L-DAY")
    MegaA_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaA-PER-M2")
    LM_HR = URIRef("http://qudt.org/vocab/unit/LM-HR")
    U = URIRef("http://qudt.org/vocab/unit/U")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    KiloJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-SEC")
    MOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM")
    MilliN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliN-M-PER-M2")
    M3_PER_KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM-SEC2")
    EV = URIRef("http://qudt.org/vocab/unit/EV")
    MilliGM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-K")
    MilliGM_PER_L_POISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-POISE")
    N_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M")
    K_PER_M = URIRef("http://qudt.org/vocab/unit/K-PER-M")
    M2_PER_N = URIRef("http://qudt.org/vocab/unit/M2-PER-N")
    N_M2 = URIRef("http://qudt.org/vocab/unit/N-M2")
    MicroM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM-PER-MilliL")
    OHM_PER_K = URIRef("http://qudt.org/vocab/unit/OHM-PER-K")
    MilliBAR_PER_K = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-K")
    M3_PER_KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM-SEC2")
    PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/PER-KiloGM2")
    CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-GM")
    LB_MIN_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-IN3")
    BARN_PER_EV = URIRef("http://qudt.org/vocab/unit/BARN-PER-EV")
    BTU_IT_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB")
    N_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-RAD")
    BTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2")
    FT2 = URIRef("http://qudt.org/vocab/unit/FT2")
    MicroL = URIRef("http://qudt.org/vocab/unit/MicroL")
    GigaBQ = URIRef("http://qudt.org/vocab/unit/GigaBQ")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    M_PER_YR = URIRef("http://qudt.org/vocab/unit/M-PER-YR")
    ExaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/ExaBIT-PER-SEC")
    GAL_UK = URIRef("http://qudt.org/vocab/unit/GAL_UK")
    LM_HR = URIRef("http://qudt.org/vocab/unit/LM-HR")
    KiloGM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    PERCENT_MIN_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-CentiM3")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    MilliGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-BAR")
    A_PER_J = URIRef("http://qudt.org/vocab/unit/A-PER-J")
    DeciC = URIRef("http://qudt.org/vocab/unit/DeciC")
    MilliSV = URIRef("http://qudt.org/vocab/unit/MilliSV")
    A_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM2")
    FemtoM = URIRef("http://qudt.org/vocab/unit/FemtoM")
    BYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/BYTE-PER-SEC")
    DEG_F_HR_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_IT")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    LB_F_FT = URIRef("http://qudt.org/vocab/unit/LB_F-FT")
    GT = URIRef("http://qudt.org/vocab/unit/GT")
    NanoM_PER_MilliM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-MilliM-MegaPA")
    OZ_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ-PER-MIN")
    OZ_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ-PER-SEC")
    QT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_US-PER-SEC")
    GM_PER_CentiM2_YR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2-YR")
    PPM = URIRef("http://qudt.org/vocab/unit/PPM")
    GM_SEC_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L-M3")
    LB_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-MOL-DEG_F")
    PER_YD3 = URIRef("http://qudt.org/vocab/unit/PER-YD3")
    KiloGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN")
    MicroGM_PER_IN2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-IN2")
    N_M2_PER_A = URIRef("http://qudt.org/vocab/unit/N-M2-PER-A")
    MicroFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-M")
    FUR = URIRef("http://qudt.org/vocab/unit/FUR")
    MicroC = URIRef("http://qudt.org/vocab/unit/MicroC")
    MilliV_A = URIRef("http://qudt.org/vocab/unit/MilliV-A")
    KiloGM_PER_L_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-K")
    NUM_PER_SEC = URIRef("http://qudt.org/vocab/unit/NUM-PER-SEC")
    OZ_PER_IN2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN2")
    BARAD = URIRef("http://qudt.org/vocab/unit/BARAD")
    C3_M_PER_J2 = URIRef("http://qudt.org/vocab/unit/C3-M-PER-J2")
    PicoMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M3")
    FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-SEC")
    FT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-DEG_F")
    MicroGM_PER_CentiM2_WK = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2-WK")
    MilliM_PER_YR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-YR")
    PER_EV_M3 = URIRef("http://qudt.org/vocab/unit/PER-EV-M3")
    BTU_IT = URIRef("http://qudt.org/vocab/unit/BTU_IT")
    GM_PER_L = URIRef("http://qudt.org/vocab/unit/GM-PER-L")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    BTU_TH_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_R")
    ZOLL = URIRef("http://qudt.org/vocab/unit/ZOLL")
    SLUG_PER_FT3 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT3")
    MicroSEC = URIRef("http://qudt.org/vocab/unit/MicroSEC")
    LB_F_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN")
    MOL_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB")
    HART = URIRef("http://qudt.org/vocab/unit/HART")
    PSI_PER_IN = URIRef("http://qudt.org/vocab/unit/PSI-PER-IN")
    SUSCEPTIBILITY_MAG = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_MAG")
    CentiM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SEC")
    MegaV_A_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A-HR")
    MegaA_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaA-PER-M2")
    N_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M2")
    PINT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-SEC")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    PER_HR = URIRef("http://qudt.org/vocab/unit/PER-HR")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    M2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2")
    MOL_PER_L = URIRef("http://qudt.org/vocab/unit/MOL-PER-L")
    DeciBAR_PER_YR = URIRef("http://qudt.org/vocab/unit/DeciBAR-PER-YR")
    MilliM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliM-PER-K")
    MI2 = URIRef("http://qudt.org/vocab/unit/MI2")
    L = URIRef("http://qudt.org/vocab/unit/L")
    NanoSEC = URIRef("http://qudt.org/vocab/unit/NanoSEC")
    PERCENT_MIN_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-CentiM3")
    M4_PER_SEC = URIRef("http://qudt.org/vocab/unit/M4-PER-SEC")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    BFT = URIRef("http://qudt.org/vocab/unit/BFT")
    MilliR_man = URIRef("http://qudt.org/vocab/unit/MilliR_man")
    MilliMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-MOL")
    M_PER_FARAD = URIRef("http://qudt.org/vocab/unit/M-PER-FARAD")
    TON_SHORT = URIRef("http://qudt.org/vocab/unit/TON_SHORT")
    N_M2_PER_A = URIRef("http://qudt.org/vocab/unit/N-M2-PER-A")
    THM_US_PER_HR = URIRef("http://qudt.org/vocab/unit/THM_US-PER-HR")
    CAL_IT_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-DEG_C")
    GM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-M2-DAY")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    MOL_LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-SEC")
    W_PER_M2_M_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M-SR")
    PA_PER_MIN = URIRef("http://qudt.org/vocab/unit/PA-PER-MIN")
    OZ_VOL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-HR")
    ZeptoC = URIRef("http://qudt.org/vocab/unit/ZeptoC")
    BU_US = URIRef("http://qudt.org/vocab/unit/BU_US")
    NanoM = URIRef("http://qudt.org/vocab/unit/NanoM")
    K = URIRef("http://qudt.org/vocab/unit/K")
    MOL_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-L-BAR")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    PER_IN3 = URIRef("http://qudt.org/vocab/unit/PER-IN3")
    L_PER_K = URIRef("http://qudt.org/vocab/unit/L-PER-K")
    PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-PER-SEC")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    GigaPA_CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/GigaPA-CentiM3-PER-GM")
    MilliL_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-BAR")
    NanoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-KiloGM")
    PHOT = URIRef("http://qudt.org/vocab/unit/PHOT")
    MIN_Sidereal = URIRef("http://qudt.org/vocab/unit/MIN_Sidereal")
    NanoGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DeciL")
    CentiM_H2O = URIRef("http://qudt.org/vocab/unit/CentiM_H2O")
    GM_HR_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L-M3")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    DIOPTER = URIRef("http://qudt.org/vocab/unit/DIOPTER")
    MilliRAD_R_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliRAD_R-PER-HR")
    PINT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-HR")
    PER_MilliL = URIRef("http://qudt.org/vocab/unit/PER-MilliL")
    KiloGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC")
    CAL_IT_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-DEG_C")
    MilliGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3")
    PA_PER_HR = URIRef("http://qudt.org/vocab/unit/PA-PER-HR")
    L_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/L-PER-MicroMOL")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    M6 = URIRef("http://qudt.org/vocab/unit/M6")
    J_PER_GM_K = URIRef("http://qudt.org/vocab/unit/J-PER-GM-K")
    J_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-M2-PER-KiloGM")
    OZ = URIRef("http://qudt.org/vocab/unit/OZ")
    AC_FT = URIRef("http://qudt.org/vocab/unit/AC-FT")
    YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD3-PER-SEC")
    E_h = URIRef("http://qudt.org/vocab/unit/E_h")
    U = URIRef("http://qudt.org/vocab/unit/U")
    V = URIRef("http://qudt.org/vocab/unit/V")
    M4 = URIRef("http://qudt.org/vocab/unit/M4")
    DAY_Sidereal = URIRef("http://qudt.org/vocab/unit/DAY_Sidereal")
    NanoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/NanoKAT-PER-L")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    MilliN_M = URIRef("http://qudt.org/vocab/unit/MilliN-M")
    POND = URIRef("http://qudt.org/vocab/unit/POND")
    TON_Metric_PER_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-BAR")
    FT_LB_F = URIRef("http://qudt.org/vocab/unit/FT-LB_F")
    FT4 = URIRef("http://qudt.org/vocab/unit/FT4")
    KiloM = URIRef("http://qudt.org/vocab/unit/KiloM")
    MegaW = URIRef("http://qudt.org/vocab/unit/MegaW")
    MicroGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-SEC")
    BBL_UK_PET_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-MIN")
    GM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR-BAR")
    LB_F_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-IN2")
    PER_T_SEC = URIRef("http://qudt.org/vocab/unit/PER-T-SEC")
    PPT = URIRef("http://qudt.org/vocab/unit/PPT")
    DEGREE_BALLING = URIRef("http://qudt.org/vocab/unit/DEGREE_BALLING")
    GM_PER_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY")
    KiloGM_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-YR")
    PSI_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-M3-PER-SEC")
    PERCENT_PER_KiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-KiloCount")
    MilliW = URIRef("http://qudt.org/vocab/unit/MilliW")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    NanoGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DeciL")
    ERG_PER_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-SEC")
    MicroGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-GM")
    MegaV_A_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A-HR")
    PER_M2 = URIRef("http://qudt.org/vocab/unit/PER-M2")
    PER_M2 = URIRef("http://qudt.org/vocab/unit/PER-M2")
    BTU_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC")
    M6 = URIRef("http://qudt.org/vocab/unit/M6")
    M2_K_PER_W = URIRef("http://qudt.org/vocab/unit/M2-K-PER-W")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    BAR_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/BAR-PER-DEG_C")
    A_HR_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-DeciM3")
    OZ_VOL_US = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US")
    YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD3-PER-SEC")
    BQ_PER_M2 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M2")
    FT3_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN")
    BIOT = URIRef("http://qudt.org/vocab/unit/BIOT")
    K_PER_MIN = URIRef("http://qudt.org/vocab/unit/K-PER-MIN")
    PERMITTIVITY_REL = URIRef("http://qudt.org/vocab/unit/PERMITTIVITY_REL")
    KiloOHM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-M")
    PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PER-SEC2")
    GigaJ = URIRef("http://qudt.org/vocab/unit/GigaJ")
    PicoS_PER_M = URIRef("http://qudt.org/vocab/unit/PicoS-PER-M")
    KiloGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM2")
    OZ_VOL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-DAY")
    DeciS = URIRef("http://qudt.org/vocab/unit/DeciS")
    SUSCEPTIBILITY_ELEC = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_ELEC")
    MilliL = URIRef("http://qudt.org/vocab/unit/MilliL")
    MI_US_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/MI_US-PER-SEC2")
    K_M = URIRef("http://qudt.org/vocab/unit/K-M")
    Da = URIRef("http://qudt.org/vocab/unit/Da")
    BQ_PER_M2 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M2")
    SEC_PER_RAD_M3 = URIRef("http://qudt.org/vocab/unit/SEC-PER-RAD-M3")
    MicroN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroN-M-PER-M2")
    TORR_PER_M = URIRef("http://qudt.org/vocab/unit/TORR-PER-M")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    IN_PDL = URIRef("http://qudt.org/vocab/unit/IN-PDL")
    PA_SEC_PER_K = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-K")
    CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-GM")
    W_PER_M2_PA = URIRef("http://qudt.org/vocab/unit/W-PER-M2-PA")
    LB_HR_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-YD3")
    A_M2_PER_J_SEC = URIRef("http://qudt.org/vocab/unit/A-M2-PER-J-SEC")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    MilliDARCY = URIRef("http://qudt.org/vocab/unit/MilliDARCY")
    PER_WK = URIRef("http://qudt.org/vocab/unit/PER-WK")
    MilliRAD = URIRef("http://qudt.org/vocab/unit/MilliRAD")
    MOHM = URIRef("http://qudt.org/vocab/unit/MOHM")
    IN_H2O = URIRef("http://qudt.org/vocab/unit/IN_H2O")
    OHM_PER_K = URIRef("http://qudt.org/vocab/unit/OHM-PER-K")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    EV = URIRef("http://qudt.org/vocab/unit/EV")
    BTU_IT_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT3")
    PK_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-DAY")
    M3_PER_M3 = URIRef("http://qudt.org/vocab/unit/M3-PER-M3")
    PER_J2 = URIRef("http://qudt.org/vocab/unit/PER-J2")
    KiloW_PER_M2_K = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M2-K")
    MicroGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-DeciL")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    DEG_F_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-HR")
    MilliBAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-M3-PER-SEC")
    MegaS_PER_M = URIRef("http://qudt.org/vocab/unit/MegaS-PER-M")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    V_Stat = URIRef("http://qudt.org/vocab/unit/V_Stat")
    MilliGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-BAR")
    CentiM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SEC")
    M2_PER_HZ = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ")
    SEC_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-FT2")
    DEG_C_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-MIN")
    PFERDESTAERKE = URIRef("http://qudt.org/vocab/unit/PFERDESTAERKE")
    KiloGM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM2")
    FR = URIRef("http://qudt.org/vocab/unit/FR")
    PPT = URIRef("http://qudt.org/vocab/unit/PPT")
    N = URIRef("http://qudt.org/vocab/unit/N")
    CAL_IT_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM-K")
    DeciC = URIRef("http://qudt.org/vocab/unit/DeciC")
    LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC")
    S = URIRef("http://qudt.org/vocab/unit/S")
    MOL_PER_KiloGM_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-PA")
    MegaHZ = URIRef("http://qudt.org/vocab/unit/MegaHZ")
    ONE_PER_ONE = URIRef("http://qudt.org/vocab/unit/ONE-PER-ONE")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    IU = URIRef("http://qudt.org/vocab/unit/IU")
    CD_PER_FT2 = URIRef("http://qudt.org/vocab/unit/CD-PER-FT2")
    DeciB_C = URIRef("http://qudt.org/vocab/unit/DeciB_C")
    DAY_Sidereal = URIRef("http://qudt.org/vocab/unit/DAY_Sidereal")
    DeciB_PER_KiloM = URIRef("http://qudt.org/vocab/unit/DeciB-PER-KiloM")
    MilliGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HA")
    OZ_M = URIRef("http://qudt.org/vocab/unit/OZ_M")
    M3_PER_HR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR")
    MicroBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-KiloGM")
    KiloCAL_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM-SEC-DEG_C")
    TEX = URIRef("http://qudt.org/vocab/unit/TEX")
    KiloCAL_IT_PER_HR_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-HR-M-DEG_C")
    DEG_F_HR_FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT-IN")
    PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/PER-KiloGM2")
    LB_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-DEG_F")
    KAT_PER_L = URIRef("http://qudt.org/vocab/unit/KAT-PER-L")
    SEC_PER_RAD_M3 = URIRef("http://qudt.org/vocab/unit/SEC-PER-RAD-M3")
    DEATHS_PER_1000000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000000I-YR")
    PicoC = URIRef("http://qudt.org/vocab/unit/PicoC")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    Hundredweight_US = URIRef("http://qudt.org/vocab/unit/Hundredweight_US")
    A_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM2")
    FT_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC2")
    CAL_IT_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM")
    CentiM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC-K")
    MilliKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MilliKAT-PER-L")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    MicroS = URIRef("http://qudt.org/vocab/unit/MicroS")
    W_PER_FT2 = URIRef("http://qudt.org/vocab/unit/W-PER-FT2")
    RAD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC2")
    PPB = URIRef("http://qudt.org/vocab/unit/PPB")
    PlanckPressure = URIRef("http://qudt.org/vocab/unit/PlanckPressure")
    YR_TROPICAL = URIRef("http://qudt.org/vocab/unit/YR_TROPICAL")
    KiloSEC = URIRef("http://qudt.org/vocab/unit/KiloSEC")
    CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-SEC")
    PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PER-M3-SEC")
    QT_US_DRY = URIRef("http://qudt.org/vocab/unit/QT_US_DRY")
    BAR_PER_K = URIRef("http://qudt.org/vocab/unit/BAR-PER-K")
    A_HR_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/A-HR-PER-KiloGM")
    BU_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-MIN")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    GAL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-DAY")
    L_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-MOL-SEC")
    MicroMOL_PER_MicroMOL_DAY = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MicroMOL-DAY")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    K_PER_M = URIRef("http://qudt.org/vocab/unit/K-PER-M")
    M2_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-V-SEC")
    FT3_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN")
    KiloMOL_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3-BAR")
    M_H2O = URIRef("http://qudt.org/vocab/unit/M_H2O")
    MOL_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-K")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    NanoGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-HR")
    TON_Register = URIRef("http://qudt.org/vocab/unit/TON_Register")
    MilliW_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-MilliGM")
    NanoMOL_PER_MicroGM_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroGM-HR")
    BTU_IT_PER_MOL_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB")
    V_Ab = URIRef("http://qudt.org/vocab/unit/V_Ab")
    DECADE = URIRef("http://qudt.org/vocab/unit/DECADE")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    PER_MILLE_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PSI")
    LB_MIN_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-YD3")
    TeraJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/TeraJ-PER-SEC")
    PlanckTime = URIRef("http://qudt.org/vocab/unit/PlanckTime")
    Debye = URIRef("http://qudt.org/vocab/unit/Debye")
    MicroN_M = URIRef("http://qudt.org/vocab/unit/MicroN-M")
    MilliM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC")
    MegaLB_F = URIRef("http://qudt.org/vocab/unit/MegaLB_F")
    RAD_R = URIRef("http://qudt.org/vocab/unit/RAD_R")
    BAR = URIRef("http://qudt.org/vocab/unit/BAR")
    CentiM3_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY-BAR")
    DeciS = URIRef("http://qudt.org/vocab/unit/DeciS")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    IN2 = URIRef("http://qudt.org/vocab/unit/IN2")
    Hundredweight_UK = URIRef("http://qudt.org/vocab/unit/Hundredweight_UK")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    KN_PER_SEC = URIRef("http://qudt.org/vocab/unit/KN-PER-SEC")
    KiloGM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3")
    YD3 = URIRef("http://qudt.org/vocab/unit/YD3")
    FemtoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-L")
    PA_SEC_PER_L = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-L")
    ERG_PER_CentiM = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM")
    J = URIRef("http://qudt.org/vocab/unit/J")
    B = URIRef("http://qudt.org/vocab/unit/B")
    DeciM3 = URIRef("http://qudt.org/vocab/unit/DeciM3")
    BIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BIT-PER-SEC")
    DeciTONNE = URIRef("http://qudt.org/vocab/unit/DeciTONNE")
    NUM_PER_SEC = URIRef("http://qudt.org/vocab/unit/NUM-PER-SEC")
    DecaC = URIRef("http://qudt.org/vocab/unit/DecaC")
    KiloHZ = URIRef("http://qudt.org/vocab/unit/KiloHZ")
    GM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY-BAR")
    MicroH = URIRef("http://qudt.org/vocab/unit/MicroH")
    PERM_US = URIRef("http://qudt.org/vocab/unit/PERM_US")
    PERCENT_PER_V = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-V")
    C_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-M2-PER-KiloGM")
    MOL_PER_M2_SEC_M = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-M")
    W_M2_PER_SR = URIRef("http://qudt.org/vocab/unit/W-M2-PER-SR")
    NUM_PER_YR = URIRef("http://qudt.org/vocab/unit/NUM-PER-YR")
    TONNE_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3-BAR")
    HP_Electric = URIRef("http://qudt.org/vocab/unit/HP_Electric")
    KiloGM_F = URIRef("http://qudt.org/vocab/unit/KiloGM_F")
    M3_PER_M3 = URIRef("http://qudt.org/vocab/unit/M3-PER-M3")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    GM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY-K")
    MegaPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-L-PER-SEC")
    A_PER_PA = URIRef("http://qudt.org/vocab/unit/A-PER-PA")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    MilliA_HR_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliA-HR-PER-GM")
    KiloJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    GigaBQ = URIRef("http://qudt.org/vocab/unit/GigaBQ")
    PK_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-SEC")
    PPT = URIRef("http://qudt.org/vocab/unit/PPT")
    LB_SEC_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK2")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    MilliKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MilliKAT-PER-L")
    M3_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-BAR")
    GM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY-K")
    C_PER_MOL = URIRef("http://qudt.org/vocab/unit/C-PER-MOL")
    LB_SEC_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-GAL_US")
    GigaPA_CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/GigaPA-CentiM3-PER-GM")
    L_PER_HR = URIRef("http://qudt.org/vocab/unit/L-PER-HR")
    NanoFARAD = URIRef("http://qudt.org/vocab/unit/NanoFARAD")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    LY = URIRef("http://qudt.org/vocab/unit/LY")
    YR_TROPICAL = URIRef("http://qudt.org/vocab/unit/YR_TROPICAL")
    GRAIN_PER_GAL = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL")
    BTU_IT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR-DEG_F")
    KiloM3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM3-PER-SEC2")
    H = URIRef("http://qudt.org/vocab/unit/H")
    MilliR = URIRef("http://qudt.org/vocab/unit/MilliR")
    M2_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-V-SEC")
    DEG_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG-PER-MIN")
    MOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3")
    L_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-K")
    K_PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PA-PER-SEC")
    MegaOHM = URIRef("http://qudt.org/vocab/unit/MegaOHM")
    DEG_C_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-SEC")
    W_M2_PER_SR = URIRef("http://qudt.org/vocab/unit/W-M2-PER-SR")
    V_PER_M2 = URIRef("http://qudt.org/vocab/unit/V-PER-M2")
    L_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-BAR")
    AC = URIRef("http://qudt.org/vocab/unit/AC")
    BARN_PER_EV = URIRef("http://qudt.org/vocab/unit/BARN-PER-EV")
    DeciM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-DAY")
    C_M2_PER_V = URIRef("http://qudt.org/vocab/unit/C-M2-PER-V")
    OZ_PER_GAL = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL")
    FRACTION = URIRef("http://qudt.org/vocab/unit/FRACTION")
    HectoPA = URIRef("http://qudt.org/vocab/unit/HectoPA")
    MilliBAR = URIRef("http://qudt.org/vocab/unit/MilliBAR")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    CAL_TH_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-K")
    PER_GigaEV2 = URIRef("http://qudt.org/vocab/unit/PER-GigaEV2")
    KiloN_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M2")
    KiloOHM = URIRef("http://qudt.org/vocab/unit/KiloOHM")
    TON_SHORT = URIRef("http://qudt.org/vocab/unit/TON_SHORT")
    PPTR_VOL = URIRef("http://qudt.org/vocab/unit/PPTR_VOL")
    BARN_PER_SR = URIRef("http://qudt.org/vocab/unit/BARN-PER-SR")
    GM_MilliM = URIRef("http://qudt.org/vocab/unit/GM-MilliM")
    CentiMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-KiloGM")
    ERG_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM-SEC")
    DEG_C_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-HR")
    BQ_PER_M2 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M2")
    BTU_IT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR-DEG_F")
    BBL_UK_PET = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET")
    L_PER_HR = URIRef("http://qudt.org/vocab/unit/L-PER-HR")
    HR_Sidereal = URIRef("http://qudt.org/vocab/unit/HR_Sidereal")
    PER_MILLE_PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PER-PSI")
    MicroGRAY = URIRef("http://qudt.org/vocab/unit/MicroGRAY")
    HP_H2O = URIRef("http://qudt.org/vocab/unit/HP_H2O")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    HP = URIRef("http://qudt.org/vocab/unit/HP")
    H = URIRef("http://qudt.org/vocab/unit/H")
    KiloGM_PER_HA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HA")
    MOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL-PER-MIN")
    N_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM2")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    M3_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-PA")
    V_Ab_SEC = URIRef("http://qudt.org/vocab/unit/V_Ab-SEC")
    FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-DEG_F")
    KibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M2")
    KiloCAL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-MIN")
    KiloS_PER_M = URIRef("http://qudt.org/vocab/unit/KiloS-PER-M")
    LB_PER_FT = URIRef("http://qudt.org/vocab/unit/LB-PER-FT")
    BTU_IT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC")
    PlanckCurrent = URIRef("http://qudt.org/vocab/unit/PlanckCurrent")
    PINT_UK = URIRef("http://qudt.org/vocab/unit/PINT_UK")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    H_PER_OHM = URIRef("http://qudt.org/vocab/unit/H-PER-OHM")
    FRAME_PER_SEC = URIRef("http://qudt.org/vocab/unit/FRAME-PER-SEC")
    FT_HR_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-GAL_US")
    MI_N_PER_HR = URIRef("http://qudt.org/vocab/unit/MI_N-PER-HR")
    FemtoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-KiloGM")
    CAL_MEAN = URIRef("http://qudt.org/vocab/unit/CAL_MEAN")
    LB_F_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-SEC")
    MilliL_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY")
    MilliMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-GM")
    GM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL")
    ExaJ = URIRef("http://qudt.org/vocab/unit/ExaJ")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    LB_F_FT = URIRef("http://qudt.org/vocab/unit/LB_F-FT")
    KiloGM_PER_MegaBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MegaBTU_IT")
    PlanckForce = URIRef("http://qudt.org/vocab/unit/PlanckForce")
    KiloGM_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM2")
    W_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M3")
    FT_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC2")
    KiloGM_PER_M2_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC2")
    MI2 = URIRef("http://qudt.org/vocab/unit/MI2")
    TON_Metric_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY-K")
    MicroL = URIRef("http://qudt.org/vocab/unit/MicroL")
    MegaBAR = URIRef("http://qudt.org/vocab/unit/MegaBAR")
    LB_MIN_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-FT3")
    Pennyweight = URIRef("http://qudt.org/vocab/unit/Pennyweight")
    KiloGM_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC2")
    N_CentiM = URIRef("http://qudt.org/vocab/unit/N-CentiM")
    A2_SEC = URIRef("http://qudt.org/vocab/unit/A2-SEC")
    TONNE_PER_DAY = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY")
    YR_Metrology = URIRef("http://qudt.org/vocab/unit/YR_Metrology")
    C_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Ab-PER-CentiM2")
    W_PER_M2_PA = URIRef("http://qudt.org/vocab/unit/W-PER-M2-PA")
    KiloGM_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-MilliM2")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    FemtoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-KiloGM")
    MilliSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-HR")
    MilliM_HG = URIRef("http://qudt.org/vocab/unit/MilliM_HG")
    AWG = URIRef("http://qudt.org/vocab/unit/AWG")
    MilliGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DeciL")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    W_PER_M_K = URIRef("http://qudt.org/vocab/unit/W-PER-M-K")
    M_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-K")
    W_PER_M2_PA = URIRef("http://qudt.org/vocab/unit/W-PER-M2-PA")
    OZ_PER_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD3")
    BTU_IT_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-HR-DEG_F")
    M6 = URIRef("http://qudt.org/vocab/unit/M6")
    MicroGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-GM")
    M2_K = URIRef("http://qudt.org/vocab/unit/M2-K")
    PHOT = URIRef("http://qudt.org/vocab/unit/PHOT")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    MegaW = URIRef("http://qudt.org/vocab/unit/MegaW")
    ERG_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM2-SEC")
    K_DAY = URIRef("http://qudt.org/vocab/unit/K-DAY")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    MOL_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-K")
    FT_LB_F = URIRef("http://qudt.org/vocab/unit/FT-LB_F")
    LM_SEC = URIRef("http://qudt.org/vocab/unit/LM-SEC")
    PERCENT_RH = URIRef("http://qudt.org/vocab/unit/PERCENT_RH")
    BARYE = URIRef("http://qudt.org/vocab/unit/BARYE")
    KiloGM_PER_L_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-K")
    KiloGM_PER_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA")
    FT_SEC_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-GAL_US")
    PT = URIRef("http://qudt.org/vocab/unit/PT")
    TeraBIT = URIRef("http://qudt.org/vocab/unit/TeraBIT")
    BTU_IT_IN_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-HR-FT2-DEG_F")
    MilliGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2")
    DYN_SEC_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM")
    CFU = URIRef("http://qudt.org/vocab/unit/CFU")
    MicroH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-KiloOHM")
    GM_PER_CentiM3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3-BAR")
    MilliGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-HR")
    NanoSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-SEC")
    PERMITTIVITY_REL = URIRef("http://qudt.org/vocab/unit/PERMITTIVITY_REL")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    PetaC = URIRef("http://qudt.org/vocab/unit/PetaC")
    IN_H2O_39dot2DEG_F = URIRef("http://qudt.org/vocab/unit/IN_H2O_39dot2DEG_F")
    PER_FT3 = URIRef("http://qudt.org/vocab/unit/PER-FT3")
    PER_T_SEC = URIRef("http://qudt.org/vocab/unit/PER-T-SEC")
    DEG_C_PER_BAR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-BAR")
    SLUG_PER_FT2 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT2")
    CentiM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC")
    PERCENT_MIN_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-L")
    PicoFARAD = URIRef("http://qudt.org/vocab/unit/PicoFARAD")
    EV_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/EV-M2-PER-KiloGM")
    KiloV = URIRef("http://qudt.org/vocab/unit/KiloV")
    PERCENT_PER_DecaCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaCount")
    KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A-HR")
    LB_SEC_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-FT3")
    CAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC")
    FemtoSEC = URIRef("http://qudt.org/vocab/unit/FemtoSEC")
    HectoGM = URIRef("http://qudt.org/vocab/unit/HectoGM")
    M2_K = URIRef("http://qudt.org/vocab/unit/M2-K")
    M3_PER_PA = URIRef("http://qudt.org/vocab/unit/M3-PER-PA")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    RAD_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-KiloGM")
    ERG_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM2-SEC")
    MilliL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-GM")
    FUR = URIRef("http://qudt.org/vocab/unit/FUR")
    CentiN_M = URIRef("http://qudt.org/vocab/unit/CentiN-M")
    SLUG_PER_FT2 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT2")
    KiloV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive-PER-K")
    WK = URIRef("http://qudt.org/vocab/unit/WK")
    FT3_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN")
    KiloGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-K")
    MI2 = URIRef("http://qudt.org/vocab/unit/MI2")
    PINT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-MIN")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    DEG_C_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-SEC")
    GM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloM")
    L_PER_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-BAR")
    KiloCAL = URIRef("http://qudt.org/vocab/unit/KiloCAL")
    FemtoM = URIRef("http://qudt.org/vocab/unit/FemtoM")
    N_M_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-RAD")
    MilliGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DeciL")
    KiloBAUD = URIRef("http://qudt.org/vocab/unit/KiloBAUD")
    M3_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-BAR")
    MegaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M2")
    TONNE_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN-BAR")
    CAL_IT = URIRef("http://qudt.org/vocab/unit/CAL_IT")
    MilliM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DAY")
    CARAT = URIRef("http://qudt.org/vocab/unit/CARAT")
    MegaW = URIRef("http://qudt.org/vocab/unit/MegaW")
    BBL_UK_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-SEC")
    MilliGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-BAR")
    PSI = URIRef("http://qudt.org/vocab/unit/PSI")
    KiloBTU_TH = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    NUM_PER_M2 = URIRef("http://qudt.org/vocab/unit/NUM-PER-M2")
    BEAT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BEAT-PER-MIN")
    PERCENT_MIN_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-CentiM3")
    DEG_F_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-HR")
    PER_MegaPA = URIRef("http://qudt.org/vocab/unit/PER-MegaPA")
    BQ_PER_L = URIRef("http://qudt.org/vocab/unit/BQ-PER-L")
    LB_PER_FT3 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3")
    C_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM")
    GM_PER_L = URIRef("http://qudt.org/vocab/unit/GM-PER-L")
    GM_HR_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L-CentiM3")
    PlanckCharge = URIRef("http://qudt.org/vocab/unit/PlanckCharge")
    PER_MOL = URIRef("http://qudt.org/vocab/unit/PER-MOL")
    MilliL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliL-PER-L")
    CentiM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY")
    ERG_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM2-SEC")
    TONNE_PER_MIN = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN")
    MilliBAR = URIRef("http://qudt.org/vocab/unit/MilliBAR")
    OZ_FT = URIRef("http://qudt.org/vocab/unit/OZ-FT")
    GAL_UK = URIRef("http://qudt.org/vocab/unit/GAL_UK")
    GM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciL")
    GM_PER_HZ = URIRef("http://qudt.org/vocab/unit/GM-PER-HZ")
    PlanckFrequency_Ang = URIRef("http://qudt.org/vocab/unit/PlanckFrequency_Ang")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    S = URIRef("http://qudt.org/vocab/unit/S")
    LB_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_US")
    EV_PER_M = URIRef("http://qudt.org/vocab/unit/EV-PER-M")
    PA2_SEC = URIRef("http://qudt.org/vocab/unit/PA2-SEC")
    PetaBQ = URIRef("http://qudt.org/vocab/unit/PetaBQ")
    K2 = URIRef("http://qudt.org/vocab/unit/K2")
    KiloN_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M3")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    WK = URIRef("http://qudt.org/vocab/unit/WK")
    GigaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-HR")
    A_PER_A_HR = URIRef("http://qudt.org/vocab/unit/A-PER-A-HR")
    SUSCEPTIBILITY_MAG = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_MAG")
    TON_FG_HR = URIRef("http://qudt.org/vocab/unit/TON_FG-HR")
    CentiM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN")
    KiloA_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M2")
    MegaPA = URIRef("http://qudt.org/vocab/unit/MegaPA")
    HP = URIRef("http://qudt.org/vocab/unit/HP")
    LB_MIN_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-FT3")
    PPB = URIRef("http://qudt.org/vocab/unit/PPB")
    NanoM = URIRef("http://qudt.org/vocab/unit/NanoM")
    GigaW_HR = URIRef("http://qudt.org/vocab/unit/GigaW-HR")
    KiloCAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-GM-K")
    FR = URIRef("http://qudt.org/vocab/unit/FR")
    BTU_MEAN = URIRef("http://qudt.org/vocab/unit/BTU_MEAN")
    C_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM3")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    BTU_TH_FT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-HR-FT2-DEG_F")
    MilliFARAD = URIRef("http://qudt.org/vocab/unit/MilliFARAD")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    PicoH = URIRef("http://qudt.org/vocab/unit/PicoH")
    BTU_TH_FT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-HR-FT2-DEG_F")
    PlanckCurrentDensity = URIRef("http://qudt.org/vocab/unit/PlanckCurrentDensity")
    KiloGM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-BAR")
    KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-SEC2")
    TeraHZ = URIRef("http://qudt.org/vocab/unit/TeraHZ")
    PER_BAR = URIRef("http://qudt.org/vocab/unit/PER-BAR")
    MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/MOL_LB-DEG_F")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    BTU_IT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_F")
    L_PER_DAY = URIRef("http://qudt.org/vocab/unit/L-PER-DAY")
    MilliBAR_PER_K = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-K")
    NanoT = URIRef("http://qudt.org/vocab/unit/NanoT")
    MicroIN = URIRef("http://qudt.org/vocab/unit/MicroIN")
    Flight = URIRef("http://qudt.org/vocab/unit/Flight")
    TebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M")
    KiloGM_PER_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA")
    GigaBQ = URIRef("http://qudt.org/vocab/unit/GigaBQ")
    MilliN_PER_M = URIRef("http://qudt.org/vocab/unit/MilliN-PER-M")
    K_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PER-SEC")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    LB = URIRef("http://qudt.org/vocab/unit/LB")
    MOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3")
    LB_MOL = URIRef("http://qudt.org/vocab/unit/LB-MOL")
    KiloPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-BAR")
    MicroMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-SEC")
    NanoFARAD = URIRef("http://qudt.org/vocab/unit/NanoFARAD")
    GM_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM2")
    MicroSV = URIRef("http://qudt.org/vocab/unit/MicroSV")
    K_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/K-PER-SEC2")
    DEGREE_API = URIRef("http://qudt.org/vocab/unit/DEGREE_API")
    MicroTORR = URIRef("http://qudt.org/vocab/unit/MicroTORR")
    MegaV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive-HR")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    KiloCAL_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM")
    GRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/GRAY-PER-MIN")
    LB_HR_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-IN3")
    IU_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliGM")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    MilliARCSEC = URIRef("http://qudt.org/vocab/unit/MilliARCSEC")
    PlanckMass = URIRef("http://qudt.org/vocab/unit/PlanckMass")
    KiloMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-SEC")
    MicroS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MicroS-PER-CentiM")
    CentiM_HG = URIRef("http://qudt.org/vocab/unit/CentiM_HG")
    M3_PER_DAY = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY")
    MicroIN = URIRef("http://qudt.org/vocab/unit/MicroIN")
    N_M2_PER_A = URIRef("http://qudt.org/vocab/unit/N-M2-PER-A")
    KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloMOL")
    PERCENT_HR_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-CentiM3")
    OZ_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN3")
    LB_MIN_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-YD3")
    OZ_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ-PER-HR")
    CAL_IT = URIRef("http://qudt.org/vocab/unit/CAL_IT")
    KiloBD = URIRef("http://qudt.org/vocab/unit/KiloBD")
    M3_PER_KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM-SEC2")
    DeciM3_PER_HR = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-HR")
    GigaJ = URIRef("http://qudt.org/vocab/unit/GigaJ")
    PERCENT_MIN_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-FT3")
    FT3_PER_HR = URIRef("http://qudt.org/vocab/unit/FT3-PER-HR")
    BAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/BAR-PER-BAR")
    PebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M2")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    MI_PER_HR = URIRef("http://qudt.org/vocab/unit/MI-PER-HR")
    TON_Metric_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC-K")
    MicroGM_PER_IN2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-IN2")
    S_Ab = URIRef("http://qudt.org/vocab/unit/S_Ab")
    NanoGM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MicroL")
    SEC_PER_M = URIRef("http://qudt.org/vocab/unit/SEC-PER-M")
    OZ_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_UK")
    MIL = URIRef("http://qudt.org/vocab/unit/MIL")
    MegaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M3")
    GM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloGM")
    PSI_PER_PSI = URIRef("http://qudt.org/vocab/unit/PSI-PER-PSI")
    GM_PER_M3 = URIRef("http://qudt.org/vocab/unit/GM-PER-M3")
    KiloMOL_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3-BAR")
    KiloN_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M2")
    MI_PER_SEC = URIRef("http://qudt.org/vocab/unit/MI-PER-SEC")
    KiloGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-BAR")
    MilliGM_HR_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L-M3")
    M3_PER_HA = URIRef("http://qudt.org/vocab/unit/M3-PER-HA")
    PER_M2 = URIRef("http://qudt.org/vocab/unit/PER-M2")
    FT3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT3-PER-DEG_F")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    BTU_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-MIN")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    BTU_IT_PER_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL-DEG_F")
    K_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-M-PER-SEC")
    R_man = URIRef("http://qudt.org/vocab/unit/R_man")
    DEG_C2_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C2-PER-SEC")
    KiloGM_PER_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-K")
    K_PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PA-PER-SEC")
    LB_PER_HR_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-HR-PSI")
    MegaC = URIRef("http://qudt.org/vocab/unit/MegaC")
    RAD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC2")
    T_SEC = URIRef("http://qudt.org/vocab/unit/T-SEC")
    FT_LA = URIRef("http://qudt.org/vocab/unit/FT-LA")
    MOL_PER_KiloGM_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-BAR")
    M4_PER_SEC = URIRef("http://qudt.org/vocab/unit/M4-PER-SEC")
    BTU_TH_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-HR-DEG_F")
    FemtoSEC = URIRef("http://qudt.org/vocab/unit/FemtoSEC")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    MI_N = URIRef("http://qudt.org/vocab/unit/MI_N")
    DecaPA = URIRef("http://qudt.org/vocab/unit/DecaPA")
    LB_PER_FT_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-HR")
    LB_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-DEG_F")
    CentiPOISE = URIRef("http://qudt.org/vocab/unit/CentiPOISE")
    DEG_R_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-MIN")
    FT_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC-PSI")
    M3_PER_DAY = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY")
    KiloGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN")
    CentiST = URIRef("http://qudt.org/vocab/unit/CentiST")
    NanoGM = URIRef("http://qudt.org/vocab/unit/NanoGM")
    DeciBAR = URIRef("http://qudt.org/vocab/unit/DeciBAR")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    PPTR = URIRef("http://qudt.org/vocab/unit/PPTR")
    OZ_VOL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-SEC")
    KiloA_HR = URIRef("http://qudt.org/vocab/unit/KiloA-HR")
    PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PER-CentiM3")
    GigaJ = URIRef("http://qudt.org/vocab/unit/GigaJ")
    MegaA = URIRef("http://qudt.org/vocab/unit/MegaA")
    BTU_IT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_F")
    MilliGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-K")
    MilliM_PER_DEG_C_M = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DEG_C-M")
    KibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    M2_PER_SR_J = URIRef("http://qudt.org/vocab/unit/M2-PER-SR-J")
    SV_PER_SEC = URIRef("http://qudt.org/vocab/unit/SV-PER-SEC")
    A_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-PER-CentiM2")
    GRAIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-M3")
    PINT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-HR")
    PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2")
    TONNE_PER_M3_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3-K")
    KiloBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT")
    MicroPOISE = URIRef("http://qudt.org/vocab/unit/MicroPOISE")
    FARAD_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/FARAD_Ab-PER-CentiM")
    M3_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-BAR")
    CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-GM")
    MegaPSI = URIRef("http://qudt.org/vocab/unit/MegaPSI")
    MOL_PER_KiloGM_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-PA")
    LB_F_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-FT2")
    MilliOHM = URIRef("http://qudt.org/vocab/unit/MilliOHM")
    NanoL = URIRef("http://qudt.org/vocab/unit/NanoL")
    LB_MIN_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT6")
    MegaPA_M0pt5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0pt5")
    MilliGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-K")
    MilliH = URIRef("http://qudt.org/vocab/unit/MilliH")
    KiloGM_PER_M_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-MIN")
    PER_MILLE_PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PER-PSI")
    HectoPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-M3-PER-SEC")
    HectoPA_PER_K = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-K")
    BTU_IT_PER_LB_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F")
    PT_BIG = URIRef("http://qudt.org/vocab/unit/PT_BIG")
    MegaGRAY = URIRef("http://qudt.org/vocab/unit/MegaGRAY")
    V_PER_MicroSEC = URIRef("http://qudt.org/vocab/unit/V-PER-MicroSEC")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    NUM_PER_HA = URIRef("http://qudt.org/vocab/unit/NUM-PER-HA")
    DYN_SEC_PER_CentiM5 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM5")
    KiloTONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloTONNE-PER-YR")
    MicroTORR = URIRef("http://qudt.org/vocab/unit/MicroTORR")
    FT3 = URIRef("http://qudt.org/vocab/unit/FT3")
    MegaV_PER_M = URIRef("http://qudt.org/vocab/unit/MegaV-PER-M")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    A_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Stat-PER-CentiM2")
    MicroFARAD = URIRef("http://qudt.org/vocab/unit/MicroFARAD")
    YR_Sidereal = URIRef("http://qudt.org/vocab/unit/YR_Sidereal")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    NanoGM_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2-DAY")
    BTU_39DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_39DEG_F")
    LB_MIN_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-GAL_US")
    PA_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC")
    PSI_PER_PSI = URIRef("http://qudt.org/vocab/unit/PSI-PER-PSI")
    TeraV_A = URIRef("http://qudt.org/vocab/unit/TeraV-A")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    Flight = URIRef("http://qudt.org/vocab/unit/Flight")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    KiloMOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-MIN")
    MicroMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2")
    PA_PER_MIN = URIRef("http://qudt.org/vocab/unit/PA-PER-MIN")
    M_PER_RAD = URIRef("http://qudt.org/vocab/unit/M-PER-RAD")
    PER_HR = URIRef("http://qudt.org/vocab/unit/PER-HR")
    GM_PER_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-BAR")
    MIN = URIRef("http://qudt.org/vocab/unit/MIN")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    NanoBQ_PER_L = URIRef("http://qudt.org/vocab/unit/NanoBQ-PER-L")
    MicroN = URIRef("http://qudt.org/vocab/unit/MicroN")
    H_PER_M = URIRef("http://qudt.org/vocab/unit/H-PER-M")
    GM_PER_L_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-L-MilliPA-SEC")
    N_M2_PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/N-M2-PER-KiloGM2")
    POISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/POISE-PER-BAR")
    SUSCEPTIBILITY_ELEC = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_ELEC")
    PINT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-HR")
    GRAIN = URIRef("http://qudt.org/vocab/unit/GRAIN")
    BTU_TH_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-HR-DEG_F")
    PER_SEC_M3 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M3")
    MilliA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/MilliA-PER-MilliM")
    GigaPA = URIRef("http://qudt.org/vocab/unit/GigaPA")
    LB_HR_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-GAL_UK")
    M_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-K")
    MilliGM_MIN_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M6")
    S_Ab = URIRef("http://qudt.org/vocab/unit/S_Ab")
    GI_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-MIN")
    LB_FT2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-IN3-LB_F-SEC")
    MilliGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-MIN")
    MilliL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-MIN")
    PER_HR = URIRef("http://qudt.org/vocab/unit/PER-HR")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    KiloN_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M3")
    QT_UK = URIRef("http://qudt.org/vocab/unit/QT_UK")
    Gs = URIRef("http://qudt.org/vocab/unit/Gs")
    RichterMagnitude = URIRef("http://qudt.org/vocab/unit/RichterMagnitude")
    V_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-PER-CentiM")
    POISE = URIRef("http://qudt.org/vocab/unit/POISE")
    DEGREE_BAUME_US_LIGHT = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_LIGHT")
    PSI_IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-IN3-PER-SEC")
    MilliR_man = URIRef("http://qudt.org/vocab/unit/MilliR_man")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    PicoMOL_PER_M_W_SEC = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M-W-SEC")
    DAY_Sidereal = URIRef("http://qudt.org/vocab/unit/DAY_Sidereal")
    TON_Metric_PER_HA = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HA")
    MicroN = URIRef("http://qudt.org/vocab/unit/MicroN")
    IN = URIRef("http://qudt.org/vocab/unit/IN")
    MegaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBYTE-PER-SEC")
    KiloMOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-MIN")
    PER_DAY = URIRef("http://qudt.org/vocab/unit/PER-DAY")
    DEG_F_HR_FT2_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH")
    MI_N_PER_HR = URIRef("http://qudt.org/vocab/unit/MI_N-PER-HR")
    ARCSEC = URIRef("http://qudt.org/vocab/unit/ARCSEC")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    KiloV_A_Reactive = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive")
    GigaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/GigaC-PER-M3")
    PER_MILLE_PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PER-PSI")
    MicroBAR = URIRef("http://qudt.org/vocab/unit/MicroBAR")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    POISE_PER_K = URIRef("http://qudt.org/vocab/unit/POISE-PER-K")
    LB_SEC_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-YD3")
    KiloLB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-FT")
    TON_LONG_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_LONG-PER-YD3")
    MilliM_HG = URIRef("http://qudt.org/vocab/unit/MilliM_HG")
    W_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-SEC-PER-M2")
    PERCENT_SEC_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-YD3")
    FC = URIRef("http://qudt.org/vocab/unit/FC")
    KiloV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive-PER-K")
    CentiN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/CentiN-M-PER-M2")
    GM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloGM")
    MilliMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-GM")
    QT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_US-PER-HR")
    PER_DEG_C = URIRef("http://qudt.org/vocab/unit/PER-DEG_C")
    HectoPA_PER_HR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-HR")
    CentiM3_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-BAR")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    GM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2")
    GALILEO = URIRef("http://qudt.org/vocab/unit/GALILEO")
    PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/PER-KiloGM-SEC")
    DEGREE_PLATO = URIRef("http://qudt.org/vocab/unit/DEGREE_PLATO")
    KiloL = URIRef("http://qudt.org/vocab/unit/KiloL")
    N_CentiM = URIRef("http://qudt.org/vocab/unit/N-CentiM")
    PDL_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-FT2")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    GM_PER_CentiM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM-BAR")
    MegaDOLLAR_US_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MegaDOLLAR_US-PER-FLIGHT")
    GigaPA = URIRef("http://qudt.org/vocab/unit/GigaPA")
    BTU_IT_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT-PER-FT2-HR-DEG_F")
    KiloN_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M2")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    KiloJ_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MIN")
    MicroGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-MIN")
    MilliGM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M")
    PER_SEC_SR_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR-M2")
    KiloFARAD = URIRef("http://qudt.org/vocab/unit/KiloFARAD")
    KiloGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-PA-SEC")
    DecaL = URIRef("http://qudt.org/vocab/unit/DecaL")
    RT = URIRef("http://qudt.org/vocab/unit/RT")
    PINT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-SEC")
    C_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Ab-PER-CentiM2")
    DEGREE_BAUME_US_LIGHT = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_LIGHT")
    CentiBAR = URIRef("http://qudt.org/vocab/unit/CentiBAR")
    DecaPA = URIRef("http://qudt.org/vocab/unit/DecaPA")
    LB_FT2 = URIRef("http://qudt.org/vocab/unit/LB-FT2")
    LB_PER_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-PSI")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    MI_PER_SEC = URIRef("http://qudt.org/vocab/unit/MI-PER-SEC")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    MegaPA_M0dot5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0dot5")
    OHM_M2_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-M2-PER-M")
    KiloGM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3")
    MESH = URIRef("http://qudt.org/vocab/unit/MESH")
    BTU_IT_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT-PER-FT2-HR-DEG_F")
    BTU_TH_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_R")
    V_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V-PER-CentiM")
    GM_PER_M3 = URIRef("http://qudt.org/vocab/unit/GM-PER-M3")
    SHANNON_PER_SEC = URIRef("http://qudt.org/vocab/unit/SHANNON-PER-SEC")
    PicoL = URIRef("http://qudt.org/vocab/unit/PicoL")
    T = URIRef("http://qudt.org/vocab/unit/T")
    MOL_PER_GM_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-GM-HR")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    PlanckEnergy = URIRef("http://qudt.org/vocab/unit/PlanckEnergy")
    CentiM6 = URIRef("http://qudt.org/vocab/unit/CentiM6")
    TON_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_US-PER-DAY")
    LB_MIN_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT6")
    KiloTON_Metric = URIRef("http://qudt.org/vocab/unit/KiloTON_Metric")
    OCTET = URIRef("http://qudt.org/vocab/unit/OCTET")
    AttoFARAD = URIRef("http://qudt.org/vocab/unit/AttoFARAD")
    M2_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-HZ2")
    LA = URIRef("http://qudt.org/vocab/unit/LA")
    MOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-DAY")
    EV = URIRef("http://qudt.org/vocab/unit/EV")
    MilliL_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY")
    FemtoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-KiloGM")
    LB_FT2 = URIRef("http://qudt.org/vocab/unit/LB-FT2")
    ExaJ = URIRef("http://qudt.org/vocab/unit/ExaJ")
    MilliGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-K")
    MI_N_PER_HR = URIRef("http://qudt.org/vocab/unit/MI_N-PER-HR")
    DEG_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC")
    PER_MILLE_PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PER-PSI")
    GAL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-MIN")
    LB_PER_LB = URIRef("http://qudt.org/vocab/unit/LB-PER-LB")
    KiloGM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-FT2")
    PER_DAY = URIRef("http://qudt.org/vocab/unit/PER-DAY")
    TeraOHM = URIRef("http://qudt.org/vocab/unit/TeraOHM")
    MilliL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliL-PER-L")
    BU_UK = URIRef("http://qudt.org/vocab/unit/BU_UK")
    ATM_PER_M = URIRef("http://qudt.org/vocab/unit/ATM-PER-M")
    PER_KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/PER-KiloV-A-HR")
    KiloCAL_Mean = URIRef("http://qudt.org/vocab/unit/KiloCAL_Mean")
    MilliN_M = URIRef("http://qudt.org/vocab/unit/MilliN-M")
    H_PER_M = URIRef("http://qudt.org/vocab/unit/H-PER-M")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    LB_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-DEG_F")
    MilliV_A = URIRef("http://qudt.org/vocab/unit/MilliV-A")
    HZ_M = URIRef("http://qudt.org/vocab/unit/HZ-M")
    PERCENT_PER_OHM = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-OHM")
    A_MIN = URIRef("http://qudt.org/vocab/unit/A-MIN")
    PA_PER_HR = URIRef("http://qudt.org/vocab/unit/PA-PER-HR")
    MegaPSI = URIRef("http://qudt.org/vocab/unit/MegaPSI")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    MIL_Circ = URIRef("http://qudt.org/vocab/unit/MIL_Circ")
    LB_PER_YD = URIRef("http://qudt.org/vocab/unit/LB-PER-YD")
    N_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M3")
    BTU_TH_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT3")
    PERCENT_PER_CentiPOISE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-CentiPOISE")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    TeraA = URIRef("http://qudt.org/vocab/unit/TeraA")
    MilliM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC2")
    DYN_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-CentiM")
    KiloJ_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM-K")
    DYN = URIRef("http://qudt.org/vocab/unit/DYN")
    T_SEC = URIRef("http://qudt.org/vocab/unit/T-SEC")
    J_PER_SEC = URIRef("http://qudt.org/vocab/unit/J-PER-SEC")
    MilliBQ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-GM")
    GM_PER_M3 = URIRef("http://qudt.org/vocab/unit/GM-PER-M3")
    MicroA = URIRef("http://qudt.org/vocab/unit/MicroA")
    PER_IN3 = URIRef("http://qudt.org/vocab/unit/PER-IN3")
    A_SEC2 = URIRef("http://qudt.org/vocab/unit/A-SEC2")
    GM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM")
    GM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL")
    NanoMOL_PER_MicroGM_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroGM-HR")
    ST = URIRef("http://qudt.org/vocab/unit/ST")
    PER_MegaK = URIRef("http://qudt.org/vocab/unit/PER-MegaK")
    NUM_PER_NanoL = URIRef("http://qudt.org/vocab/unit/NUM-PER-NanoL")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    KiloS = URIRef("http://qudt.org/vocab/unit/KiloS")
    PlanckFrequency_Ang = URIRef("http://qudt.org/vocab/unit/PlanckFrequency_Ang")
    J_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-GM-DEG_C")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    M3_PER_KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM-SEC2")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    PER_MilliSEC = URIRef("http://qudt.org/vocab/unit/PER-MilliSEC")
    C_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM2")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    UnitPole = URIRef("http://qudt.org/vocab/unit/UnitPole")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    MicroOHM = URIRef("http://qudt.org/vocab/unit/MicroOHM")
    FT2_PER_HR = URIRef("http://qudt.org/vocab/unit/FT2-PER-HR")
    GI_US = URIRef("http://qudt.org/vocab/unit/GI_US")
    YD_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD-PER-DEG_F")
    KiloV_A = URIRef("http://qudt.org/vocab/unit/KiloV-A")
    MOL_PER_KiloGM_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-BAR")
    YoctoC = URIRef("http://qudt.org/vocab/unit/YoctoC")
    PINT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-SEC")
    BTU_TH_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-HR-DEG_F")
    PlanckCharge = URIRef("http://qudt.org/vocab/unit/PlanckCharge")
    KiloGM_PER_M_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-DAY")
    CD_PER_M2 = URIRef("http://qudt.org/vocab/unit/CD-PER-M2")
    GigaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/GigaC-PER-M3")
    PlanckMass = URIRef("http://qudt.org/vocab/unit/PlanckMass")
    TeraHZ = URIRef("http://qudt.org/vocab/unit/TeraHZ")
    KiloMOL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-HR")
    MicroW = URIRef("http://qudt.org/vocab/unit/MicroW")
    ATM_T = URIRef("http://qudt.org/vocab/unit/ATM_T")
    FT_US = URIRef("http://qudt.org/vocab/unit/FT_US")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    TONNE_PER_HA_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA-YR")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    K_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-M-PER-SEC")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    LB_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT2")
    DEG_F_PER_BAR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-BAR")
    NanoGM_PER_L = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-L")
    SPF = URIRef("http://qudt.org/vocab/unit/SPF")
    HP_Boiler = URIRef("http://qudt.org/vocab/unit/HP_Boiler")
    KiloGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-K")
    PicoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-KiloGM")
    LB_F_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-SEC")
    IN4 = URIRef("http://qudt.org/vocab/unit/IN4")
    MegaBIT = URIRef("http://qudt.org/vocab/unit/MegaBIT")
    MilliMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-KiloGM")
    PER_MilliL = URIRef("http://qudt.org/vocab/unit/PER-MilliL")
    MicroM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroM-PER-SEC")
    BARN_PER_SR_EV = URIRef("http://qudt.org/vocab/unit/BARN-PER-SR-EV")
    KiloM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC-BAR")
    MOL_K = URIRef("http://qudt.org/vocab/unit/MOL-K")
    KiloW = URIRef("http://qudt.org/vocab/unit/KiloW")
    QUAD = URIRef("http://qudt.org/vocab/unit/QUAD")
    MicroGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    MilliM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DAY")
    GM_PER_M3 = URIRef("http://qudt.org/vocab/unit/GM-PER-M3")
    BTU_IT_PER_SEC_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2")
    FT = URIRef("http://qudt.org/vocab/unit/FT")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    LB_MIN_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-YD3")
    M2_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-PA")
    ERG_PER_CentiM = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM")
    KiloCAL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-SEC")
    CAL_IT_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM2-K")
    PER_PA_SEC = URIRef("http://qudt.org/vocab/unit/PER-PA-SEC")
    PlanckPressure = URIRef("http://qudt.org/vocab/unit/PlanckPressure")
    Debye = URIRef("http://qudt.org/vocab/unit/Debye")
    BTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR")
    N_M_PER_MIN_Angle = URIRef("http://qudt.org/vocab/unit/N-M-PER-MIN_Angle")
    PERCENT_MIN_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-FT3")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    PPQ = URIRef("http://qudt.org/vocab/unit/PPQ")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    KiloBTU_TH = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH")
    FemtoM = URIRef("http://qudt.org/vocab/unit/FemtoM")
    OZ_TROY = URIRef("http://qudt.org/vocab/unit/OZ_TROY")
    MegaJ = URIRef("http://qudt.org/vocab/unit/MegaJ")
    KiloHZ = URIRef("http://qudt.org/vocab/unit/KiloHZ")
    MicroFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-M")
    PERCENT_PER_K = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-K")
    BBL_US = URIRef("http://qudt.org/vocab/unit/BBL_US")
    GM_SEC_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M6")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    J_PER_M3_K = URIRef("http://qudt.org/vocab/unit/J-PER-M3-K")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    MilliR_man = URIRef("http://qudt.org/vocab/unit/MilliR_man")
    MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/MOL-DEG_C")
    GM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC-BAR")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    GM_PER_GM = URIRef("http://qudt.org/vocab/unit/GM-PER-GM")
    J_PER_M = URIRef("http://qudt.org/vocab/unit/J-PER-M")
    W_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-PER-KiloGM")
    KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloGM-K")
    ST_PER_PA = URIRef("http://qudt.org/vocab/unit/ST-PER-PA")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    KiloGM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-BAR")
    KAT_PER_M3 = URIRef("http://qudt.org/vocab/unit/KAT-PER-M3")
    GALILEO = URIRef("http://qudt.org/vocab/unit/GALILEO")
    BTU_TH_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    ERLANG = URIRef("http://qudt.org/vocab/unit/ERLANG")
    KiloCAL_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-HR")
    M2_PER_HZ_DEG = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ-DEG")
    PK_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-MIN")
    MegaOHM_PER_K = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-K")
    KIP_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KIP_F-PER-IN2")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    GM_PER_GM = URIRef("http://qudt.org/vocab/unit/GM-PER-GM")
    MicroOHM_M = URIRef("http://qudt.org/vocab/unit/MicroOHM-M")
    N_CentiM = URIRef("http://qudt.org/vocab/unit/N-CentiM")
    HP = URIRef("http://qudt.org/vocab/unit/HP")
    V = URIRef("http://qudt.org/vocab/unit/V")
    MicroMOL_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM-SEC")
    TON_LONG = URIRef("http://qudt.org/vocab/unit/TON_LONG")
    GM_Carbon_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Carbon-PER-M2-DAY")
    OZ_PER_GAL = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL")
    KiloGM_PER_MegaBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MegaBTU_IT")
    BTU_TH_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC-FT2-DEG_F")
    CAL_TH_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM-SEC-DEG_C")
    PER_GM = URIRef("http://qudt.org/vocab/unit/PER-GM")
    PlanckCharge = URIRef("http://qudt.org/vocab/unit/PlanckCharge")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    MicroM = URIRef("http://qudt.org/vocab/unit/MicroM")
    PetaC = URIRef("http://qudt.org/vocab/unit/PetaC")
    CAL_TH_PER_G = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-G")
    KiloM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC")
    FemtoA = URIRef("http://qudt.org/vocab/unit/FemtoA")
    GM_PER_HZ = URIRef("http://qudt.org/vocab/unit/GM-PER-HZ")
    KiloPA = URIRef("http://qudt.org/vocab/unit/KiloPA")
    HectoGM = URIRef("http://qudt.org/vocab/unit/HectoGM")
    PINT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-DAY")
    BBL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-DAY")
    SLUG_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT-SEC")
    MicroM2 = URIRef("http://qudt.org/vocab/unit/MicroM2")
    LUX_SEC = URIRef("http://qudt.org/vocab/unit/LUX-SEC")
    PicoPA_PER_KiloM = URIRef("http://qudt.org/vocab/unit/PicoPA-PER-KiloM")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    KiloPA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-MilliM")
    H_Ab = URIRef("http://qudt.org/vocab/unit/H_Ab")
    TeraFLOPS = URIRef("http://qudt.org/vocab/unit/TeraFLOPS")
    M2_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/M2-SEC-PER-RAD")
    MIL = URIRef("http://qudt.org/vocab/unit/MIL")
    PicoGM_PER_GM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-GM")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    LB_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-DEG_F")
    PSI_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-M3-PER-SEC")
    PicoGM = URIRef("http://qudt.org/vocab/unit/PicoGM")
    KiloGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM2")
    TON_UK = URIRef("http://qudt.org/vocab/unit/TON_UK")
    M_K = URIRef("http://qudt.org/vocab/unit/M-K")
    TONNE_PER_HR_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR-K")
    KiloC_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M2")
    GigaBIT_PER_M = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-M")
    RHE = URIRef("http://qudt.org/vocab/unit/RHE")
    V_Stat = URIRef("http://qudt.org/vocab/unit/V_Stat")
    BTU_IT_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-SEC-DEG_F")
    M2_SR = URIRef("http://qudt.org/vocab/unit/M2-SR")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    MegaPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-BAR")
    W_PER_GM = URIRef("http://qudt.org/vocab/unit/W-PER-GM")
    FT_LB_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-MIN")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    KiloLB_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloLB-PER-HR")
    ST_PER_BAR = URIRef("http://qudt.org/vocab/unit/ST-PER-BAR")
    TebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M3")
    GM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciL")
    BFT = URIRef("http://qudt.org/vocab/unit/BFT")
    WB_M = URIRef("http://qudt.org/vocab/unit/WB-M")
    HP_H2O = URIRef("http://qudt.org/vocab/unit/HP_H2O")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    MicroMOL = URIRef("http://qudt.org/vocab/unit/MicroMOL")
    M3_PER_HA = URIRef("http://qudt.org/vocab/unit/M3-PER-HA")
    TON_SHIPPING_US = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_US")
    MO_Synodic = URIRef("http://qudt.org/vocab/unit/MO_Synodic")
    MilliL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC")
    J_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-M2-PER-KiloGM")
    MilliM_PER_YR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-YR")
    GM_MIN_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M3-L")
    HectoGM = URIRef("http://qudt.org/vocab/unit/HectoGM")
    MilliMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-KiloGM")
    DeciS = URIRef("http://qudt.org/vocab/unit/DeciS")
    BTU_IT_PER_LB_F_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_R")
    LB_MIN_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK2")
    LB_M = URIRef("http://qudt.org/vocab/unit/LB_M")
    PER_H = URIRef("http://qudt.org/vocab/unit/PER-H")
    CentiM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    MicroIN = URIRef("http://qudt.org/vocab/unit/MicroIN")
    M3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-BAR")
    DeciB_M = URIRef("http://qudt.org/vocab/unit/DeciB_M")
    MilliA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliA-PER-BAR")
    GM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3")
    MegaHZ = URIRef("http://qudt.org/vocab/unit/MegaHZ")
    MicroL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroL-PER-L")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    GM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3-BAR")
    MegaW = URIRef("http://qudt.org/vocab/unit/MegaW")
    KiloOHM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-M")
    TON_Metric_PER_HA = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HA")
    PERCENT_SEC_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-FT3")
    A_Ab = URIRef("http://qudt.org/vocab/unit/A_Ab")
    A_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM2")
    PERCENT_PER_MilliM = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MilliM")
    LB_SEC_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-IN3")
    IN3_PER_LB = URIRef("http://qudt.org/vocab/unit/IN3-PER-LB")
    BBL_UK_PET_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-MIN")
    MilliGM_HR_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L-CentiM3")
    GigaV = URIRef("http://qudt.org/vocab/unit/GigaV")
    S = URIRef("http://qudt.org/vocab/unit/S")
    NanoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MilliL")
    MilliA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliA-PER-BAR")
    OCTET_PER_SEC = URIRef("http://qudt.org/vocab/unit/OCTET-PER-SEC")
    MicroV_PER_M = URIRef("http://qudt.org/vocab/unit/MicroV-PER-M")
    J_PER_KiloGM_K_PA = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-PA")
    KiloGM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR")
    PER_MicroMOL_L = URIRef("http://qudt.org/vocab/unit/PER-MicroMOL-L")
    T = URIRef("http://qudt.org/vocab/unit/T")
    OERSTED = URIRef("http://qudt.org/vocab/unit/OERSTED")
    NanoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L")
    NanoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-KiloGM")
    H_Stat = URIRef("http://qudt.org/vocab/unit/H_Stat")
    MilliBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-KiloGM")
    KiloTONNE = URIRef("http://qudt.org/vocab/unit/KiloTONNE")
    MilliM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM2-PER-SEC")
    M3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC2")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    MOL_PER_L_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-L-K")
    GM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/GM-PER-HR-K")
    J_PER_KiloGM_K_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-M3")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    PERCENT_PER_DecaCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaCount")
    K_PER_T = URIRef("http://qudt.org/vocab/unit/K-PER-T")
    PetaV_A = URIRef("http://qudt.org/vocab/unit/PetaV-A")
    MicroMOL = URIRef("http://qudt.org/vocab/unit/MicroMOL")
    OHM_M2_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-M2-PER-M")
    MilliM3_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-GM")
    PINT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-DAY")
    CentiGM = URIRef("http://qudt.org/vocab/unit/CentiGM")
    MilliL_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-K")
    M_PER_PA = URIRef("http://qudt.org/vocab/unit/M-PER-PA")
    KiloGM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC2")
    MicroGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-SEC")
    SPF = URIRef("http://qudt.org/vocab/unit/SPF")
    LB_F_FT = URIRef("http://qudt.org/vocab/unit/LB_F-FT")
    KiloPA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-MilliM")
    MicroH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-OHM")
    KiloPA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-K")
    BTU_IT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MIN")
    CAL_TH_PER_G = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-G")
    FemtoL = URIRef("http://qudt.org/vocab/unit/FemtoL")
    FT2_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT2-PER-SEC")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    M3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM")
    FR = URIRef("http://qudt.org/vocab/unit/FR")
    OZ_MIN_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-YD3")
    MOMME_Pearl = URIRef("http://qudt.org/vocab/unit/MOMME_Pearl")
    KiloLB_F = URIRef("http://qudt.org/vocab/unit/KiloLB_F")
    PA_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC2")
    PicoA_PER_HectoPA = URIRef("http://qudt.org/vocab/unit/PicoA-PER-HectoPA")
    GAL_UK = URIRef("http://qudt.org/vocab/unit/GAL_UK")
    LB_F_IN_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN-PER-IN")
    N_PER_MilliM = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM")
    GigaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBYTE-PER-SEC")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    DEG_C_WK = URIRef("http://qudt.org/vocab/unit/DEG_C-WK")
    NUM_PER_HR = URIRef("http://qudt.org/vocab/unit/NUM-PER-HR")
    KiloC = URIRef("http://qudt.org/vocab/unit/KiloC")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    KiloJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM")
    K = URIRef("http://qudt.org/vocab/unit/K")
    FT_LB_F = URIRef("http://qudt.org/vocab/unit/FT-LB_F")
    MegaOHM_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-M")
    MicroGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2")
    A_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-M2")
    EU_PER_L = URIRef("http://qudt.org/vocab/unit/EU-PER-L")
    SON = URIRef("http://qudt.org/vocab/unit/SON")
    CentiM2_PER_SR_ERG = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SR-ERG")
    CD_PER_M2 = URIRef("http://qudt.org/vocab/unit/CD-PER-M2")
    MicroGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-MilliL")
    ATM_T = URIRef("http://qudt.org/vocab/unit/ATM_T")
    PSI = URIRef("http://qudt.org/vocab/unit/PSI")
    PA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-L-PER-SEC")
    GM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM")
    KiloPA = URIRef("http://qudt.org/vocab/unit/KiloPA")
    A = URIRef("http://qudt.org/vocab/unit/A")
    HA = URIRef("http://qudt.org/vocab/unit/HA")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    HectoPA = URIRef("http://qudt.org/vocab/unit/HectoPA")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    NAT = URIRef("http://qudt.org/vocab/unit/NAT")
    TON_Metric_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN-BAR")
    PA2_SEC = URIRef("http://qudt.org/vocab/unit/PA2-SEC")
    NanoSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-MIN")
    MegaOHM = URIRef("http://qudt.org/vocab/unit/MegaOHM")
    AttoJ_SEC = URIRef("http://qudt.org/vocab/unit/AttoJ-SEC")
    PINT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-HR")
    MI_PER_SEC = URIRef("http://qudt.org/vocab/unit/MI-PER-SEC")
    KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloM2")
    GM_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM2")
    PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/PER-M2-SEC")
    CM_H2O = URIRef("http://qudt.org/vocab/unit/CM_H2O")
    IN3_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN3-PER-MIN")
    FT3_PER_HR = URIRef("http://qudt.org/vocab/unit/FT3-PER-HR")
    CentiM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-M3")
    MegaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M3")
    GM_PER_GM = URIRef("http://qudt.org/vocab/unit/GM-PER-GM")
    LB_MIN_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-YD3")
    SLUG_PER_HR = URIRef("http://qudt.org/vocab/unit/SLUG-PER-HR")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    MilliL_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-K")
    MilliGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MilliL")
    Quarter_UK = URIRef("http://qudt.org/vocab/unit/Quarter_UK")
    GM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN-BAR")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    MilliGM_SEC_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M3-CentiM3")
    BTU_IT_PER_FT2_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR")
    KiloMOL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-HR")
    KiloGM_PER_DeciM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-K")
    MilliMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-KiloGM")
    GRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/GRAY-PER-SEC")
    LB_PER_MIN_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN-DEG_F")
    KiloGAUSS = URIRef("http://qudt.org/vocab/unit/KiloGAUSS")
    FRACTION = URIRef("http://qudt.org/vocab/unit/FRACTION")
    PER_IN3 = URIRef("http://qudt.org/vocab/unit/PER-IN3")
    MegaBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaBTU_IT-PER-HR")
    MebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M")
    MilliGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-SEC")
    MicroS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MicroS-PER-CentiM")
    KibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M2")
    MHO_Stat = URIRef("http://qudt.org/vocab/unit/MHO_Stat")
    M2_K_PER_W = URIRef("http://qudt.org/vocab/unit/M2-K-PER-W")
    W_PER_M_K = URIRef("http://qudt.org/vocab/unit/W-PER-M-K")
    MilliRAD = URIRef("http://qudt.org/vocab/unit/MilliRAD")
    MilliN_PER_M = URIRef("http://qudt.org/vocab/unit/MilliN-PER-M")
    Kilo_FT3 = URIRef("http://qudt.org/vocab/unit/Kilo-FT3")
    PA2_SEC = URIRef("http://qudt.org/vocab/unit/PA2-SEC")
    SUSCEPTIBILITY_MAG = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_MAG")
    PlanckCharge = URIRef("http://qudt.org/vocab/unit/PlanckCharge")
    TeraHZ = URIRef("http://qudt.org/vocab/unit/TeraHZ")
    PPB = URIRef("http://qudt.org/vocab/unit/PPB")
    TeraC = URIRef("http://qudt.org/vocab/unit/TeraC")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    LB_SEC_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-YD3")
    FT_LB_F = URIRef("http://qudt.org/vocab/unit/FT-LB_F")
    MegaA_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaA-PER-M2")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    PPM = URIRef("http://qudt.org/vocab/unit/PPM")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    MilliGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-KiloGM")
    DecaL = URIRef("http://qudt.org/vocab/unit/DecaL")
    MicroS_PER_M = URIRef("http://qudt.org/vocab/unit/MicroS-PER-M")
    MicroBQ = URIRef("http://qudt.org/vocab/unit/MicroBQ")
    PA2_SEC = URIRef("http://qudt.org/vocab/unit/PA2-SEC")
    GM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC-BAR")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    HP = URIRef("http://qudt.org/vocab/unit/HP")
    MicroG_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroG-PER-CentiM2")
    EV_PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/EV-PER-ANGSTROM")
    CAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-K")
    GigaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-PER-M")
    MegaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBIT-PER-SEC")
    TON_US = URIRef("http://qudt.org/vocab/unit/TON_US")
    A_PER_GM = URIRef("http://qudt.org/vocab/unit/A-PER-GM")
    GM_PER_M = URIRef("http://qudt.org/vocab/unit/GM-PER-M")
    PER_SEC_SR_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR-M2")
    MicroV_A_PER_K = URIRef("http://qudt.org/vocab/unit/MicroV-A-PER-K")
    MilliGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-KiloGM")
    GM_PER_MilliM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM-BAR")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    BQ_PER_M2 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M2")
    L_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-K")
    BTU_IT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR-DEG_F")
    ARE = URIRef("http://qudt.org/vocab/unit/ARE")
    NUM_PER_M2 = URIRef("http://qudt.org/vocab/unit/NUM-PER-M2")
    SHANNON_PER_SEC = URIRef("http://qudt.org/vocab/unit/SHANNON-PER-SEC")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    DEGREE_PLATO = URIRef("http://qudt.org/vocab/unit/DEGREE_PLATO")
    PER_GigaEV2 = URIRef("http://qudt.org/vocab/unit/PER-GigaEV2")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    KiloGM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM-PER-SEC")
    DEG_F_SEC_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-SEC-PER-BTU_IT")
    NanoM2 = URIRef("http://qudt.org/vocab/unit/NanoM2")
    MilliMOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2-SEC")
    MicroPOISE = URIRef("http://qudt.org/vocab/unit/MicroPOISE")
    HeartBeat = URIRef("http://qudt.org/vocab/unit/HeartBeat")
    C_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM2")
    NanoMOL_PER_MicroGM_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroGM-HR")
    IN_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN-PER-MIN")
    MicroMOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-SEC")
    LB_PER_IN3_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3-PSI")
    DEG2 = URIRef("http://qudt.org/vocab/unit/DEG2")
    FT_HR_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-GAL_UK")
    MilliGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HA")
    V_PER_IN = URIRef("http://qudt.org/vocab/unit/V-PER-IN")
    DeciN_M = URIRef("http://qudt.org/vocab/unit/DeciN-M")
    NanoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-KiloGM")
    MilliJ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-GM")
    N_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M3")
    MilliGM_PER_M3_POISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-POISE")
    KiloM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC-BAR")
    MegaPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-L-PER-SEC")
    TON_UK = URIRef("http://qudt.org/vocab/unit/TON_UK")
    PER_M_SR = URIRef("http://qudt.org/vocab/unit/PER-M-SR")
    K_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/K-PER-SEC2")
    RAD_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-KiloGM")
    LB_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-MOL-DEG_F")
    FT_LB_F_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-HR")
    KiloPA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-MilliM")
    FT_LB_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-SEC")
    FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-SEC")
    LB_HR_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-YD3")
    NanoS_PER_M = URIRef("http://qudt.org/vocab/unit/NanoS-PER-M")
    MilliGM_HR_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M6")
    CentiM = URIRef("http://qudt.org/vocab/unit/CentiM")
    MicroM_PER_N = URIRef("http://qudt.org/vocab/unit/MicroM-PER-N")
    GM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-K")
    M2_SR = URIRef("http://qudt.org/vocab/unit/M2-SR")
    KIP_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KIP_F-PER-IN2")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    OZ_M = URIRef("http://qudt.org/vocab/unit/OZ_M")
    MilliGM_PER_M3_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-MilliPA-SEC")
    IN3_PER_LB = URIRef("http://qudt.org/vocab/unit/IN3-PER-LB")
    YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD3-PER-SEC")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    J_PER_GM_K = URIRef("http://qudt.org/vocab/unit/J-PER-GM-K")
    PPTR = URIRef("http://qudt.org/vocab/unit/PPTR")
    MilliSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-SEC")
    GAL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-DAY")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    E = URIRef("http://qudt.org/vocab/unit/E")
    GigaC = URIRef("http://qudt.org/vocab/unit/GigaC")
    OZ_PER_GAL = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL")
    DeciM3 = URIRef("http://qudt.org/vocab/unit/DeciM3")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    M2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    C = URIRef("http://qudt.org/vocab/unit/C")
    GT = URIRef("http://qudt.org/vocab/unit/GT")
    NanoGM_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2-DAY")
    OZ_VOL_UK = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK")
    FT_LB_F = URIRef("http://qudt.org/vocab/unit/FT-LB_F")
    CentiC = URIRef("http://qudt.org/vocab/unit/CentiC")
    MilliL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    PA_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    KiloTONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloTONNE-PER-YR")
    NanoA = URIRef("http://qudt.org/vocab/unit/NanoA")
    RAD_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-KiloGM")
    Ci = URIRef("http://qudt.org/vocab/unit/Ci")
    TON_Metric_PER_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-BAR")
    V_PER_PA = URIRef("http://qudt.org/vocab/unit/V-PER-PA")
    J = URIRef("http://qudt.org/vocab/unit/J")
    OZ_FT = URIRef("http://qudt.org/vocab/unit/OZ-FT")
    V = URIRef("http://qudt.org/vocab/unit/V")
    LB_PER_YD2 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD2")
    MicroGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-DeciL")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    LB_PER_IN3 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    PINT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-SEC")
    DEGREE_BAUME_US_HEAVY = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_HEAVY")
    FT_PER_PSI = URIRef("http://qudt.org/vocab/unit/FT-PER-PSI")
    ERG = URIRef("http://qudt.org/vocab/unit/ERG")
    MegaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-HR")
    BU_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-SEC")
    U = URIRef("http://qudt.org/vocab/unit/U")
    FT2 = URIRef("http://qudt.org/vocab/unit/FT2")
    TeraBIT = URIRef("http://qudt.org/vocab/unit/TeraBIT")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    PA_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M")
    IN_PER_PSI = URIRef("http://qudt.org/vocab/unit/IN-PER-PSI")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    C_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM3")
    ERG = URIRef("http://qudt.org/vocab/unit/ERG")
    M3_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-K")
    HectoPA_PER_M = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-M")
    KiloBQ = URIRef("http://qudt.org/vocab/unit/KiloBQ")
    H_PER_M = URIRef("http://qudt.org/vocab/unit/H-PER-M")
    DYN_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM2")
    GAL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-DAY")
    MegaDOLLAR_US_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MegaDOLLAR_US-PER-FLIGHT")
    NUM_PER_CentiM_KiloYR = URIRef("http://qudt.org/vocab/unit/NUM-PER-CentiM-KiloYR")
    PERCENT_IN2_PER_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-IN2-PER-LB_F-SEC")
    PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-PSI")
    QT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-MIN")
    FATH = URIRef("http://qudt.org/vocab/unit/FATH")
    MicroMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2")
    Hundredweight_US = URIRef("http://qudt.org/vocab/unit/Hundredweight_US")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    M2_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-BAR")
    KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloMOL")
    MegaOHM_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-M")
    OHM_PER_MI = URIRef("http://qudt.org/vocab/unit/OHM-PER-MI")
    MegaBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaBTU_IT-PER-HR")
    PER_MO = URIRef("http://qudt.org/vocab/unit/PER-MO")
    Gs = URIRef("http://qudt.org/vocab/unit/Gs")
    KiloCAL_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM-DEG_C")
    MegaS_PER_M = URIRef("http://qudt.org/vocab/unit/MegaS-PER-M")
    KiloN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-M2")
    GibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M3")
    K_PER_HR = URIRef("http://qudt.org/vocab/unit/K-PER-HR")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    PINT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-MIN")
    GigaV_A = URIRef("http://qudt.org/vocab/unit/GigaV-A")
    S = URIRef("http://qudt.org/vocab/unit/S")
    ERG_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM3")
    IN_HG = URIRef("http://qudt.org/vocab/unit/IN_HG")
    V2_PER_K2 = URIRef("http://qudt.org/vocab/unit/V2-PER-K2")
    DEG_C2_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C2-PER-SEC")
    DeciBAR_PER_YR = URIRef("http://qudt.org/vocab/unit/DeciBAR-PER-YR")
    MegaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-HR")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    KiloBD = URIRef("http://qudt.org/vocab/unit/KiloBD")
    HR_PER_FT2 = URIRef("http://qudt.org/vocab/unit/HR-PER-FT2")
    MicroM = URIRef("http://qudt.org/vocab/unit/MicroM")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    KiloSEC = URIRef("http://qudt.org/vocab/unit/KiloSEC")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    CAL_TH_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM-SEC-DEG_C")
    LB_MIN_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-IN3")
    V_PER_SEC = URIRef("http://qudt.org/vocab/unit/V-PER-SEC")
    MilliARCSEC = URIRef("http://qudt.org/vocab/unit/MilliARCSEC")
    PERCENT_PER_DEG = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEG")
    OZ_TROY = URIRef("http://qudt.org/vocab/unit/OZ_TROY")
    PER_WB = URIRef("http://qudt.org/vocab/unit/PER-WB")
    MilliGAL = URIRef("http://qudt.org/vocab/unit/MilliGAL")
    PER_IN2 = URIRef("http://qudt.org/vocab/unit/PER-IN2")
    A_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-PER-CentiM2")
    MilliGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-SEC")
    KiloGM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC2")
    GM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloM")
    MOL_LB_PER_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-LB")
    DeciM3_PER_HR = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-HR")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    OHM_M2_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-M2-PER-M")
    OZ_PER_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD3")
    DECADE = URIRef("http://qudt.org/vocab/unit/DECADE")
    MilliGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-BAR")
    TON_Metric = URIRef("http://qudt.org/vocab/unit/TON_Metric")
    CP = URIRef("http://qudt.org/vocab/unit/CP")
    LA_FT = URIRef("http://qudt.org/vocab/unit/LA_FT")
    IN = URIRef("http://qudt.org/vocab/unit/IN")
    FT3_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT3-PER-SEC")
    N_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M")
    OZ_PER_FT2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-FT2")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    MilliWB = URIRef("http://qudt.org/vocab/unit/MilliWB")
    CentiGM = URIRef("http://qudt.org/vocab/unit/CentiGM")
    V_Ab_SEC = URIRef("http://qudt.org/vocab/unit/V_Ab-SEC")
    ExbiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M")
    ERG_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM-SEC")
    ZeptoC = URIRef("http://qudt.org/vocab/unit/ZeptoC")
    TON_SHIPPING_UK = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_UK")
    MOL_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-DeciM3")
    A_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-PER-DEG_C")
    MilliGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-GM")
    IN3 = URIRef("http://qudt.org/vocab/unit/IN3")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    TONNE_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN-K")
    P = URIRef("http://qudt.org/vocab/unit/P")
    KiloGM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MilliM")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    AWG = URIRef("http://qudt.org/vocab/unit/AWG")
    LB_PER_IN3 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3")
    KiloGM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3")
    MilliGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-BAR")
    TON_SHIPPING_UK = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_UK")
    BTU_TH_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_F")
    PA_M0dot5 = URIRef("http://qudt.org/vocab/unit/PA-M0dot5")
    V_A_PER_K = URIRef("http://qudt.org/vocab/unit/V-A-PER-K")
    L_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-MOL-SEC")
    KiloGM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC2")
    HectoBAR = URIRef("http://qudt.org/vocab/unit/HectoBAR")
    OZ_TROY = URIRef("http://qudt.org/vocab/unit/OZ_TROY")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    LB_SEC_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-FT3")
    CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-SEC")
    C_Stat = URIRef("http://qudt.org/vocab/unit/C_Stat")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    MOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM")
    TeraW = URIRef("http://qudt.org/vocab/unit/TeraW")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    MegaN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaN-M-PER-M2")
    MilliM3_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-GM")
    YR = URIRef("http://qudt.org/vocab/unit/YR")
    ERG = URIRef("http://qudt.org/vocab/unit/ERG")
    MilliH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-KiloOHM")
    GM_HR_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M6")
    DecaPA = URIRef("http://qudt.org/vocab/unit/DecaPA")
    BTU_TH_FT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-HR-FT2-DEG_F")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    BTU_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC")
    KiloLB_F_FT_PER_LB = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-LB")
    C_M2_PER_V = URIRef("http://qudt.org/vocab/unit/C-M2-PER-V")
    PINT_US = URIRef("http://qudt.org/vocab/unit/PINT_US")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    CentiM3_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-K")
    PDL_IN = URIRef("http://qudt.org/vocab/unit/PDL-IN")
    NanoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MilliL")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    MilliV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/MilliV-A_Reactive-PER-K")
    PPTH_PER_HR = URIRef("http://qudt.org/vocab/unit/PPTH-PER-HR")
    MilliM3_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-GM")
    M_PER_MIN = URIRef("http://qudt.org/vocab/unit/M-PER-MIN")
    PK_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-DAY")
    LB_IN2_PER_GAL_UK_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-GAL_UK-LB_F-SEC")
    KiloOHM_M = URIRef("http://qudt.org/vocab/unit/KiloOHM-M")
    MilliW = URIRef("http://qudt.org/vocab/unit/MilliW")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    PER_J_M3 = URIRef("http://qudt.org/vocab/unit/PER-J-M3")
    M2_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/M2-SEC-PER-RAD")
    DEGREE_BAUME_US_HEAVY = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_HEAVY")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    MilliGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY")
    TON_Metric_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY-BAR")
    PER_T_SEC = URIRef("http://qudt.org/vocab/unit/PER-T-SEC")
    NanoV_A_Reactive = URIRef("http://qudt.org/vocab/unit/NanoV-A_Reactive")
    LB_F_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-IN2")
    M6 = URIRef("http://qudt.org/vocab/unit/M6")
    V_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V-PER-CentiM")
    H = URIRef("http://qudt.org/vocab/unit/H")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    MicroATM = URIRef("http://qudt.org/vocab/unit/MicroATM")
    MilliM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-M3")
    MilliGAL_PER_MO = URIRef("http://qudt.org/vocab/unit/MilliGAL-PER-MO")
    NUM_PER_NanoL = URIRef("http://qudt.org/vocab/unit/NUM-PER-NanoL")
    LB_SEC_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-GAL_UK")
    KiloV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive-PER-K")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    IU_PER_L = URIRef("http://qudt.org/vocab/unit/IU-PER-L")
    IN_H2O = URIRef("http://qudt.org/vocab/unit/IN_H2O")
    MI2 = URIRef("http://qudt.org/vocab/unit/MI2")
    LB_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_US")
    GM_PER_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-BAR")
    SAMPLE_PER_SEC = URIRef("http://qudt.org/vocab/unit/SAMPLE-PER-SEC")
    DecaL = URIRef("http://qudt.org/vocab/unit/DecaL")
    MegaC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M2")
    MegaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBIT-PER-SEC")
    CentiM3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-K")
    MI3 = URIRef("http://qudt.org/vocab/unit/MI3")
    MegaEV_FemtoM = URIRef("http://qudt.org/vocab/unit/MegaEV-FemtoM")
    BBL_US_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-HR")
    DPI = URIRef("http://qudt.org/vocab/unit/DPI")
    AT_PER_IN = URIRef("http://qudt.org/vocab/unit/AT-PER-IN")
    FemtoGM_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-L")
    KiloTONNE = URIRef("http://qudt.org/vocab/unit/KiloTONNE")
    KiloGM_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-M2")
    KiloPA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-MilliM")
    MilliGM_HR_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L-CentiM3")
    MilliGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-K")
    MegaEV = URIRef("http://qudt.org/vocab/unit/MegaEV")
    N_M_PER_ARCMIN = URIRef("http://qudt.org/vocab/unit/N-M-PER-ARCMIN")
    BIOT = URIRef("http://qudt.org/vocab/unit/BIOT")
    MicroN_M = URIRef("http://qudt.org/vocab/unit/MicroN-M")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    MebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M")
    PERCENT_MIN_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-L")
    MilliGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-BAR")
    LB_PER_IN3 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3")
    STR = URIRef("http://qudt.org/vocab/unit/STR")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM-SEC-DEG_C")
    PINT = URIRef("http://qudt.org/vocab/unit/PINT")
    NAT_PER_SEC = URIRef("http://qudt.org/vocab/unit/NAT-PER-SEC")
    M2_SR = URIRef("http://qudt.org/vocab/unit/M2-SR")
    MicroM = URIRef("http://qudt.org/vocab/unit/MicroM")
    KiloGM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR")
    BIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/BIT-PER-M2")
    CAL_IT_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-DEG_C")
    PER_PlanckMass2 = URIRef("http://qudt.org/vocab/unit/PER-PlanckMass2")
    MilliM_H2O = URIRef("http://qudt.org/vocab/unit/MilliM_H2O")
    CM_H2O = URIRef("http://qudt.org/vocab/unit/CM_H2O")
    PER_DEG_F = URIRef("http://qudt.org/vocab/unit/PER-DEG_F")
    MegaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-SEC")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    S_Stat = URIRef("http://qudt.org/vocab/unit/S_Stat")
    PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/PER-M2-SEC")
    KiloLB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-FT")
    MilliGM_HR_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L2")
    GI_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-SEC")
    YD = URIRef("http://qudt.org/vocab/unit/YD")
    SolarMass = URIRef("http://qudt.org/vocab/unit/SolarMass")
    MegaV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive")
    DeciM3 = URIRef("http://qudt.org/vocab/unit/DeciM3")
    KiloJ_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM-K")
    J_PER_M3_K = URIRef("http://qudt.org/vocab/unit/J-PER-M3-K")
    TONNE_PER_HR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR")
    TON_SHORT_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-YD3")
    M3_PER_HR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR")
    CAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-MIN")
    CAL_TH_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM-K")
    MegaGM = URIRef("http://qudt.org/vocab/unit/MegaGM")
    FT_LB_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-SEC")
    BTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR")
    A_PER_GM = URIRef("http://qudt.org/vocab/unit/A-PER-GM")
    C_M2 = URIRef("http://qudt.org/vocab/unit/C-M2")
    KiloJ = URIRef("http://qudt.org/vocab/unit/KiloJ")
    M4 = URIRef("http://qudt.org/vocab/unit/M4")
    MegaGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-HA")
    NanoFARAD = URIRef("http://qudt.org/vocab/unit/NanoFARAD")
    SLUG_PER_MIN = URIRef("http://qudt.org/vocab/unit/SLUG-PER-MIN")
    BTU_IT_PER_SEC_FT_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT-DEG_R")
    KiloBAR = URIRef("http://qudt.org/vocab/unit/KiloBAR")
    TON_Metric_PER_M3_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3-K")
    MilliM3_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-GM")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    NanoS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/NanoS-PER-CentiM")
    M3_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-K")
    LB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT")
    OHM_Stat = URIRef("http://qudt.org/vocab/unit/OHM_Stat")
    QT_UK = URIRef("http://qudt.org/vocab/unit/QT_UK")
    DEG_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG-PER-MIN")
    MicroGRAY = URIRef("http://qudt.org/vocab/unit/MicroGRAY")
    PINT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-SEC")
    CentiM3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL-SEC")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    GAL_US = URIRef("http://qudt.org/vocab/unit/GAL_US")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    V_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V-PER-CentiM")
    KiloN_M_PER_DEG_M = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-DEG-M")
    PFERDESTAERKE = URIRef("http://qudt.org/vocab/unit/PFERDESTAERKE")
    LB_F = URIRef("http://qudt.org/vocab/unit/LB_F")
    PER_MilliL = URIRef("http://qudt.org/vocab/unit/PER-MilliL")
    KiloT = URIRef("http://qudt.org/vocab/unit/KiloT")
    IU_PER_L = URIRef("http://qudt.org/vocab/unit/IU-PER-L")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    MicroMOL = URIRef("http://qudt.org/vocab/unit/MicroMOL")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    PER_EV2 = URIRef("http://qudt.org/vocab/unit/PER-EV2")
    T = URIRef("http://qudt.org/vocab/unit/T")
    FT2_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT2-PER-SEC")
    MilliGM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M")
    OZ_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ-PER-SEC")
    TON_Metric = URIRef("http://qudt.org/vocab/unit/TON_Metric")
    HART = URIRef("http://qudt.org/vocab/unit/HART")
    MX = URIRef("http://qudt.org/vocab/unit/MX")
    CentiN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/CentiN-M-PER-M2")
    PERCENT_HR_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-FT3")
    CentiM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-M3")
    MegaLB_F = URIRef("http://qudt.org/vocab/unit/MegaLB_F")
    MilliM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliM-PER-K")
    MilliL_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-BAR")
    NanoFARAD = URIRef("http://qudt.org/vocab/unit/NanoFARAD")
    MicroGM = URIRef("http://qudt.org/vocab/unit/MicroGM")
    KibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M3")
    PER_TONNE = URIRef("http://qudt.org/vocab/unit/PER-TONNE")
    PER_M2 = URIRef("http://qudt.org/vocab/unit/PER-M2")
    DIOPTER = URIRef("http://qudt.org/vocab/unit/DIOPTER")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    BTU_IT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MIN")
    PERCENT_MIN_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-IN3")
    CentiM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC")
    MilliL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN")
    N_PER_MilliM = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM")
    BTU_39DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_39DEG_F")
    S = URIRef("http://qudt.org/vocab/unit/S")
    MilliW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2")
    PPTM = URIRef("http://qudt.org/vocab/unit/PPTM")
    CAL_IT_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM-K")
    DEG2 = URIRef("http://qudt.org/vocab/unit/DEG2")
    FT_PDL = URIRef("http://qudt.org/vocab/unit/FT-PDL")
    QT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_US-PER-SEC")
    DEG_F_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-HR")
    GAL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-SEC")
    AT_PER_M = URIRef("http://qudt.org/vocab/unit/AT-PER-M")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    MicroSV = URIRef("http://qudt.org/vocab/unit/MicroSV")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    CentiM = URIRef("http://qudt.org/vocab/unit/CentiM")
    PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/PER-KiloGM2")
    OHM_KiloM = URIRef("http://qudt.org/vocab/unit/OHM-KiloM")
    DecaM3 = URIRef("http://qudt.org/vocab/unit/DecaM3")
    KiloGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-BAR")
    CentiM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY")
    CAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-MIN")
    L_PER_MIN = URIRef("http://qudt.org/vocab/unit/L-PER-MIN")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    DYN = URIRef("http://qudt.org/vocab/unit/DYN")
    NUM_PER_M2 = URIRef("http://qudt.org/vocab/unit/NUM-PER-M2")
    PetaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/PetaJ-PER-SEC")
    DEGREE_BAUME_US_LIGHT = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_LIGHT")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    MicroM2 = URIRef("http://qudt.org/vocab/unit/MicroM2")
    PERCENT_SEC_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-GAL_UK")
    W_HR_PER_L = URIRef("http://qudt.org/vocab/unit/W-HR-PER-L")
    ANGSTROM3 = URIRef("http://qudt.org/vocab/unit/ANGSTROM3")
    FT_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-PER-HR")
    NanoJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoJ-PER-SEC")
    F = URIRef("http://qudt.org/vocab/unit/F")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    KiloN_M = URIRef("http://qudt.org/vocab/unit/KiloN-M")
    FemtoFARAD = URIRef("http://qudt.org/vocab/unit/FemtoFARAD")
    FT_LB_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-SEC")
    J_PER_GM = URIRef("http://qudt.org/vocab/unit/J-PER-GM")
    GM_PER_M = URIRef("http://qudt.org/vocab/unit/GM-PER-M")
    HectoPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-L-PER-SEC")
    V_PER_IN = URIRef("http://qudt.org/vocab/unit/V-PER-IN")
    MilliIN = URIRef("http://qudt.org/vocab/unit/MilliIN")
    W_SEC = URIRef("http://qudt.org/vocab/unit/W-SEC")
    MOL_PER_L = URIRef("http://qudt.org/vocab/unit/MOL-PER-L")
    KiloMOL_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3-BAR")
    FATH = URIRef("http://qudt.org/vocab/unit/FATH")
    DeciM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-KiloGM")
    TON_SHORT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-DEG_F")
    KiloGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC")
    MilliGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-CentiM2")
    MicroGM_PER_IN2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-IN2")
    KiloOHM = URIRef("http://qudt.org/vocab/unit/KiloOHM")
    DecaM3 = URIRef("http://qudt.org/vocab/unit/DecaM3")
    OZ_SEC_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-GAL_UK")
    W_SEC = URIRef("http://qudt.org/vocab/unit/W-SEC")
    ST_PER_BAR = URIRef("http://qudt.org/vocab/unit/ST-PER-BAR")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    MilliSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-HR")
    DeciB_PER_KiloM = URIRef("http://qudt.org/vocab/unit/DeciB-PER-KiloM")
    PER_M_NanoM_SR = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM-SR")
    SEC2 = URIRef("http://qudt.org/vocab/unit/SEC2")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    LB_SEC_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK2")
    CAL_TH_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM2-K")
    PERCENT_PER_DecaK = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaK")
    DeciN_M = URIRef("http://qudt.org/vocab/unit/DeciN-M")
    SV_PER_MIN = URIRef("http://qudt.org/vocab/unit/SV-PER-MIN")
    KiloGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-K")
    LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC")
    NanoGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-SEC")
    W_M2_PER_SR = URIRef("http://qudt.org/vocab/unit/W-M2-PER-SR")
    MilliGM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR")
    MilliL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-SEC")
    CAL_IT_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM")
    A_M2 = URIRef("http://qudt.org/vocab/unit/A-M2")
    V_A_PER_K = URIRef("http://qudt.org/vocab/unit/V-A-PER-K")
    LB_MIN_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK2")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    MI_US_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/MI_US-PER-SEC2")
    TONNE_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN-BAR")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    MilliM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC")
    GRAIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL_US")
    MilliR_man = URIRef("http://qudt.org/vocab/unit/MilliR_man")
    GRAIN_PER_GAL = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL")
    A_PER_A_HR = URIRef("http://qudt.org/vocab/unit/A-PER-A-HR")
    KibiBYTE = URIRef("http://qudt.org/vocab/unit/KibiBYTE")
    MicroMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MOL")
    BTU_MEAN = URIRef("http://qudt.org/vocab/unit/BTU_MEAN")
    MegaEV_PER_SpeedOfLight = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-SpeedOfLight")
    KiloGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-BAR")
    HectoM = URIRef("http://qudt.org/vocab/unit/HectoM")
    KiloGM_PER_M_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-HR")
    YD3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD3-PER-DEG_F")
    CentiMOL_PER_L = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-L")
    MicroGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-HR")
    KiloGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-BAR")
    LB_HR_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-IN3")
    BTU_TH_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_R")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    HART = URIRef("http://qudt.org/vocab/unit/HART")
    LB_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT2")
    DEGREE_API = URIRef("http://qudt.org/vocab/unit/DEGREE_API")
    BTU_TH_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-FT2-HR-DEG_F")
    TONNE_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC-BAR")
    M_PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PA-PER-SEC")
    GM_Nitrogen_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Nitrogen-PER-M2-DAY")
    RAD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC2")
    CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CentiM2-MIN")
    CUP_US = URIRef("http://qudt.org/vocab/unit/CUP_US")
    PebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M3")
    LB_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-SEC")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    OZ_VOL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-SEC")
    DecaM = URIRef("http://qudt.org/vocab/unit/DecaM")
    PicoFARAD = URIRef("http://qudt.org/vocab/unit/PicoFARAD")
    MilliM_PER_DEG_C_M = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DEG_C-M")
    N_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M3")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    MebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M")
    A = URIRef("http://qudt.org/vocab/unit/A")
    NanoGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DeciL")
    DEG_C_PER_BAR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-BAR")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    MegaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-HR")
    C2_M2_PER_J = URIRef("http://qudt.org/vocab/unit/C2-M2-PER-J")
    FemtoGM = URIRef("http://qudt.org/vocab/unit/FemtoGM")
    Ci = URIRef("http://qudt.org/vocab/unit/Ci")
    YottaC = URIRef("http://qudt.org/vocab/unit/YottaC")
    DeciS = URIRef("http://qudt.org/vocab/unit/DeciS")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    GM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3")
    KiloN_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M")
    CentiM3_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-CentiM3")
    DeciGM = URIRef("http://qudt.org/vocab/unit/DeciGM")
    QT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-DAY")
    GigaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/GigaC-PER-M3")
    AttoC = URIRef("http://qudt.org/vocab/unit/AttoC")
    EV_PER_K = URIRef("http://qudt.org/vocab/unit/EV-PER-K")
    C = URIRef("http://qudt.org/vocab/unit/C")
    V_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/V-SEC-PER-M")
    MicroH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-KiloOHM")
    Denier = URIRef("http://qudt.org/vocab/unit/Denier")
    KibiBYTE = URIRef("http://qudt.org/vocab/unit/KibiBYTE")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    MilliGM_PER_L_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-MilliPA-SEC")
    MicroM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM-PER-MilliL")
    LB_HR_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-IN3")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    J_PER_MOL_K = URIRef("http://qudt.org/vocab/unit/J-PER-MOL-K")
    QT_US_DRY = URIRef("http://qudt.org/vocab/unit/QT_US_DRY")
    MicroGM_PER_L = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L")
    CD_PER_LM = URIRef("http://qudt.org/vocab/unit/CD-PER-LM")
    MilliA_SEC = URIRef("http://qudt.org/vocab/unit/MilliA-SEC")
    MilliARCSEC = URIRef("http://qudt.org/vocab/unit/MilliARCSEC")
    GM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC-K")
    MilliM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-M3")
    S = URIRef("http://qudt.org/vocab/unit/S")
    KiloGM_F_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-MilliM2")
    DEG_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG-PER-HR")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    CentiM_HG_0DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_HG_0DEG_C")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    PER_WK = URIRef("http://qudt.org/vocab/unit/PER-WK")
    S = URIRef("http://qudt.org/vocab/unit/S")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    OZ = URIRef("http://qudt.org/vocab/unit/OZ")
    BTU_IT_PER_SEC_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2")
    CentiM2_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-CentiM3")
    MilliL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliL-PER-L")
    PT = URIRef("http://qudt.org/vocab/unit/PT")
    GigaJ = URIRef("http://qudt.org/vocab/unit/GigaJ")
    OHM_Ab = URIRef("http://qudt.org/vocab/unit/OHM_Ab")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    IN_H2O_39dot2DEG_F = URIRef("http://qudt.org/vocab/unit/IN_H2O_39dot2DEG_F")
    KiloJ = URIRef("http://qudt.org/vocab/unit/KiloJ")
    NanoBQ = URIRef("http://qudt.org/vocab/unit/NanoBQ")
    TON = URIRef("http://qudt.org/vocab/unit/TON")
    J_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-GM-DEG_C")
    MI_UK3 = URIRef("http://qudt.org/vocab/unit/MI_UK3")
    MegaTOE = URIRef("http://qudt.org/vocab/unit/MegaTOE")
    LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC")
    MilliGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-CentiM2")
    CAL_TH_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM")
    HectoPA = URIRef("http://qudt.org/vocab/unit/HectoPA")
    MicroMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-KiloGM")
    HectoM = URIRef("http://qudt.org/vocab/unit/HectoM")
    OZ_SEC_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-GAL_UK")
    CentiMOL = URIRef("http://qudt.org/vocab/unit/CentiMOL")
    MilliMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-L")
    GM_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/GM-PER-DEG_C")
    C_Stat = URIRef("http://qudt.org/vocab/unit/C_Stat")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    Kilo_FT3 = URIRef("http://qudt.org/vocab/unit/Kilo-FT3")
    MegaV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive-HR")
    FT_LB_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-M2")
    MilliH = URIRef("http://qudt.org/vocab/unit/MilliH")
    M3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    GM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM_F-PER-CentiM2")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    OZ_VOL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-DAY")
    KiloPA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-K")
    A_M2_PER_J_SEC = URIRef("http://qudt.org/vocab/unit/A-M2-PER-J-SEC")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    BTU_TH_FT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-HR-FT2-DEG_F")
    KiloT = URIRef("http://qudt.org/vocab/unit/KiloT")
    FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-SEC-DEG_F")
    AttoFARAD = URIRef("http://qudt.org/vocab/unit/AttoFARAD")
    DeciN = URIRef("http://qudt.org/vocab/unit/DeciN")
    MicroT = URIRef("http://qudt.org/vocab/unit/MicroT")
    TSP = URIRef("http://qudt.org/vocab/unit/TSP")
    KiloS = URIRef("http://qudt.org/vocab/unit/KiloS")
    BTU_TH = URIRef("http://qudt.org/vocab/unit/BTU_TH")
    YD3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD3-PER-DEG_F")
    KiloTONNE = URIRef("http://qudt.org/vocab/unit/KiloTONNE")
    GM_MIN_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M6")
    PER_MIN = URIRef("http://qudt.org/vocab/unit/PER-MIN")
    TON_Metric_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC-BAR")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    MicroC = URIRef("http://qudt.org/vocab/unit/MicroC")
    OZ_MIN_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-GAL_UK")
    KiloR = URIRef("http://qudt.org/vocab/unit/KiloR")
    MegaPA_M0pt5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0pt5")
    MicroBQ = URIRef("http://qudt.org/vocab/unit/MicroBQ")
    OZ_VOL_US = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    FemtoSEC = URIRef("http://qudt.org/vocab/unit/FemtoSEC")
    MACH = URIRef("http://qudt.org/vocab/unit/MACH")
    PER_SR = URIRef("http://qudt.org/vocab/unit/PER-SR")
    NanoM_PER_MilliM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-MilliM-MegaPA")
    GM_MilliM = URIRef("http://qudt.org/vocab/unit/GM-MilliM")
    N_M_PER_DEG_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG-M")
    MOL_PER_KiloGM_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-BAR")
    W_PER_IN2 = URIRef("http://qudt.org/vocab/unit/W-PER-IN2")
    KiloEV = URIRef("http://qudt.org/vocab/unit/KiloEV")
    KiloGM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3")
    MI_N_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI_N-PER-MIN")
    PERCENT_SEC_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-YD3")
    A = URIRef("http://qudt.org/vocab/unit/A")
    MilliGM_PER_L_CentiPOISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-CentiPOISE")
    PERCENT_PER_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MilliPA-SEC")
    K_PER_HR = URIRef("http://qudt.org/vocab/unit/K-PER-HR")
    KiloA_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M2")
    FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-DEG_F")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    PA2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA2-PER-SEC2")
    FT4 = URIRef("http://qudt.org/vocab/unit/FT4")
    KiloV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive-HR")
    NanoGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DeciL")
    PPTM = URIRef("http://qudt.org/vocab/unit/PPTM")
    V_M = URIRef("http://qudt.org/vocab/unit/V-M")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    MicroN = URIRef("http://qudt.org/vocab/unit/MicroN")
    FT2 = URIRef("http://qudt.org/vocab/unit/FT2")
    MicroBQ = URIRef("http://qudt.org/vocab/unit/MicroBQ")
    failures_in_time = URIRef("http://qudt.org/vocab/unit/failures-in-time")
    PlanckPressure = URIRef("http://qudt.org/vocab/unit/PlanckPressure")
    ExaJ = URIRef("http://qudt.org/vocab/unit/ExaJ")
    N_M_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-M-PER-KiloGM")
    LA_FT = URIRef("http://qudt.org/vocab/unit/LA_FT")
    BTU_IT_PER_SEC_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2")
    A_SEC = URIRef("http://qudt.org/vocab/unit/A-SEC")
    KiloGM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-CentiM2")
    MilliM_PER_YR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-YR")
    TeraJ = URIRef("http://qudt.org/vocab/unit/TeraJ")
    CAL_15_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_15_DEG_C")
    MicroGM_PER_IN2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-IN2")
    KiloHZ_M = URIRef("http://qudt.org/vocab/unit/KiloHZ-M")
    PER_MIN = URIRef("http://qudt.org/vocab/unit/PER-MIN")
    MicroGRAY = URIRef("http://qudt.org/vocab/unit/MicroGRAY")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    KiloS_PER_M = URIRef("http://qudt.org/vocab/unit/KiloS-PER-M")
    KiloA_HR = URIRef("http://qudt.org/vocab/unit/KiloA-HR")
    MicroGM = URIRef("http://qudt.org/vocab/unit/MicroGM")
    ANGSTROM = URIRef("http://qudt.org/vocab/unit/ANGSTROM")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    MilliGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-CentiM2")
    PINT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-DAY")
    DEG_F_HR_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_TH")
    KiloGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloGM")
    LB_PER_GAL = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL")
    DeciM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MIN")
    DWT = URIRef("http://qudt.org/vocab/unit/DWT")
    CentiM = URIRef("http://qudt.org/vocab/unit/CentiM")
    FemtoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-KiloGM")
    MilliR = URIRef("http://qudt.org/vocab/unit/MilliR")
    Gs = URIRef("http://qudt.org/vocab/unit/Gs")
    NanoGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M3")
    DeciGM = URIRef("http://qudt.org/vocab/unit/DeciGM")
    PER_M_SEC = URIRef("http://qudt.org/vocab/unit/PER-M-SEC")
    FRAME_PER_SEC = URIRef("http://qudt.org/vocab/unit/FRAME-PER-SEC")
    KiloM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC-BAR")
    MegaOHM = URIRef("http://qudt.org/vocab/unit/MegaOHM")
    OZ_PER_FT2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-FT2")
    M_PER_BAR = URIRef("http://qudt.org/vocab/unit/M-PER-BAR")
    M3_PER_HR_K = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-K")
    MilliJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-SEC")
    PicoMOL_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L-DAY")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    MilliGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-SEC")
    M3_PER_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-M2")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    BTU_IT_PER_SEC_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_R")
    MilliMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2")
    BAR_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/BAR-PER-DEG_C")
    KiloGM_PER_DeciM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-K")
    KiloLB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-IN2")
    PicoSEC = URIRef("http://qudt.org/vocab/unit/PicoSEC")
    TON_UK_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-YD3")
    MilliGAL_PER_MO = URIRef("http://qudt.org/vocab/unit/MilliGAL-PER-MO")
    TONNE_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR-BAR")
    OHM_Ab = URIRef("http://qudt.org/vocab/unit/OHM_Ab")
    CentiM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC-BAR")
    KiloCAL_Mean = URIRef("http://qudt.org/vocab/unit/KiloCAL_Mean")
    A_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM2")
    LB_SEC_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US2")
    MilliL = URIRef("http://qudt.org/vocab/unit/MilliL")
    KiloPA = URIRef("http://qudt.org/vocab/unit/KiloPA")
    TONNE_PER_HA_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA-YR")
    C_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM3")
    MilliM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DAY")
    EV_SEC = URIRef("http://qudt.org/vocab/unit/EV-SEC")
    PINT_US_DRY = URIRef("http://qudt.org/vocab/unit/PINT_US_DRY")
    TON_Metric_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN-BAR")
    MilliGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HA")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    GigaJ = URIRef("http://qudt.org/vocab/unit/GigaJ")
    KiloCAL_Mean = URIRef("http://qudt.org/vocab/unit/KiloCAL_Mean")
    K_PER_HR = URIRef("http://qudt.org/vocab/unit/K-PER-HR")
    DRAM_UK = URIRef("http://qudt.org/vocab/unit/DRAM_UK")
    W_PER_IN2 = URIRef("http://qudt.org/vocab/unit/W-PER-IN2")
    H_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/H_Stat-PER-CentiM")
    LB_IN = URIRef("http://qudt.org/vocab/unit/LB-IN")
    MilliC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M2")
    BIT_PER_M = URIRef("http://qudt.org/vocab/unit/BIT-PER-M")
    GM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3")
    LUX_SEC = URIRef("http://qudt.org/vocab/unit/LUX-SEC")
    DeciL = URIRef("http://qudt.org/vocab/unit/DeciL")
    GM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3")
    PicoC = URIRef("http://qudt.org/vocab/unit/PicoC")
    GigaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-PER-M")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    LB_MIN_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-IN3")
    FT3_PER_LB = URIRef("http://qudt.org/vocab/unit/FT3-PER-LB")
    ROD = URIRef("http://qudt.org/vocab/unit/ROD")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    MilliGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-K")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    BTU_59DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_59DEG_F")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    KiloBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBYTE-PER-SEC")
    MOL_PER_M2_SEC_SR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-SR")
    KiloGM_PER_M3_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-PA")
    CAL_15_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_15_DEG_C")
    MilliM_PER_YR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-YR")
    MicroM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroM-PER-SEC")
    LB_HR_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-GAL_UK")
    FemtoGM_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-L")
    PER_IN = URIRef("http://qudt.org/vocab/unit/PER-IN")
    PlanckForce = URIRef("http://qudt.org/vocab/unit/PlanckForce")
    PINT = URIRef("http://qudt.org/vocab/unit/PINT")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    FT_HR_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-GAL_UK")
    FT_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC2")
    BTU_IT_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC")
    GigaC = URIRef("http://qudt.org/vocab/unit/GigaC")
    PPTM = URIRef("http://qudt.org/vocab/unit/PPTM")
    GRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/GRAY-PER-SEC")
    CAL_TH_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM-SEC-DEG_C")
    KiloGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY")
    MilliGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-BAR")
    PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PER-CentiM3")
    PER_DEG_F = URIRef("http://qudt.org/vocab/unit/PER-DEG_F")
    L_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-K")
    J_M2 = URIRef("http://qudt.org/vocab/unit/J-M2")
    P = URIRef("http://qudt.org/vocab/unit/P")
    QT_UK = URIRef("http://qudt.org/vocab/unit/QT_UK")
    GI_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_US-PER-SEC")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    YD = URIRef("http://qudt.org/vocab/unit/YD")
    MegaGM = URIRef("http://qudt.org/vocab/unit/MegaGM")
    PA_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M")
    MOL_LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-SEC")
    MilliL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-GM")
    MicroC = URIRef("http://qudt.org/vocab/unit/MicroC")
    FT_H2O = URIRef("http://qudt.org/vocab/unit/FT_H2O")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    FT3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT3-PER-DEG_F")
    TON_Metric_PER_M3_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3-K")
    REM = URIRef("http://qudt.org/vocab/unit/REM")
    A_PER_M2_K2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2-K2")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    KiloGM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-BAR")
    WB_M = URIRef("http://qudt.org/vocab/unit/WB-M")
    GM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-BAR")
    DEG_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-MIN")
    LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN")
    PK_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-DAY")
    DEG_C_GROWING_CEREAL_DAY = URIRef("http://qudt.org/vocab/unit/DEG_C_GROWING_CEREAL-DAY")
    KiloC = URIRef("http://qudt.org/vocab/unit/KiloC")
    PERCENT_PER_PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-PERCENT")
    MicroCi = URIRef("http://qudt.org/vocab/unit/MicroCi")
    M2_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-K")
    SLUG_PER_FT3 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT3")
    DEG_C_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-MIN")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    ERG_CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-CentiM2-PER-GM")
    LUX_HR = URIRef("http://qudt.org/vocab/unit/LUX-HR")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    AC_FT = URIRef("http://qudt.org/vocab/unit/AC-FT")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    N = URIRef("http://qudt.org/vocab/unit/N")
    C_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM2")
    H_PER_M = URIRef("http://qudt.org/vocab/unit/H-PER-M")
    KiloGM_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MOL")
    OZ_HR_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-FT3")
    LB_IN = URIRef("http://qudt.org/vocab/unit/LB-IN")
    ExaJ = URIRef("http://qudt.org/vocab/unit/ExaJ")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    TON = URIRef("http://qudt.org/vocab/unit/TON")
    J_PER_M3_K = URIRef("http://qudt.org/vocab/unit/J-PER-M3-K")
    PPT = URIRef("http://qudt.org/vocab/unit/PPT")
    PicoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L")
    OZ_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN3")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    MicroW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroW-PER-M2")
    PINT_UK = URIRef("http://qudt.org/vocab/unit/PINT_UK")
    MilliGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-GM")
    DeciB_A = URIRef("http://qudt.org/vocab/unit/DeciB_A")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    CentiM3_PER_HR_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR-K")
    PT = URIRef("http://qudt.org/vocab/unit/PT")
    N_CentiM = URIRef("http://qudt.org/vocab/unit/N-CentiM")
    DeciB_C = URIRef("http://qudt.org/vocab/unit/DeciB_C")
    GM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-M2-DAY")
    REV_PER_SEC = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC")
    DeciB_Z = URIRef("http://qudt.org/vocab/unit/DeciB_Z")
    CentiL = URIRef("http://qudt.org/vocab/unit/CentiL")
    KiloCAL_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-HR")
    KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloMOL")
    M2_PER_SR_J = URIRef("http://qudt.org/vocab/unit/M2-PER-SR-J")
    M3_PER_MIN = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    KiloGM_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-MilliM2")
    MicroGM_PER_L = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L")
    KiloL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloL-PER-HR")
    MilliV_PER_V = URIRef("http://qudt.org/vocab/unit/MilliV-PER-V")
    MegaV_A = URIRef("http://qudt.org/vocab/unit/MegaV-A")
    MI_PER_HR = URIRef("http://qudt.org/vocab/unit/MI-PER-HR")
    KiloLB_F_FT_PER_A = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-A")
    V_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Ab-PER-CentiM")
    GigaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-SEC")
    NanoMOL_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L-DAY")
    NUM_PER_CentiM_KiloYR = URIRef("http://qudt.org/vocab/unit/NUM-PER-CentiM-KiloYR")
    PERCENT_PER_DecaKiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaKiloCount")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    DecaM = URIRef("http://qudt.org/vocab/unit/DecaM")
    KiloGM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-K")
    M2_PER_KiloW = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloW")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    FT_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT-PER-DAY")
    MicroM2 = URIRef("http://qudt.org/vocab/unit/MicroM2")
    FR = URIRef("http://qudt.org/vocab/unit/FR")
    LB_MOL = URIRef("http://qudt.org/vocab/unit/LB-MOL")
    PER_WB = URIRef("http://qudt.org/vocab/unit/PER-WB")
    KiloBQ = URIRef("http://qudt.org/vocab/unit/KiloBQ")
    BTU_IT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC")
    KiloMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-KiloGM")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    PER_MicroMOL_L = URIRef("http://qudt.org/vocab/unit/PER-MicroMOL-L")
    CentiN_M = URIRef("http://qudt.org/vocab/unit/CentiN-M")
    PER_H = URIRef("http://qudt.org/vocab/unit/PER-H")
    CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-GM")
    GI_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_US-PER-DAY")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    PERCENT_RH = URIRef("http://qudt.org/vocab/unit/PERCENT_RH")
    GM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3")
    DEG_F_SEC_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-SEC-PER-BTU_TH")
    SV_PER_MIN = URIRef("http://qudt.org/vocab/unit/SV-PER-MIN")
    KiloBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT")
    PicoPA = URIRef("http://qudt.org/vocab/unit/PicoPA")
    CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-SEC")
    FT_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-PER-HR")
    GM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN-K")
    MilliGM_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-HR")
    MilliJ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-GM")
    LB_SEC_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-YD3")
    MegaA = URIRef("http://qudt.org/vocab/unit/MegaA")
    GM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN-K")
    KiloWB_PER_M = URIRef("http://qudt.org/vocab/unit/KiloWB-PER-M")
    PA_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC2")
    IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC")
    IN_PDL = URIRef("http://qudt.org/vocab/unit/IN-PDL")
    A_Ab = URIRef("http://qudt.org/vocab/unit/A_Ab")
    KiloGM_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MOL")
    PER_YD3 = URIRef("http://qudt.org/vocab/unit/PER-YD3")
    LB_F_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-FT2")
    MilliV_PER_M = URIRef("http://qudt.org/vocab/unit/MilliV-PER-M")
    KN_PER_SEC = URIRef("http://qudt.org/vocab/unit/KN-PER-SEC")
    MilliCD = URIRef("http://qudt.org/vocab/unit/MilliCD")
    KiloGM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-K")
    PDL_IN = URIRef("http://qudt.org/vocab/unit/PDL-IN")
    J_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-M2-PER-KiloGM")
    TONNE_PER_HR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR")
    Debye = URIRef("http://qudt.org/vocab/unit/Debye")
    KiloGM_PER_M_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC")
    LUX_HR = URIRef("http://qudt.org/vocab/unit/LUX-HR")
    LB_F_PER_LB = URIRef("http://qudt.org/vocab/unit/LB_F-PER-LB")
    FA = URIRef("http://qudt.org/vocab/unit/FA")
    Flight = URIRef("http://qudt.org/vocab/unit/Flight")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    PetaFLOPS = URIRef("http://qudt.org/vocab/unit/PetaFLOPS")
    OZ_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_US")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    BIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/BIT-PER-M2")
    GM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-K")
    MilliGM_PER_M3_PA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-PA-SEC")
    MilliGM_PER_M3_PA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-PA-SEC")
    Hundredweight_US = URIRef("http://qudt.org/vocab/unit/Hundredweight_US")
    K_PER_T = URIRef("http://qudt.org/vocab/unit/K-PER-T")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    V_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/V-A_Reactive-HR")
    MilliC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M2")
    PA2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA2-PER-SEC2")
    BTU_TH_PER_FT2_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-MIN")
    FT_LB_F_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2-SEC")
    DeciM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-SEC")
    N = URIRef("http://qudt.org/vocab/unit/N")
    ERG_PER_G = URIRef("http://qudt.org/vocab/unit/ERG-PER-G")
    IN_PER_2PiRAD = URIRef("http://qudt.org/vocab/unit/IN-PER-2PiRAD")
    A_PER_K = URIRef("http://qudt.org/vocab/unit/A-PER-K")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    S_Stat = URIRef("http://qudt.org/vocab/unit/S_Stat")
    KiloGM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MilliM")
    GM_SEC_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M3-CentiM3")
    PERCENT_MIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-M3")
    L_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/L-PER-KiloGM")
    GAUGE_FR = URIRef("http://qudt.org/vocab/unit/GAUGE_FR")
    H_Ab = URIRef("http://qudt.org/vocab/unit/H_Ab")
    SLUG_PER_MIN = URIRef("http://qudt.org/vocab/unit/SLUG-PER-MIN")
    MOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-SEC")
    KiloGM_M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M2-PER-SEC")
    BTU_TH_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2")
    MegaN_M = URIRef("http://qudt.org/vocab/unit/MegaN-M")
    MilliR = URIRef("http://qudt.org/vocab/unit/MilliR")
    NanoW = URIRef("http://qudt.org/vocab/unit/NanoW")
    KiloGM_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-M2")
    KibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M")
    YR = URIRef("http://qudt.org/vocab/unit/YR")
    KiloCAL_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL")
    MOL_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-K")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    MicroC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M2")
    K_PER_BAR = URIRef("http://qudt.org/vocab/unit/K-PER-BAR")
    MicroC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M3")
    MilliV_PER_M = URIRef("http://qudt.org/vocab/unit/MilliV-PER-M")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    QUAD = URIRef("http://qudt.org/vocab/unit/QUAD")
    M2_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-V-SEC")
    MicroC = URIRef("http://qudt.org/vocab/unit/MicroC")
    FT_H2O = URIRef("http://qudt.org/vocab/unit/FT_H2O")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    PERCENT_SEC_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-GAL_US")
    NanoSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-SEC")
    FM = URIRef("http://qudt.org/vocab/unit/FM")
    PER_J_M3 = URIRef("http://qudt.org/vocab/unit/PER-J-M3")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    KiloGM_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-BAR")
    MegaW = URIRef("http://qudt.org/vocab/unit/MegaW")
    KiloL = URIRef("http://qudt.org/vocab/unit/KiloL")
    GAL_US_DRY = URIRef("http://qudt.org/vocab/unit/GAL_US_DRY")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    PA_SEC_PER_K = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-K")
    TORR = URIRef("http://qudt.org/vocab/unit/TORR")
    BBL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-DAY")
    MilliGM_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-HR")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    Z = URIRef("http://qudt.org/vocab/unit/Z")
    DEG_F_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-HR")
    PINT = URIRef("http://qudt.org/vocab/unit/PINT")
    MOL_LB_PER_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-LB")
    MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/MOL-DEG_C")
    OZ_PER_YD2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD2")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    ATM_T_PER_M = URIRef("http://qudt.org/vocab/unit/ATM_T-PER-M")
    BTU_IT_IN_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-HR-FT2-DEG_F")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    DecaL = URIRef("http://qudt.org/vocab/unit/DecaL")
    PicoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/PicoFARAD-PER-M")
    LB_SEC_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-FT3")
    PetaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/PetaJ-PER-SEC")
    YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD3-PER-SEC")
    GigaV = URIRef("http://qudt.org/vocab/unit/GigaV")
    PERCENT_RH = URIRef("http://qudt.org/vocab/unit/PERCENT_RH")
    MilliM_PER_DEG_C_M = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DEG_C-M")
    KiloGM_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-M2")
    KiloGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN")
    CH = URIRef("http://qudt.org/vocab/unit/CH")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    KiloGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY")
    FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/FT2-PER-BTU_IT-IN")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    R = URIRef("http://qudt.org/vocab/unit/R")
    MilliKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MilliKAT-PER-L")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    MilliGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DeciL")
    PERCENT_FT_SEC_PER_LB = URIRef("http://qudt.org/vocab/unit/PERCENT-FT-SEC-PER-LB")
    ATM_M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/ATM-M3-PER-MOL")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    LB_F_PER_LB = URIRef("http://qudt.org/vocab/unit/LB_F-PER-LB")
    W = URIRef("http://qudt.org/vocab/unit/W")
    MegaJ_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M3")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    PDL = URIRef("http://qudt.org/vocab/unit/PDL")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    PlanckPower = URIRef("http://qudt.org/vocab/unit/PlanckPower")
    DEG_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC")
    ERG_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM-SEC")
    GigaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-HR")
    KN = URIRef("http://qudt.org/vocab/unit/KN")
    YR = URIRef("http://qudt.org/vocab/unit/YR")
    KiloPA_A = URIRef("http://qudt.org/vocab/unit/KiloPA_A")
    N_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-M-PER-M2")
    DecaL = URIRef("http://qudt.org/vocab/unit/DecaL")
    C_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-CentiM2")
    SH = URIRef("http://qudt.org/vocab/unit/SH")
    KiloGM_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MOL")
    MilliGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MilliL")
    Pennyweight = URIRef("http://qudt.org/vocab/unit/Pennyweight")
    HR_Sidereal = URIRef("http://qudt.org/vocab/unit/HR_Sidereal")
    GigaBasePair = URIRef("http://qudt.org/vocab/unit/GigaBasePair")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    MilliGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-GM")
    N_M_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-M")
    BTU_TH_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-HR-DEG_F")
    KiloGM_PER_J = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-J")
    KiloJ = URIRef("http://qudt.org/vocab/unit/KiloJ")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    CentiPOISE_PER_K = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-K")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    HectoC = URIRef("http://qudt.org/vocab/unit/HectoC")
    H_PER_M = URIRef("http://qudt.org/vocab/unit/H-PER-M")
    MilliTORR = URIRef("http://qudt.org/vocab/unit/MilliTORR")
    OHM_Stat = URIRef("http://qudt.org/vocab/unit/OHM_Stat")
    KiloGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-BAR")
    PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PER-CentiM3")
    DecaC = URIRef("http://qudt.org/vocab/unit/DecaC")
    MilliGM_SEC_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M6")
    FBM = URIRef("http://qudt.org/vocab/unit/FBM")
    FT_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT-PER-DAY")
    PA_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M")
    KiloCAL_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-HR")
    MX = URIRef("http://qudt.org/vocab/unit/MX")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    NanoMOL_PER_CentiM3_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-CentiM3-HR")
    M2_PER_J = URIRef("http://qudt.org/vocab/unit/M2-PER-J")
    LB_PER_HR_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-HR-PSI")
    J_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2")
    MicroGM_PER_IN2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-IN2")
    MicroGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-KiloGM")
    MicroRAD = URIRef("http://qudt.org/vocab/unit/MicroRAD")
    AU = URIRef("http://qudt.org/vocab/unit/AU")
    MicroMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM")
    MegaA = URIRef("http://qudt.org/vocab/unit/MegaA")
    QT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-MIN")
    KiloHZ_M = URIRef("http://qudt.org/vocab/unit/KiloHZ-M")
    LB_HR_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-YD3")
    PH = URIRef("http://qudt.org/vocab/unit/PH")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    CentiM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN")
    PINT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-HR")
    MegaOHM_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-M")
    CH = URIRef("http://qudt.org/vocab/unit/CH")
    N_PER_CentiM = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM")
    OZ_VOL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-HR")
    TORR = URIRef("http://qudt.org/vocab/unit/TORR")
    BBL_UK_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-SEC")
    BTU_TH_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-SEC-DEG_F")
    KN_PER_SEC = URIRef("http://qudt.org/vocab/unit/KN-PER-SEC")
    NUM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/NUM-PER-M2-DAY")
    BTU_TH_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-SEC-DEG_F")
    OZ_F_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ_F-PER-IN3")
    GAL_US_DRY = URIRef("http://qudt.org/vocab/unit/GAL_US_DRY")
    KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-SEC2")
    MicroGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-BAR")
    MilliGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-GM")
    MilliGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-SEC")
    BAN = URIRef("http://qudt.org/vocab/unit/BAN")
    ExaV_A = URIRef("http://qudt.org/vocab/unit/ExaV-A")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    RAD_PER_HR = URIRef("http://qudt.org/vocab/unit/RAD-PER-HR")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    KiloPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-BAR")
    MicroBQ = URIRef("http://qudt.org/vocab/unit/MicroBQ")
    PlanckCurrentDensity = URIRef("http://qudt.org/vocab/unit/PlanckCurrentDensity")
    J_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K")
    M2_HZ4 = URIRef("http://qudt.org/vocab/unit/M2-HZ4")
    LB_MIN_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-GAL_UK")
    OHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/OHM-PER-BAR")
    BU_UK = URIRef("http://qudt.org/vocab/unit/BU_UK")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    ANGSTROM = URIRef("http://qudt.org/vocab/unit/ANGSTROM")
    KiloEV_PER_MicroM = URIRef("http://qudt.org/vocab/unit/KiloEV-PER-MicroM")
    KiloV = URIRef("http://qudt.org/vocab/unit/KiloV")
    DEG_C_PER_YR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-YR")
    HectoPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-M3-PER-SEC")
    NanoMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    QT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-HR")
    MicroM_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/MicroM-PER-L-DAY")
    FT3_PER_HR = URIRef("http://qudt.org/vocab/unit/FT3-PER-HR")
    REM = URIRef("http://qudt.org/vocab/unit/REM")
    N = URIRef("http://qudt.org/vocab/unit/N")
    PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PER-M3-SEC")
    BTU_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC")
    MilliL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M3")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    HART = URIRef("http://qudt.org/vocab/unit/HART")
    BTU_MEAN = URIRef("http://qudt.org/vocab/unit/BTU_MEAN")
    KiloGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-SEC")
    MegaHZ_M = URIRef("http://qudt.org/vocab/unit/MegaHZ-M")
    FemtoL = URIRef("http://qudt.org/vocab/unit/FemtoL")
    L_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-M2")
    GAL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-MIN")
    MicroGM_PER_CentiM2_WK = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2-WK")
    SLUG_PER_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-SEC")
    PK_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-DAY")
    REV_PER_SEC = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC")
    OZ_FT_HR_PER_IN3_LB = URIRef("http://qudt.org/vocab/unit/OZ-FT-HR-PER-IN3-LB")
    MOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3")
    DYN_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM3")
    SEC_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-FT2")
    NAT_PER_SEC = URIRef("http://qudt.org/vocab/unit/NAT-PER-SEC")
    MilliL = URIRef("http://qudt.org/vocab/unit/MilliL")
    MOL_PER_L_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-L-K")
    KiloPA_A = URIRef("http://qudt.org/vocab/unit/KiloPA_A")
    BAN = URIRef("http://qudt.org/vocab/unit/BAN")
    BTU_IT_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT3")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    LB_MIN_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-GAL_UK")
    M2_PER_SR_J = URIRef("http://qudt.org/vocab/unit/M2-PER-SR-J")
    BTU_TH_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-SEC-DEG_F")
    K_PER_BAR = URIRef("http://qudt.org/vocab/unit/K-PER-BAR")
    MilliGM_SEC_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M6")
    Hundredweight_UK = URIRef("http://qudt.org/vocab/unit/Hundredweight_UK")
    HP_Metric = URIRef("http://qudt.org/vocab/unit/HP_Metric")
    KiloGM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-FT2")
    MilliMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2-DAY")
    PERMITTIVITY_REL = URIRef("http://qudt.org/vocab/unit/PERMITTIVITY_REL")
    MilliMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3")
    KiloOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-BAR")
    AU = URIRef("http://qudt.org/vocab/unit/AU")
    HectoPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-M3-PER-SEC")
    GM_PER_DeciM3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3-K")
    OHM_CIRC_MIL_PER_FT = URIRef("http://qudt.org/vocab/unit/OHM_CIRC-MIL-PER-FT")
    MilliL_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-K")
    PARSEC = URIRef("http://qudt.org/vocab/unit/PARSEC")
    FT_LB_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-SEC")
    IN_HG_32DEG_F = URIRef("http://qudt.org/vocab/unit/IN_HG_32DEG_F")
    NanoGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-SEC")
    CD_PER_IN2 = URIRef("http://qudt.org/vocab/unit/CD-PER-IN2")
    CD_PER_M2 = URIRef("http://qudt.org/vocab/unit/CD-PER-M2")
    MilliA_SEC = URIRef("http://qudt.org/vocab/unit/MilliA-SEC")
    FA = URIRef("http://qudt.org/vocab/unit/FA")
    PHOT = URIRef("http://qudt.org/vocab/unit/PHOT")
    MegaTONNE = URIRef("http://qudt.org/vocab/unit/MegaTONNE")
    PER_SEC_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR")
    SLUG_PER_HR = URIRef("http://qudt.org/vocab/unit/SLUG-PER-HR")
    TeraBQ = URIRef("http://qudt.org/vocab/unit/TeraBQ")
    TONNE_PER_HR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    ExaW = URIRef("http://qudt.org/vocab/unit/ExaW")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    PERCENT_HR_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-FT3")
    PicoM = URIRef("http://qudt.org/vocab/unit/PicoM")
    ERG = URIRef("http://qudt.org/vocab/unit/ERG")
    MilliBQ = URIRef("http://qudt.org/vocab/unit/MilliBQ")
    MicroRAD = URIRef("http://qudt.org/vocab/unit/MicroRAD")
    MilliT = URIRef("http://qudt.org/vocab/unit/MilliT")
    CentiL = URIRef("http://qudt.org/vocab/unit/CentiL")
    MicroW = URIRef("http://qudt.org/vocab/unit/MicroW")
    KiloLB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-IN2")
    HART_PER_SEC = URIRef("http://qudt.org/vocab/unit/HART-PER-SEC")
    MicroMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2")
    GM_HR_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L-CentiM3")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    DeciTONNE = URIRef("http://qudt.org/vocab/unit/DeciTONNE")
    IN_PER_PSI = URIRef("http://qudt.org/vocab/unit/IN-PER-PSI")
    T = URIRef("http://qudt.org/vocab/unit/T")
    MicroC = URIRef("http://qudt.org/vocab/unit/MicroC")
    PER_MO = URIRef("http://qudt.org/vocab/unit/PER-MO")
    A_Ab = URIRef("http://qudt.org/vocab/unit/A_Ab")
    CH = URIRef("http://qudt.org/vocab/unit/CH")
    DEG_R_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-HR")
    KiloOHM_M = URIRef("http://qudt.org/vocab/unit/KiloOHM-M")
    DEG_F_HR_FT2_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT")
    HR_FT2 = URIRef("http://qudt.org/vocab/unit/HR-FT2")
    L_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/L-PER-KiloGM")
    KiloGM_PER_M_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC")
    MicroN = URIRef("http://qudt.org/vocab/unit/MicroN")
    KiloGM_M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M2-PER-SEC")
    DeciM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-KiloGM")
    WB_M = URIRef("http://qudt.org/vocab/unit/WB-M")
    GibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M2")
    GI_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_US-PER-MIN")
    KiloBQ = URIRef("http://qudt.org/vocab/unit/KiloBQ")
    MilliM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM2-PER-SEC")
    KiloN_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-DEG")
    IU_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliGM")
    KiloCAL_Mean = URIRef("http://qudt.org/vocab/unit/KiloCAL_Mean")
    KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloMOL")
    KiloGM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3")
    KiloGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-BAR")
    BAUD = URIRef("http://qudt.org/vocab/unit/BAUD")
    DEGREE_TWADDELL = URIRef("http://qudt.org/vocab/unit/DEGREE_TWADDELL")
    OZ_SEC_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-YD3")
    DeciM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-KiloGM")
    MilliL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN")
    OHM_PER_K = URIRef("http://qudt.org/vocab/unit/OHM-PER-K")
    MicroGM = URIRef("http://qudt.org/vocab/unit/MicroGM")
    NanoGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DAY")
    BTU_IT_PER_SEC_FT_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT-DEG_R")
    MegaDOLLAR_US_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MegaDOLLAR_US-PER-FLIGHT")
    BTU_TH_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-HR-DEG_F")
    KiloGM_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-M2")
    LB_PER_FT_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-HR")
    V_PER_M2 = URIRef("http://qudt.org/vocab/unit/V-PER-M2")
    LB = URIRef("http://qudt.org/vocab/unit/LB")
    PER_M_SEC = URIRef("http://qudt.org/vocab/unit/PER-M-SEC")
    PPT = URIRef("http://qudt.org/vocab/unit/PPT")
    M3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC2")
    MilliN_PER_M = URIRef("http://qudt.org/vocab/unit/MilliN-PER-M")
    PicoV = URIRef("http://qudt.org/vocab/unit/PicoV")
    QT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-SEC")
    PPTM_PER_K = URIRef("http://qudt.org/vocab/unit/PPTM-PER-K")
    A = URIRef("http://qudt.org/vocab/unit/A")
    HZ_PER_V = URIRef("http://qudt.org/vocab/unit/HZ-PER-V")
    GM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-BAR")
    LB_PER_MIN_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN-DEG_F")
    M_PER_BAR = URIRef("http://qudt.org/vocab/unit/M-PER-BAR")
    IN_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-DEG_F")
    NanoA_PER_K = URIRef("http://qudt.org/vocab/unit/NanoA-PER-K")
    KiloL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloL-PER-HR")
    PCA = URIRef("http://qudt.org/vocab/unit/PCA")
    POISE = URIRef("http://qudt.org/vocab/unit/POISE")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    UnitPole = URIRef("http://qudt.org/vocab/unit/UnitPole")
    L_PER_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-SEC")
    W_PER_IN2 = URIRef("http://qudt.org/vocab/unit/W-PER-IN2")
    FARAD_Stat = URIRef("http://qudt.org/vocab/unit/FARAD_Stat")
    FT_LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2")
    ERG_CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-CentiM2-PER-GM")
    NanoL = URIRef("http://qudt.org/vocab/unit/NanoL")
    CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    MegaV = URIRef("http://qudt.org/vocab/unit/MegaV")
    M3_PER_K = URIRef("http://qudt.org/vocab/unit/M3-PER-K")
    GM_HR_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L2")
    CentiST = URIRef("http://qudt.org/vocab/unit/CentiST")
    LB_IN2 = URIRef("http://qudt.org/vocab/unit/LB-IN2")
    MilliRAD_R = URIRef("http://qudt.org/vocab/unit/MilliRAD_R")
    YottaC = URIRef("http://qudt.org/vocab/unit/YottaC")
    N_M2_PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/N-M2-PER-KiloGM2")
    MilliW_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM")
    BIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BIT-PER-SEC")
    TON_SHORT = URIRef("http://qudt.org/vocab/unit/TON_SHORT")
    MilliL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN")
    BEAT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BEAT-PER-MIN")
    BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN")
    MicroN = URIRef("http://qudt.org/vocab/unit/MicroN")
    A_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM2")
    MHO_Stat = URIRef("http://qudt.org/vocab/unit/MHO_Stat")
    C_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM-SEC")
    DeciSEC = URIRef("http://qudt.org/vocab/unit/DeciSEC")
    KibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M2")
    MegaJ_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M3")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    C3_M_PER_J2 = URIRef("http://qudt.org/vocab/unit/C3-M-PER-J2")
    KiloGM_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-MilliM2")
    MegaJ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-K")
    KiloLB_F = URIRef("http://qudt.org/vocab/unit/KiloLB_F")
    W_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-PER-KiloGM")
    N_M_PER_MIN_Angle = URIRef("http://qudt.org/vocab/unit/N-M-PER-MIN_Angle")
    FT_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC-PSI")
    BTU_IT_PER_LB_F_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_F")
    TONNE_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY-K")
    MicroPA = URIRef("http://qudt.org/vocab/unit/MicroPA")
    NanoSV_PER_HR = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-HR")
    AttoSEC = URIRef("http://qudt.org/vocab/unit/AttoSEC")
    PERCENT_SEC_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-GAL_UK")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    MilliN_PER_M = URIRef("http://qudt.org/vocab/unit/MilliN-PER-M")
    MilliGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-KiloGM")
    ANGSTROM = URIRef("http://qudt.org/vocab/unit/ANGSTROM")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    MilliGM_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-HR")
    B = URIRef("http://qudt.org/vocab/unit/B")
    MegaLB_F = URIRef("http://qudt.org/vocab/unit/MegaLB_F")
    OZ_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_US")
    MilliL_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-BAR")
    HectoM = URIRef("http://qudt.org/vocab/unit/HectoM")
    OHM_PER_MI = URIRef("http://qudt.org/vocab/unit/OHM-PER-MI")
    NUM_PER_NanoL = URIRef("http://qudt.org/vocab/unit/NUM-PER-NanoL")
    DRAM_US = URIRef("http://qudt.org/vocab/unit/DRAM_US")
    KN = URIRef("http://qudt.org/vocab/unit/KN")
    T = URIRef("http://qudt.org/vocab/unit/T")
    POISE = URIRef("http://qudt.org/vocab/unit/POISE")
    V_PER_PA = URIRef("http://qudt.org/vocab/unit/V-PER-PA")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    A_PER_K = URIRef("http://qudt.org/vocab/unit/A-PER-K")
    MegaS = URIRef("http://qudt.org/vocab/unit/MegaS")
    BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN")
    KiloGM_PER_M_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC2")
    M3_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-K")
    NUM_PER_HA = URIRef("http://qudt.org/vocab/unit/NUM-PER-HA")
    DEG_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-MIN")
    PA_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M")
    PicoMOL_PER_M_W_SEC = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M-W-SEC")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    LB_PER_FT3_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3-DEG_F")
    MOL_PER_M2_SEC_SR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-SR")
    LB_HR_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK2")
    J_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2")
    M_PER_MIN = URIRef("http://qudt.org/vocab/unit/M-PER-MIN")
    MicroL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroL-PER-L")
    J_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K")
    MegaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M3")
    NanoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-KiloGM")
    THERM_US = URIRef("http://qudt.org/vocab/unit/THERM_US")
    PER_M2 = URIRef("http://qudt.org/vocab/unit/PER-M2")
    MilliGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-GM")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    DeciM2 = URIRef("http://qudt.org/vocab/unit/DeciM2")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    PERCENT_SEC_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-GAL_US")
    MegaS_PER_M = URIRef("http://qudt.org/vocab/unit/MegaS-PER-M")
    BIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/BIT-PER-M2")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    CAL_TH_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM-SEC-DEG_C")
    A_M2_PER_J_SEC = URIRef("http://qudt.org/vocab/unit/A-M2-PER-J-SEC")
    TONNE_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC-BAR")
    DRAM_US = URIRef("http://qudt.org/vocab/unit/DRAM_US")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    ATM_M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/ATM-M3-PER-MOL")
    QT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-DAY")
    L_PER_K = URIRef("http://qudt.org/vocab/unit/L-PER-K")
    MicroMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-SEC")
    M2_K = URIRef("http://qudt.org/vocab/unit/M2-K")
    H_PER_OHM = URIRef("http://qudt.org/vocab/unit/H-PER-OHM")
    MicroV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/MicroV-A_Reactive-PER-K")
    CP = URIRef("http://qudt.org/vocab/unit/CP")
    KiloLB_F = URIRef("http://qudt.org/vocab/unit/KiloLB_F")
    MilliM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-HR")
    KiloGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-BAR")
    A_HR_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-HR-PER-DEG_C")
    KiloW = URIRef("http://qudt.org/vocab/unit/KiloW")
    LB_DEG_R = URIRef("http://qudt.org/vocab/unit/LB-DEG_R")
    HectoC = URIRef("http://qudt.org/vocab/unit/HectoC")
    M_K = URIRef("http://qudt.org/vocab/unit/M-K")
    MilliA_PER_K = URIRef("http://qudt.org/vocab/unit/MilliA-PER-K")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    KiloGM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-FT2")
    PER_BAR = URIRef("http://qudt.org/vocab/unit/PER-BAR")
    M3_PER_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-M2")
    GM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/GM-PER-HR-K")
    M_PER_HR = URIRef("http://qudt.org/vocab/unit/M-PER-HR")
    DeciB_M = URIRef("http://qudt.org/vocab/unit/DeciB_M")
    FT3_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT3-PER-SEC")
    KiloLB_F_FT_PER_LB = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-LB")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    CentiPOISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-BAR")
    L = URIRef("http://qudt.org/vocab/unit/L")
    ROD = URIRef("http://qudt.org/vocab/unit/ROD")
    MOL_PER_L = URIRef("http://qudt.org/vocab/unit/MOL-PER-L")
    MO_Synodic = URIRef("http://qudt.org/vocab/unit/MO_Synodic")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    SUSCEPTIBILITY_MAG = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_MAG")
    PER_WK = URIRef("http://qudt.org/vocab/unit/PER-WK")
    MegaPA_M0dot5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0dot5")
    FT_LB_F = URIRef("http://qudt.org/vocab/unit/FT-LB_F")
    FT_PER_PSI = URIRef("http://qudt.org/vocab/unit/FT-PER-PSI")
    LB_MIN_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-YD3")
    OZ_MIN_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN6")
    KiloGM_PER_L_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-K")
    MegaBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaBTU_IT-PER-HR")
    W_PER_M2_K4 = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K4")
    LB_HR_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-FT3")
    MI_PER_HR = URIRef("http://qudt.org/vocab/unit/MI-PER-HR")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    LB_SEC_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-IN3")
    TON_LONG = URIRef("http://qudt.org/vocab/unit/TON_LONG")
    PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/PER-M2-SEC")
    KiloM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM2-PER-SEC2")
    KiloGM_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-M2")
    BTU_IT_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT3")
    BTU_TH_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-FT2-HR-DEG_F")
    MilliA = URIRef("http://qudt.org/vocab/unit/MilliA")
    CAL_TH_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2")
    MegaC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M2")
    A = URIRef("http://qudt.org/vocab/unit/A")
    KAT_PER_M3 = URIRef("http://qudt.org/vocab/unit/KAT-PER-M3")
    KIP_F = URIRef("http://qudt.org/vocab/unit/KIP_F")
    PER_MegaPA = URIRef("http://qudt.org/vocab/unit/PER-MegaPA")
    M3_PER_C = URIRef("http://qudt.org/vocab/unit/M3-PER-C")
    M_PER_HR = URIRef("http://qudt.org/vocab/unit/M-PER-HR")
    CentiPOISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-BAR")
    BTU_TH_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    CentiM3_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY-BAR")
    KiloGM_PER_MegaBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MegaBTU_IT")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    L_PER_HR = URIRef("http://qudt.org/vocab/unit/L-PER-HR")
    C_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM3")
    MicroH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-KiloOHM")
    NanoM_PER_MilliM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-MilliM-MegaPA")
    K2 = URIRef("http://qudt.org/vocab/unit/K2")
    KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A-HR")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    ERG_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM2-SEC")
    PSI_PER_PSI = URIRef("http://qudt.org/vocab/unit/PSI-PER-PSI")
    PER_YR = URIRef("http://qudt.org/vocab/unit/PER-YR")
    PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PER-SEC2")
    LB_SEC_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-GAL_UK")
    MicroW = URIRef("http://qudt.org/vocab/unit/MicroW")
    FT_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-PER-HR")
    BTU_IT_PER_MOL_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB")
    PERCENT_MIN_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-YD3")
    M3_PER_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-BAR")
    GigaW = URIRef("http://qudt.org/vocab/unit/GigaW")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    QT_UK = URIRef("http://qudt.org/vocab/unit/QT_UK")
    CentiM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    GM_PER_M = URIRef("http://qudt.org/vocab/unit/GM-PER-M")
    LB_PER_FT_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-DAY")
    B = URIRef("http://qudt.org/vocab/unit/B")
    FT_PDL = URIRef("http://qudt.org/vocab/unit/FT-PDL")
    H_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/H_Stat-PER-CentiM")
    GM_HR_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M3-CentiM3")
    KiloGM_M = URIRef("http://qudt.org/vocab/unit/KiloGM-M")
    NanoS = URIRef("http://qudt.org/vocab/unit/NanoS")
    PSI = URIRef("http://qudt.org/vocab/unit/PSI")
    NanoMOL_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL")
    MIL = URIRef("http://qudt.org/vocab/unit/MIL")
    SEC_PER_M = URIRef("http://qudt.org/vocab/unit/SEC-PER-M")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    MOHM = URIRef("http://qudt.org/vocab/unit/MOHM")
    PicoGM = URIRef("http://qudt.org/vocab/unit/PicoGM")
    PA_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC")
    MilliR_man = URIRef("http://qudt.org/vocab/unit/MilliR_man")
    W_PER_SR = URIRef("http://qudt.org/vocab/unit/W-PER-SR")
    IN3_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN3-PER-MIN")
    KiloBQ = URIRef("http://qudt.org/vocab/unit/KiloBQ")
    MicroMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2")
    GRAIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-M3")
    AttoFARAD = URIRef("http://qudt.org/vocab/unit/AttoFARAD")
    MicroGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-GM")
    PER_LB = URIRef("http://qudt.org/vocab/unit/PER-LB")
    POISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/POISE-PER-BAR")
    DeciBAR = URIRef("http://qudt.org/vocab/unit/DeciBAR")
    GM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC")
    MOL_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB")
    DEGREE_BRIX = URIRef("http://qudt.org/vocab/unit/DEGREE_BRIX")
    HP = URIRef("http://qudt.org/vocab/unit/HP")
    NanoA = URIRef("http://qudt.org/vocab/unit/NanoA")
    ERLANG = URIRef("http://qudt.org/vocab/unit/ERLANG")
    N = URIRef("http://qudt.org/vocab/unit/N")
    S_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/S-M2-PER-MOL")
    CentiPOISE_PER_K = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-K")
    HP_Metric = URIRef("http://qudt.org/vocab/unit/HP_Metric")
    J_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2-DAY")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    LB_PER_IN = URIRef("http://qudt.org/vocab/unit/LB-PER-IN")
    PERCENT_MIN_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-FT3")
    BTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR")
    FARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/FARAD-PER-KiloM")
    J_PER_HR = URIRef("http://qudt.org/vocab/unit/J-PER-HR")
    CAL_TH = URIRef("http://qudt.org/vocab/unit/CAL_TH")
    KiloGM_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-M2")
    GM_MIN_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M3-L")
    OERSTED_CentiM = URIRef("http://qudt.org/vocab/unit/OERSTED-CentiM")
    FT_HR_PER_IN3 = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-IN3")
    DeciSEC = URIRef("http://qudt.org/vocab/unit/DeciSEC")
    CH = URIRef("http://qudt.org/vocab/unit/CH")
    MegaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBYTE-PER-SEC")
    IN_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN-PER-MIN")
    CAL_IT_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM-K")
    MicroRAD = URIRef("http://qudt.org/vocab/unit/MicroRAD")
    OZ_PER_FT2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-FT2")
    BTU_TH_PER_FT2_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-HR")
    GRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/GRAY-PER-SEC")
    NP = URIRef("http://qudt.org/vocab/unit/NP")
    IU_PER_MilliL = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliL")
    CentiM_HG = URIRef("http://qudt.org/vocab/unit/CentiM_HG")
    LB_HR_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-IN3")
    DEG_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG-PER-MIN")
    YR = URIRef("http://qudt.org/vocab/unit/YR")
    TeraW_HR = URIRef("http://qudt.org/vocab/unit/TeraW-HR")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    MegaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-M")
    MilliMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-L")
    OZ_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_UK")
    PPT = URIRef("http://qudt.org/vocab/unit/PPT")
    OZ_IN2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/OZ-IN2-PER-IN3-LB_F-SEC")
    J_PER_MOL_K = URIRef("http://qudt.org/vocab/unit/J-PER-MOL-K")
    NanoS_PER_M = URIRef("http://qudt.org/vocab/unit/NanoS-PER-M")
    NanoL = URIRef("http://qudt.org/vocab/unit/NanoL")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    MilliGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY")
    PINT_US_DRY = URIRef("http://qudt.org/vocab/unit/PINT_US_DRY")
    LB_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT2")
    MilliL_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-BAR")
    TON_Metric_PER_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-BAR")
    MegaOHM_KiloM = URIRef("http://qudt.org/vocab/unit/MegaOHM-KiloM")
    GAL_IMP = URIRef("http://qudt.org/vocab/unit/GAL_IMP")
    MilliBQ_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-M2-DAY")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    MilliL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M2-DAY")
    J_PER_MOL_K = URIRef("http://qudt.org/vocab/unit/J-PER-MOL-K")
    TON_Metric_PER_SEC = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC")
    MilliOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-BAR")
    PER_FT3 = URIRef("http://qudt.org/vocab/unit/PER-FT3")
    J_PER_MIN = URIRef("http://qudt.org/vocab/unit/J-PER-MIN")
    MilliGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HA")
    MicroGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M2-DAY")
    PERCENT_SEC_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-YD3")
    MilliGM_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-DAY")
    M2_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-PA")
    NanoM_PER_CentiM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-MegaPA")
    K_PER_T = URIRef("http://qudt.org/vocab/unit/K-PER-T")
    HP_Brake = URIRef("http://qudt.org/vocab/unit/HP_Brake")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    MegaV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive")
    DEG_C_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-HR")
    FRAME_PER_SEC = URIRef("http://qudt.org/vocab/unit/FRAME-PER-SEC")
    C_Stat = URIRef("http://qudt.org/vocab/unit/C_Stat")
    J_M_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-M-PER-MOL")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    TeraJ = URIRef("http://qudt.org/vocab/unit/TeraJ")
    KiloS_PER_M = URIRef("http://qudt.org/vocab/unit/KiloS-PER-M")
    GRAIN = URIRef("http://qudt.org/vocab/unit/GRAIN")
    TON_LONG = URIRef("http://qudt.org/vocab/unit/TON_LONG")
    GigaEV = URIRef("http://qudt.org/vocab/unit/GigaEV")
    PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PER-CentiM3")
    DYN_SEC_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    MI_N = URIRef("http://qudt.org/vocab/unit/MI_N")
    KiloW = URIRef("http://qudt.org/vocab/unit/KiloW")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    MilliL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC")
    QT_US = URIRef("http://qudt.org/vocab/unit/QT_US")
    GM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3-BAR")
    KiloM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM2-PER-SEC2")
    MicroGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-KiloGM")
    DEG_F_SEC_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-SEC-PER-BTU_TH")
    BTU_IT_PER_HR_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_R")
    PK_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-DAY")
    DeciS = URIRef("http://qudt.org/vocab/unit/DeciS")
    DeciM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-M3")
    LM_PER_W = URIRef("http://qudt.org/vocab/unit/LM-PER-W")
    M2_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-K")
    GM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN-BAR")
    NanoC = URIRef("http://qudt.org/vocab/unit/NanoC")
    SH = URIRef("http://qudt.org/vocab/unit/SH")
    PERCENT_PER_HectoBAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-HectoBAR")
    PlanckEnergy = URIRef("http://qudt.org/vocab/unit/PlanckEnergy")
    MebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M")
    LM_SEC = URIRef("http://qudt.org/vocab/unit/LM-SEC")
    CASES_PER_KiloINDIV_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-KiloINDIV-YR")
    DEATHS_PER_1000000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000000I-YR")
    KiloCAL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-MIN")
    LB_PER_FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-LB_F-SEC")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    M_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-K")
    GAL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-HR")
    MilliC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliC-PER-KiloGM")
    N = URIRef("http://qudt.org/vocab/unit/N")
    N_M_PER_M_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-M-RAD")
    TONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-YR")
    W_M_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-M-PER-M2-SR")
    MegaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBYTE-PER-SEC")
    MilliBQ = URIRef("http://qudt.org/vocab/unit/MilliBQ")
    OZ_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_UK")
    MilliA_PER_IN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-IN")
    PER_MilliSEC = URIRef("http://qudt.org/vocab/unit/PER-MilliSEC")
    W_PER_FT2 = URIRef("http://qudt.org/vocab/unit/W-PER-FT2")
    GM_PER_MIN = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    CAL_TH_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM2-K")
    GALILEO = URIRef("http://qudt.org/vocab/unit/GALILEO")
    GM_PER_M3_PA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-PA-SEC")
    GigaC = URIRef("http://qudt.org/vocab/unit/GigaC")
    PERCENT_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEG_C")
    MilliC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M3")
    KiloLB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-FT")
    MilliGAL = URIRef("http://qudt.org/vocab/unit/MilliGAL")
    FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC")
    CentiGRAY = URIRef("http://qudt.org/vocab/unit/CentiGRAY")
    LB_SEC_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-YD3")
    MOL_PER_GM_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-GM-HR")
    CUP_US = URIRef("http://qudt.org/vocab/unit/CUP_US")
    TON_Metric_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    PER_WB = URIRef("http://qudt.org/vocab/unit/PER-WB")
    M3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC2")
    MilliV = URIRef("http://qudt.org/vocab/unit/MilliV")
    RAD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC2")
    MilliN_M = URIRef("http://qudt.org/vocab/unit/MilliN-M")
    OZ_SEC_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-YD3")
    L_PER_MOL = URIRef("http://qudt.org/vocab/unit/L-PER-MOL")
    DeciM2 = URIRef("http://qudt.org/vocab/unit/DeciM2")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloGM-K")
    MOL_PER_M2_SEC_M_SR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-M-SR")
    M3_PER_HR_K = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-K")
    HectoM = URIRef("http://qudt.org/vocab/unit/HectoM")
    M_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-K")
    MilliGM_SEC_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M3-CentiM3")
    GigaBasePair = URIRef("http://qudt.org/vocab/unit/GigaBasePair")
    TON_SHORT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-DEG_F")
    KiloPA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-M")
    K_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PER-SEC")
    PERM_23DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_23DEG_C")
    W_M2 = URIRef("http://qudt.org/vocab/unit/W-M2")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    TeraOHM = URIRef("http://qudt.org/vocab/unit/TeraOHM")
    BTU_IT_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT-PER-FT2-HR-DEG_F")
    L_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-MOL-SEC")
    PER_MIN = URIRef("http://qudt.org/vocab/unit/PER-MIN")
    MicroV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MicroV-A_Reactive")
    PDL_IN = URIRef("http://qudt.org/vocab/unit/PDL-IN")
    GM_PER_MilliL_K = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL-K")
    N_M_PER_W0dot5 = URIRef("http://qudt.org/vocab/unit/N-M-PER-W0dot5")
    DEG_F_HR_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_IT")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    NUM_PER_L = URIRef("http://qudt.org/vocab/unit/NUM-PER-L")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    MOL_PER_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-HR")
    TON_SHIPPING_US = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_US")
    K_PER_W = URIRef("http://qudt.org/vocab/unit/K-PER-W")
    EUR_PER_KiloW_HR = URIRef("http://qudt.org/vocab/unit/EUR-PER-KiloW-HR")
    LB_F_PER_YD = URIRef("http://qudt.org/vocab/unit/LB_F-PER-YD")
    PetaJ = URIRef("http://qudt.org/vocab/unit/PetaJ")
    HZ_M = URIRef("http://qudt.org/vocab/unit/HZ-M")
    MilliMOL_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3-DAY")
    IN_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC2")
    KiloFARAD = URIRef("http://qudt.org/vocab/unit/KiloFARAD")
    N_PER_CentiM = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM")
    MilliGAL = URIRef("http://qudt.org/vocab/unit/MilliGAL")
    LB = URIRef("http://qudt.org/vocab/unit/LB")
    PH = URIRef("http://qudt.org/vocab/unit/PH")
    LB_SEC_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK2")
    Hundredweight_UK = URIRef("http://qudt.org/vocab/unit/Hundredweight_UK")
    M2_K = URIRef("http://qudt.org/vocab/unit/M2-K")
    DEG_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC")
    PER_FT3 = URIRef("http://qudt.org/vocab/unit/PER-FT3")
    MO_MeanGREGORIAN = URIRef("http://qudt.org/vocab/unit/MO_MeanGREGORIAN")
    DecaC = URIRef("http://qudt.org/vocab/unit/DecaC")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    IN_PER_PSI = URIRef("http://qudt.org/vocab/unit/IN-PER-PSI")
    PDL_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/PDL-SEC-PER-IN2")
    IU_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliGM")
    PER_IN2 = URIRef("http://qudt.org/vocab/unit/PER-IN2")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    PER_RAD = URIRef("http://qudt.org/vocab/unit/PER-RAD")
    W_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M2")
    KiloW_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloW-HR-PER-M2")
    MicroSV = URIRef("http://qudt.org/vocab/unit/MicroSV")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    LB_SEC_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-IN3")
    PicoL = URIRef("http://qudt.org/vocab/unit/PicoL")
    MOHM = URIRef("http://qudt.org/vocab/unit/MOHM")
    KiloGM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-CentiM2")
    CAL_TH_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM")
    MicroM_PER_M = URIRef("http://qudt.org/vocab/unit/MicroM-PER-M")
    ARCSEC = URIRef("http://qudt.org/vocab/unit/ARCSEC")
    KiloGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloGM")
    N_PER_MilliM = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM")
    LB_PER_FT_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-MIN")
    DEG_C_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-SEC")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    BTU_TH_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT3")
    KiloGM_PER_M_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC2")
    M_PER_HR = URIRef("http://qudt.org/vocab/unit/M-PER-HR")
    KiloCAL = URIRef("http://qudt.org/vocab/unit/KiloCAL")
    MilliM_PER_YR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-YR")
    AttoA = URIRef("http://qudt.org/vocab/unit/AttoA")
    LB_SEC_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-YD3")
    L_PER_K = URIRef("http://qudt.org/vocab/unit/L-PER-K")
    IN_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC-PSI")
    PER_YD3 = URIRef("http://qudt.org/vocab/unit/PER-YD3")
    MilliW_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM-SR")
    OZ_SEC_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN6")
    MicroCi = URIRef("http://qudt.org/vocab/unit/MicroCi")
    MegaBAR = URIRef("http://qudt.org/vocab/unit/MegaBAR")
    TONNE_PER_MO = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MO")
    DeciSEC = URIRef("http://qudt.org/vocab/unit/DeciSEC")
    MIN_Sidereal = URIRef("http://qudt.org/vocab/unit/MIN_Sidereal")
    GM_PER_HR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR")
    NanoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L")
    CentiM_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-K")
    MegaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M2")
    DYN_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-CentiM")
    MegaV_A = URIRef("http://qudt.org/vocab/unit/MegaV-A")
    CentiM_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-HR")
    DEG_F_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC2")
    THM_US = URIRef("http://qudt.org/vocab/unit/THM_US")
    C_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM3")
    KiloGM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM2")
    BBL_US_DRY = URIRef("http://qudt.org/vocab/unit/BBL_US_DRY")
    GI_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-MIN")
    BU_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-HR")
    TeraBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/TeraBIT-PER-SEC")
    NanoGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2")
    OZ_VOL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-SEC")
    LB_SEC_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-GAL_US")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    J_PER_SEC = URIRef("http://qudt.org/vocab/unit/J-PER-SEC")
    OZ_F = URIRef("http://qudt.org/vocab/unit/OZ_F")
    ARCMIN = URIRef("http://qudt.org/vocab/unit/ARCMIN")
    MegaOHM = URIRef("http://qudt.org/vocab/unit/MegaOHM")
    SLUG_PER_MIN = URIRef("http://qudt.org/vocab/unit/SLUG-PER-MIN")
    WK = URIRef("http://qudt.org/vocab/unit/WK")
    KiloM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM2-PER-SEC2")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    NAT = URIRef("http://qudt.org/vocab/unit/NAT")
    BTU_IT_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_F")
    C_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM-SEC")
    KiloWB = URIRef("http://qudt.org/vocab/unit/KiloWB")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    KiloA = URIRef("http://qudt.org/vocab/unit/KiloA")
    MilliGM_PER_L_PA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-PA-SEC")
    LB_SEC_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT6")
    BU_US = URIRef("http://qudt.org/vocab/unit/BU_US")
    PERCENT_SEC_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-IN3")
    PER_PlanckMass2 = URIRef("http://qudt.org/vocab/unit/PER-PlanckMass2")
    V_PER_MicroSEC = URIRef("http://qudt.org/vocab/unit/V-PER-MicroSEC")
    PER_EV_M3 = URIRef("http://qudt.org/vocab/unit/PER-EV-M3")
    LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    YD2 = URIRef("http://qudt.org/vocab/unit/YD2")
    PER_SEC_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR")
    MilliGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-K")
    F = URIRef("http://qudt.org/vocab/unit/F")
    NanoH_PER_M = URIRef("http://qudt.org/vocab/unit/NanoH-PER-M")
    TONNE_PER_M3 = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    OZ_VOL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-HR")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    A_SEC2 = URIRef("http://qudt.org/vocab/unit/A-SEC2")
    HZ_M = URIRef("http://qudt.org/vocab/unit/HZ-M")
    EV_PER_M = URIRef("http://qudt.org/vocab/unit/EV-PER-M")
    J_PER_KiloGM_K_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-M3")
    LB_HR_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK2")
    MilliW = URIRef("http://qudt.org/vocab/unit/MilliW")
    TONNE_PER_SEC = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC")
    BTU_IT_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT3")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    PicoH = URIRef("http://qudt.org/vocab/unit/PicoH")
    MegaDOLLAR_US_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MegaDOLLAR_US-PER-FLIGHT")
    FARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/FARAD-PER-KiloM")
    KiloSEC = URIRef("http://qudt.org/vocab/unit/KiloSEC")
    TON_Metric_PER_M3 = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3")
    GM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2")
    MilliSV = URIRef("http://qudt.org/vocab/unit/MilliSV")
    PK_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-SEC")
    R_PER_SEC = URIRef("http://qudt.org/vocab/unit/R-PER-SEC")
    GAL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-DAY")
    MicroSEC = URIRef("http://qudt.org/vocab/unit/MicroSEC")
    M2_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-HZ2")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    MegaPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-M3-PER-SEC")
    FT_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC-PSI")
    PERCENT_PER_DEG = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEG")
    PERCENT_PER_KiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-KiloCount")
    MilliL_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-BAR")
    MegaBAR = URIRef("http://qudt.org/vocab/unit/MegaBAR")
    V = URIRef("http://qudt.org/vocab/unit/V")
    POISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/POISE-PER-BAR")
    M_PER_FARAD = URIRef("http://qudt.org/vocab/unit/M-PER-FARAD")
    M_K_PER_W = URIRef("http://qudt.org/vocab/unit/M-K-PER-W")
    KiloMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-SEC")
    HA = URIRef("http://qudt.org/vocab/unit/HA")
    L_PER_K = URIRef("http://qudt.org/vocab/unit/L-PER-K")
    TONNE_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3-BAR")
    MilliGM_SEC_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L-CentiM3")
    MegaGM = URIRef("http://qudt.org/vocab/unit/MegaGM")
    REM_PER_SEC = URIRef("http://qudt.org/vocab/unit/REM-PER-SEC")
    KiloGM_F = URIRef("http://qudt.org/vocab/unit/KiloGM_F")
    MOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MOL-PER-MOL")
    BIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BIT-PER-SEC")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F")
    LB_MIN_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-FT3")
    MilliGM_SEC_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L-CentiM3")
    DEATHS_PER_KiloINDIV_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-KiloINDIV-YR")
    DeciB_M = URIRef("http://qudt.org/vocab/unit/DeciB_M")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    MilliL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M2-DAY")
    TON_Metric = URIRef("http://qudt.org/vocab/unit/TON_Metric")
    MegaPA_PER_K = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-K")
    GRAIN = URIRef("http://qudt.org/vocab/unit/GRAIN")
    M2_PER_K = URIRef("http://qudt.org/vocab/unit/M2-PER-K")
    PDL = URIRef("http://qudt.org/vocab/unit/PDL")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC")
    M_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-PA")
    MilliGM_MIN_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L-CentiM3")
    KiloLB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-IN2")
    MilliM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliM-PER-M")
    C = URIRef("http://qudt.org/vocab/unit/C")
    MESH = URIRef("http://qudt.org/vocab/unit/MESH")
    S = URIRef("http://qudt.org/vocab/unit/S")
    GigaBIT_PER_M = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-M")
    PERM_23DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_23DEG_C")
    MOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC")
    GT = URIRef("http://qudt.org/vocab/unit/GT")
    MilliGM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M")
    DEG_F_HR_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_TH")
    LB_SEC_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-YD3")
    KibiBIT = URIRef("http://qudt.org/vocab/unit/KibiBIT")
    AttoSEC = URIRef("http://qudt.org/vocab/unit/AttoSEC")
    MicroA = URIRef("http://qudt.org/vocab/unit/MicroA")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    PERCENT_PER_10KiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-10KiloCount")
    GM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-K")
    DWT = URIRef("http://qudt.org/vocab/unit/DWT")
    A_HR = URIRef("http://qudt.org/vocab/unit/A-HR")
    FT3_PER_PSI = URIRef("http://qudt.org/vocab/unit/FT3-PER-PSI")
    N_M_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-RAD")
    V_PER_SEC = URIRef("http://qudt.org/vocab/unit/V-PER-SEC")
    L_PER_MIN = URIRef("http://qudt.org/vocab/unit/L-PER-MIN")
    LA_FT = URIRef("http://qudt.org/vocab/unit/LA_FT")
    CentiM3_PER_HR_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR-K")
    KiloLB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-IN2")
    DeciB_PER_M = URIRef("http://qudt.org/vocab/unit/DeciB-PER-M")
    C_M2 = URIRef("http://qudt.org/vocab/unit/C-M2")
    V_PER_MilliM = URIRef("http://qudt.org/vocab/unit/V-PER-MilliM")
    C4_M4_PER_J3 = URIRef("http://qudt.org/vocab/unit/C4-M4-PER-J3")
    RAD_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-KiloGM")
    NanoGM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MicroL")
    PDL_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-FT2")
    FT3_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN")
    CentiM3_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-CentiM3")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    KiloPA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-M")
    BQ_PER_M2 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M2")
    YD3_PER_DAY = URIRef("http://qudt.org/vocab/unit/YD3-PER-DAY")
    PER_SEC_SR_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR-M2")
    NUM_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/NUM-PER-MilliGM")
    FemtoJ = URIRef("http://qudt.org/vocab/unit/FemtoJ")
    PDL_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-FT2")
    TeraA = URIRef("http://qudt.org/vocab/unit/TeraA")
    R_man = URIRef("http://qudt.org/vocab/unit/R_man")
    KiloOHM_PER_K = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-K")
    LB_HR_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-GAL_US")
    ST = URIRef("http://qudt.org/vocab/unit/ST")
    FRACTION = URIRef("http://qudt.org/vocab/unit/FRACTION")
    MicroGM_PER_L = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L")
    KiloV = URIRef("http://qudt.org/vocab/unit/KiloV")
    MegaHZ = URIRef("http://qudt.org/vocab/unit/MegaHZ")
    FT_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-PER-MIN")
    MilliV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliV-PER-MIN")
    NanoC = URIRef("http://qudt.org/vocab/unit/NanoC")
    MilliGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY")
    DeciBAR = URIRef("http://qudt.org/vocab/unit/DeciBAR")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    MilliGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-BAR")
    MilliM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC2")
    FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-SEC-DEG_F")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    PFUND = URIRef("http://qudt.org/vocab/unit/PFUND")
    OHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/OHM-PER-BAR")
    KiloH = URIRef("http://qudt.org/vocab/unit/KiloH")
    OZ_PER_YD2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD2")
    AU = URIRef("http://qudt.org/vocab/unit/AU")
    MilliS = URIRef("http://qudt.org/vocab/unit/MilliS")
    PlanckLength = URIRef("http://qudt.org/vocab/unit/PlanckLength")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    L_PER_MOL = URIRef("http://qudt.org/vocab/unit/L-PER-MOL")
    A_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-M3")
    W_PER_M = URIRef("http://qudt.org/vocab/unit/W-PER-M")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    DYN_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    PERCENT_SEC_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-GAL_UK")
    MicroGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-K")
    CFU = URIRef("http://qudt.org/vocab/unit/CFU")
    PERCENT_PER_PA_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-PA-SEC")
    MilliGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-K")
    N = URIRef("http://qudt.org/vocab/unit/N")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    CWT_LONG = URIRef("http://qudt.org/vocab/unit/CWT_LONG")
    KAT_PER_L = URIRef("http://qudt.org/vocab/unit/KAT-PER-L")
    KiloM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC")
    NanoGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DeciL")
    TONNE_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC-BAR")
    CentiM3_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-K")
    MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    LUX_SEC = URIRef("http://qudt.org/vocab/unit/LUX-SEC")
    MilliM3 = URIRef("http://qudt.org/vocab/unit/MilliM3")
    MicroM = URIRef("http://qudt.org/vocab/unit/MicroM")
    PERCENT_PER_WK = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-WK")
    L_PER_L = URIRef("http://qudt.org/vocab/unit/L-PER-L")
    M2_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-HZ2")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    MilliH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-OHM")
    A_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/A-PER-KiloGM")
    ExaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/ExaBIT-PER-SEC")
    PetaJ = URIRef("http://qudt.org/vocab/unit/PetaJ")
    GM_PER_HR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR")
    GigaHZ = URIRef("http://qudt.org/vocab/unit/GigaHZ")
    M3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL-SEC")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    MegaS = URIRef("http://qudt.org/vocab/unit/MegaS")
    CD_PER_M2 = URIRef("http://qudt.org/vocab/unit/CD-PER-M2")
    KiloOHM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-M")
    W_M_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-M-PER-M2-SR")
    MicroBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-KiloGM")
    L_PER_L = URIRef("http://qudt.org/vocab/unit/L-PER-L")
    NanoV_A_Reactive = URIRef("http://qudt.org/vocab/unit/NanoV-A_Reactive")
    GRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/GRAY-PER-MIN")
    LM_PER_W = URIRef("http://qudt.org/vocab/unit/LM-PER-W")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    CAL_MEAN = URIRef("http://qudt.org/vocab/unit/CAL_MEAN")
    KiloBTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-FT2")
    GI_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-DAY")
    CentiGM = URIRef("http://qudt.org/vocab/unit/CentiGM")
    DEG_C_GROWING_CEREAL_DAY = URIRef("http://qudt.org/vocab/unit/DEG_C_GROWING_CEREAL-DAY")
    DeciB_W = URIRef("http://qudt.org/vocab/unit/DeciB-W")
    DEG_C_CentiM = URIRef("http://qudt.org/vocab/unit/DEG_C-CentiM")
    CWT_SHORT = URIRef("http://qudt.org/vocab/unit/CWT_SHORT")
    H = URIRef("http://qudt.org/vocab/unit/H")
    MicroGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-MilliL")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    MilliBAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-L-PER-SEC")
    LB_FT2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-IN3-LB_F-SEC")
    LB_PER_IN3_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3-DEG_F")
    OZ_MIN_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-FT3")
    HZ_M = URIRef("http://qudt.org/vocab/unit/HZ-M")
    V_PER_PA = URIRef("http://qudt.org/vocab/unit/V-PER-PA")
    TONNE_PER_MIN = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN")
    KiloGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM2")
    L_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-MOL-SEC")
    N_M_PER_W0dot5 = URIRef("http://qudt.org/vocab/unit/N-M-PER-W0dot5")
    NP = URIRef("http://qudt.org/vocab/unit/NP")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    GM_SEC_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L-M3")
    GM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3-BAR")
    MilliV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/MilliV-A_Reactive-PER-K")
    LB_PER_FT3_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3-DEG_F")
    MegaW_HR = URIRef("http://qudt.org/vocab/unit/MegaW-HR")
    SEC_PER_RAD_M3 = URIRef("http://qudt.org/vocab/unit/SEC-PER-RAD-M3")
    MilliGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2")
    MicroPA = URIRef("http://qudt.org/vocab/unit/MicroPA")
    N_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM2")
    MilliGM_SEC_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L-CentiM3")
    NanoGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2")
    MOL_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-BAR")
    MilliM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC")
    PER_MilliL = URIRef("http://qudt.org/vocab/unit/PER-MilliL")
    PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-PSI")
    N_M2 = URIRef("http://qudt.org/vocab/unit/N-M2")
    MicroMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L")
    MilliGM = URIRef("http://qudt.org/vocab/unit/MilliGM")
    FT3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT3-PER-DEG_F")
    GM_PER_M3_CentiPOISE = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-CentiPOISE")
    PER_RAD = URIRef("http://qudt.org/vocab/unit/PER-RAD")
    MilliPA_PER_M = URIRef("http://qudt.org/vocab/unit/MilliPA-PER-M")
    KiloGM_PER_DeciM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-K")
    BTU_IT_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_R")
    LB_MIN_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-FT3")
    V_IN2_PER_LB_F = URIRef("http://qudt.org/vocab/unit/V-IN2-PER-LB_F")
    DYN_SEC_PER_CentiM5 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM5")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    K_PER_HR = URIRef("http://qudt.org/vocab/unit/K-PER-HR")
    KiloTONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloTONNE-PER-YR")
    WB_M = URIRef("http://qudt.org/vocab/unit/WB-M")
    K_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PER-SEC")
    MI = URIRef("http://qudt.org/vocab/unit/MI")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    MI_PER_HR = URIRef("http://qudt.org/vocab/unit/MI-PER-HR")
    BBL_US_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-SEC")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    AU = URIRef("http://qudt.org/vocab/unit/AU")
    REV_PER_SEC = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC")
    QT_UK = URIRef("http://qudt.org/vocab/unit/QT_UK")
    EV_PER_M = URIRef("http://qudt.org/vocab/unit/EV-PER-M")
    AT_PER_M = URIRef("http://qudt.org/vocab/unit/AT-PER-M")
    CentiM_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-HR")
    NanoMOL_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L-DAY")
    SHANNON_PER_SEC = URIRef("http://qudt.org/vocab/unit/SHANNON-PER-SEC")
    CentiN = URIRef("http://qudt.org/vocab/unit/CentiN")
    BTU_IT_PER_MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB-DEG_F")
    KiloN_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-DEG")
    MilliPA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-BAR")
    MilliBAR = URIRef("http://qudt.org/vocab/unit/MilliBAR")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    MicroGM_PER_IN2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-IN2")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    FT_HG = URIRef("http://qudt.org/vocab/unit/FT_HG")
    ATM_PER_M = URIRef("http://qudt.org/vocab/unit/ATM-PER-M")
    DEG_F_SEC_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-SEC-PER-BTU_IT")
    GM_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/GM-PER-DEG_C")
    TORR_PER_M = URIRef("http://qudt.org/vocab/unit/TORR-PER-M")
    MicroS_PER_M = URIRef("http://qudt.org/vocab/unit/MicroS-PER-M")
    MegaL = URIRef("http://qudt.org/vocab/unit/MegaL")
    BTU_IT_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC-DEG_F")
    PERM_0DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_0DEG_C")
    DecaM = URIRef("http://qudt.org/vocab/unit/DecaM")
    BU_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-DAY")
    LB_SEC_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT6")
    TON_UK_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-YD3")
    BBL_US_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-SEC")
    TON_SHORT_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-YD3")
    KibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M")
    KiloCAL_IT_PER_HR_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-HR-M-DEG_C")
    FemtoM = URIRef("http://qudt.org/vocab/unit/FemtoM")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    GigaBasePair = URIRef("http://qudt.org/vocab/unit/GigaBasePair")
    MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC")
    MicroFARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-KiloM")
    BFT = URIRef("http://qudt.org/vocab/unit/BFT")
    CentiM_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-HR")
    MicroM3 = URIRef("http://qudt.org/vocab/unit/MicroM3")
    CAL_TH_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM-K")
    T_Ab = URIRef("http://qudt.org/vocab/unit/T_Ab")
    GM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC")
    ARCSEC = URIRef("http://qudt.org/vocab/unit/ARCSEC")
    KiloC_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M3")
    PDL_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-SEC-PER-FT2")
    M2_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-HZ2")
    PA_PER_M = URIRef("http://qudt.org/vocab/unit/PA-PER-M")
    PER_DAY = URIRef("http://qudt.org/vocab/unit/PER-DAY")
    OZ_SEC_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-YD3")
    M2_PER_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ2")
    BTU_IT = URIRef("http://qudt.org/vocab/unit/BTU_IT")
    DeciM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MOL")
    MilliFARAD = URIRef("http://qudt.org/vocab/unit/MilliFARAD")
    A_HR = URIRef("http://qudt.org/vocab/unit/A-HR")
    MilliGRAY = URIRef("http://qudt.org/vocab/unit/MilliGRAY")
    M2_SR = URIRef("http://qudt.org/vocab/unit/M2-SR")
    A_HR = URIRef("http://qudt.org/vocab/unit/A-HR")
    MicroN = URIRef("http://qudt.org/vocab/unit/MicroN")
    GigaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-SEC")
    MegaL = URIRef("http://qudt.org/vocab/unit/MegaL")
    KiloGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN")
    PER_BAR = URIRef("http://qudt.org/vocab/unit/PER-BAR")
    MOL_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-K")
    W_PER_M2_PA = URIRef("http://qudt.org/vocab/unit/W-PER-M2-PA")
    PERMEABILITY_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_REL")
    BTU_IT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_F")
    DECADE = URIRef("http://qudt.org/vocab/unit/DECADE")
    BBL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-MIN")
    OHM_M2_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-M2-PER-M")
    PK_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-SEC")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    KiloW = URIRef("http://qudt.org/vocab/unit/KiloW")
    MegaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-SEC")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    KiloMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-SEC")
    LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT2")
    MI_US2 = URIRef("http://qudt.org/vocab/unit/MI_US2")
    M2_K_PER_W = URIRef("http://qudt.org/vocab/unit/M2-K-PER-W")
    GM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloM")
    KiloM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC-BAR")
    KiloCAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-SEC")
    DYN_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM2")
    NanoMOL_PER_MicroGM_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroGM-HR")
    DEG_R = URIRef("http://qudt.org/vocab/unit/DEG_R")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    TON_UK_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-YD3")
    MilliRAD_R_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliRAD_R-PER-HR")
    PicoSEC = URIRef("http://qudt.org/vocab/unit/PicoSEC")
    NanoOHM_M = URIRef("http://qudt.org/vocab/unit/NanoOHM-M")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    PA_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M")
    BTU_IT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC")
    HectoBAR = URIRef("http://qudt.org/vocab/unit/HectoBAR")
    MebiBYTE = URIRef("http://qudt.org/vocab/unit/MebiBYTE")
    TonEnergy = URIRef("http://qudt.org/vocab/unit/TonEnergy")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    HP_Electric = URIRef("http://qudt.org/vocab/unit/HP_Electric")
    KiloGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN")
    MilliBQ = URIRef("http://qudt.org/vocab/unit/MilliBQ")
    DeciB_MilliW_PER_MegaHZ = URIRef("http://qudt.org/vocab/unit/DeciB-MilliW-PER-MegaHZ")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    TON_US = URIRef("http://qudt.org/vocab/unit/TON_US")
    NP = URIRef("http://qudt.org/vocab/unit/NP")
    LB_MIN_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-YD3")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    LB_HR_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-YD3")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    NanoSV_PER_HR = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-HR")
    M3_PER_KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM-SEC2")
    CASES_PER_KiloINDIV_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-KiloINDIV-YR")
    MicroGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-KiloGM")
    DeciM3_PER_HR = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-HR")
    FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F")
    MilliA_HR = URIRef("http://qudt.org/vocab/unit/MilliA-HR")
    TeraJ = URIRef("http://qudt.org/vocab/unit/TeraJ")
    NUM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/NUM-PER-KiloM2")
    PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-PER-SEC")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    KiloMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-KiloGM")
    MilliJ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-GM")
    PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-PER-SEC")
    MicroGM_PER_L = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L")
    M2_PER_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ2")
    PER_MIN = URIRef("http://qudt.org/vocab/unit/PER-MIN")
    KiloCAL_TH = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH")
    UnitPole = URIRef("http://qudt.org/vocab/unit/UnitPole")
    MilliM4 = URIRef("http://qudt.org/vocab/unit/MilliM4")
    BTU_IT_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_R")
    TONNE_PER_MIN = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    CentiM_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-K")
    L_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-M2")
    MOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM")
    MicroGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-HR")
    GM_HR_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L-CentiM3")
    LB_PER_IN3_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3-PSI")
    V_PER_L_MIN = URIRef("http://qudt.org/vocab/unit/V-PER-L-MIN")
    LB_SEC_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-IN3")
    MilliH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-OHM")
    MI = URIRef("http://qudt.org/vocab/unit/MI")
    V_PER_BAR = URIRef("http://qudt.org/vocab/unit/V-PER-BAR")
    S = URIRef("http://qudt.org/vocab/unit/S")
    MilliL_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-BAR")
    NanoM_PER_CentiM_PSI = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-PSI")
    PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2")
    DeciC = URIRef("http://qudt.org/vocab/unit/DeciC")
    J_PER_MOL_K = URIRef("http://qudt.org/vocab/unit/J-PER-MOL-K")
    KiloMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3")
    SEC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/SEC-PER-KiloGM")
    PicoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/PicoW-PER-M2")
    PER_WK = URIRef("http://qudt.org/vocab/unit/PER-WK")
    PER_EV2 = URIRef("http://qudt.org/vocab/unit/PER-EV2")
    MegaBAR = URIRef("http://qudt.org/vocab/unit/MegaBAR")
    MOL_K = URIRef("http://qudt.org/vocab/unit/MOL-K")
    MicroGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-HR")
    DeciL = URIRef("http://qudt.org/vocab/unit/DeciL")
    DEG_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-MIN")
    OZ_PER_IN2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN2")
    PicoPA_PER_KiloM = URIRef("http://qudt.org/vocab/unit/PicoPA-PER-KiloM")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    PSI_YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-YD3-PER-SEC")
    MilliMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3")
    M3_PER_PA = URIRef("http://qudt.org/vocab/unit/M3-PER-PA")
    BU_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-MIN")
    HectoGM = URIRef("http://qudt.org/vocab/unit/HectoGM")
    OZ_MIN_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-FT3")
    GigaOHM = URIRef("http://qudt.org/vocab/unit/GigaOHM")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    W_PER_M2_K = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K")
    NanoW = URIRef("http://qudt.org/vocab/unit/NanoW")
    CM_H2O = URIRef("http://qudt.org/vocab/unit/CM_H2O")
    C_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM-SEC")
    PERCENT_PER_CentiPOISE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-CentiPOISE")
    K_PER_MIN = URIRef("http://qudt.org/vocab/unit/K-PER-MIN")
    MilliGM_MIN_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L2")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    BAR_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/BAR-PER-DEG_C")
    MegaN = URIRef("http://qudt.org/vocab/unit/MegaN")
    G = URIRef("http://qudt.org/vocab/unit/G")
    MegaEV = URIRef("http://qudt.org/vocab/unit/MegaEV")
    MicroMOL = URIRef("http://qudt.org/vocab/unit/MicroMOL")
    NanoM2 = URIRef("http://qudt.org/vocab/unit/NanoM2")
    C_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Ab-PER-CentiM2")
    HA = URIRef("http://qudt.org/vocab/unit/HA")
    KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT")
    HectoPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-M3-PER-SEC")
    MilliGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-SEC")
    PERCENT_PER_POISE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-POISE")
    PA_PER_K = URIRef("http://qudt.org/vocab/unit/PA-PER-K")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    V_Stat = URIRef("http://qudt.org/vocab/unit/V_Stat")
    GRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/GRAY-PER-MIN")
    Hundredweight_UK = URIRef("http://qudt.org/vocab/unit/Hundredweight_UK")
    V_PER_IN = URIRef("http://qudt.org/vocab/unit/V-PER-IN")
    LB_PER_FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-LB_F-SEC")
    J_M_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-M-PER-MOL")
    GAL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-MIN")
    LB_PER_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-DAY")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    MI_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI-PER-MIN")
    A_PER_PA = URIRef("http://qudt.org/vocab/unit/A-PER-PA")
    PINT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-DAY")
    ExaC = URIRef("http://qudt.org/vocab/unit/ExaC")
    A_PER_PA = URIRef("http://qudt.org/vocab/unit/A-PER-PA")
    MicroC = URIRef("http://qudt.org/vocab/unit/MicroC")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    MilliM3 = URIRef("http://qudt.org/vocab/unit/MilliM3")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    IU = URIRef("http://qudt.org/vocab/unit/IU")
    BAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-L-PER-SEC")
    FT_HR_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-GAL_US")
    DEG_R_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-SEC")
    N = URIRef("http://qudt.org/vocab/unit/N")
    PetaJ = URIRef("http://qudt.org/vocab/unit/PetaJ")
    LB_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC-PSI")
    CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM-SEC-DEG_C")
    PPTM_PER_K = URIRef("http://qudt.org/vocab/unit/PPTM-PER-K")
    MilliJ = URIRef("http://qudt.org/vocab/unit/MilliJ")
    LB_MIN_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US2")
    LB_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT2")
    MicroSV = URIRef("http://qudt.org/vocab/unit/MicroSV")
    MilliM3 = URIRef("http://qudt.org/vocab/unit/MilliM3")
    MilliM4 = URIRef("http://qudt.org/vocab/unit/MilliM4")
    MegaEV = URIRef("http://qudt.org/vocab/unit/MegaEV")
    KiloPA_A = URIRef("http://qudt.org/vocab/unit/KiloPA_A")
    KibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M3")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC")
    TONNE = URIRef("http://qudt.org/vocab/unit/TONNE")
    DYN_SEC_PER_CentiM5 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM5")
    LB_SEC_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-IN3")
    MOL_LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-SEC")
    N_M_PER_A = URIRef("http://qudt.org/vocab/unit/N-M-PER-A")
    TSP = URIRef("http://qudt.org/vocab/unit/TSP")
    MI_N = URIRef("http://qudt.org/vocab/unit/MI_N")
    BTU_IT_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_F")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    MicroV = URIRef("http://qudt.org/vocab/unit/MicroV")
    LY = URIRef("http://qudt.org/vocab/unit/LY")
    LB_F_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-IN2")
    MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/MOL_LB-DEG_F")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    KiloGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM2")
    MilliGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3")
    C_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM3")
    MOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2")
    PERMEABILITY_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_REL")
    M_KiloGM = URIRef("http://qudt.org/vocab/unit/M-KiloGM")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    W_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M3")
    MilliJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-SEC")
    MegaN_M = URIRef("http://qudt.org/vocab/unit/MegaN-M")
    N_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M")
    A_PER_CentiM = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM")
    MHO = URIRef("http://qudt.org/vocab/unit/MHO")
    MegaV = URIRef("http://qudt.org/vocab/unit/MegaV")
    LB_SEC_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-GAL_UK")
    W = URIRef("http://qudt.org/vocab/unit/W")
    GM = URIRef("http://qudt.org/vocab/unit/GM")
    KiloEV_PER_MicroM = URIRef("http://qudt.org/vocab/unit/KiloEV-PER-MicroM")
    M3_PER_HR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR")
    PER_YD3 = URIRef("http://qudt.org/vocab/unit/PER-YD3")
    A_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-PER-DEG_C")
    MilLength = URIRef("http://qudt.org/vocab/unit/MilLength")
    PicoJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/PicoJ-PER-SEC")
    LB_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT2")
    GM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/GM-PER-HR-K")
    GRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/GRAY-PER-MIN")
    A_Stat = URIRef("http://qudt.org/vocab/unit/A_Stat")
    CentiM2_PER_SR_ERG = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SR-ERG")
    DEG_C_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-MIN")
    PERCENT_HR_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-GAL_US")
    KiloM = URIRef("http://qudt.org/vocab/unit/KiloM")
    MilliGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC")
    KiloGM_PER_GigaJ = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-GigaJ")
    DeciC = URIRef("http://qudt.org/vocab/unit/DeciC")
    TON_LONG = URIRef("http://qudt.org/vocab/unit/TON_LONG")
    MilliM4 = URIRef("http://qudt.org/vocab/unit/MilliM4")
    PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/PER-KiloGM-SEC")
    PERCENT_PER_M = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-M")
    PSI = URIRef("http://qudt.org/vocab/unit/PSI")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    PetaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/PetaBIT-PER-SEC")
    TeraBIT = URIRef("http://qudt.org/vocab/unit/TeraBIT")
    MilliL_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY")
    BU_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-DAY")
    MilliM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliM-PER-M")
    KiloGM_F_M = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    GAL_UK = URIRef("http://qudt.org/vocab/unit/GAL_UK")
    BU_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-SEC")
    PER_CentiM = URIRef("http://qudt.org/vocab/unit/PER-CentiM")
    MESH = URIRef("http://qudt.org/vocab/unit/MESH")
    NanoOHM_M = URIRef("http://qudt.org/vocab/unit/NanoOHM-M")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    MicroMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2")
    MilliL_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-K")
    CAL_TH_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM")
    EUR_PER_W_HR = URIRef("http://qudt.org/vocab/unit/EUR-PER-W-HR")
    PERCENT_MIN_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-FT3")
    MilliGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC")
    MOL_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-BAR")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    NUM_PER_SEC = URIRef("http://qudt.org/vocab/unit/NUM-PER-SEC")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    MilliW_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-MilliGM")
    CentiM_H2O = URIRef("http://qudt.org/vocab/unit/CentiM_H2O")
    YD_PER_HR = URIRef("http://qudt.org/vocab/unit/YD-PER-HR")
    LB_F_IN_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN-PER-IN")
    OHM_Ab = URIRef("http://qudt.org/vocab/unit/OHM_Ab")
    M2_SR = URIRef("http://qudt.org/vocab/unit/M2-SR")
    OZ_VOL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-DAY")
    GM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3")
    V_M = URIRef("http://qudt.org/vocab/unit/V-M")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    L_PER_DAY = URIRef("http://qudt.org/vocab/unit/L-PER-DAY")
    MicroMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MOL")
    GM_PER_HR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR")
    GM_Nitrogen_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Nitrogen-PER-M2-DAY")
    M_PER_FARAD = URIRef("http://qudt.org/vocab/unit/M-PER-FARAD")
    HR_FT2 = URIRef("http://qudt.org/vocab/unit/HR-FT2")
    LB_MOL = URIRef("http://qudt.org/vocab/unit/LB-MOL")
    PicoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/PicoW-PER-M2")
    OZ_IN = URIRef("http://qudt.org/vocab/unit/OZ-IN")
    MilliGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-BAR")
    MilliOHM = URIRef("http://qudt.org/vocab/unit/MilliOHM")
    N_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-RAD")
    N_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-PER-KiloGM")
    PINT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-MIN")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    IN_H2O_39dot2DEG_F = URIRef("http://qudt.org/vocab/unit/IN_H2O_39dot2DEG_F")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    MicroTORR = URIRef("http://qudt.org/vocab/unit/MicroTORR")
    BTU_IT_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_F")
    PER_HR = URIRef("http://qudt.org/vocab/unit/PER-HR")
    BU_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-SEC")
    LB_IN = URIRef("http://qudt.org/vocab/unit/LB-IN")
    KiloN_M_PER_DEG_M = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-DEG-M")
    V_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/V-SEC-PER-M")
    KiloMOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-MIN")
    J_SEC_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-SEC-PER-MOL")
    SHANNON_PER_SEC = URIRef("http://qudt.org/vocab/unit/SHANNON-PER-SEC")
    MegaOHM_PER_K = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-K")
    M3_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-PA")
    KiloL = URIRef("http://qudt.org/vocab/unit/KiloL")
    NanoGM = URIRef("http://qudt.org/vocab/unit/NanoGM")
    R_man = URIRef("http://qudt.org/vocab/unit/R_man")
    MicroMOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-SEC")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    A_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/A-PER-KiloGM")
    NUM_PER_PicoL = URIRef("http://qudt.org/vocab/unit/NUM-PER-PicoL")
    MilliBQ = URIRef("http://qudt.org/vocab/unit/MilliBQ")
    Ci = URIRef("http://qudt.org/vocab/unit/Ci")
    GM_PER_L_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-L-MilliPA-SEC")
    LB_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-DEG_F")
    FT3_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT3-PER-DAY")
    PK_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-HR")
    DEATHS_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000I-YR")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    H_Stat = URIRef("http://qudt.org/vocab/unit/H_Stat")
    MilliMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3")
    KiloGM_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-MilliM2")
    LB_IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN-PER-SEC")
    MOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM")
    PSI_PER_PSI = URIRef("http://qudt.org/vocab/unit/PSI-PER-PSI")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    YD3_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD3-PER-MIN")
    KiloEV = URIRef("http://qudt.org/vocab/unit/KiloEV")
    LB_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC-DEG_F")
    C = URIRef("http://qudt.org/vocab/unit/C")
    DeciBAR_PER_YR = URIRef("http://qudt.org/vocab/unit/DeciBAR-PER-YR")
    LB_SEC_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-GAL_US")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    PicoSEC = URIRef("http://qudt.org/vocab/unit/PicoSEC")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    BTU_IT_PER_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL-DEG_F")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    KiloM3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM3-PER-SEC2")
    MIN_Angle = URIRef("http://qudt.org/vocab/unit/MIN_Angle")
    LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN")
    BTU_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-MIN")
    PA_M0pt5 = URIRef("http://qudt.org/vocab/unit/PA-M0pt5")
    MegaPA_M0dot5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0dot5")
    MicroSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-MIN")
    BBL_UK_PET_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-DAY")
    V = URIRef("http://qudt.org/vocab/unit/V")
    CentiPOISE = URIRef("http://qudt.org/vocab/unit/CentiPOISE")
    ERG = URIRef("http://qudt.org/vocab/unit/ERG")
    K_M_PER_W = URIRef("http://qudt.org/vocab/unit/K-M-PER-W")
    GigaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/GigaC-PER-M3")
    MOL_PER_TONNE = URIRef("http://qudt.org/vocab/unit/MOL-PER-TONNE")
    MilliL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN")
    TONNE_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3-BAR")
    MicroGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-MilliL")
    THM_EEC = URIRef("http://qudt.org/vocab/unit/THM_EEC")
    GR = URIRef("http://qudt.org/vocab/unit/GR")
    PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PER-SEC2")
    LB_SEC_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-IN3")
    KiloH = URIRef("http://qudt.org/vocab/unit/KiloH")
    BTU_IT_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC-DEG_F")
    MicroH_PER_M = URIRef("http://qudt.org/vocab/unit/MicroH-PER-M")
    PER_GigaEV2 = URIRef("http://qudt.org/vocab/unit/PER-GigaEV2")
    LB_SEC_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US2")
    MilliL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-GM")
    LB_HR_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-FT3")
    FT3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT3-PER-DEG_F")
    V_A_PER_K = URIRef("http://qudt.org/vocab/unit/V-A-PER-K")
    MegaJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-KiloGM")
    MilliGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-K")
    MilliGM_HR_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M3-CentiM3")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    W_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M2")
    MilliGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY")
    KiloM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-HR")
    ATM = URIRef("http://qudt.org/vocab/unit/ATM")
    MilliC = URIRef("http://qudt.org/vocab/unit/MilliC")
    PER_WB = URIRef("http://qudt.org/vocab/unit/PER-WB")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    GM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloM")
    MegaA = URIRef("http://qudt.org/vocab/unit/MegaA")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    TON_F_US = URIRef("http://qudt.org/vocab/unit/TON_F_US")
    MI_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI-PER-MIN")
    CentiM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN")
    LB_SEC_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-FT3")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    MegaC = URIRef("http://qudt.org/vocab/unit/MegaC")
    MicroH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-KiloOHM")
    DEG_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC2")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    PA_SEC_PER_K = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-K")
    PERCENT_HR_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-GAL_UK")
    MilliGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-BAR")
    MilliL = URIRef("http://qudt.org/vocab/unit/MilliL")
    MilliL_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-K")
    IU = URIRef("http://qudt.org/vocab/unit/IU")
    L = URIRef("http://qudt.org/vocab/unit/L")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    PERCENT_HR_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-CentiM3")
    CentiM_H2O = URIRef("http://qudt.org/vocab/unit/CentiM_H2O")
    M2_PER_GM_DRY = URIRef("http://qudt.org/vocab/unit/M2-PER-GM_DRY")
    M_K = URIRef("http://qudt.org/vocab/unit/M-K")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    BQ_PER_L = URIRef("http://qudt.org/vocab/unit/BQ-PER-L")
    DEG_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC")
    PERCENT_PER_DEG = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEG")
    CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM-SEC-DEG_C")
    S_PER_CentiM = URIRef("http://qudt.org/vocab/unit/S-PER-CentiM")
    DEG_F_HR_FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT-IN")
    CentiM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL")
    MESH = URIRef("http://qudt.org/vocab/unit/MESH")
    NanoJ = URIRef("http://qudt.org/vocab/unit/NanoJ")
    PSI = URIRef("http://qudt.org/vocab/unit/PSI")
    KY = URIRef("http://qudt.org/vocab/unit/KY")
    V_Ab = URIRef("http://qudt.org/vocab/unit/V_Ab")
    CentiM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL")
    U = URIRef("http://qudt.org/vocab/unit/U")
    BBL_UK_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-HR")
    BAR_PER_K = URIRef("http://qudt.org/vocab/unit/BAR-PER-K")
    HP_Electric = URIRef("http://qudt.org/vocab/unit/HP_Electric")
    LUX_HR = URIRef("http://qudt.org/vocab/unit/LUX-HR")
    ONE = URIRef("http://qudt.org/vocab/unit/ONE")
    MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/MOL-DEG_C")
    BIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BIT-PER-SEC")
    FARAD_Ab = URIRef("http://qudt.org/vocab/unit/FARAD_Ab")
    KiloOHM = URIRef("http://qudt.org/vocab/unit/KiloOHM")
    MilliGM_PER_M3_CentiPOISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-CentiPOISE")
    HectoPA_PER_M = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-M")
    FT2_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT2-PER-SEC")
    K_M2_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/K-M2-PER-KiloGM-SEC")
    MicroBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-KiloGM")
    GRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/GRAY-PER-SEC")
    MegaJ = URIRef("http://qudt.org/vocab/unit/MegaJ")
    BBL_UK_PET = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    KiloLB_F = URIRef("http://qudt.org/vocab/unit/KiloLB_F")
    AttoJ_SEC = URIRef("http://qudt.org/vocab/unit/AttoJ-SEC")
    EUR_PER_KiloW = URIRef("http://qudt.org/vocab/unit/EUR-PER-KiloW")
    DEG_C_GROWING_CEREAL_DAY = URIRef("http://qudt.org/vocab/unit/DEG_C_GROWING_CEREAL-DAY")
    J_M2 = URIRef("http://qudt.org/vocab/unit/J-M2")
    KiloGM_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MOL")
    OZ_VOL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-SEC")
    IU_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliGM")
    FUR = URIRef("http://qudt.org/vocab/unit/FUR")
    GM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2")
    LB_PER_FT_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-DAY")
    KiloGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY")
    BTU_IT_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT-PER-FT2-HR-DEG_F")
    M3_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-BAR")
    LB_PER_FT_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-DAY")
    GibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M3")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    KiloGM_PER_J = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-J")
    OZ_VOL_US = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US")
    KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT")
    LB_PER_GAL = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL")
    SUSCEPTIBILITY_ELEC = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_ELEC")
    MegaGM = URIRef("http://qudt.org/vocab/unit/MegaGM")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    LUX_HR = URIRef("http://qudt.org/vocab/unit/LUX-HR")
    DeciB_PER_M = URIRef("http://qudt.org/vocab/unit/DeciB-PER-M")
    KiloGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-K")
    MilliGM_MIN_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M3-L")
    THM_US = URIRef("http://qudt.org/vocab/unit/THM_US")
    M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/M2-PER-MOL")
    PERCENT_SEC_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-GAL_UK")
    PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PER-M3-SEC")
    KiloMIL_Circ = URIRef("http://qudt.org/vocab/unit/KiloMIL_Circ")
    BTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR")
    MilliV_A = URIRef("http://qudt.org/vocab/unit/MilliV-A")
    PER_MO = URIRef("http://qudt.org/vocab/unit/PER-MO")
    MilliCi = URIRef("http://qudt.org/vocab/unit/MilliCi")
    A_PER_M2_K2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2-K2")
    ERG_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM2-SEC")
    MicroFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-M")
    C_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM2")
    MicroV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/MicroV-A_Reactive-PER-K")
    GM_MIN_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M3-L")
    A_M2 = URIRef("http://qudt.org/vocab/unit/A-M2")
    MilliA_SEC = URIRef("http://qudt.org/vocab/unit/MilliA-SEC")
    MilliGM_PER_M3_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-MilliPA-SEC")
    PK_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-DAY")
    GigaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/GigaC-PER-M3")
    KiloGM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    KiloTONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloTONNE-PER-YR")
    CentiM3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL-SEC")
    CAL_TH_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM-SEC-DEG_C")
    MegaGRAY = URIRef("http://qudt.org/vocab/unit/MegaGRAY")
    MilliOHM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-M")
    PER_GM = URIRef("http://qudt.org/vocab/unit/PER-GM")
    MilliGM_SEC_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L-M3")
    OZ_F_IN = URIRef("http://qudt.org/vocab/unit/OZ_F-IN")
    A_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM2")
    N_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-RAD")
    MilliS_PER_M = URIRef("http://qudt.org/vocab/unit/MilliS-PER-M")
    MIL = URIRef("http://qudt.org/vocab/unit/MIL")
    J_PER_M4 = URIRef("http://qudt.org/vocab/unit/J-PER-M4")
    M3_PER_MIN = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN")
    TON_Metric = URIRef("http://qudt.org/vocab/unit/TON_Metric")
    W_PER_IN2 = URIRef("http://qudt.org/vocab/unit/W-PER-IN2")
    OZ_PER_IN2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN2")
    MilliGM_HR_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L-CentiM3")
    GigaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBYTE-PER-SEC")
    LB_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN2")
    MDOLLAR_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MDOLLAR-PER-FLIGHT")
    FT3_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT3-PER-SEC")
    FUR = URIRef("http://qudt.org/vocab/unit/FUR")
    KiloCAL_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM-DEG_C")
    PSI_PER_IN = URIRef("http://qudt.org/vocab/unit/PSI-PER-IN")
    MOL_PER_M2_SEC_M_SR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-M-SR")
    BQ_PER_M2 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M2")
    V_PER_V = URIRef("http://qudt.org/vocab/unit/V-PER-V")
    DeciB_PER_KiloM = URIRef("http://qudt.org/vocab/unit/DeciB-PER-KiloM")
    NanoW = URIRef("http://qudt.org/vocab/unit/NanoW")
    REV_PER_SEC = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC")
    Ci = URIRef("http://qudt.org/vocab/unit/Ci")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    PA_M = URIRef("http://qudt.org/vocab/unit/PA-M")
    AT_PER_M = URIRef("http://qudt.org/vocab/unit/AT-PER-M")
    DYN_SEC_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM")
    MicroMOL_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-HR")
    PINT_US_DRY = URIRef("http://qudt.org/vocab/unit/PINT_US_DRY")
    MOL_PER_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-HR")
    KiloM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-HR")
    MilliGM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M")
    BTU_IT_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT3")
    MilliN = URIRef("http://qudt.org/vocab/unit/MilliN")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    DeciBAR_PER_YR = URIRef("http://qudt.org/vocab/unit/DeciBAR-PER-YR")
    KiloBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBYTE-PER-SEC")
    MegaV = URIRef("http://qudt.org/vocab/unit/MegaV")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    FRACTION = URIRef("http://qudt.org/vocab/unit/FRACTION")
    MilliFARAD = URIRef("http://qudt.org/vocab/unit/MilliFARAD")
    W_PER_SR = URIRef("http://qudt.org/vocab/unit/W-PER-SR")
    GAL_UK = URIRef("http://qudt.org/vocab/unit/GAL_UK")
    MilliW_PER_CentiM2_MicroM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-CentiM2-MicroM-SR")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    BAN = URIRef("http://qudt.org/vocab/unit/BAN")
    GM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciL")
    GibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M")
    LB_IN2 = URIRef("http://qudt.org/vocab/unit/LB-IN2")
    GA_Charriere = URIRef("http://qudt.org/vocab/unit/GA_Charriere")
    KiloR = URIRef("http://qudt.org/vocab/unit/KiloR")
    NanoT = URIRef("http://qudt.org/vocab/unit/NanoT")
    GI_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_US-PER-MIN")
    BTU_TH_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT3")
    MicroM2 = URIRef("http://qudt.org/vocab/unit/MicroM2")
    MOL_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-SEC")
    PK_US_DRY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY")
    NanoH = URIRef("http://qudt.org/vocab/unit/NanoH")
    LB_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN2")
    NanoM = URIRef("http://qudt.org/vocab/unit/NanoM")
    CentiM3_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN-BAR")
    M3_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-K")
    MilliMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2")
    LB_PER_MIN_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN-PSI")
    C_Stat_PER_MOL = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-MOL")
    L_PER_HR_K = URIRef("http://qudt.org/vocab/unit/L-PER-HR-K")
    LB_PER_YD2 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD2")
    CentiM_PER_KiloYR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-KiloYR")
    FT_H2O = URIRef("http://qudt.org/vocab/unit/FT_H2O")
    N_M_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-M-PER-KiloGM")
    GM_HR_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L-CentiM3")
    J_PER_M3_K = URIRef("http://qudt.org/vocab/unit/J-PER-M3-K")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    B = URIRef("http://qudt.org/vocab/unit/B")
    CentiM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN")
    KiloC = URIRef("http://qudt.org/vocab/unit/KiloC")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    NanoC = URIRef("http://qudt.org/vocab/unit/NanoC")
    PER_SEC_M3 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M3")
    KiloTON_Metric = URIRef("http://qudt.org/vocab/unit/KiloTON_Metric")
    S_Ab = URIRef("http://qudt.org/vocab/unit/S_Ab")
    KiloJ_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MOL")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    PDL_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-SEC-PER-FT2")
    DeciS_PER_M = URIRef("http://qudt.org/vocab/unit/DeciS-PER-M")
    YoctoC = URIRef("http://qudt.org/vocab/unit/YoctoC")
    MOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL-PER-MIN")
    FemtoL = URIRef("http://qudt.org/vocab/unit/FemtoL")
    KiloGM_M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M2-PER-SEC")
    MilliGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-HR")
    C_PER_MOL = URIRef("http://qudt.org/vocab/unit/C-PER-MOL")
    A_M2 = URIRef("http://qudt.org/vocab/unit/A-M2")
    BTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2")
    KiloGM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC2")
    PERCENT_RH = URIRef("http://qudt.org/vocab/unit/PERCENT_RH")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    MilliM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliM-PER-K")
    BBL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-MIN")
    LB_PER_FT = URIRef("http://qudt.org/vocab/unit/LB-PER-FT")
    NanoH = URIRef("http://qudt.org/vocab/unit/NanoH")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    KiloBIT = URIRef("http://qudt.org/vocab/unit/KiloBIT")
    IN3_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN3-PER-MIN")
    N_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    GI_UK = URIRef("http://qudt.org/vocab/unit/GI_UK")
    CentiM3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-BAR")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    MilliM2 = URIRef("http://qudt.org/vocab/unit/MilliM2")
    PERCENT_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-M3")
    DeciM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-M3")
    TON_Metric_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY")
    V_Stat = URIRef("http://qudt.org/vocab/unit/V_Stat")
    OZ_TROY = URIRef("http://qudt.org/vocab/unit/OZ_TROY")
    KiloGM_PER_MegaBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MegaBTU_IT")
    MilliM_H2O = URIRef("http://qudt.org/vocab/unit/MilliM_H2O")
    B = URIRef("http://qudt.org/vocab/unit/B")
    KiloGM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-BAR")
    KiloGM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-CentiM2")
    FARAD_Stat = URIRef("http://qudt.org/vocab/unit/FARAD_Stat")
    MicroSEC = URIRef("http://qudt.org/vocab/unit/MicroSEC")
    DeciN_M = URIRef("http://qudt.org/vocab/unit/DeciN-M")
    KiloGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-K")
    W_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-SEC-PER-M2")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    PIXEL = URIRef("http://qudt.org/vocab/unit/PIXEL")
    OZ_F = URIRef("http://qudt.org/vocab/unit/OZ_F")
    MegaOHM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-KiloM")
    MilliGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-BAR")
    N_M_PER_ARCMIN = URIRef("http://qudt.org/vocab/unit/N-M-PER-ARCMIN")
    LB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT")
    GM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3-K")
    PERCENT_PER_DektoKiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DektoKiloCount")
    OCTET = URIRef("http://qudt.org/vocab/unit/OCTET")
    PER_EV2 = URIRef("http://qudt.org/vocab/unit/PER-EV2")
    CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3")
    DeciN = URIRef("http://qudt.org/vocab/unit/DeciN")
    GM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL")
    CD_PER_FT2 = URIRef("http://qudt.org/vocab/unit/CD-PER-FT2")
    MilliGM_PER_L = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L")
    MicroM = URIRef("http://qudt.org/vocab/unit/MicroM")
    TON_US_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_US-PER-YD3")
    KiloOHM = URIRef("http://qudt.org/vocab/unit/KiloOHM")
    FT_LB_F = URIRef("http://qudt.org/vocab/unit/FT-LB_F")
    MicroSV = URIRef("http://qudt.org/vocab/unit/MicroSV")
    DEG_R_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-MIN")
    GM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-CentiM-PER-SEC")
    IN_HG = URIRef("http://qudt.org/vocab/unit/IN_HG")
    L_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/L-PER-KiloGM")
    TONNE_PER_DAY = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY")
    W_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/W-PER-CentiM2")
    SLUG_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT-SEC")
    MilliDARCY = URIRef("http://qudt.org/vocab/unit/MilliDARCY")
    MilliFARAD = URIRef("http://qudt.org/vocab/unit/MilliFARAD")
    PERCENT_PER_WK = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-WK")
    V_PER_MilliM = URIRef("http://qudt.org/vocab/unit/V-PER-MilliM")
    MegaTOE = URIRef("http://qudt.org/vocab/unit/MegaTOE")
    BARAD = URIRef("http://qudt.org/vocab/unit/BARAD")
    KiloLB_F = URIRef("http://qudt.org/vocab/unit/KiloLB_F")
    KiloPA_A = URIRef("http://qudt.org/vocab/unit/KiloPA_A")
    BTU_IT_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT-PER-FT2-HR-DEG_F")
    T_SEC = URIRef("http://qudt.org/vocab/unit/T-SEC")
    DEG_F_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-K")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    KiloV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive-HR")
    CentiM3_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-BAR")
    GigaV_A = URIRef("http://qudt.org/vocab/unit/GigaV-A")
    BU_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-HR")
    HR_Sidereal = URIRef("http://qudt.org/vocab/unit/HR_Sidereal")
    J = URIRef("http://qudt.org/vocab/unit/J")
    ERG_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM")
    PERCENT_SEC_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-FT3")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    PER_H = URIRef("http://qudt.org/vocab/unit/PER-H")
    TEX = URIRef("http://qudt.org/vocab/unit/TEX")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    C3_M_PER_J2 = URIRef("http://qudt.org/vocab/unit/C3-M-PER-J2")
    LB_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT2")
    BTU_IT_PER_SEC_FT_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT-DEG_R")
    V_Stat = URIRef("http://qudt.org/vocab/unit/V_Stat")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    NanoS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/NanoS-PER-CentiM")
    CAL_TH_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-K")
    DeciGM = URIRef("http://qudt.org/vocab/unit/DeciGM")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    MilliGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY")
    OZ_TROY = URIRef("http://qudt.org/vocab/unit/OZ_TROY")
    MilliR = URIRef("http://qudt.org/vocab/unit/MilliR")
    A_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-PER-CentiM2")
    C_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM")
    MicroG = URIRef("http://qudt.org/vocab/unit/MicroG")
    BBL_US_DRY = URIRef("http://qudt.org/vocab/unit/BBL_US_DRY")
    ExaBYTE = URIRef("http://qudt.org/vocab/unit/ExaBYTE")
    FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-DEG_F")
    OZ_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_US")
    MegaS = URIRef("http://qudt.org/vocab/unit/MegaS")
    A_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM2")
    ExaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/ExaBIT-PER-SEC")
    M3_PER_K = URIRef("http://qudt.org/vocab/unit/M3-PER-K")
    CentiM_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-HR")
    MOL_PER_KiloGM_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-PA")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    M4 = URIRef("http://qudt.org/vocab/unit/M4")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    BARYE = URIRef("http://qudt.org/vocab/unit/BARYE")
    KiloCAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-SEC")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    LB_PER_FT3_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3-DEG_F")
    MI_N = URIRef("http://qudt.org/vocab/unit/MI_N")
    MHO_Stat = URIRef("http://qudt.org/vocab/unit/MHO_Stat")
    MicroH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-KiloOHM")
    BBL_UK_PET = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET")
    M6 = URIRef("http://qudt.org/vocab/unit/M6")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    GI_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_US-PER-HR")
    PERMEABILITY_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_REL")
    PSI_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-L-PER-SEC")
    PER_GigaEV2 = URIRef("http://qudt.org/vocab/unit/PER-GigaEV2")
    AC = URIRef("http://qudt.org/vocab/unit/AC")
    PK_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-DAY")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    KiloBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBIT-PER-SEC")
    KiloN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-M2")
    HZ_PER_V = URIRef("http://qudt.org/vocab/unit/HZ-PER-V")
    CORD = URIRef("http://qudt.org/vocab/unit/CORD")
    ZettaC = URIRef("http://qudt.org/vocab/unit/ZettaC")
    DEG_C_PER_M = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-M")
    MOL_PER_KiloGM_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-PA")
    ERG_PER_CentiM = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM")
    FT_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-PER-MIN")
    A = URIRef("http://qudt.org/vocab/unit/A")
    KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloMOL")
    RAYL = URIRef("http://qudt.org/vocab/unit/RAYL")
    M3_PER_K = URIRef("http://qudt.org/vocab/unit/M3-PER-K")
    LB_PER_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-DAY")
    MilliWB = URIRef("http://qudt.org/vocab/unit/MilliWB")
    KiloJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-SEC")
    H_PER_OHM = URIRef("http://qudt.org/vocab/unit/H-PER-OHM")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    PK_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-MIN")
    CUP_US = URIRef("http://qudt.org/vocab/unit/CUP_US")
    BTU_TH_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-SEC")
    GM_PER_CentiM2_YR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2-YR")
    PERCENT_PER_DEGREE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEGREE")
    PA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-L-PER-SEC")
    MicroBAR = URIRef("http://qudt.org/vocab/unit/MicroBAR")
    LB_FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT-PER-SEC")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    PetaBQ = URIRef("http://qudt.org/vocab/unit/PetaBQ")
    MegaJ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-K")
    MilliBQ_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-M2-DAY")
    MilliM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-BAR")
    LB_F_FT = URIRef("http://qudt.org/vocab/unit/LB_F-FT")
    PER_MILLE_PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PER-PSI")
    BBL_US_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-SEC")
    PlanckCharge = URIRef("http://qudt.org/vocab/unit/PlanckCharge")
    SEC_PER_M3_RAD = URIRef("http://qudt.org/vocab/unit/SEC-PER-M3-RAD")
    KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A-HR")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    FemtoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-KiloGM")
    TONNE_PER_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-BAR")
    H_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/H-PER-KiloOHM")
    GAL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-DAY")
    N_M_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-RAD")
    NUM_PER_HA = URIRef("http://qudt.org/vocab/unit/NUM-PER-HA")
    PA_M = URIRef("http://qudt.org/vocab/unit/PA-M")
    CASES_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-1000I-YR")
    KiloGM_F = URIRef("http://qudt.org/vocab/unit/KiloGM_F")
    YD3_PER_DAY = URIRef("http://qudt.org/vocab/unit/YD3-PER-DAY")
    W_PER_K = URIRef("http://qudt.org/vocab/unit/W-PER-K")
    ZOLL = URIRef("http://qudt.org/vocab/unit/ZOLL")
    ElementaryCharge = URIRef("http://qudt.org/vocab/unit/ElementaryCharge")
    MegaS_PER_M = URIRef("http://qudt.org/vocab/unit/MegaS-PER-M")
    QT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_US-PER-DAY")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    H = URIRef("http://qudt.org/vocab/unit/H")
    PK_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-SEC")
    BTU_TH_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_R")
    MicroSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-MIN")
    MilliM_H2O = URIRef("http://qudt.org/vocab/unit/MilliM_H2O")
    J = URIRef("http://qudt.org/vocab/unit/J")
    MicroGM_PER_L = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L")
    DEG_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC")
    L_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-BAR")
    A_PER_M2_K2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2-K2")
    NanoA = URIRef("http://qudt.org/vocab/unit/NanoA")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    DEG_C_PER_YR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-YR")
    ERG_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM2-SEC")
    MegaHZ_PER_T = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-T")
    MicroGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-K")
    GigaV_A = URIRef("http://qudt.org/vocab/unit/GigaV-A")
    L = URIRef("http://qudt.org/vocab/unit/L")
    NanoM = URIRef("http://qudt.org/vocab/unit/NanoM")
    MegaV_A_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A-HR")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    N_M_PER_M_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-M-RAD")
    NanoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-KiloGM")
    HART = URIRef("http://qudt.org/vocab/unit/HART")
    PebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M3")
    PSI = URIRef("http://qudt.org/vocab/unit/PSI")
    UnitPole = URIRef("http://qudt.org/vocab/unit/UnitPole")
    KiloLB_F_FT_PER_A = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-A")
    R_PER_SEC = URIRef("http://qudt.org/vocab/unit/R-PER-SEC")
    MOL_PER_M2_SEC_SR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-SR")
    PINT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-DAY")
    BTU_IT_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-SEC-DEG_F")
    CAL_TH_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2")
    J_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2")
    OZ_VOL_US = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US")
    ERG_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM-SEC")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    SV_PER_HR = URIRef("http://qudt.org/vocab/unit/SV-PER-HR")
    KiloM = URIRef("http://qudt.org/vocab/unit/KiloM")
    L_PER_DAY = URIRef("http://qudt.org/vocab/unit/L-PER-DAY")
    PetaC = URIRef("http://qudt.org/vocab/unit/PetaC")
    BTU_IT_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC")
    W_PER_M_K = URIRef("http://qudt.org/vocab/unit/W-PER-M-K")
    PERCENT_PER_DEG = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEG")
    U = URIRef("http://qudt.org/vocab/unit/U")
    MicroMOL_PER_GM_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM-HR")
    BU_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-MIN")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT")
    PicoW = URIRef("http://qudt.org/vocab/unit/PicoW")
    TeraC = URIRef("http://qudt.org/vocab/unit/TeraC")
    KiloCAL = URIRef("http://qudt.org/vocab/unit/KiloCAL")
    GM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3")
    M2_HZ3 = URIRef("http://qudt.org/vocab/unit/M2-HZ3")
    FT_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-PER-HR")
    TON_Metric_PER_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-K")
    LB_SEC_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-YD3")
    MegaBAUD = URIRef("http://qudt.org/vocab/unit/MegaBAUD")
    GM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN-BAR")
    CentiM_PER_KiloYR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-KiloYR")
    PicoJ = URIRef("http://qudt.org/vocab/unit/PicoJ")
    PlanckEnergy = URIRef("http://qudt.org/vocab/unit/PlanckEnergy")
    BAR_PER_K = URIRef("http://qudt.org/vocab/unit/BAR-PER-K")
    LB_MIN_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-GAL_US")
    TON_Metric = URIRef("http://qudt.org/vocab/unit/TON_Metric")
    LB_HR_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN6")
    MegaOHM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-KiloM")
    MegaS = URIRef("http://qudt.org/vocab/unit/MegaS")
    PERCENT_HR_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-L")
    PER_SR = URIRef("http://qudt.org/vocab/unit/PER-SR")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    MilliGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-CentiM2")
    V_A_Reactive = URIRef("http://qudt.org/vocab/unit/V-A_Reactive")
    MicroS_PER_M = URIRef("http://qudt.org/vocab/unit/MicroS-PER-M")
    KiloN_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M3")
    MebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M")
    OHM_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-PER-M")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    OZ_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ-PER-MIN")
    MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/MOL_LB-DEG_F")
    Gamma = URIRef("http://qudt.org/vocab/unit/Gamma")
    BTU_IT_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-SEC-DEG_F")
    OHM_Ab = URIRef("http://qudt.org/vocab/unit/OHM_Ab")
    KiloGM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-FT2")
    N = URIRef("http://qudt.org/vocab/unit/N")
    MOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MOL-PER-MOL")
    PERCENT_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-M3")
    ST_PER_K = URIRef("http://qudt.org/vocab/unit/ST-PER-K")
    A_HR_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/A-HR-PER-KiloGM")
    ERG_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM3")
    L_PER_DAY = URIRef("http://qudt.org/vocab/unit/L-PER-DAY")
    N_PER_C = URIRef("http://qudt.org/vocab/unit/N-PER-C")
    KiloGM_PER_L = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L")
    LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN")
    KiloCAL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-SEC")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    KiloJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-SEC")
    KiloJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-SEC")
    WK = URIRef("http://qudt.org/vocab/unit/WK")
    M3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-K")
    MilliJ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-GM")
    CentiM2_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-CentiM3")
    TON_Metric_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR")
    PINT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-MIN")
    NanoMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L-HR")
    T = URIRef("http://qudt.org/vocab/unit/T")
    BARN = URIRef("http://qudt.org/vocab/unit/BARN")
    BTU_TH_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR-FT2-DEG_F")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    GigaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-SEC")
    KiloM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM2-PER-SEC2")
    BTU_TH_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_F")
    V = URIRef("http://qudt.org/vocab/unit/V")
    MilliN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliN-M-PER-M2")
    MicroC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M3")
    SLUG_PER_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-SEC")
    PicoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-KiloGM")
    M_K = URIRef("http://qudt.org/vocab/unit/M-K")
    TONNE_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR-BAR")
    ONE_PER_ONE = URIRef("http://qudt.org/vocab/unit/ONE-PER-ONE")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    KiloGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-K")
    GM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM")
    LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT2")
    GM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL")
    LB_IN = URIRef("http://qudt.org/vocab/unit/LB-IN")
    LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT2")
    MicroSEC = URIRef("http://qudt.org/vocab/unit/MicroSEC")
    FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F")
    TeraW_HR = URIRef("http://qudt.org/vocab/unit/TeraW-HR")
    PERCENT_FT2_PER_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-FT2-PER-LB_F-SEC")
    MI_N = URIRef("http://qudt.org/vocab/unit/MI_N")
    BBL_US_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-HR")
    K = URIRef("http://qudt.org/vocab/unit/K")
    GigaOHM = URIRef("http://qudt.org/vocab/unit/GigaOHM")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    K_M_PER_W = URIRef("http://qudt.org/vocab/unit/K-M-PER-W")
    C_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-CentiM2")
    LB_MOL = URIRef("http://qudt.org/vocab/unit/LB-MOL")
    MI2 = URIRef("http://qudt.org/vocab/unit/MI2")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    CentiPOISE_PER_K = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-K")
    YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD3-PER-SEC")
    MilliOHM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-K")
    M2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2")
    PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PER-SEC2")
    AttoC = URIRef("http://qudt.org/vocab/unit/AttoC")
    PSU = URIRef("http://qudt.org/vocab/unit/PSU")
    ExaC = URIRef("http://qudt.org/vocab/unit/ExaC")
    Kilo_FT3 = URIRef("http://qudt.org/vocab/unit/Kilo-FT3")
    C_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM2")
    HK = URIRef("http://qudt.org/vocab/unit/HK")
    MicroGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3")
    KibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M2")
    OERSTED = URIRef("http://qudt.org/vocab/unit/OERSTED")
    KiloPA = URIRef("http://qudt.org/vocab/unit/KiloPA")
    PicoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L")
    MegaJ_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M3")
    V_Stat_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-CentiM")
    IN_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC-PSI")
    TON_Metric_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY-BAR")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    PT_BIG = URIRef("http://qudt.org/vocab/unit/PT_BIG")
    MOL_PER_TONNE = URIRef("http://qudt.org/vocab/unit/MOL-PER-TONNE")
    TON_Metric_PER_MIN = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    BFT = URIRef("http://qudt.org/vocab/unit/BFT")
    DeciBAR_PER_YR = URIRef("http://qudt.org/vocab/unit/DeciBAR-PER-YR")
    W_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-PER-KiloGM")
    GigaBIT = URIRef("http://qudt.org/vocab/unit/GigaBIT")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    DEATHS_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000I-YR")
    CAL_TH_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM-K")
    A_Ab_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-CentiM2")
    MicroGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3")
    NanoH_PER_M = URIRef("http://qudt.org/vocab/unit/NanoH-PER-M")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    DEG_F_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-HR")
    SEC_PER_M3_RAD = URIRef("http://qudt.org/vocab/unit/SEC-PER-M3-RAD")
    KiloOHM = URIRef("http://qudt.org/vocab/unit/KiloOHM")
    L_PER_MOL = URIRef("http://qudt.org/vocab/unit/L-PER-MOL")
    A_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/A-PER-KiloGM")
    NanoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/NanoFARAD-PER-M")
    MilliGM_SEC_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M3-L")
    A_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM2")
    FT3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT3-PER-DEG_F")
    BIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/BIT-PER-M3")
    M_PER_RAD = URIRef("http://qudt.org/vocab/unit/M-PER-RAD")
    TON_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_US-PER-DAY")
    FemtoV = URIRef("http://qudt.org/vocab/unit/FemtoV")
    OERSTED_CentiM = URIRef("http://qudt.org/vocab/unit/OERSTED-CentiM")
    DEATHS_PER_MegaINDIV_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-MegaINDIV-YR")
    KY = URIRef("http://qudt.org/vocab/unit/KY")
    PERMITTIVITY_REL = URIRef("http://qudt.org/vocab/unit/PERMITTIVITY_REL")
    W_PER_K = URIRef("http://qudt.org/vocab/unit/W-PER-K")
    CI_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CI-PER-KiloGM")
    IN3_PER_HR = URIRef("http://qudt.org/vocab/unit/IN3-PER-HR")
    GigaV = URIRef("http://qudt.org/vocab/unit/GigaV")
    KiloS_PER_M = URIRef("http://qudt.org/vocab/unit/KiloS-PER-M")
    CentiM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SEC")
    NUM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NUM-PER-MicroL")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    MHO_Stat = URIRef("http://qudt.org/vocab/unit/MHO_Stat")
    FT_LB_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-MIN")
    BTU_TH_FT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-HR-FT2-DEG_F")
    IN_PER_2PiRAD = URIRef("http://qudt.org/vocab/unit/IN-PER-2PiRAD")
    CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CentiM2-MIN")
    KiloN = URIRef("http://qudt.org/vocab/unit/KiloN")
    CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3")
    BTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2")
    M_PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PA-PER-SEC")
    MicroGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3")
    HZ_PER_T = URIRef("http://qudt.org/vocab/unit/HZ-PER-T")
    CentiMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-KiloGM")
    PER_DEG_F = URIRef("http://qudt.org/vocab/unit/PER-DEG_F")
    ExaV_A = URIRef("http://qudt.org/vocab/unit/ExaV-A")
    GM_HR_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M3-CentiM3")
    KiloCAL_Mean = URIRef("http://qudt.org/vocab/unit/KiloCAL_Mean")
    M2_PER_SR = URIRef("http://qudt.org/vocab/unit/M2-PER-SR")
    FemtoM = URIRef("http://qudt.org/vocab/unit/FemtoM")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    KiloW_HR = URIRef("http://qudt.org/vocab/unit/KiloW-HR")
    MegaV = URIRef("http://qudt.org/vocab/unit/MegaV")
    CentiM_HG = URIRef("http://qudt.org/vocab/unit/CentiM_HG")
    NanoV = URIRef("http://qudt.org/vocab/unit/NanoV")
    LB_PER_GAL = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL")
    M2_PER_J = URIRef("http://qudt.org/vocab/unit/M2-PER-J")
    MilliSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-SEC")
    RAD_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-KiloGM")
    KiloJ_PER_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-K")
    GM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciL")
    OZ_SEC_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-GAL_US")
    SEC_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-FT2")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    A_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Stat-PER-CentiM2")
    KiloL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloL-PER-HR")
    PicoW = URIRef("http://qudt.org/vocab/unit/PicoW")
    LB_PER_YD3 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD3")
    CAL_MEAN = URIRef("http://qudt.org/vocab/unit/CAL_MEAN")
    FemtoM = URIRef("http://qudt.org/vocab/unit/FemtoM")
    LB_F_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN")
    N_PER_A = URIRef("http://qudt.org/vocab/unit/N-PER-A")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    GM_SEC_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L-CentiM3")
    FemtoMOL = URIRef("http://qudt.org/vocab/unit/FemtoMOL")
    MilliBAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-M3-PER-SEC")
    Da = URIRef("http://qudt.org/vocab/unit/Da")
    KiloMOL_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3-K")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    W_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-PER-M3")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    NanoFARAD = URIRef("http://qudt.org/vocab/unit/NanoFARAD")
    MilliGM_PER_L_PA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-PA-SEC")
    NanoM_PER_CentiM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-MegaPA")
    PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-PSI")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    PlanckVolume = URIRef("http://qudt.org/vocab/unit/PlanckVolume")
    KiloGM_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC2")
    CM_H2O = URIRef("http://qudt.org/vocab/unit/CM_H2O")
    MilliA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliA-PER-BAR")
    N_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M3")
    MegaEV_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-CentiM")
    MegaS_PER_M = URIRef("http://qudt.org/vocab/unit/MegaS-PER-M")
    PPB = URIRef("http://qudt.org/vocab/unit/PPB")
    GR = URIRef("http://qudt.org/vocab/unit/GR")
    PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/PER-MilliM3")
    M2_HZ = URIRef("http://qudt.org/vocab/unit/M2-HZ")
    PINT_US_DRY = URIRef("http://qudt.org/vocab/unit/PINT_US_DRY")
    CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CentiM2-MIN")
    MilliL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-SEC")
    CFU = URIRef("http://qudt.org/vocab/unit/CFU")
    NanoS_PER_M = URIRef("http://qudt.org/vocab/unit/NanoS-PER-M")
    MilliM_PER_YR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-YR")
    MicroGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-DeciL")
    LB_HR_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-GAL_UK")
    GI = URIRef("http://qudt.org/vocab/unit/GI")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    PERCENT_PER_HR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-HR")
    FemtoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-KiloGM")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    PER_L = URIRef("http://qudt.org/vocab/unit/PER-L")
    S = URIRef("http://qudt.org/vocab/unit/S")
    BIT_PER_M = URIRef("http://qudt.org/vocab/unit/BIT-PER-M")
    PA_M0dot5 = URIRef("http://qudt.org/vocab/unit/PA-M0dot5")
    N_M_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-RAD")
    BAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-L-PER-SEC")
    NAT_PER_SEC = URIRef("http://qudt.org/vocab/unit/NAT-PER-SEC")
    KiloN_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M2")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    M_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-V-SEC")
    GM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC")
    LB_HR_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-YD3")
    MilliBAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-M3-PER-SEC")
    PlanckFrequency = URIRef("http://qudt.org/vocab/unit/PlanckFrequency")
    PER_GM = URIRef("http://qudt.org/vocab/unit/PER-GM")
    BTU_IT_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT-PER-FT2-HR-DEG_F")
    FemtoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-KiloGM")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    LB_F_PER_YD = URIRef("http://qudt.org/vocab/unit/LB_F-PER-YD")
    QT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-SEC")
    MicroH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-OHM")
    LA_FT = URIRef("http://qudt.org/vocab/unit/LA_FT")
    ERG_CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-CentiM2-PER-GM")
    LB_SEC_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK2")
    BBL_UK_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-SEC")
    PINT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-DAY")
    CI_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CI-PER-KiloGM")
    DeciM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-DAY")
    KiloGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM2")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    MicroM2 = URIRef("http://qudt.org/vocab/unit/MicroM2")
    C = URIRef("http://qudt.org/vocab/unit/C")
    NanoGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M3")
    H = URIRef("http://qudt.org/vocab/unit/H")
    GigaC = URIRef("http://qudt.org/vocab/unit/GigaC")
    HectoPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-M3-PER-SEC")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    S_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/S-M2-PER-MOL")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    BTU_TH_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT3")
    OCTET = URIRef("http://qudt.org/vocab/unit/OCTET")
    TeraJ = URIRef("http://qudt.org/vocab/unit/TeraJ")
    PER_DEG_C = URIRef("http://qudt.org/vocab/unit/PER-DEG_C")
    LB_IN2 = URIRef("http://qudt.org/vocab/unit/LB-IN2")
    N_M_PER_A = URIRef("http://qudt.org/vocab/unit/N-M-PER-A")
    BTU_IT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_F")
    PK_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-HR")
    OZ = URIRef("http://qudt.org/vocab/unit/OZ")
    MilliM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-HR")
    KiloV_PER_M = URIRef("http://qudt.org/vocab/unit/KiloV-PER-M")
    LB_SEC_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-GAL_UK")
    N_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-PER-RAD")
    GigaW_HR = URIRef("http://qudt.org/vocab/unit/GigaW-HR")
    BARN = URIRef("http://qudt.org/vocab/unit/BARN")
    PlanckDensity = URIRef("http://qudt.org/vocab/unit/PlanckDensity")
    IN2 = URIRef("http://qudt.org/vocab/unit/IN2")
    N_M_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-RAD")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    OZ_MIN_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-FT3")
    MilliV_PER_V = URIRef("http://qudt.org/vocab/unit/MilliV-PER-V")
    DEG_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC2")
    M2_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-K")
    MilliGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-DAY")
    BBL_US_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-SEC")
    DEATHS_PER_MegaINDIV_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-MegaINDIV-YR")
    PERCENT_SEC_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-IN3")
    DEG_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC")
    PicoC = URIRef("http://qudt.org/vocab/unit/PicoC")
    FRACTION = URIRef("http://qudt.org/vocab/unit/FRACTION")
    HectoPA = URIRef("http://qudt.org/vocab/unit/HectoPA")
    LB_PER_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-DAY")
    PERCENT_PER_V = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-V")
    QT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-MIN")
    KiloBAR = URIRef("http://qudt.org/vocab/unit/KiloBAR")
    NUM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NUM-PER-MicroL")
    DEG_R = URIRef("http://qudt.org/vocab/unit/DEG_R")
    MIN = URIRef("http://qudt.org/vocab/unit/MIN")
    PicoPA_PER_KiloM = URIRef("http://qudt.org/vocab/unit/PicoPA-PER-KiloM")
    DeciM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MOL")
    V_PER_MicroSEC = URIRef("http://qudt.org/vocab/unit/V-PER-MicroSEC")
    CentiPOISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-BAR")
    LB_MIN_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-FT3")
    PlanckForce = URIRef("http://qudt.org/vocab/unit/PlanckForce")
    GRAIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL_US")
    M2_HZ3 = URIRef("http://qudt.org/vocab/unit/M2-HZ3")
    MegaA = URIRef("http://qudt.org/vocab/unit/MegaA")
    NanoM_PER_MilliM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-MilliM-MegaPA")
    FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-SEC-DEG_F")
    L_PER_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-SEC")
    M2_PER_HZ = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ")
    PHOT = URIRef("http://qudt.org/vocab/unit/PHOT")
    BU_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-SEC")
    MegaDOLLAR_US_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MegaDOLLAR_US-PER-FLIGHT")
    MicroW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroW-PER-M2")
    CAL_IT_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM2-K")
    L_PER_HR = URIRef("http://qudt.org/vocab/unit/L-PER-HR")
    C_Stat = URIRef("http://qudt.org/vocab/unit/C_Stat")
    RAYL = URIRef("http://qudt.org/vocab/unit/RAYL")
    MicroV_A = URIRef("http://qudt.org/vocab/unit/MicroV-A")
    L = URIRef("http://qudt.org/vocab/unit/L")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    HP = URIRef("http://qudt.org/vocab/unit/HP")
    AT = URIRef("http://qudt.org/vocab/unit/AT")
    SAMPLE_PER_SEC = URIRef("http://qudt.org/vocab/unit/SAMPLE-PER-SEC")
    SV_PER_HR = URIRef("http://qudt.org/vocab/unit/SV-PER-HR")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    FT_LA = URIRef("http://qudt.org/vocab/unit/FT-LA")
    CentiM2_PER_ERG = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-ERG")
    PicoFARAD = URIRef("http://qudt.org/vocab/unit/PicoFARAD")
    LB_PER_IN = URIRef("http://qudt.org/vocab/unit/LB-PER-IN")
    PER_H = URIRef("http://qudt.org/vocab/unit/PER-H")
    E = URIRef("http://qudt.org/vocab/unit/E")
    L_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-BAR")
    Stone_UK = URIRef("http://qudt.org/vocab/unit/Stone_UK")
    GI_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_US-PER-DAY")
    OZ_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_UK")
    MilliA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/MilliA-PER-MilliM")
    PER_LB = URIRef("http://qudt.org/vocab/unit/PER-LB")
    MicroCi = URIRef("http://qudt.org/vocab/unit/MicroCi")
    LB_IN2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-IN3-LB_F-SEC")
    KiloGM_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM2")
    GM_HR_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M3-L")
    BTU_IT_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_F")
    QT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_US-PER-MIN")
    CentiM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN")
    ONE_PER_ONE = URIRef("http://qudt.org/vocab/unit/ONE-PER-ONE")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    NanoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/NanoKAT-PER-L")
    LB_PER_YD2 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD2")
    N_CentiM = URIRef("http://qudt.org/vocab/unit/N-CentiM")
    BARYE = URIRef("http://qudt.org/vocab/unit/BARYE")
    MilliL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-MIN")
    REM_PER_SEC = URIRef("http://qudt.org/vocab/unit/REM-PER-SEC")
    PER_M2 = URIRef("http://qudt.org/vocab/unit/PER-M2")
    PicoMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M2-DAY")
    KiloBTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH-PER-HR")
    KiloGM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MilliM")
    KiloOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-BAR")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    MicroBAR = URIRef("http://qudt.org/vocab/unit/MicroBAR")
    A_Ab_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-CentiM2")
    SAMPLE_PER_SEC = URIRef("http://qudt.org/vocab/unit/SAMPLE-PER-SEC")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    M3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-BAR")
    MilliV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MilliV-A_Reactive")
    MilliPA = URIRef("http://qudt.org/vocab/unit/MilliPA")
    M3_PER_DAY = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY")
    KiloTON_Metric = URIRef("http://qudt.org/vocab/unit/KiloTON_Metric")
    KiloCi = URIRef("http://qudt.org/vocab/unit/KiloCi")
    T_SEC = URIRef("http://qudt.org/vocab/unit/T-SEC")
    CentiMOL = URIRef("http://qudt.org/vocab/unit/CentiMOL")
    MilliGM_PER_L = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L")
    GigaA = URIRef("http://qudt.org/vocab/unit/GigaA")
    MilliBAR_PER_K = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-K")
    FemtoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-KiloGM")
    PERCENT_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-M3")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    BTU_IT_PER_HR_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_R")
    J_PER_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-DAY")
    DEGREE_BAUME_US_LIGHT = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_LIGHT")
    MOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-SEC")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    M_PER_DEG_C_M = URIRef("http://qudt.org/vocab/unit/M-PER-DEG_C-M")
    LB_FT2 = URIRef("http://qudt.org/vocab/unit/LB-FT2")
    CentiBAR = URIRef("http://qudt.org/vocab/unit/CentiBAR")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    MicroIN = URIRef("http://qudt.org/vocab/unit/MicroIN")
    KiloS_PER_M = URIRef("http://qudt.org/vocab/unit/KiloS-PER-M")
    MilliGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MilliL")
    PER_M2 = URIRef("http://qudt.org/vocab/unit/PER-M2")
    BTU_TH = URIRef("http://qudt.org/vocab/unit/BTU_TH")
    FT3 = URIRef("http://qudt.org/vocab/unit/FT3")
    PetaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/PetaJ-PER-SEC")
    SH = URIRef("http://qudt.org/vocab/unit/SH")
    GM_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM2")
    KiloGM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR")
    REV_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC2")
    BARN_PER_SR_EV = URIRef("http://qudt.org/vocab/unit/BARN-PER-SR-EV")
    MilliC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M2")
    EV_PER_M = URIRef("http://qudt.org/vocab/unit/EV-PER-M")
    YD3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD3-PER-DEG_F")
    PSI_YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-YD3-PER-SEC")
    DEG_C_KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/DEG_C-KiloGM-PER-M2")
    BTU_IT_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_R")
    MegaPSI = URIRef("http://qudt.org/vocab/unit/MegaPSI")
    C_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM")
    L_PER_HR = URIRef("http://qudt.org/vocab/unit/L-PER-HR")
    N_M_PER_MIN_Angle = URIRef("http://qudt.org/vocab/unit/N-M-PER-MIN_Angle")
    DeciM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-DAY")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    DeciM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MIN")
    CentiM_PER_YR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-YR")
    FemtoSEC = URIRef("http://qudt.org/vocab/unit/FemtoSEC")
    MicroGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-MilliL")
    DEG_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC2")
    GR = URIRef("http://qudt.org/vocab/unit/GR")
    AT_PER_IN = URIRef("http://qudt.org/vocab/unit/AT-PER-IN")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    GM_PER_MIN = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN")
    PicoV_A_Reactive = URIRef("http://qudt.org/vocab/unit/PicoV-A_Reactive")
    KiloGM_PER_M_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-DAY")
    GigaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBYTE-PER-SEC")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    TonEnergy = URIRef("http://qudt.org/vocab/unit/TonEnergy")
    GibiBIT = URIRef("http://qudt.org/vocab/unit/GibiBIT")
    PPM = URIRef("http://qudt.org/vocab/unit/PPM")
    DYN_M = URIRef("http://qudt.org/vocab/unit/DYN-M")
    EV_PER_T = URIRef("http://qudt.org/vocab/unit/EV-PER-T")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    BTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR")
    MegaN_M = URIRef("http://qudt.org/vocab/unit/MegaN-M")
    PlanckLength = URIRef("http://qudt.org/vocab/unit/PlanckLength")
    MegaV_PER_M = URIRef("http://qudt.org/vocab/unit/MegaV-PER-M")
    PA_PER_M = URIRef("http://qudt.org/vocab/unit/PA-PER-M")
    MegaOHM_KiloM = URIRef("http://qudt.org/vocab/unit/MegaOHM-KiloM")
    HR_PER_FT2 = URIRef("http://qudt.org/vocab/unit/HR-PER-FT2")
    PA_PER_M = URIRef("http://qudt.org/vocab/unit/PA-PER-M")
    MicroN_M = URIRef("http://qudt.org/vocab/unit/MicroN-M")
    PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/PER-M2-SEC")
    EV_PER_T = URIRef("http://qudt.org/vocab/unit/EV-PER-T")
    MilliGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-BAR")
    KibiBYTE = URIRef("http://qudt.org/vocab/unit/KibiBYTE")
    TON_Metric_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN-BAR")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    MicroT = URIRef("http://qudt.org/vocab/unit/MicroT")
    W_M2 = URIRef("http://qudt.org/vocab/unit/W-M2")
    PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-PSI")
    MilliGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-BAR")
    BQ_PER_L = URIRef("http://qudt.org/vocab/unit/BQ-PER-L")
    LB_MIN_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-YD3")
    GM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3")
    FemtoC = URIRef("http://qudt.org/vocab/unit/FemtoC")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    GigaBIT_PER_M = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-M")
    NUM_PER_GM = URIRef("http://qudt.org/vocab/unit/NUM-PER-GM")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    RichterMagnitude = URIRef("http://qudt.org/vocab/unit/RichterMagnitude")
    AC_FT = URIRef("http://qudt.org/vocab/unit/AC-FT")
    IN3_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN3-PER-MIN")
    L_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-MOL-SEC")
    Standard = URIRef("http://qudt.org/vocab/unit/Standard")
    RT = URIRef("http://qudt.org/vocab/unit/RT")
    DeciL = URIRef("http://qudt.org/vocab/unit/DeciL")
    MOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MOL-PER-MOL")
    MilliGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-CentiM2")
    HP_Metric = URIRef("http://qudt.org/vocab/unit/HP_Metric")
    NanoA_PER_K = URIRef("http://qudt.org/vocab/unit/NanoA-PER-K")
    HR_FT2 = URIRef("http://qudt.org/vocab/unit/HR-FT2")
    SV_PER_HR = URIRef("http://qudt.org/vocab/unit/SV-PER-HR")
    GM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3-K")
    PicoH = URIRef("http://qudt.org/vocab/unit/PicoH")
    MicroBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-L")
    MilliG = URIRef("http://qudt.org/vocab/unit/MilliG")
    DECADE = URIRef("http://qudt.org/vocab/unit/DECADE")
    MicroL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroL-PER-L")
    KiloHZ_M = URIRef("http://qudt.org/vocab/unit/KiloHZ-M")
    KiloGM_PER_L = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L")
    GRAIN = URIRef("http://qudt.org/vocab/unit/GRAIN")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    KiloCi = URIRef("http://qudt.org/vocab/unit/KiloCi")
    M_PER_HR = URIRef("http://qudt.org/vocab/unit/M-PER-HR")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A-HR")
    OERSTED_CentiM = URIRef("http://qudt.org/vocab/unit/OERSTED-CentiM")
    ST_PER_PA = URIRef("http://qudt.org/vocab/unit/ST-PER-PA")
    MicroGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-GM")
    KibiBIT = URIRef("http://qudt.org/vocab/unit/KibiBIT")
    M2_PER_SR_J = URIRef("http://qudt.org/vocab/unit/M2-PER-SR-J")
    H_Ab = URIRef("http://qudt.org/vocab/unit/H_Ab")
    MicroIN = URIRef("http://qudt.org/vocab/unit/MicroIN")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    FT_PDL = URIRef("http://qudt.org/vocab/unit/FT-PDL")
    NanoA = URIRef("http://qudt.org/vocab/unit/NanoA")
    MOL_LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-MIN")
    PA_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-PER-BAR")
    MilliGAL_PER_MO = URIRef("http://qudt.org/vocab/unit/MilliGAL-PER-MO")
    NUM_PER_CentiM_KiloYR = URIRef("http://qudt.org/vocab/unit/NUM-PER-CentiM-KiloYR")
    OZ_F = URIRef("http://qudt.org/vocab/unit/OZ_F")
    PA_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC")
    TON_UK_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-YD3")
    V = URIRef("http://qudt.org/vocab/unit/V")
    YD_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD-PER-DEG_F")
    K_PER_PA = URIRef("http://qudt.org/vocab/unit/K-PER-PA")
    MicroM_PER_N = URIRef("http://qudt.org/vocab/unit/MicroM-PER-N")
    MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/MOL_LB-DEG_F")
    MicroW = URIRef("http://qudt.org/vocab/unit/MicroW")
    MIN_Sidereal = URIRef("http://qudt.org/vocab/unit/MIN_Sidereal")
    DEG_C_GROWING_CEREAL_DAY = URIRef("http://qudt.org/vocab/unit/DEG_C_GROWING_CEREAL-DAY")
    GigaW = URIRef("http://qudt.org/vocab/unit/GigaW")
    PER_DAY = URIRef("http://qudt.org/vocab/unit/PER-DAY")
    V_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-PER-CentiM")
    BREATH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BREATH-PER-MIN")
    CentiM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC-K")
    LB_PER_FT3 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3")
    W_HR = URIRef("http://qudt.org/vocab/unit/W-HR")
    KiloJ_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-DAY")
    MicroMOL_PER_GM_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM-HR")
    NanoGM_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2-DAY")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    KiloPOND = URIRef("http://qudt.org/vocab/unit/KiloPOND")
    PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/PER-MilliM3")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    PER_K = URIRef("http://qudt.org/vocab/unit/PER-K")
    GI_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_US-PER-DAY")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    KiloGM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-FT2")
    KiloGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC")
    PER_J2 = URIRef("http://qudt.org/vocab/unit/PER-J2")
    BBL_UK_PET_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-DAY")
    PER_CentiM = URIRef("http://qudt.org/vocab/unit/PER-CentiM")
    PK_US_DRY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY")
    MicroS = URIRef("http://qudt.org/vocab/unit/MicroS")
    DecaGM = URIRef("http://qudt.org/vocab/unit/DecaGM")
    N_M_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-M")
    GI_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-DAY")
    PA_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC2")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    MilliSV = URIRef("http://qudt.org/vocab/unit/MilliSV")
    LB_SEC_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-IN3")
    CAL_TH_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-K")
    NanoSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-MIN")
    PER_T_M = URIRef("http://qudt.org/vocab/unit/PER-T-M")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    LB_SEC_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US2")
    Gs = URIRef("http://qudt.org/vocab/unit/Gs")
    MicroV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MicroV-A_Reactive")
    PK_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-HR")
    BTU_TH_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_R")
    MOMME_Textile = URIRef("http://qudt.org/vocab/unit/MOMME_Textile")
    PERCENT_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-CentiM3")
    HP_Brake = URIRef("http://qudt.org/vocab/unit/HP_Brake")
    KiloCAL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MIN")
    MicroM_PER_K = URIRef("http://qudt.org/vocab/unit/MicroM-PER-K")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    N = URIRef("http://qudt.org/vocab/unit/N")
    PlanckFrequency = URIRef("http://qudt.org/vocab/unit/PlanckFrequency")
    AttoC = URIRef("http://qudt.org/vocab/unit/AttoC")
    DeciM3 = URIRef("http://qudt.org/vocab/unit/DeciM3")
    A_MIN = URIRef("http://qudt.org/vocab/unit/A-MIN")
    CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-GM")
    MI_PER_SEC = URIRef("http://qudt.org/vocab/unit/MI-PER-SEC")
    W_PER_M2_M = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M")
    MOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM")
    GM_SEC_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M3-CentiM3")
    LY = URIRef("http://qudt.org/vocab/unit/LY")
    GR = URIRef("http://qudt.org/vocab/unit/GR")
    GM_PER_M2 = URIRef("http://qudt.org/vocab/unit/GM-PER-M2")
    Gamma = URIRef("http://qudt.org/vocab/unit/Gamma")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    MicroFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-M")
    FemtoC = URIRef("http://qudt.org/vocab/unit/FemtoC")
    NanoC = URIRef("http://qudt.org/vocab/unit/NanoC")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    CD_PER_IN2 = URIRef("http://qudt.org/vocab/unit/CD-PER-IN2")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    M2_HZ = URIRef("http://qudt.org/vocab/unit/M2-HZ")
    MicroMOL_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM-SEC")
    BTU_IT_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-HR-DEG_F")
    CD_PER_M2 = URIRef("http://qudt.org/vocab/unit/CD-PER-M2")
    V_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/V-A_Reactive-PER-K")
    Denier = URIRef("http://qudt.org/vocab/unit/Denier")
    TON_Metric_PER_MIN = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN")
    LB_MIN_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-FT3")
    BTU_IT_IN_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-SEC-FT2-DEG_F")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    MilliJ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-GM")
    M_PER_HR = URIRef("http://qudt.org/vocab/unit/M-PER-HR")
    MilliGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-CentiM2")
    MOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-DAY")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    MilliL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M3")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    MilliN_M = URIRef("http://qudt.org/vocab/unit/MilliN-M")
    BBL_UK_PET = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET")
    GA_Charriere = URIRef("http://qudt.org/vocab/unit/GA_Charriere")
    GM_PER_MilliM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM-BAR")
    MOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL-PER-MIN")
    LB_F_FT = URIRef("http://qudt.org/vocab/unit/LB_F-FT")
    NanoM_PER_MilliM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-MilliM-MegaPA")
    LM_PER_W = URIRef("http://qudt.org/vocab/unit/LM-PER-W")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    PERCENT_PER_MO = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MO")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    SEC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/SEC-PER-KiloGM")
    DEGREE_BAUME = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME")
    F = URIRef("http://qudt.org/vocab/unit/F")
    MicroL = URIRef("http://qudt.org/vocab/unit/MicroL")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    M = URIRef("http://qudt.org/vocab/unit/M")
    KiloA = URIRef("http://qudt.org/vocab/unit/KiloA")
    KiloLB_F = URIRef("http://qudt.org/vocab/unit/KiloLB_F")
    GM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-BAR")
    KiloHZ = URIRef("http://qudt.org/vocab/unit/KiloHZ")
    MicroH = URIRef("http://qudt.org/vocab/unit/MicroH")
    BU_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-SEC")
    S_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/S-M2-PER-MOL")
    M2_K = URIRef("http://qudt.org/vocab/unit/M2-K")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    BTU_IT_PER_MOL_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    MegaOHM = URIRef("http://qudt.org/vocab/unit/MegaOHM")
    AMU = URIRef("http://qudt.org/vocab/unit/AMU")
    W_M2 = URIRef("http://qudt.org/vocab/unit/W-M2")
    QT_UK = URIRef("http://qudt.org/vocab/unit/QT_UK")
    PlanckImpedance = URIRef("http://qudt.org/vocab/unit/PlanckImpedance")
    GigaBasePair = URIRef("http://qudt.org/vocab/unit/GigaBasePair")
    MegaOHM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-KiloM")
    ERG = URIRef("http://qudt.org/vocab/unit/ERG")
    PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PER-SEC2")
    KiloGM_PER_MegaBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MegaBTU_IT")
    Flight = URIRef("http://qudt.org/vocab/unit/Flight")
    FT_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC-DEG_F")
    C_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM-SEC")
    MilliH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-OHM")
    YD3_PER_HR = URIRef("http://qudt.org/vocab/unit/YD3-PER-HR")
    PT = URIRef("http://qudt.org/vocab/unit/PT")
    MilliGM = URIRef("http://qudt.org/vocab/unit/MilliGM")
    PicoV = URIRef("http://qudt.org/vocab/unit/PicoV")
    KiloJ_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM-K")
    OZ_VOL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-SEC")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    P = URIRef("http://qudt.org/vocab/unit/P")
    OZ_PER_YD2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD2")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    GM_PER_MOL = URIRef("http://qudt.org/vocab/unit/GM-PER-MOL")
    MicroMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L-HR")
    S_PER_CentiM = URIRef("http://qudt.org/vocab/unit/S-PER-CentiM")
    DecaARE = URIRef("http://qudt.org/vocab/unit/DecaARE")
    DecaGM = URIRef("http://qudt.org/vocab/unit/DecaGM")
    PicoL = URIRef("http://qudt.org/vocab/unit/PicoL")
    TORR = URIRef("http://qudt.org/vocab/unit/TORR")
    PERCENT_PER_IN = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-IN")
    MilliMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-GM")
    L_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-MOL-SEC")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    FARAD_Ab = URIRef("http://qudt.org/vocab/unit/FARAD_Ab")
    PicoMOL_PER_M_W_SEC = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M-W-SEC")
    MicroGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-MilliL")
    FemtoJ = URIRef("http://qudt.org/vocab/unit/FemtoJ")
    M2_PER_M2 = URIRef("http://qudt.org/vocab/unit/M2-PER-M2")
    QT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-DAY")
    PPB = URIRef("http://qudt.org/vocab/unit/PPB")
    KiloC = URIRef("http://qudt.org/vocab/unit/KiloC")
    MicroM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroM-PER-SEC")
    A_PER_RAD = URIRef("http://qudt.org/vocab/unit/A-PER-RAD")
    KiloGM_PER_M3_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-PA")
    PA_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M")
    MilliGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-BAR")
    MegaOHM_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-M")
    KiloJ_PER_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-K")
    GigaOHM_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-M")
    TeraOHM = URIRef("http://qudt.org/vocab/unit/TeraOHM")
    EV = URIRef("http://qudt.org/vocab/unit/EV")
    GM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC-K")
    PINT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-HR")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    DEGREE_BALLING = URIRef("http://qudt.org/vocab/unit/DEGREE_BALLING")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    PicoH = URIRef("http://qudt.org/vocab/unit/PicoH")
    MilliW = URIRef("http://qudt.org/vocab/unit/MilliW")
    BBL = URIRef("http://qudt.org/vocab/unit/BBL")
    RAD_PER_HR = URIRef("http://qudt.org/vocab/unit/RAD-PER-HR")
    CAL_TH_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM2-K")
    LB_HR_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN6")
    DEG_F_HR_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_IT")
    LANGLEY = URIRef("http://qudt.org/vocab/unit/LANGLEY")
    KiloGM_PER_M_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-HR")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    K = URIRef("http://qudt.org/vocab/unit/K")
    MilliGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-DAY")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    A_HR = URIRef("http://qudt.org/vocab/unit/A-HR")
    ZeptoC = URIRef("http://qudt.org/vocab/unit/ZeptoC")
    KiloGM_F_M_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-CentiM2")
    PebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M")
    A = URIRef("http://qudt.org/vocab/unit/A")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    M3_PER_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-M2")
    KiloN_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M2")
    MilliJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-M2")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    GI_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-DAY")
    FT_LB_F = URIRef("http://qudt.org/vocab/unit/FT-LB_F")
    FT_PER_PSI = URIRef("http://qudt.org/vocab/unit/FT-PER-PSI")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    QT_US_DRY = URIRef("http://qudt.org/vocab/unit/QT_US_DRY")
    KIP_F = URIRef("http://qudt.org/vocab/unit/KIP_F")
    V_A_HR = URIRef("http://qudt.org/vocab/unit/V-A-HR")
    GM_PER_MIN = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN")
    LB_IN2 = URIRef("http://qudt.org/vocab/unit/LB-IN2")
    LB_PER_IN3 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3")
    FT3_PER_MIN_FT2 = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN-FT2")
    MilliGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-SEC")
    MilliRAD_R = URIRef("http://qudt.org/vocab/unit/MilliRAD_R")
    PER_DEG_F = URIRef("http://qudt.org/vocab/unit/PER-DEG_F")
    V_PER_V = URIRef("http://qudt.org/vocab/unit/V-PER-V")
    FemtoJ = URIRef("http://qudt.org/vocab/unit/FemtoJ")
    OZ_MIN_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-YD3")
    CAL_IT = URIRef("http://qudt.org/vocab/unit/CAL_IT")
    HR_FT2 = URIRef("http://qudt.org/vocab/unit/HR-FT2")
    GM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL")
    PSU = URIRef("http://qudt.org/vocab/unit/PSU")
    KiloBAR = URIRef("http://qudt.org/vocab/unit/KiloBAR")
    MilliGM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-BAR")
    SEC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/SEC-PER-KiloGM")
    CAL_TH_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM")
    MilliGM_SEC_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M6")
    LB_HR_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-GAL_UK")
    LB_PER_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-PSI")
    OCTET = URIRef("http://qudt.org/vocab/unit/OCTET")
    PER_YR = URIRef("http://qudt.org/vocab/unit/PER-YR")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    TON_FG_HR = URIRef("http://qudt.org/vocab/unit/TON_FG-HR")
    BTU_TH_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-SEC-DEG_F")
    CentiM3_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN-K")
    LB_SEC_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US2")
    OZ_SEC_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-GAL_US")
    FT_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC-DEG_F")
    PSU = URIRef("http://qudt.org/vocab/unit/PSU")
    MicroT = URIRef("http://qudt.org/vocab/unit/MicroT")
    N_M_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-RAD")
    KiloGM_M = URIRef("http://qudt.org/vocab/unit/KiloGM-M")
    FT_LB_F_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2-SEC")
    CHAIN_US = URIRef("http://qudt.org/vocab/unit/CHAIN_US")
    TONNE_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY-BAR")
    CAL_TH_PER_G = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-G")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    LB_IN2_PER_GAL_US_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-GAL_US-LB_F-SEC")
    PlanckCurrent = URIRef("http://qudt.org/vocab/unit/PlanckCurrent")
    PlanckFrequency = URIRef("http://qudt.org/vocab/unit/PlanckFrequency")
    FARAD_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/FARAD_Ab-PER-CentiM")
    LB_F_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-SEC")
    M_PER_DEG_C_M = URIRef("http://qudt.org/vocab/unit/M-PER-DEG_C-M")
    MilliM3 = URIRef("http://qudt.org/vocab/unit/MilliM3")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    SEC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/SEC-PER-KiloGM")
    MicroH_PER_M = URIRef("http://qudt.org/vocab/unit/MicroH-PER-M")
    GM_PER_HZ = URIRef("http://qudt.org/vocab/unit/GM-PER-HZ")
    HectoPA_PER_HR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-HR")
    DIOPTER = URIRef("http://qudt.org/vocab/unit/DIOPTER")
    K_PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PA-PER-SEC")
    CentiM_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-HR")
    M_K_PER_W = URIRef("http://qudt.org/vocab/unit/M-K-PER-W")
    MO_MeanGREGORIAN = URIRef("http://qudt.org/vocab/unit/MO_MeanGREGORIAN")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    MilliMOL = URIRef("http://qudt.org/vocab/unit/MilliMOL")
    PSI_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-L-PER-SEC")
    C_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM-SEC")
    MegaS = URIRef("http://qudt.org/vocab/unit/MegaS")
    KiloJ_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MOL")
    MicroOHM = URIRef("http://qudt.org/vocab/unit/MicroOHM")
    NanoOHM_M = URIRef("http://qudt.org/vocab/unit/NanoOHM-M")
    KN_PER_SEC = URIRef("http://qudt.org/vocab/unit/KN-PER-SEC")
    DecaC = URIRef("http://qudt.org/vocab/unit/DecaC")
    LB_F_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-FT2")
    MilliGM_SEC_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L-M3")
    BU_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-SEC")
    KiloLB_F_FT_PER_A = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-A")
    LB_HR_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-FT3")
    MilliGM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR")
    C_M2 = URIRef("http://qudt.org/vocab/unit/C-M2")
    N_M_PER_A = URIRef("http://qudt.org/vocab/unit/N-M-PER-A")
    M3_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-BAR")
    MicroGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-MilliL")
    HZ_M = URIRef("http://qudt.org/vocab/unit/HZ-M")
    MegaV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive")
    BAR = URIRef("http://qudt.org/vocab/unit/BAR")
    KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT")
    FT_SEC_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-GAL_UK")
    MOL_K = URIRef("http://qudt.org/vocab/unit/MOL-K")
    V = URIRef("http://qudt.org/vocab/unit/V")
    KiloCAL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-SEC")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    HectoC = URIRef("http://qudt.org/vocab/unit/HectoC")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    KiloGM_PER_M_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-MIN")
    MicroSV = URIRef("http://qudt.org/vocab/unit/MicroSV")
    GAL_IMP = URIRef("http://qudt.org/vocab/unit/GAL_IMP")
    M5 = URIRef("http://qudt.org/vocab/unit/M5")
    ExaV_A = URIRef("http://qudt.org/vocab/unit/ExaV-A")
    DeciL_PER_GM = URIRef("http://qudt.org/vocab/unit/DeciL-PER-GM")
    OZ_FT2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/OZ-FT2-PER-IN3-LB_F-SEC")
    YD3_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD3-PER-MIN")
    AttoA = URIRef("http://qudt.org/vocab/unit/AttoA")
    LB_PER_MIN_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN-PSI")
    DIOPTER = URIRef("http://qudt.org/vocab/unit/DIOPTER")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    LB_F_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-IN2")
    PDL = URIRef("http://qudt.org/vocab/unit/PDL")
    KiloCAL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-SEC")
    MilliBAR_PER_K = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-K")
    MilliPA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-BAR")
    PDL_PER_IN2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-IN2")
    FT_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC-PSI")
    MOL_PER_KiloGM_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-BAR")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    ERG_CentiM2 = URIRef("http://qudt.org/vocab/unit/ERG-CentiM2")
    MegaPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-L-PER-SEC")
    TONNE_PER_M3 = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3")
    CentiM4 = URIRef("http://qudt.org/vocab/unit/CentiM4")
    MOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC")
    MilliM_HG = URIRef("http://qudt.org/vocab/unit/MilliM_HG")
    HP_Brake = URIRef("http://qudt.org/vocab/unit/HP_Brake")
    MilliGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN")
    BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN")
    IN = URIRef("http://qudt.org/vocab/unit/IN")
    K_M = URIRef("http://qudt.org/vocab/unit/K-M")
    CLO = URIRef("http://qudt.org/vocab/unit/CLO")
    LB_MIN_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-GAL_UK")
    W_PER_M2_K = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K")
    W_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M3")
    BTU_TH_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-SEC")
    M2_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-V-SEC")
    OZ_F = URIRef("http://qudt.org/vocab/unit/OZ_F")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    C_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM-SEC")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    M3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM")
    GAL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-DAY")
    W_PER_M_K = URIRef("http://qudt.org/vocab/unit/W-PER-M-K")
    M2_PER_J = URIRef("http://qudt.org/vocab/unit/M2-PER-J")
    DecaGM = URIRef("http://qudt.org/vocab/unit/DecaGM")
    MilliL_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY")
    ZeptoC = URIRef("http://qudt.org/vocab/unit/ZeptoC")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    CentiM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC-BAR")
    MegaBIT = URIRef("http://qudt.org/vocab/unit/MegaBIT")
    MilliSV = URIRef("http://qudt.org/vocab/unit/MilliSV")
    KiloGM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-BAR")
    M2_PER_J = URIRef("http://qudt.org/vocab/unit/M2-PER-J")
    FT_LB_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-M2")
    BTU_IT_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-SEC-DEG_F")
    A_Ab_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-CentiM2")
    KiloLB_F_FT_PER_LB = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-LB")
    KiloPA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-MilliM")
    PK_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-MIN")
    J_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2-DAY")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    LunarMass = URIRef("http://qudt.org/vocab/unit/LunarMass")
    ERG = URIRef("http://qudt.org/vocab/unit/ERG")
    GAL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-HR")
    OZ_VOL_UK = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK")
    PER_SEC_M2_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2-SR")
    OZ_FT2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/OZ-FT2-PER-IN3-LB_F-SEC")
    S_PER_CentiM = URIRef("http://qudt.org/vocab/unit/S-PER-CentiM")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    PPTM = URIRef("http://qudt.org/vocab/unit/PPTM")
    DEG_R_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-MIN")
    BU_US = URIRef("http://qudt.org/vocab/unit/BU_US")
    AttoFARAD = URIRef("http://qudt.org/vocab/unit/AttoFARAD")
    KiloGM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM2-PER-SEC2")
    PER_MilliL = URIRef("http://qudt.org/vocab/unit/PER-MilliL")
    GM_Carbon_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Carbon-PER-M2-DAY")
    W_PER_M2_M = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M")
    J_M2 = URIRef("http://qudt.org/vocab/unit/J-M2")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    ERG_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM3")
    DEG_C_PER_YR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-YR")
    CAL_IT_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM-K")
    MilloMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilloMOL-PER-L")
    PERCENT_MIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-GAL_US")
    EV_PER_K = URIRef("http://qudt.org/vocab/unit/EV-PER-K")
    CentiM_HG = URIRef("http://qudt.org/vocab/unit/CentiM_HG")
    GM_Carbon_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Carbon-PER-M2-DAY")
    KiloSEC = URIRef("http://qudt.org/vocab/unit/KiloSEC")
    TON_SHORT_PER_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR-DEG_F")
    CD_PER_M2 = URIRef("http://qudt.org/vocab/unit/CD-PER-M2")
    W_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-PER-M3")
    MicroV = URIRef("http://qudt.org/vocab/unit/MicroV")
    DEG_C_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-K")
    N_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-PER-M3")
    FT_LB_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-M2")
    KibiBYTE = URIRef("http://qudt.org/vocab/unit/KibiBYTE")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    N_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM2")
    PicoFARAD = URIRef("http://qudt.org/vocab/unit/PicoFARAD")
    MOL_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB")
    PERM_23DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_23DEG_C")
    MOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-DAY")
    N_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M")
    MilliM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-HR")
    OZ_FT_SEC_PER_IN3_LB = URIRef("http://qudt.org/vocab/unit/OZ-FT-SEC-PER-IN3-LB")
    MOL_PER_M2_SEC_SR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-SR")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    LB_MIN_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-GAL_US")
    AMU = URIRef("http://qudt.org/vocab/unit/AMU")
    MegaGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-M3")
    MilliGM_HR_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L-CentiM3")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    CentiM3_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR-BAR")
    CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-SEC")
    BTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2")
    OHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/OHM-PER-BAR")
    PER_M_NanoM_SR = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM-SR")
    MicroBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-L")
    GigaFLOPS = URIRef("http://qudt.org/vocab/unit/GigaFLOPS")
    PicoMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M3")
    GM_PER_M2 = URIRef("http://qudt.org/vocab/unit/GM-PER-M2")
    PlanckMomentum = URIRef("http://qudt.org/vocab/unit/PlanckMomentum")
    BTU_TH_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT3")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    MegaEV_PER_SpeedOfLight = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-SpeedOfLight")
    MilliM_PER_DEG_C_M = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DEG_C-M")
    POISE_PER_K = URIRef("http://qudt.org/vocab/unit/POISE-PER-K")
    S = URIRef("http://qudt.org/vocab/unit/S")
    M2_PER_M2 = URIRef("http://qudt.org/vocab/unit/M2-PER-M2")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    DeciC = URIRef("http://qudt.org/vocab/unit/DeciC")
    TONNE_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN-BAR")
    LB_FT2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-IN3-LB_F-SEC")
    DEG_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG-PER-MIN")
    MilliIN = URIRef("http://qudt.org/vocab/unit/MilliIN")
    FT_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC-PSI")
    QT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_US-PER-HR")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    IN_PER_YR = URIRef("http://qudt.org/vocab/unit/IN-PER-YR")
    W_PER_M_K = URIRef("http://qudt.org/vocab/unit/W-PER-M-K")
    KiloGM_F_M_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-CentiM2")
    FBM = URIRef("http://qudt.org/vocab/unit/FBM")
    AttoC = URIRef("http://qudt.org/vocab/unit/AttoC")
    MilliJ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-GM")
    PDL_PER_IN = URIRef("http://qudt.org/vocab/unit/PDL-PER-IN")
    MDOLLAR_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MDOLLAR-PER-FLIGHT")
    QT_US_DRY = URIRef("http://qudt.org/vocab/unit/QT_US_DRY")
    PERCENT_HR_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-YD3")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    BBL_UK_PET_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-DAY")
    DecaL = URIRef("http://qudt.org/vocab/unit/DecaL")
    THM_US = URIRef("http://qudt.org/vocab/unit/THM_US")
    NUM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/NUM-PER-M2-DAY")
    KN = URIRef("http://qudt.org/vocab/unit/KN")
    MegaV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive")
    TON_SHORT_PER_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR-DEG_F")
    MilliM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC")
    EUR_PER_W_SEC = URIRef("http://qudt.org/vocab/unit/EUR-PER-W-SEC")
    MegaPSI = URIRef("http://qudt.org/vocab/unit/MegaPSI")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    CentiM3_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-CentiM3")
    GigaOHM = URIRef("http://qudt.org/vocab/unit/GigaOHM")
    AttoSEC = URIRef("http://qudt.org/vocab/unit/AttoSEC")
    BU_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-HR")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    TON_F_US = URIRef("http://qudt.org/vocab/unit/TON_F_US")
    MegaV_PER_M = URIRef("http://qudt.org/vocab/unit/MegaV-PER-M")
    V_A_Reactive = URIRef("http://qudt.org/vocab/unit/V-A_Reactive")
    CAL_TH_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2-SEC")
    MilliMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-GM")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    KiloCAL_TH = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH")
    KiloGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-PA-SEC")
    KiloMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-KiloGM")
    EarthMass = URIRef("http://qudt.org/vocab/unit/EarthMass")
    BTU_TH_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_F")
    GM_PER_MOL = URIRef("http://qudt.org/vocab/unit/GM-PER-MOL")
    DEG_R_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-MIN")
    PicoMOL_PER_M_W_SEC = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M-W-SEC")
    BTU_TH_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR-FT2-DEG_F")
    GAL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-DAY")
    TONNE_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY-K")
    PicoGM_PER_GM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-GM")
    FemtoGM = URIRef("http://qudt.org/vocab/unit/FemtoGM")
    MicroFARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-KiloM")
    S = URIRef("http://qudt.org/vocab/unit/S")
    MilliGM_PER_M3_POISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-POISE")
    GAL_US = URIRef("http://qudt.org/vocab/unit/GAL_US")
    MicroGM = URIRef("http://qudt.org/vocab/unit/MicroGM")
    LB_PER_FT = URIRef("http://qudt.org/vocab/unit/LB-PER-FT")
    BTU_60DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_60DEG_F")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    MOL_PER_L = URIRef("http://qudt.org/vocab/unit/MOL-PER-L")
    FT_H2O = URIRef("http://qudt.org/vocab/unit/FT_H2O")
    CentiM2_PER_ERG = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-ERG")
    MilliGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-SEC")
    N_PER_CentiM = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM")
    FT_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT-PER-DAY")
    MilliL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-KiloGM")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    FT = URIRef("http://qudt.org/vocab/unit/FT")
    YD3_PER_HR = URIRef("http://qudt.org/vocab/unit/YD3-PER-HR")
    NanoH = URIRef("http://qudt.org/vocab/unit/NanoH")
    ERG_SEC = URIRef("http://qudt.org/vocab/unit/ERG-SEC")
    MegaDOLLAR_US_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MegaDOLLAR_US-PER-FLIGHT")
    YD = URIRef("http://qudt.org/vocab/unit/YD")
    TONNE = URIRef("http://qudt.org/vocab/unit/TONNE")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    CARAT = URIRef("http://qudt.org/vocab/unit/CARAT")
    MilliM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DAY")
    OZ_VOL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-DAY")
    MilliL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC")
    CARAT = URIRef("http://qudt.org/vocab/unit/CARAT")
    GM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-M2-DAY")
    J_PER_M3_K = URIRef("http://qudt.org/vocab/unit/J-PER-M3-K")
    MilliM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC2")
    PER_SEC_SR_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR-M2")
    Kilo_FT3 = URIRef("http://qudt.org/vocab/unit/Kilo-FT3")
    C_M2 = URIRef("http://qudt.org/vocab/unit/C-M2")
    DeciGM = URIRef("http://qudt.org/vocab/unit/DeciGM")
    MilliGM_HR_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M6")
    HP_Electric = URIRef("http://qudt.org/vocab/unit/HP_Electric")
    W_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M3")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    MicroGM_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L-HR")
    HK = URIRef("http://qudt.org/vocab/unit/HK")
    YD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/YD-PER-SEC2")
    M_H2O = URIRef("http://qudt.org/vocab/unit/M_H2O")
    PA_M0pt5 = URIRef("http://qudt.org/vocab/unit/PA-M0pt5")
    N_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG")
    C_Stat_PER_MOL = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-MOL")
    L_PER_HR_K = URIRef("http://qudt.org/vocab/unit/L-PER-HR-K")
    PlanckDensity = URIRef("http://qudt.org/vocab/unit/PlanckDensity")
    BTU_IT_PER_MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB-DEG_F")
    W_PER_K = URIRef("http://qudt.org/vocab/unit/W-PER-K")
    MI = URIRef("http://qudt.org/vocab/unit/MI")
    PicoPA_PER_KiloM = URIRef("http://qudt.org/vocab/unit/PicoPA-PER-KiloM")
    TONNE_PER_M3 = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3")
    KiloMOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-MIN")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    MebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M")
    GAUGE_FR = URIRef("http://qudt.org/vocab/unit/GAUGE_FR")
    MilliA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/MilliA-PER-MilliM")
    BAUD = URIRef("http://qudt.org/vocab/unit/BAUD")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    GI_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_US-PER-HR")
    PicoH = URIRef("http://qudt.org/vocab/unit/PicoH")
    TON_Metric_PER_HR_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR-K")
    BTU_IT_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT3")
    N_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M2")
    N_M_PER_A = URIRef("http://qudt.org/vocab/unit/N-M-PER-A")
    TONNE_PER_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-K")
    PA_PER_MIN = URIRef("http://qudt.org/vocab/unit/PA-PER-MIN")
    V_PER_V = URIRef("http://qudt.org/vocab/unit/V-PER-V")
    M3_PER_M3 = URIRef("http://qudt.org/vocab/unit/M3-PER-M3")
    W_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM")
    BBL_UK_PET_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-MIN")
    KiloL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloL-PER-HR")
    DEGREE_BALLING = URIRef("http://qudt.org/vocab/unit/DEGREE_BALLING")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    MilliV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/MilliV-A_Reactive-PER-K")
    LB_F_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-IN2")
    A_PER_K = URIRef("http://qudt.org/vocab/unit/A-PER-K")
    PicoV_A = URIRef("http://qudt.org/vocab/unit/PicoV-A")
    EV_M2 = URIRef("http://qudt.org/vocab/unit/EV-M2")
    GAUGE_FR = URIRef("http://qudt.org/vocab/unit/GAUGE_FR")
    FemtoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-L")
    FT3_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN")
    M2_HZ3 = URIRef("http://qudt.org/vocab/unit/M2-HZ3")
    TON_F_US = URIRef("http://qudt.org/vocab/unit/TON_F_US")
    DeciSEC = URIRef("http://qudt.org/vocab/unit/DeciSEC")
    FARAD_Ab = URIRef("http://qudt.org/vocab/unit/FARAD_Ab")
    FemtoA = URIRef("http://qudt.org/vocab/unit/FemtoA")
    FemtoL = URIRef("http://qudt.org/vocab/unit/FemtoL")
    FemtoM = URIRef("http://qudt.org/vocab/unit/FemtoM")
    N_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-M-PER-M2")
    PERCENT_PER_K = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-K")
    E_h = URIRef("http://qudt.org/vocab/unit/E_h")
    IN = URIRef("http://qudt.org/vocab/unit/IN")
    KiloGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-K")
    GM_MIN_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L2")
    MDOLLAR_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MDOLLAR-PER-FLIGHT")
    KiloGM_PER_HA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HA")
    KiloGM_PER_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA")
    MicroC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M2")
    R = URIRef("http://qudt.org/vocab/unit/R")
    HZ_M = URIRef("http://qudt.org/vocab/unit/HZ-M")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    DeciM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-DAY")
    CM_H2O = URIRef("http://qudt.org/vocab/unit/CM_H2O")
    HART_PER_SEC = URIRef("http://qudt.org/vocab/unit/HART-PER-SEC")
    LB_T = URIRef("http://qudt.org/vocab/unit/LB_T")
    W_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-PER-KiloGM")
    BIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BIT-PER-SEC")
    PERCENT_SEC_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-IN3")
    LB_PER_FT_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-DAY")
    PER_PA_SEC = URIRef("http://qudt.org/vocab/unit/PER-PA-SEC")
    SEC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/SEC-PER-KiloGM")
    BARYE = URIRef("http://qudt.org/vocab/unit/BARYE")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    GI_US = URIRef("http://qudt.org/vocab/unit/GI_US")
    MegaHZ = URIRef("http://qudt.org/vocab/unit/MegaHZ")
    PERCENT_MIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-GAL_US")
    TONNE = URIRef("http://qudt.org/vocab/unit/TONNE")
    MilliMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-MOL")
    QT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-SEC")
    KiloPA_M2_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloPA-M2-PER-GM")
    MilliGM = URIRef("http://qudt.org/vocab/unit/MilliGM")
    MicroA = URIRef("http://qudt.org/vocab/unit/MicroA")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    KiloPA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-M")
    GM_PER_GM = URIRef("http://qudt.org/vocab/unit/GM-PER-GM")
    MegaL = URIRef("http://qudt.org/vocab/unit/MegaL")
    CAL_TH = URIRef("http://qudt.org/vocab/unit/CAL_TH")
    KiloHZ_M = URIRef("http://qudt.org/vocab/unit/KiloHZ-M")
    M = URIRef("http://qudt.org/vocab/unit/M")
    CentiM_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-BAR")
    DeciB_M = URIRef("http://qudt.org/vocab/unit/DeciB_M")
    KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloMOL")
    MegaS = URIRef("http://qudt.org/vocab/unit/MegaS")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    OZ_VOL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-MIN")
    M3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-K")
    CentiM3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-K")
    ATM_T = URIRef("http://qudt.org/vocab/unit/ATM_T")
    GM_PER_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY")
    LB_SEC_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-FT3")
    PicoMOL = URIRef("http://qudt.org/vocab/unit/PicoMOL")
    FT_LB_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-MIN")
    DEG2 = URIRef("http://qudt.org/vocab/unit/DEG2")
    DEG_C_WK = URIRef("http://qudt.org/vocab/unit/DEG_C-WK")
    OZ_PER_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD3")
    BARAD = URIRef("http://qudt.org/vocab/unit/BARAD")
    KiloGM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-K")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    MegaW_HR = URIRef("http://qudt.org/vocab/unit/MegaW-HR")
    A_PER_MilliM = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM")
    NanoV_A = URIRef("http://qudt.org/vocab/unit/NanoV-A")
    MilliV_A = URIRef("http://qudt.org/vocab/unit/MilliV-A")
    BTU_TH_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-HR-DEG_F")
    M5 = URIRef("http://qudt.org/vocab/unit/M5")
    TONNE_PER_HR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR")
    FT = URIRef("http://qudt.org/vocab/unit/FT")
    KiloV_A_Reactive = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive")
    PHOT = URIRef("http://qudt.org/vocab/unit/PHOT")
    KiloPA = URIRef("http://qudt.org/vocab/unit/KiloPA")
    MilliMOL = URIRef("http://qudt.org/vocab/unit/MilliMOL")
    HectoL = URIRef("http://qudt.org/vocab/unit/HectoL")
    MilliL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M2-DAY")
    MilliIN = URIRef("http://qudt.org/vocab/unit/MilliIN")
    SEC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/SEC-PER-KiloGM")
    GigaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-PER-M")
    N_M_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-RAD")
    C_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-CentiM2")
    TeraV_A_Reactive = URIRef("http://qudt.org/vocab/unit/TeraV-A_Reactive")
    DeciB_M = URIRef("http://qudt.org/vocab/unit/DeciB_M")
    CAL_TH = URIRef("http://qudt.org/vocab/unit/CAL_TH")
    HectoPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-L-PER-SEC")
    NanoSV_PER_HR = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-HR")
    PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/PER-M2-SEC")
    LB_PER_IN3_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3-PSI")
    CentiM3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-BAR")
    THERM_EC = URIRef("http://qudt.org/vocab/unit/THERM_EC")
    MegaJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-KiloGM")
    NUM_PER_HectoGM = URIRef("http://qudt.org/vocab/unit/NUM-PER-HectoGM")
    C_M2_PER_V = URIRef("http://qudt.org/vocab/unit/C-M2-PER-V")
    TONNE_PER_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-BAR")
    W_PER_M2_K = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K")
    MegaW = URIRef("http://qudt.org/vocab/unit/MegaW")
    C = URIRef("http://qudt.org/vocab/unit/C")
    TON_Metric_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC-K")
    IN_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC2")
    MOL_PER_TONNE = URIRef("http://qudt.org/vocab/unit/MOL-PER-TONNE")
    LM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LM-PER-FT2")
    DEG_F_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-HR")
    PER_MILLE_PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PER-PSI")
    MicroMOL_PER_MicroMOL_DAY = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MicroMOL-DAY")
    N_M_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-M")
    DEG_F_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-HR")
    M5 = URIRef("http://qudt.org/vocab/unit/M5")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    LB_HR_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT6")
    MI = URIRef("http://qudt.org/vocab/unit/MI")
    CAL_MEAN = URIRef("http://qudt.org/vocab/unit/CAL_MEAN")
    K = URIRef("http://qudt.org/vocab/unit/K")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    M = URIRef("http://qudt.org/vocab/unit/M")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    CAL_IT_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-DEG_C")
    GM_MIN_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M6")
    MegaPA = URIRef("http://qudt.org/vocab/unit/MegaPA")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    MicroGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-HR")
    PER_RAD = URIRef("http://qudt.org/vocab/unit/PER-RAD")
    FemtoL = URIRef("http://qudt.org/vocab/unit/FemtoL")
    RAD_PER_MIN = URIRef("http://qudt.org/vocab/unit/RAD-PER-MIN")
    KiloA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M")
    PER_SEC_M2_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2-SR")
    FT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-DEG_F")
    KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A-HR")
    J_SEC_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-SEC-PER-MOL")
    KiloS = URIRef("http://qudt.org/vocab/unit/KiloS")
    M = URIRef("http://qudt.org/vocab/unit/M")
    OZ_IN = URIRef("http://qudt.org/vocab/unit/OZ-IN")
    OZ_VOL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-MIN")
    PERCENT_HR_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-CentiM3")
    MilliL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M2-DAY")
    MilliK_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliK-PER-BAR")
    LB_SEC_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-FT3")
    MilloMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilloMOL-PER-L")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    CentiL = URIRef("http://qudt.org/vocab/unit/CentiL")
    NUM_PER_HectoGM = URIRef("http://qudt.org/vocab/unit/NUM-PER-HectoGM")
    S = URIRef("http://qudt.org/vocab/unit/S")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    ExaBYTE = URIRef("http://qudt.org/vocab/unit/ExaBYTE")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    MicroMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MOL")
    TON_SHORT_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-YD3")
    FT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-DEG_F")
    GAL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-DAY")
    MegaN_M = URIRef("http://qudt.org/vocab/unit/MegaN-M")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    PicoV_A_Reactive = URIRef("http://qudt.org/vocab/unit/PicoV-A_Reactive")
    KiloCAL_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM-DEG_C")
    KiloGM_F_M_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-CentiM2")
    FC = URIRef("http://qudt.org/vocab/unit/FC")
    GM_HR_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M3-CentiM3")
    NanoMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-M2-DAY")
    OZ_PER_YD2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD2")
    CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-GM")
    W_PER_M_K = URIRef("http://qudt.org/vocab/unit/W-PER-M-K")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    M_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-BAR")
    TOE = URIRef("http://qudt.org/vocab/unit/TOE")
    A_PER_J = URIRef("http://qudt.org/vocab/unit/A-PER-J")
    PERCENT_MIN_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-L")
    KiloEV = URIRef("http://qudt.org/vocab/unit/KiloEV")
    AMU = URIRef("http://qudt.org/vocab/unit/AMU")
    ERG = URIRef("http://qudt.org/vocab/unit/ERG")
    FRAME_PER_SEC = URIRef("http://qudt.org/vocab/unit/FRAME-PER-SEC")
    FBM = URIRef("http://qudt.org/vocab/unit/FBM")
    ARE = URIRef("http://qudt.org/vocab/unit/ARE")
    MegaPA = URIRef("http://qudt.org/vocab/unit/MegaPA")
    BTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    ExaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/ExaBIT-PER-SEC")
    MicroH_PER_M = URIRef("http://qudt.org/vocab/unit/MicroH-PER-M")
    PER_J = URIRef("http://qudt.org/vocab/unit/PER-J")
    MegaDOLLAR_US_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MegaDOLLAR_US-PER-FLIGHT")
    PINT_UK = URIRef("http://qudt.org/vocab/unit/PINT_UK")
    MicroV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/MicroV-A_Reactive-PER-K")
    PER_SEC_M2_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2-SR")
    NanoMOL_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL")
    GM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3-K")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    MI_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI-PER-MIN")
    DeciB_PER_M = URIRef("http://qudt.org/vocab/unit/DeciB-PER-M")
    FT3_PER_HR = URIRef("http://qudt.org/vocab/unit/FT3-PER-HR")
    IN2_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN2-PER-SEC")
    MilliGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-BAR")
    N_M2_PER_A = URIRef("http://qudt.org/vocab/unit/N-M2-PER-A")
    CentiM_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-HR")
    EV_PER_T = URIRef("http://qudt.org/vocab/unit/EV-PER-T")
    KAT_PER_M3 = URIRef("http://qudt.org/vocab/unit/KAT-PER-M3")
    M2_SR = URIRef("http://qudt.org/vocab/unit/M2-SR")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    MilliMOL = URIRef("http://qudt.org/vocab/unit/MilliMOL")
    T_Ab = URIRef("http://qudt.org/vocab/unit/T_Ab")
    NanoOHM_M = URIRef("http://qudt.org/vocab/unit/NanoOHM-M")
    MegaA = URIRef("http://qudt.org/vocab/unit/MegaA")
    NanoW = URIRef("http://qudt.org/vocab/unit/NanoW")
    PERCENT_PER_K = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-K")
    LB_HR_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-GAL_UK")
    NanoN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/NanoN-M-PER-M2")
    EV_SEC = URIRef("http://qudt.org/vocab/unit/EV-SEC")
    PDL_FT = URIRef("http://qudt.org/vocab/unit/PDL-FT")
    L_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/L-PER-MicroMOL")
    KiloMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3")
    GRAIN_PER_GAL = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL")
    MegaPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-L-PER-SEC")
    CAL_TH_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2")
    K_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/K-PER-SEC2")
    PERCENT_PER_DektoKiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DektoKiloCount")
    M_PER_FARAD = URIRef("http://qudt.org/vocab/unit/M-PER-FARAD")
    NanoGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DeciL")
    PER_DAY = URIRef("http://qudt.org/vocab/unit/PER-DAY")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    CentiM2_PER_ERG = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-ERG")
    BTU_TH_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT3")
    PER_BAR = URIRef("http://qudt.org/vocab/unit/PER-BAR")
    MicroOHM = URIRef("http://qudt.org/vocab/unit/MicroOHM")
    PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PER-SEC2")
    TON_SHORT_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR")
    IN_PDL = URIRef("http://qudt.org/vocab/unit/IN-PDL")
    GAL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-SEC")
    MilliRAD_R_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliRAD_R-PER-HR")
    S = URIRef("http://qudt.org/vocab/unit/S")
    GAUSS = URIRef("http://qudt.org/vocab/unit/GAUSS")
    IN_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC-PSI")
    CentiPOISE = URIRef("http://qudt.org/vocab/unit/CentiPOISE")
    DeciM3 = URIRef("http://qudt.org/vocab/unit/DeciM3")
    KiloW_PER_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M-DEG_C")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    KiloM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloM-PER-DAY")
    S_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/S-M2-PER-MOL")
    K = URIRef("http://qudt.org/vocab/unit/K")
    CentiM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-M3")
    HP_Boiler = URIRef("http://qudt.org/vocab/unit/HP_Boiler")
    V_A_Reactive = URIRef("http://qudt.org/vocab/unit/V-A_Reactive")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    KiloGM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3")
    LA = URIRef("http://qudt.org/vocab/unit/LA")
    MicroMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-SEC")
    LB_IN2_PER_GAL_UK_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-GAL_UK-LB_F-SEC")
    PER_V_A_SEC = URIRef("http://qudt.org/vocab/unit/PER-V-A-SEC")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    KiloJ_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM-K")
    MilliJ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-GM")
    BTU_IT_PER_SEC_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2")
    PPM_PER_K = URIRef("http://qudt.org/vocab/unit/PPM-PER-K")
    LB_MIN_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK2")
    GRAIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-M3")
    MilliGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-HR")
    GM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR-BAR")
    BTU_IT_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-IN2-SEC")
    A_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM2")
    TonEnergy = URIRef("http://qudt.org/vocab/unit/TonEnergy")
    MilliGM_PER_L_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-MilliPA-SEC")
    M3_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-BAR")
    M3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL-SEC")
    NanoGM_PER_L = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-L")
    GM_PER_L_K = URIRef("http://qudt.org/vocab/unit/GM-PER-L-K")
    DEG_R = URIRef("http://qudt.org/vocab/unit/DEG_R")
    J_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2")
    FARAD_Ab = URIRef("http://qudt.org/vocab/unit/FARAD_Ab")
    A_PER_GM = URIRef("http://qudt.org/vocab/unit/A-PER-GM")
    PA_PER_M = URIRef("http://qudt.org/vocab/unit/PA-PER-M")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    BTU_IT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_F")
    MicroC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M3")
    BTU_TH_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-FT2-HR-DEG_F")
    MilliGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-DAY")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    BARYE = URIRef("http://qudt.org/vocab/unit/BARYE")
    L_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-BAR")
    PER_OZ = URIRef("http://qudt.org/vocab/unit/PER-OZ")
    BTU_IT_PER_LB_F_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_F")
    GM_Carbon_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Carbon-PER-M2-DAY")
    PERMITTIVITY_REL = URIRef("http://qudt.org/vocab/unit/PERMITTIVITY_REL")
    MilliL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-GM")
    RAD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC2")
    J_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2-DAY")
    TON_US_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_US-PER-YD3")
    W_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M2")
    C_M2 = URIRef("http://qudt.org/vocab/unit/C-M2")
    NanoGM_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2-DAY")
    EV_PER_M = URIRef("http://qudt.org/vocab/unit/EV-PER-M")
    K_M2_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/K-M2-PER-KiloGM-SEC")
    PPM = URIRef("http://qudt.org/vocab/unit/PPM")
    MilliOHM_M = URIRef("http://qudt.org/vocab/unit/MilliOHM-M")
    QT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_US-PER-HR")
    KiloGM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM2-PER-SEC2")
    SEC_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-FT2")
    KiloGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloGM")
    MicroGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-K")
    KiloGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    QT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_US-PER-SEC")
    PK_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-DAY")
    OZ_VOL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-MIN")
    KiloBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBYTE-PER-SEC")
    KiloGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-K")
    MilliDARCY = URIRef("http://qudt.org/vocab/unit/MilliDARCY")
    KiloPA_M2_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloPA-M2-PER-GM")
    TON_SHORT = URIRef("http://qudt.org/vocab/unit/TON_SHORT")
    FT2 = URIRef("http://qudt.org/vocab/unit/FT2")
    GM_PER_CentiM_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM-SEC")
    KiloLB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-IN2")
    TeraBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/TeraBIT-PER-SEC")
    PER_MilliSEC = URIRef("http://qudt.org/vocab/unit/PER-MilliSEC")
    MegaV_A = URIRef("http://qudt.org/vocab/unit/MegaV-A")
    GigaEV = URIRef("http://qudt.org/vocab/unit/GigaEV")
    MegaA_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaA-PER-M2")
    PA2_SEC = URIRef("http://qudt.org/vocab/unit/PA2-SEC")
    V = URIRef("http://qudt.org/vocab/unit/V")
    DEG_F_SEC_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-SEC-PER-BTU_IT")
    ERG_PER_G = URIRef("http://qudt.org/vocab/unit/ERG-PER-G")
    CentiM_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-HR")
    BQ_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-SEC-PER-M3")
    CentiM_PER_KiloYR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-KiloYR")
    FT_LB_F_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-HR")
    GM_PER_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY")
    GRAIN_PER_GAL = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL")
    MicroM = URIRef("http://qudt.org/vocab/unit/MicroM")
    W_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM")
    MicroGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-KiloGM")
    W_SEC = URIRef("http://qudt.org/vocab/unit/W-SEC")
    DeciM3_PER_HR = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-HR")
    N_M_PER_W0dot5 = URIRef("http://qudt.org/vocab/unit/N-M-PER-W0dot5")
    KIP_F = URIRef("http://qudt.org/vocab/unit/KIP_F")
    MilliMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-GM")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    NanoS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/NanoS-PER-CentiM")
    M2_HR_DEG_C_PER_KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/M2-HR-DEG_C-PER-KiloCAL_IT")
    GM_PER_CentiM_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM-SEC")
    C_Stat = URIRef("http://qudt.org/vocab/unit/C_Stat")
    GigaFLOPS = URIRef("http://qudt.org/vocab/unit/GigaFLOPS")
    NanoGM_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2-DAY")
    BTU_MEAN = URIRef("http://qudt.org/vocab/unit/BTU_MEAN")
    Denier = URIRef("http://qudt.org/vocab/unit/Denier")
    Debye = URIRef("http://qudt.org/vocab/unit/Debye")
    MilliJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-SEC")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    YD_PER_PSI = URIRef("http://qudt.org/vocab/unit/YD-PER-PSI")
    N_M2_PER_A = URIRef("http://qudt.org/vocab/unit/N-M2-PER-A")
    MicroGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3")
    LB_IN2_PER_GAL_US_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-GAL_US-LB_F-SEC")
    MOL_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-K")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    DEG_C_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-HR")
    KiloM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC")
    MegaOHM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-KiloM")
    YD2 = URIRef("http://qudt.org/vocab/unit/YD2")
    PER_FT3 = URIRef("http://qudt.org/vocab/unit/PER-FT3")
    MicroMOL = URIRef("http://qudt.org/vocab/unit/MicroMOL")
    DeciTON_Metric = URIRef("http://qudt.org/vocab/unit/DeciTON_Metric")
    DeciM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MIN")
    TON_SHIPPING_US = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_US")
    K_PER_K = URIRef("http://qudt.org/vocab/unit/K-PER-K")
    M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/M2-PER-MOL")
    PERCENT_HR_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-FT3")
    L_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/L-PER-KiloGM")
    C_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM-SEC")
    LB_HR_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-IN3")
    DEGREE_PLATO = URIRef("http://qudt.org/vocab/unit/DEGREE_PLATO")
    TON_US = URIRef("http://qudt.org/vocab/unit/TON_US")
    LB_PER_IN3 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3")
    PlanckTime = URIRef("http://qudt.org/vocab/unit/PlanckTime")
    NanoL = URIRef("http://qudt.org/vocab/unit/NanoL")
    W_PER_K = URIRef("http://qudt.org/vocab/unit/W-PER-K")
    ATM_T = URIRef("http://qudt.org/vocab/unit/ATM_T")
    C_PER_MOL = URIRef("http://qudt.org/vocab/unit/C-PER-MOL")
    MilliGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-BAR")
    PicoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/PicoW-PER-M2")
    MOHM = URIRef("http://qudt.org/vocab/unit/MOHM")
    DeciB_A = URIRef("http://qudt.org/vocab/unit/DeciB_A")
    PDL_PER_IN = URIRef("http://qudt.org/vocab/unit/PDL-PER-IN")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    MilliBAR = URIRef("http://qudt.org/vocab/unit/MilliBAR")
    PER_J = URIRef("http://qudt.org/vocab/unit/PER-J")
    PPTR = URIRef("http://qudt.org/vocab/unit/PPTR")
    PetaW = URIRef("http://qudt.org/vocab/unit/PetaW")
    BEAT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BEAT-PER-MIN")
    CentiM_H20_4DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_H20_4DEG_C")
    QT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-HR")
    C2_M2_PER_J = URIRef("http://qudt.org/vocab/unit/C2-M2-PER-J")
    M_PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PA-PER-SEC")
    GT = URIRef("http://qudt.org/vocab/unit/GT")
    KibiBYTE = URIRef("http://qudt.org/vocab/unit/KibiBYTE")
    LB_PER_YD3 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD3")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    MilliWB = URIRef("http://qudt.org/vocab/unit/MilliWB")
    TON_Metric_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY-K")
    M2_PER_HA = URIRef("http://qudt.org/vocab/unit/M2-PER-HA")
    Z = URIRef("http://qudt.org/vocab/unit/Z")
    MicroMOL_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-HR")
    TebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    DeciM3_PER_HR = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-HR")
    CentiM3_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR-BAR")
    GigaN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaN-M-PER-M2")
    KiloGM_PER_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-K")
    GI_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_US-PER-DAY")
    KiloGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    OZ_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_UK")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    PSI_YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-YD3-PER-SEC")
    SEC_PER_M3_RAD = URIRef("http://qudt.org/vocab/unit/SEC-PER-M3-RAD")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    OHM_Ab = URIRef("http://qudt.org/vocab/unit/OHM_Ab")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    RAD_PER_MIN = URIRef("http://qudt.org/vocab/unit/RAD-PER-MIN")
    HR_Sidereal = URIRef("http://qudt.org/vocab/unit/HR_Sidereal")
    GM_SEC_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M3-L")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    FUR_Long = URIRef("http://qudt.org/vocab/unit/FUR_Long")
    NanoGM_PER_L = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-L")
    PicoC = URIRef("http://qudt.org/vocab/unit/PicoC")
    MicroN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroN-M-PER-M2")
    PicoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/PicoFARAD-PER-M")
    KiloGM_F_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-MilliM2")
    ERG_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM3")
    KiloN_M = URIRef("http://qudt.org/vocab/unit/KiloN-M")
    TONNE_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3-BAR")
    MilliOHM = URIRef("http://qudt.org/vocab/unit/MilliOHM")
    YD3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD3-PER-DEG_F")
    AT_PER_IN = URIRef("http://qudt.org/vocab/unit/AT-PER-IN")
    KiloA_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M2")
    PPM = URIRef("http://qudt.org/vocab/unit/PPM")
    MI_US2 = URIRef("http://qudt.org/vocab/unit/MI_US2")
    PER_MicroMOL_L = URIRef("http://qudt.org/vocab/unit/PER-MicroMOL-L")
    FT3_PER_MIN_FT2 = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN-FT2")
    A_PER_RAD = URIRef("http://qudt.org/vocab/unit/A-PER-RAD")
    KiloEV = URIRef("http://qudt.org/vocab/unit/KiloEV")
    FRACTION = URIRef("http://qudt.org/vocab/unit/FRACTION")
    MOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3")
    ERG_PER_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-SEC")
    CentiPOISE_PER_K = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-K")
    MegaPA = URIRef("http://qudt.org/vocab/unit/MegaPA")
    HectoPA_PER_M = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-M")
    GibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M")
    HectoPA_PER_K = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-K")
    YR = URIRef("http://qudt.org/vocab/unit/YR")
    MicroPA = URIRef("http://qudt.org/vocab/unit/MicroPA")
    CentiM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL")
    KiloJ_PER_KiloV = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloV")
    KiloPA = URIRef("http://qudt.org/vocab/unit/KiloPA")
    QUAD = URIRef("http://qudt.org/vocab/unit/QUAD")
    SEC_PER_RAD_M3 = URIRef("http://qudt.org/vocab/unit/SEC-PER-RAD-M3")
    OZ_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_UK")
    H_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/H-PER-KiloOHM")
    N_M_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-RAD")
    BTU_IT_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_F")
    GM_SEC_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M3-L")
    Da = URIRef("http://qudt.org/vocab/unit/Da")
    MicroBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-KiloGM")
    BTU_IT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_F")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    PHOT = URIRef("http://qudt.org/vocab/unit/PHOT")
    PERM_Metric_0DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_Metric_0DEG_C")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    NanoGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M3")
    LB_F = URIRef("http://qudt.org/vocab/unit/LB_F")
    OHM_PER_MI = URIRef("http://qudt.org/vocab/unit/OHM-PER-MI")
    PicoM = URIRef("http://qudt.org/vocab/unit/PicoM")
    SLUG = URIRef("http://qudt.org/vocab/unit/SLUG")
    TONNE_PER_HR_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR-K")
    MebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M3")
    CentiM3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-BAR")
    FT4 = URIRef("http://qudt.org/vocab/unit/FT4")
    GigaEV = URIRef("http://qudt.org/vocab/unit/GigaEV")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    MilliGM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M")
    TONNE_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN-K")
    K_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PER-SEC")
    L_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-BAR")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    TON_Metric_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR")
    DEG_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC")
    OZ_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_US")
    SHANNON_PER_SEC = URIRef("http://qudt.org/vocab/unit/SHANNON-PER-SEC")
    M2_K_PER_W = URIRef("http://qudt.org/vocab/unit/M2-K-PER-W")
    MilliL_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-K")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    MilliGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MilliL")
    PER_YR = URIRef("http://qudt.org/vocab/unit/PER-YR")
    MilliL_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR")
    MilliL_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR")
    TONNE_PER_MIN = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN")
    K_PER_PA = URIRef("http://qudt.org/vocab/unit/K-PER-PA")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    Gamma = URIRef("http://qudt.org/vocab/unit/Gamma")
    MilliM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC")
    HR_Sidereal = URIRef("http://qudt.org/vocab/unit/HR_Sidereal")
    PA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M3-PER-SEC")
    GRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/GRAY-PER-SEC")
    KiloGM_F_M = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    KiloJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-SEC")
    KiloM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloM-PER-DAY")
    STR = URIRef("http://qudt.org/vocab/unit/STR")
    ZeptoC = URIRef("http://qudt.org/vocab/unit/ZeptoC")
    KiloWB = URIRef("http://qudt.org/vocab/unit/KiloWB")
    PlanckPower = URIRef("http://qudt.org/vocab/unit/PlanckPower")
    FT4 = URIRef("http://qudt.org/vocab/unit/FT4")
    BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN")
    NanoGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M3")
    MilliGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MilliL")
    PSI_PER_PSI = URIRef("http://qudt.org/vocab/unit/PSI-PER-PSI")
    FemtoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-KiloGM")
    W_PER_M2_K4 = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K4")
    K = URIRef("http://qudt.org/vocab/unit/K")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    MilliH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-KiloOHM")
    MilliA_PER_K = URIRef("http://qudt.org/vocab/unit/MilliA-PER-K")
    N_M_PER_DEG_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG-M")
    KibiBYTE = URIRef("http://qudt.org/vocab/unit/KibiBYTE")
    WB_M = URIRef("http://qudt.org/vocab/unit/WB-M")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    MilliK_PER_K = URIRef("http://qudt.org/vocab/unit/MilliK-PER-K")
    MicroM = URIRef("http://qudt.org/vocab/unit/MicroM")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    MilliM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-BAR")
    GI_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-MIN")
    NanoS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/NanoS-PER-CentiM")
    M_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-K")
    BU_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-HR")
    FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC")
    EUR_PER_M2 = URIRef("http://qudt.org/vocab/unit/EUR-PER-M2")
    NanoGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DeciL")
    LB_PER_YD3 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD3")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    LB_M = URIRef("http://qudt.org/vocab/unit/LB_M")
    MicroKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MicroKAT-PER-L")
    KiloA = URIRef("http://qudt.org/vocab/unit/KiloA")
    MilliOHM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-M")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    PPTR = URIRef("http://qudt.org/vocab/unit/PPTR")
    OZ_IN = URIRef("http://qudt.org/vocab/unit/OZ-IN")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    DeciC = URIRef("http://qudt.org/vocab/unit/DeciC")
    Z = URIRef("http://qudt.org/vocab/unit/Z")
    MOL_PER_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-HR")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    MicroC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M3")
    PA_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-PER-BAR")
    M_PER_YR = URIRef("http://qudt.org/vocab/unit/M-PER-YR")
    ZeptoC = URIRef("http://qudt.org/vocab/unit/ZeptoC")
    MegaBAUD = URIRef("http://qudt.org/vocab/unit/MegaBAUD")
    N_M_PER_W0dot5 = URIRef("http://qudt.org/vocab/unit/N-M-PER-W0dot5")
    FT2 = URIRef("http://qudt.org/vocab/unit/FT2")
    FT_LA = URIRef("http://qudt.org/vocab/unit/FT-LA")
    NanoJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoJ-PER-SEC")
    MicroS = URIRef("http://qudt.org/vocab/unit/MicroS")
    MicroGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-MilliL")
    FT3_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT3-PER-DAY")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    PicoMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L-HR")
    MilliOHM = URIRef("http://qudt.org/vocab/unit/MilliOHM")
    MilliA_PER_L_MIN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-L-MIN")
    IU_PER_MilliL = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliL")
    KiloN_M_PER_DEG_M = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-DEG-M")
    KiloGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-K")
    MilliOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-BAR")
    C_M2 = URIRef("http://qudt.org/vocab/unit/C-M2")
    PicoMOL = URIRef("http://qudt.org/vocab/unit/PicoMOL")
    KiloPA = URIRef("http://qudt.org/vocab/unit/KiloPA")
    BTU_IT_PER_MOL_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB")
    CentiL = URIRef("http://qudt.org/vocab/unit/CentiL")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    LB_SEC_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-IN3")
    FT_LB_F = URIRef("http://qudt.org/vocab/unit/FT-LB_F")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    PER_T_M = URIRef("http://qudt.org/vocab/unit/PER-T-M")
    DEG_PER_M = URIRef("http://qudt.org/vocab/unit/DEG-PER-M")
    FemtoSEC = URIRef("http://qudt.org/vocab/unit/FemtoSEC")
    NanoGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-HR")
    TON_FG = URIRef("http://qudt.org/vocab/unit/TON_FG")
    MicroGM_PER_IN2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-IN2")
    TON_Metric_PER_MIN = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN")
    MilliGM_PER_L_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-MilliPA-SEC")
    LB_MIN_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-IN3")
    MilliOHM = URIRef("http://qudt.org/vocab/unit/MilliOHM")
    KiloCD = URIRef("http://qudt.org/vocab/unit/KiloCD")
    OZ = URIRef("http://qudt.org/vocab/unit/OZ")
    RAD_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-MOL")
    EUR_PER_W = URIRef("http://qudt.org/vocab/unit/EUR-PER-W")
    FemtoGM = URIRef("http://qudt.org/vocab/unit/FemtoGM")
    MegaGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-M3")
    GM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-CentiM-PER-SEC")
    BTU_IT_FT = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT")
    LB_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-MOL-DEG_F")
    YD_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD-PER-MIN")
    LB_SEC_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-FT3")
    GI_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-HR")
    QT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_US-PER-DAY")
    MicroGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-KiloGM")
    CentiM6 = URIRef("http://qudt.org/vocab/unit/CentiM6")
    PSI_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-L-PER-SEC")
    PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-PSI")
    QT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_US-PER-SEC")
    A_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM2")
    GibiBIT = URIRef("http://qudt.org/vocab/unit/GibiBIT")
    MilliOHM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-K")
    J_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-GM-DEG_C")
    QT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-DAY")
    ExbiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M3")
    MX = URIRef("http://qudt.org/vocab/unit/MX")
    KAT_PER_M3 = URIRef("http://qudt.org/vocab/unit/KAT-PER-M3")
    TOE = URIRef("http://qudt.org/vocab/unit/TOE")
    POISE_PER_PA = URIRef("http://qudt.org/vocab/unit/POISE-PER-PA")
    TeraW = URIRef("http://qudt.org/vocab/unit/TeraW")
    KiloV_A_PER_K = URIRef("http://qudt.org/vocab/unit/KiloV-A-PER-K")
    MegaLB_F = URIRef("http://qudt.org/vocab/unit/MegaLB_F")
    MilliV = URIRef("http://qudt.org/vocab/unit/MilliV")
    POISE_PER_K = URIRef("http://qudt.org/vocab/unit/POISE-PER-K")
    TONNE_PER_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-K")
    CAL_IT = URIRef("http://qudt.org/vocab/unit/CAL_IT")
    PER_MIN = URIRef("http://qudt.org/vocab/unit/PER-MIN")
    YD_PER_PSI = URIRef("http://qudt.org/vocab/unit/YD-PER-PSI")
    KiloMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-KiloGM")
    KiloGM_PER_L_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-K")
    MilliW_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-MilliGM")
    PetaHZ = URIRef("http://qudt.org/vocab/unit/PetaHZ")
    N_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM2")
    KiloGM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-FT2")
    PERCENT_PER_BAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-BAR")
    TONNE_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR-BAR")
    BIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BIT-PER-SEC")
    FT3_PER_PSI = URIRef("http://qudt.org/vocab/unit/FT3-PER-PSI")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    CAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC")
    MicroPA = URIRef("http://qudt.org/vocab/unit/MicroPA")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    LB_IN = URIRef("http://qudt.org/vocab/unit/LB-IN")
    LB_HR_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-FT3")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    H_PER_M = URIRef("http://qudt.org/vocab/unit/H-PER-M")
    PER_EV_M3 = URIRef("http://qudt.org/vocab/unit/PER-EV-M3")
    J_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-M2-PER-KiloGM")
    ST = URIRef("http://qudt.org/vocab/unit/ST")
    EUR_PER_M2 = URIRef("http://qudt.org/vocab/unit/EUR-PER-M2")
    NanoMOL_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L-DAY")
    CAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-MIN")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    BQ_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-SEC-PER-M3")
    M_PER_K = URIRef("http://qudt.org/vocab/unit/M-PER-K")
    M4 = URIRef("http://qudt.org/vocab/unit/M4")
    MilliPA = URIRef("http://qudt.org/vocab/unit/MilliPA")
    PicoM = URIRef("http://qudt.org/vocab/unit/PicoM")
    LANGLEY = URIRef("http://qudt.org/vocab/unit/LANGLEY")
    KiloGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC")
    A_Ab = URIRef("http://qudt.org/vocab/unit/A_Ab")
    DeciM3_PER_HR = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-HR")
    GI_UK = URIRef("http://qudt.org/vocab/unit/GI_UK")
    MilliRAD = URIRef("http://qudt.org/vocab/unit/MilliRAD")
    FT3 = URIRef("http://qudt.org/vocab/unit/FT3")
    CentiM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC")
    LM_PER_M2 = URIRef("http://qudt.org/vocab/unit/LM-PER-M2")
    FT_LB_F_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2-SEC")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    PicoM = URIRef("http://qudt.org/vocab/unit/PicoM")
    DAY_Sidereal = URIRef("http://qudt.org/vocab/unit/DAY_Sidereal")
    LB_MIN_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-FT3")
    MilliJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-SEC")
    L_PER_HR_K = URIRef("http://qudt.org/vocab/unit/L-PER-HR-K")
    HectoL = URIRef("http://qudt.org/vocab/unit/HectoL")
    J_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2")
    DEG_C_PER_YR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-YR")
    KY = URIRef("http://qudt.org/vocab/unit/KY")
    BIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/BIT-PER-M3")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    MilliGM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR")
    BTU_TH_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-SEC-DEG_F")
    CAL_TH_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM-K")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    M2_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-BAR")
    BQ_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-SEC-PER-M3")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    NTU = URIRef("http://qudt.org/vocab/unit/NTU")
    CAL_TH = URIRef("http://qudt.org/vocab/unit/CAL_TH")
    MilliM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC")
    DeciM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-M3")
    OERSTED = URIRef("http://qudt.org/vocab/unit/OERSTED")
    MIN = URIRef("http://qudt.org/vocab/unit/MIN")
    IU_PER_MilliL = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliL")
    GM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC")
    TON_Metric_PER_SEC = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC")
    BTU_IT_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_R")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    L_PER_MOL = URIRef("http://qudt.org/vocab/unit/L-PER-MOL")
    PicoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/PicoKAT-PER-L")
    NanoMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL")
    MilliRAD = URIRef("http://qudt.org/vocab/unit/MilliRAD")
    MilliN_M = URIRef("http://qudt.org/vocab/unit/MilliN-M")
    CentiPOISE = URIRef("http://qudt.org/vocab/unit/CentiPOISE")
    OZ_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ-PER-MIN")
    MilliT = URIRef("http://qudt.org/vocab/unit/MilliT")
    OZ_VOL_UK = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK")
    MicroMOL_PER_GM_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM-HR")
    TONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-YR")
    FT3 = URIRef("http://qudt.org/vocab/unit/FT3")
    N_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M2")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    MicroV = URIRef("http://qudt.org/vocab/unit/MicroV")
    CAL_TH_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    HP_Metric = URIRef("http://qudt.org/vocab/unit/HP_Metric")
    ARE = URIRef("http://qudt.org/vocab/unit/ARE")
    ExaV_A = URIRef("http://qudt.org/vocab/unit/ExaV-A")
    KiloGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-K")
    M3_PER_HR_K = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-K")
    RAD_PER_HR = URIRef("http://qudt.org/vocab/unit/RAD-PER-HR")
    KiloGM_PER_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-K")
    M = URIRef("http://qudt.org/vocab/unit/M")
    MilliM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-KiloGM")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    POISE = URIRef("http://qudt.org/vocab/unit/POISE")
    M_K = URIRef("http://qudt.org/vocab/unit/M-K")
    A_SEC = URIRef("http://qudt.org/vocab/unit/A-SEC")
    MegaA = URIRef("http://qudt.org/vocab/unit/MegaA")
    BREATH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BREATH-PER-MIN")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    M3_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-K")
    PH = URIRef("http://qudt.org/vocab/unit/PH")
    TON_SHORT_PER_HR_PSI = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR-PSI")
    PDL_PER_IN2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-IN2")
    PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PER-CentiM3")
    MOL_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-K")
    MegaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-SEC")
    CAL_IT_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM2-K")
    PlanckTemperature = URIRef("http://qudt.org/vocab/unit/PlanckTemperature")
    DEATHS_PER_KiloINDIV_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-KiloINDIV-YR")
    DeciM2 = URIRef("http://qudt.org/vocab/unit/DeciM2")
    GM = URIRef("http://qudt.org/vocab/unit/GM")
    SLUG_PER_DAY = URIRef("http://qudt.org/vocab/unit/SLUG-PER-DAY")
    N_M2_PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/N-M2-PER-KiloGM2")
    KiloBD = URIRef("http://qudt.org/vocab/unit/KiloBD")
    BIOT = URIRef("http://qudt.org/vocab/unit/BIOT")
    ARE = URIRef("http://qudt.org/vocab/unit/ARE")
    MilliW_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM")
    M3_PER_MIN = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN")
    MegaHZ = URIRef("http://qudt.org/vocab/unit/MegaHZ")
    PA_PER_M = URIRef("http://qudt.org/vocab/unit/PA-PER-M")
    MicroN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroN-M-PER-M2")
    MegaHZ = URIRef("http://qudt.org/vocab/unit/MegaHZ")
    MI_US_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/MI_US-PER-SEC2")
    C_Stat = URIRef("http://qudt.org/vocab/unit/C_Stat")
    PA_PER_HR = URIRef("http://qudt.org/vocab/unit/PA-PER-HR")
    MilliL_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-K")
    A_M2 = URIRef("http://qudt.org/vocab/unit/A-M2")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    N = URIRef("http://qudt.org/vocab/unit/N")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    PER_WK = URIRef("http://qudt.org/vocab/unit/PER-WK")
    SEC_PER_RAD_M3 = URIRef("http://qudt.org/vocab/unit/SEC-PER-RAD-M3")
    ERG_CentiM2 = URIRef("http://qudt.org/vocab/unit/ERG-CentiM2")
    MicroGAL_PER_M = URIRef("http://qudt.org/vocab/unit/MicroGAL-PER-M")
    MilliGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DeciL")
    LB_MIN_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-GAL_UK")
    MilliA_HR = URIRef("http://qudt.org/vocab/unit/MilliA-HR")
    CWT_LONG = URIRef("http://qudt.org/vocab/unit/CWT_LONG")
    KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloM2")
    IN_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC-DEG_F")
    YR_Metrology = URIRef("http://qudt.org/vocab/unit/YR_Metrology")
    PERM_0DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_0DEG_C")
    MicroS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MicroS-PER-CentiM")
    PA_PER_M = URIRef("http://qudt.org/vocab/unit/PA-PER-M")
    MegaPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-M3-PER-SEC")
    MicroL = URIRef("http://qudt.org/vocab/unit/MicroL")
    KiloA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M")
    AttoJ = URIRef("http://qudt.org/vocab/unit/AttoJ")
    SLUG_PER_FT3 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT3")
    PPQ = URIRef("http://qudt.org/vocab/unit/PPQ")
    M_K = URIRef("http://qudt.org/vocab/unit/M-K")
    MilliW_PER_CentiM2_MicroM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-CentiM2-MicroM-SR")
    HeartBeat = URIRef("http://qudt.org/vocab/unit/HeartBeat")
    NanoS = URIRef("http://qudt.org/vocab/unit/NanoS")
    CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-GM")
    KiloGM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM")
    OHM_M2_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-M2-PER-M")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    PERCENT_SEC_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-GAL_US")
    BTU_IT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_F")
    PSI = URIRef("http://qudt.org/vocab/unit/PSI")
    MilliL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M3")
    OZ_FT2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/OZ-FT2-PER-IN3-LB_F-SEC")
    PER_K = URIRef("http://qudt.org/vocab/unit/PER-K")
    LB_SEC_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-YD3")
    MilliGM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR")
    BAR_PER_K = URIRef("http://qudt.org/vocab/unit/BAR-PER-K")
    MegaEV_FemtoM = URIRef("http://qudt.org/vocab/unit/MegaEV-FemtoM")
    YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD3-PER-SEC")
    Flight = URIRef("http://qudt.org/vocab/unit/Flight")
    LB_F_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-SEC")
    MilliSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-HR")
    DeciB_W = URIRef("http://qudt.org/vocab/unit/DeciB-W")
    DYN_SEC_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM")
    L_PER_K = URIRef("http://qudt.org/vocab/unit/L-PER-K")
    TONNE_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN-K")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    KiloGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-BAR")
    BTU_IT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_F")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    MilliS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MilliS-PER-CentiM")
    H_PER_OHM = URIRef("http://qudt.org/vocab/unit/H-PER-OHM")
    KiloWB = URIRef("http://qudt.org/vocab/unit/KiloWB")
    NanoBQ_PER_L = URIRef("http://qudt.org/vocab/unit/NanoBQ-PER-L")
    NanoM = URIRef("http://qudt.org/vocab/unit/NanoM")
    MilliL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC")
    MebiBYTE = URIRef("http://qudt.org/vocab/unit/MebiBYTE")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    L_PER_L = URIRef("http://qudt.org/vocab/unit/L-PER-L")
    PA_M = URIRef("http://qudt.org/vocab/unit/PA-M")
    TSP = URIRef("http://qudt.org/vocab/unit/TSP")
    PER_MIN = URIRef("http://qudt.org/vocab/unit/PER-MIN")
    V_Stat_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-CentiM")
    DecaM = URIRef("http://qudt.org/vocab/unit/DecaM")
    LB_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-DEG_F")
    S_PER_CentiM = URIRef("http://qudt.org/vocab/unit/S-PER-CentiM")
    DYN = URIRef("http://qudt.org/vocab/unit/DYN")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    KibiBIT = URIRef("http://qudt.org/vocab/unit/KibiBIT")
    KiloGM_PER_HA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HA")
    MegaHZ_PER_T = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-T")
    TON_SHORT_PER_PSI = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-PSI")
    R_man = URIRef("http://qudt.org/vocab/unit/R_man")
    J_PER_GM = URIRef("http://qudt.org/vocab/unit/J-PER-GM")
    LB_FT2_PER_GAL_UK_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-GAL_UK-LB_F-SEC")
    GRAIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-M3")
    KiloGM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM")
    MilliGM_HR_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M6")
    M_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-BAR")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    MicroBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-KiloGM")
    RAD_R = URIRef("http://qudt.org/vocab/unit/RAD_R")
    LB_FT2 = URIRef("http://qudt.org/vocab/unit/LB-FT2")
    DYN_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-CentiM")
    HectoPA_PER_M = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-M")
    MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/MOL_LB-DEG_F")
    M3_PER_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-M2")
    MegaBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaBTU_IT-PER-HR")
    PicoW = URIRef("http://qudt.org/vocab/unit/PicoW")
    BTU_IT_PER_LB_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F")
    K_PER_M = URIRef("http://qudt.org/vocab/unit/K-PER-M")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    OZ_HR_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-GAL_UK")
    LB_F_FT = URIRef("http://qudt.org/vocab/unit/LB_F-FT")
    PER_M_K = URIRef("http://qudt.org/vocab/unit/PER-M-K")
    MicroN = URIRef("http://qudt.org/vocab/unit/MicroN")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    MicroV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MicroV-A_Reactive")
    MOL_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-K")
    NanoGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-HR")
    MilliGM_PER_L = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L")
    M3_PER_KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM-SEC2")
    MegaBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaBTU_IT-PER-HR")
    CentiM_PER_YR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-YR")
    MI = URIRef("http://qudt.org/vocab/unit/MI")
    M3_PER_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-M2")
    MicroM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroM-PER-SEC")
    E = URIRef("http://qudt.org/vocab/unit/E")
    EV_PER_M = URIRef("http://qudt.org/vocab/unit/EV-PER-M")
    HectoPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-BAR")
    N_M_PER_M_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-M-RAD")
    DEG_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC2")
    MegaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-HR")
    CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CentiM2-MIN")
    C_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM3")
    BTU_IT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR-DEG_F")
    MegaJ = URIRef("http://qudt.org/vocab/unit/MegaJ")
    NanoL = URIRef("http://qudt.org/vocab/unit/NanoL")
    W_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/W-PER-CentiM2")
    MOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM")
    MicroGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2")
    MegaJ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-K")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    CARAT = URIRef("http://qudt.org/vocab/unit/CARAT")
    N_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-PER-KiloGM")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    KiloGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-BAR")
    S = URIRef("http://qudt.org/vocab/unit/S")
    DEG_C_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-SEC")
    PetaA = URIRef("http://qudt.org/vocab/unit/PetaA")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    J_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2-DAY")
    Hundredweight_UK = URIRef("http://qudt.org/vocab/unit/Hundredweight_UK")
    SV_PER_MIN = URIRef("http://qudt.org/vocab/unit/SV-PER-MIN")
    CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM-SEC-DEG_C")
    TONNE_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY-K")
    CentiM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL")
    PicoW = URIRef("http://qudt.org/vocab/unit/PicoW")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    W_PER_SR_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-SR-M2")
    GI_UK = URIRef("http://qudt.org/vocab/unit/GI_UK")
    PA_PER_M = URIRef("http://qudt.org/vocab/unit/PA-PER-M")
    ERG_SEC = URIRef("http://qudt.org/vocab/unit/ERG-SEC")
    NUM_PER_M2 = URIRef("http://qudt.org/vocab/unit/NUM-PER-M2")
    RAD_R = URIRef("http://qudt.org/vocab/unit/RAD_R")
    DeciM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-DAY")
    NanoGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-MIN")
    OZ_SEC_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-FT3")
    W = URIRef("http://qudt.org/vocab/unit/W")
    A_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM2")
    PlanckTime = URIRef("http://qudt.org/vocab/unit/PlanckTime")
    FT4 = URIRef("http://qudt.org/vocab/unit/FT4")
    DEG_F_HR_FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT-IN")
    K_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/K-PER-SEC2")
    PERCENT_PER_V = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-V")
    YD3_PER_DAY = URIRef("http://qudt.org/vocab/unit/YD3-PER-DAY")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    M3_PER_HR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR")
    TSP = URIRef("http://qudt.org/vocab/unit/TSP")
    DeciM3_PER_HR = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-HR")
    LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT2")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    TON_Assay = URIRef("http://qudt.org/vocab/unit/TON_Assay")
    MI_PER_HR = URIRef("http://qudt.org/vocab/unit/MI-PER-HR")
    BIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/BIT-PER-M2")
    MicroGM = URIRef("http://qudt.org/vocab/unit/MicroGM")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    MilliL_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR")
    CD_PER_LM = URIRef("http://qudt.org/vocab/unit/CD-PER-LM")
    GigaBQ = URIRef("http://qudt.org/vocab/unit/GigaBQ")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    TON_Register = URIRef("http://qudt.org/vocab/unit/TON_Register")
    GAL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-HR")
    MilliL_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-K")
    PicoS = URIRef("http://qudt.org/vocab/unit/PicoS")
    MilliA_PER_LB_F_IN2 = URIRef("http://qudt.org/vocab/unit/MilliA-PER-LB_F-IN2")
    MilliGM_MIN_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L-M3")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    LB_DEG_R = URIRef("http://qudt.org/vocab/unit/LB-DEG_R")
    LB_F_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    CentiN = URIRef("http://qudt.org/vocab/unit/CentiN")
    FT_LB_F = URIRef("http://qudt.org/vocab/unit/FT-LB_F")
    KiloPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-BAR")
    FT_LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    MilliM4 = URIRef("http://qudt.org/vocab/unit/MilliM4")
    N_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M2")
    N_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M3")
    KiloMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-SEC")
    GM_SEC_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M3-L")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    IN_HG_60DEG_F = URIRef("http://qudt.org/vocab/unit/IN_HG_60DEG_F")
    PER_H = URIRef("http://qudt.org/vocab/unit/PER-H")
    A_PER_GM = URIRef("http://qudt.org/vocab/unit/A-PER-GM")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    MicroMOL_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM-SEC")
    PER_GM = URIRef("http://qudt.org/vocab/unit/PER-GM")
    KiloEV = URIRef("http://qudt.org/vocab/unit/KiloEV")
    MicroV = URIRef("http://qudt.org/vocab/unit/MicroV")
    PERCENT_FT_HR_PER_LB = URIRef("http://qudt.org/vocab/unit/PERCENT-FT-HR-PER-LB")
    GM_PER_CentiM3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3-BAR")
    BTU_IT_PER_LB_MOL = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-MOL")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    J_PER_M3_K = URIRef("http://qudt.org/vocab/unit/J-PER-M3-K")
    WB_PER_MilliM = URIRef("http://qudt.org/vocab/unit/WB-PER-MilliM")
    L_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-BAR")
    MI_N = URIRef("http://qudt.org/vocab/unit/MI_N")
    C_M2 = URIRef("http://qudt.org/vocab/unit/C-M2")
    DYN_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM3")
    OZ_VOL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-DAY")
    KiloLB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-FT")
    FT_H2O_39dot2DEG_F = URIRef("http://qudt.org/vocab/unit/FT_H2O_39dot2DEG_F")
    DYN = URIRef("http://qudt.org/vocab/unit/DYN")
    RAD_PER_HR = URIRef("http://qudt.org/vocab/unit/RAD-PER-HR")
    DeciM3 = URIRef("http://qudt.org/vocab/unit/DeciM3")
    KiloBTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH-PER-HR")
    DEATHS_PER_1000000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000000I-YR")
    FT2_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT2-PER-SEC")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    KAT_PER_MicroL = URIRef("http://qudt.org/vocab/unit/KAT-PER-MicroL")
    LB_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_UK")
    MilliM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliM-PER-K")
    KiloA_HR = URIRef("http://qudt.org/vocab/unit/KiloA-HR")
    MicroG_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroG-PER-CentiM2")
    MilliN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliN-M-PER-M2")
    DEG_F_HR_FT2_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH")
    MicroV = URIRef("http://qudt.org/vocab/unit/MicroV")
    MicroM_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/MicroM-PER-L-DAY")
    KiloJ_PER_KiloV = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloV")
    KiloGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC")
    KiloGRAY = URIRef("http://qudt.org/vocab/unit/KiloGRAY")
    M_PER_RAD = URIRef("http://qudt.org/vocab/unit/M-PER-RAD")
    MilliSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-MIN")
    CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3")
    LB_DEG_R = URIRef("http://qudt.org/vocab/unit/LB-DEG_R")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    KiloJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-SEC")
    KiloLB_F = URIRef("http://qudt.org/vocab/unit/KiloLB_F")
    BTU_IT_PER_LB_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F")
    CAL_20DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_20DEG_C")
    BTU_IT_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB")
    MOL_PER_GM_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-GM-HR")
    PERCENT_HR_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-IN3")
    MilliGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HA")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    GigaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/GigaC-PER-M3")
    GI = URIRef("http://qudt.org/vocab/unit/GI")
    MegaJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-KiloGM")
    MilliL_PER_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-K")
    CD_PER_LM = URIRef("http://qudt.org/vocab/unit/CD-PER-LM")
    MilliM_H2O = URIRef("http://qudt.org/vocab/unit/MilliM_H2O")
    S = URIRef("http://qudt.org/vocab/unit/S")
    MegaA_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaA-PER-M2")
    E = URIRef("http://qudt.org/vocab/unit/E")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    MilliGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MilliL")
    MilliL_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-BAR")
    OZ_PER_FT2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-FT2")
    SLUG_PER_MIN = URIRef("http://qudt.org/vocab/unit/SLUG-PER-MIN")
    LB_T = URIRef("http://qudt.org/vocab/unit/LB_T")
    PER_T_SEC = URIRef("http://qudt.org/vocab/unit/PER-T-SEC")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    NUM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NUM-PER-M3")
    A_MIN = URIRef("http://qudt.org/vocab/unit/A-MIN")
    PERMITTIVITY_REL = URIRef("http://qudt.org/vocab/unit/PERMITTIVITY_REL")
    M3_PER_HR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR")
    KiloM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC2")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    KiloCAL_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM-SEC-DEG_C")
    MicroPA = URIRef("http://qudt.org/vocab/unit/MicroPA")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    YD_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD-PER-SEC")
    MilliGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN")
    LB_IN2_PER_GAL_US_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-GAL_US-LB_F-SEC")
    MOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-DAY")
    MicroMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L-HR")
    TON_Metric_PER_SEC = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC")
    MilliL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-SEC")
    CentiPOISE_PER_K = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-K")
    ATM_T_PER_M = URIRef("http://qudt.org/vocab/unit/ATM_T-PER-M")
    ERG_PER_CentiM = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM")
    TONNE = URIRef("http://qudt.org/vocab/unit/TONNE")
    DeciM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-SEC")
    MegaJ = URIRef("http://qudt.org/vocab/unit/MegaJ")
    MilliPA_SEC_PER_K = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-K")
    OZ_PER_IN2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN2")
    DecaPA = URIRef("http://qudt.org/vocab/unit/DecaPA")
    KiloGM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-FT2")
    OZ_F = URIRef("http://qudt.org/vocab/unit/OZ_F")
    IN_H2O_39dot2DEG_F = URIRef("http://qudt.org/vocab/unit/IN_H2O_39dot2DEG_F")
    BTU_IT_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC-DEG_F")
    BTU_IT_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-HR-DEG_F")
    KiloCi = URIRef("http://qudt.org/vocab/unit/KiloCi")
    PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PER-M3-SEC")
    OZ_PER_FT2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-FT2")
    GI_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-DAY")
    LB_PER_YD3 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD3")
    LA = URIRef("http://qudt.org/vocab/unit/LA")
    BAR = URIRef("http://qudt.org/vocab/unit/BAR")
    KiloGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-BAR")
    M3_PER_PA = URIRef("http://qudt.org/vocab/unit/M3-PER-PA")
    CD_PER_IN2 = URIRef("http://qudt.org/vocab/unit/CD-PER-IN2")
    PicoW = URIRef("http://qudt.org/vocab/unit/PicoW")
    PicoFARAD = URIRef("http://qudt.org/vocab/unit/PicoFARAD")
    KiloA = URIRef("http://qudt.org/vocab/unit/KiloA")
    GI = URIRef("http://qudt.org/vocab/unit/GI")
    PERCENT_PER_DecaCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaCount")
    DEG_F_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-HR")
    TONNE_PER_MO = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MO")
    MOMME_Textile = URIRef("http://qudt.org/vocab/unit/MOMME_Textile")
    GigaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/GigaC-PER-M3")
    CentiN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/CentiN-M-PER-M2")
    KiloOHM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-M")
    BARN_PER_SR_EV = URIRef("http://qudt.org/vocab/unit/BARN-PER-SR-EV")
    FemtoM = URIRef("http://qudt.org/vocab/unit/FemtoM")
    PSI_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-L-PER-SEC")
    GI = URIRef("http://qudt.org/vocab/unit/GI")
    MicroGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-BAR")
    DEATHS_PER_KiloINDIV_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-KiloINDIV-YR")
    MilliGM_PER_M3_PA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-PA-SEC")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    DWT = URIRef("http://qudt.org/vocab/unit/DWT")
    A_PER_PA = URIRef("http://qudt.org/vocab/unit/A-PER-PA")
    GM_Nitrogen_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Nitrogen-PER-M2-DAY")
    J_PER_HR = URIRef("http://qudt.org/vocab/unit/J-PER-HR")
    MicroMOL = URIRef("http://qudt.org/vocab/unit/MicroMOL")
    KiloV_PER_M = URIRef("http://qudt.org/vocab/unit/KiloV-PER-M")
    MilliC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliC-PER-KiloGM")
    ATM_T = URIRef("http://qudt.org/vocab/unit/ATM_T")
    J_M2 = URIRef("http://qudt.org/vocab/unit/J-M2")
    MicroBAR = URIRef("http://qudt.org/vocab/unit/MicroBAR")
    MilliGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-BAR")
    W_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-SEC-PER-M2")
    MegaPA = URIRef("http://qudt.org/vocab/unit/MegaPA")
    H_PER_OHM = URIRef("http://qudt.org/vocab/unit/H-PER-OHM")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    FT_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC-PSI")
    GM_PER_MilliM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM-BAR")
    DYN_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM")
    LM_HR = URIRef("http://qudt.org/vocab/unit/LM-HR")
    MilliA_HR_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliA-HR-PER-GM")
    GM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY-K")
    C_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-M2-PER-KiloGM")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    PlanckForce = URIRef("http://qudt.org/vocab/unit/PlanckForce")
    QT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_US-PER-DAY")
    KiloN_M_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-M")
    H_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/H-PER-KiloOHM")
    KiloCAL_TH = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH")
    M2_PER_GM = URIRef("http://qudt.org/vocab/unit/M2-PER-GM")
    PER_MegaPA = URIRef("http://qudt.org/vocab/unit/PER-MegaPA")
    LB_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-DEG_F")
    KiloGM_PER_M_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC")
    PetaV_A = URIRef("http://qudt.org/vocab/unit/PetaV-A")
    STR = URIRef("http://qudt.org/vocab/unit/STR")
    KiloHZ = URIRef("http://qudt.org/vocab/unit/KiloHZ")
    MI_US2 = URIRef("http://qudt.org/vocab/unit/MI_US2")
    MOL_PER_M3_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-PA")
    MicroM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroM-PER-SEC")
    MicroCi = URIRef("http://qudt.org/vocab/unit/MicroCi")
    TON_Assay = URIRef("http://qudt.org/vocab/unit/TON_Assay")
    GM_Carbon_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Carbon-PER-M2-DAY")
    YR_Metrology = URIRef("http://qudt.org/vocab/unit/YR_Metrology")
    PlanckFrequency = URIRef("http://qudt.org/vocab/unit/PlanckFrequency")
    GAL_US_DRY = URIRef("http://qudt.org/vocab/unit/GAL_US_DRY")
    MicroS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MicroS-PER-CentiM")
    KiloP = URIRef("http://qudt.org/vocab/unit/KiloP")
    YD = URIRef("http://qudt.org/vocab/unit/YD")
    KiloS = URIRef("http://qudt.org/vocab/unit/KiloS")
    KiloJ_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MOL")
    LB_F = URIRef("http://qudt.org/vocab/unit/LB_F")
    GigaBasePair = URIRef("http://qudt.org/vocab/unit/GigaBasePair")
    MilliM2 = URIRef("http://qudt.org/vocab/unit/MilliM2")
    GM_PER_HZ = URIRef("http://qudt.org/vocab/unit/GM-PER-HZ")
    LB_MIN_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-GAL_UK")
    LB_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_US")
    LB_M = URIRef("http://qudt.org/vocab/unit/LB_M")
    MilliGM_HR_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M6")
    DYN_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM2")
    DARCY = URIRef("http://qudt.org/vocab/unit/DARCY")
    AMU = URIRef("http://qudt.org/vocab/unit/AMU")
    N_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M3")
    J_PER_GM_K = URIRef("http://qudt.org/vocab/unit/J-PER-GM-K")
    M3_PER_K = URIRef("http://qudt.org/vocab/unit/M3-PER-K")
    MegaEV = URIRef("http://qudt.org/vocab/unit/MegaEV")
    BTU_IT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MIN")
    CentiM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC-K")
    KiloGM_M = URIRef("http://qudt.org/vocab/unit/KiloGM-M")
    MilliN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliN-M-PER-M2")
    SLUG_PER_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-SEC")
    PERCENT_PER_BAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-BAR")
    RAD_R = URIRef("http://qudt.org/vocab/unit/RAD_R")
    KiloBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBIT-PER-SEC")
    PebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M3")
    T = URIRef("http://qudt.org/vocab/unit/T")
    CAL_TH_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM-K")
    TeraHZ = URIRef("http://qudt.org/vocab/unit/TeraHZ")
    E_h = URIRef("http://qudt.org/vocab/unit/E_h")
    CentiM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-M3")
    MilliBAR_PER_K = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-K")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/M2-PER-MOL")
    IN_H2O = URIRef("http://qudt.org/vocab/unit/IN_H2O")
    NanoC = URIRef("http://qudt.org/vocab/unit/NanoC")
    FT_PDL = URIRef("http://qudt.org/vocab/unit/FT-PDL")
    MilliL_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-BAR")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    PERCENT_PER_BAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-BAR")
    ST_PER_BAR = URIRef("http://qudt.org/vocab/unit/ST-PER-BAR")
    NanoM_PER_MilliM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-MilliM-MegaPA")
    GM_PER_M2 = URIRef("http://qudt.org/vocab/unit/GM-PER-M2")
    V_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V-PER-CentiM")
    C_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM")
    IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC")
    MilliGM_PER_L_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-MilliPA-SEC")
    EV_PER_M = URIRef("http://qudt.org/vocab/unit/EV-PER-M")
    TON_Metric_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR-BAR")
    KiloMOL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-HR")
    OZ_TROY = URIRef("http://qudt.org/vocab/unit/OZ_TROY")
    L_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-M2")
    CentiM3_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR")
    BTU_IT_IN_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-SEC-FT2-DEG_F")
    V_IN2_PER_LB_F = URIRef("http://qudt.org/vocab/unit/V-IN2-PER-LB_F")
    GigaW = URIRef("http://qudt.org/vocab/unit/GigaW")
    LB_MIN_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-IN3")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    BTU_TH_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB")
    PicoV_A = URIRef("http://qudt.org/vocab/unit/PicoV-A")
    KiloGM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    W_PER_SR = URIRef("http://qudt.org/vocab/unit/W-PER-SR")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    GM_PER_M2 = URIRef("http://qudt.org/vocab/unit/GM-PER-M2")
    N_M_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-M")
    R = URIRef("http://qudt.org/vocab/unit/R")
    SUSCEPTIBILITY_ELEC = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_ELEC")
    MOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-SEC")
    MicroOHM = URIRef("http://qudt.org/vocab/unit/MicroOHM")
    OZ_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ-PER-HR")
    NUM_PER_M2 = URIRef("http://qudt.org/vocab/unit/NUM-PER-M2")
    PebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M2")
    V_PER_IN = URIRef("http://qudt.org/vocab/unit/V-PER-IN")
    MilliDEG_C = URIRef("http://qudt.org/vocab/unit/MilliDEG_C")
    MicroGM_PER_IN2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-IN2")
    MilliJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-M2")
    MilliJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-SEC")
    M_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-K")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    PER_PlanckMass2 = URIRef("http://qudt.org/vocab/unit/PER-PlanckMass2")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    OZ_IN = URIRef("http://qudt.org/vocab/unit/OZ-IN")
    H_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/H_Stat-PER-CentiM")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    N_PER_A = URIRef("http://qudt.org/vocab/unit/N-PER-A")
    MicroSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-SEC")
    DeciM2 = URIRef("http://qudt.org/vocab/unit/DeciM2")
    OZ_VOL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-MIN")
    MegaSEC = URIRef("http://qudt.org/vocab/unit/MegaSEC")
    QT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-HR")
    MOL_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-L-BAR")
    MIN = URIRef("http://qudt.org/vocab/unit/MIN")
    M_SEC = URIRef("http://qudt.org/vocab/unit/M-SEC")
    C_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-M2-PER-KiloGM")
    KibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M3")
    OZ_IN = URIRef("http://qudt.org/vocab/unit/OZ-IN")
    M_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-V-SEC")
    SLUG_PER_MIN = URIRef("http://qudt.org/vocab/unit/SLUG-PER-MIN")
    ARCSEC = URIRef("http://qudt.org/vocab/unit/ARCSEC")
    OZ_VOL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-SEC")
    A_Ab = URIRef("http://qudt.org/vocab/unit/A_Ab")
    BBL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-DAY")
    MilliPA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-BAR")
    GM_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM2")
    MilliGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DeciL")
    K_M = URIRef("http://qudt.org/vocab/unit/K-M")
    PERCENT_RH = URIRef("http://qudt.org/vocab/unit/PERCENT_RH")
    PERCENT_PER_CentiPOISE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-CentiPOISE")
    DEATHS_PER_KiloINDIV_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-KiloINDIV-YR")
    K_PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PA-PER-SEC")
    LB_HR_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN6")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    BTU_IT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_F")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    MicroM3_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-MilliL")
    PERCENT_MIN_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-GAL_UK")
    PER_MOL = URIRef("http://qudt.org/vocab/unit/PER-MOL")
    MilliK_PER_K = URIRef("http://qudt.org/vocab/unit/MilliK-PER-K")
    K_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/K-PER-SEC2")
    SLUG_PER_FT3 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT3")
    B = URIRef("http://qudt.org/vocab/unit/B")
    TON_F_US = URIRef("http://qudt.org/vocab/unit/TON_F_US")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    MicroS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MicroS-PER-CentiM")
    FemtoC = URIRef("http://qudt.org/vocab/unit/FemtoC")
    PERCENT_PER_PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-PERCENT")
    KiloGM_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-YR")
    W = URIRef("http://qudt.org/vocab/unit/W")
    GM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC-K")
    YD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/YD-PER-SEC2")
    OZ_IN = URIRef("http://qudt.org/vocab/unit/OZ-IN")
    L_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-K")
    BTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR")
    PicoA = URIRef("http://qudt.org/vocab/unit/PicoA")
    M3_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-BAR")
    L_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-M2")
    QT_US = URIRef("http://qudt.org/vocab/unit/QT_US")
    PERCENT_HR_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-GAL_US")
    FUR = URIRef("http://qudt.org/vocab/unit/FUR")
    STILB = URIRef("http://qudt.org/vocab/unit/STILB")
    J_PER_MIN = URIRef("http://qudt.org/vocab/unit/J-PER-MIN")
    ATM = URIRef("http://qudt.org/vocab/unit/ATM")
    GM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloGM")
    GM_PER_L_CentiPOISE = URIRef("http://qudt.org/vocab/unit/GM-PER-L-CentiPOISE")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    KiloCAL_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2")
    DecaM3 = URIRef("http://qudt.org/vocab/unit/DecaM3")
    LM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LM-PER-FT2")
    KiloGM_F_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-MilliM2")
    SV_PER_SEC = URIRef("http://qudt.org/vocab/unit/SV-PER-SEC")
    PicoMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M2-DAY")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    EUR_PER_M2 = URIRef("http://qudt.org/vocab/unit/EUR-PER-M2")
    FT_PDL = URIRef("http://qudt.org/vocab/unit/FT-PDL")
    MegaPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-BAR")
    ExaV_A = URIRef("http://qudt.org/vocab/unit/ExaV-A")
    MilliL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-SEC")
    OERSTED = URIRef("http://qudt.org/vocab/unit/OERSTED")
    DEG_F_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC2")
    YD_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD-PER-SEC")
    LB_M = URIRef("http://qudt.org/vocab/unit/LB_M")
    MegaBAR = URIRef("http://qudt.org/vocab/unit/MegaBAR")
    PER_M_NanoM = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM")
    PH = URIRef("http://qudt.org/vocab/unit/PH")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    V_PER_IN = URIRef("http://qudt.org/vocab/unit/V-PER-IN")
    CentiM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    MOHM = URIRef("http://qudt.org/vocab/unit/MOHM")
    BTU_TH_PER_FT2_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-MIN")
    GM_PER_MilliL_K = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL-K")
    N_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M2")
    CAL_TH_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-K")
    W_M2 = URIRef("http://qudt.org/vocab/unit/W-M2")
    TeraV_A_Reactive = URIRef("http://qudt.org/vocab/unit/TeraV-A_Reactive")
    GRAIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL_US")
    PERCENT_FT_SEC_PER_LB = URIRef("http://qudt.org/vocab/unit/PERCENT-FT-SEC-PER-LB")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    DeciBAR = URIRef("http://qudt.org/vocab/unit/DeciBAR")
    GM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/GM-PER-HR-K")
    CWT_SHORT = URIRef("http://qudt.org/vocab/unit/CWT_SHORT")
    S_Ab = URIRef("http://qudt.org/vocab/unit/S_Ab")
    KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-SEC2")
    MilliM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM2-PER-SEC")
    BIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/BIT-PER-M3")
    GI_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-HR")
    PA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M3-PER-SEC")
    YD3 = URIRef("http://qudt.org/vocab/unit/YD3")
    M_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-K")
    KiloPA = URIRef("http://qudt.org/vocab/unit/KiloPA")
    NUM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NUM-PER-M3")
    KiloS = URIRef("http://qudt.org/vocab/unit/KiloS")
    OZ_VOL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-MIN")
    NUM_PER_CentiM_KiloYR = URIRef("http://qudt.org/vocab/unit/NUM-PER-CentiM-KiloYR")
    AT = URIRef("http://qudt.org/vocab/unit/AT")
    N_PER_MilliM = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM")
    TON_Metric_PER_SEC = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC")
    KiloM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC")
    MOL_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-DeciM3")
    MilliBAR = URIRef("http://qudt.org/vocab/unit/MilliBAR")
    J_PER_HR = URIRef("http://qudt.org/vocab/unit/J-PER-HR")
    KiloWB_PER_M = URIRef("http://qudt.org/vocab/unit/KiloWB-PER-M")
    LB_SEC_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN6")
    MilliV = URIRef("http://qudt.org/vocab/unit/MilliV")
    CentiM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC-BAR")
    MilliGM_MIN_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M6")
    PER_SR = URIRef("http://qudt.org/vocab/unit/PER-SR")
    DYN_SEC_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM")
    PINT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-DAY")
    FT_LB_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-MIN")
    GM_SEC_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M3-CentiM3")
    M3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL-SEC")
    AC = URIRef("http://qudt.org/vocab/unit/AC")
    MilliBQ_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-M2-DAY")
    C_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM2")
    FemtoL = URIRef("http://qudt.org/vocab/unit/FemtoL")
    SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-PER-FT2")
    J_PER_GM_K = URIRef("http://qudt.org/vocab/unit/J-PER-GM-K")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    W_HR = URIRef("http://qudt.org/vocab/unit/W-HR")
    GM_MIN_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L-M3")
    MilliWB = URIRef("http://qudt.org/vocab/unit/MilliWB")
    M2_HR_DEG_C_PER_KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/M2-HR-DEG_C-PER-KiloCAL_IT")
    N_M_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-M-PER-KiloGM")
    KiloGM_PER_DeciM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-K")
    MegaHZ_M = URIRef("http://qudt.org/vocab/unit/MegaHZ-M")
    AC = URIRef("http://qudt.org/vocab/unit/AC")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    M2_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-V-SEC")
    OZ_VOL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-SEC")
    PSI_PER_IN = URIRef("http://qudt.org/vocab/unit/PSI-PER-IN")
    QT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-MIN")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    NUM_PER_GM = URIRef("http://qudt.org/vocab/unit/NUM-PER-GM")
    AU = URIRef("http://qudt.org/vocab/unit/AU")
    OZ_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_US")
    F = URIRef("http://qudt.org/vocab/unit/F")
    ENZ_PER_L = URIRef("http://qudt.org/vocab/unit/ENZ-PER-L")
    M_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-V-SEC")
    L_PER_L = URIRef("http://qudt.org/vocab/unit/L-PER-L")
    YR_TROPICAL = URIRef("http://qudt.org/vocab/unit/YR_TROPICAL")
    LB_SEC_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-YD3")
    BTU_IT_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_F")
    CUP = URIRef("http://qudt.org/vocab/unit/CUP")
    ST_PER_BAR = URIRef("http://qudt.org/vocab/unit/ST-PER-BAR")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    BU_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-MIN")
    CentiGM = URIRef("http://qudt.org/vocab/unit/CentiGM")
    MilliM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliM-PER-MIN")
    THM_US_PER_HR = URIRef("http://qudt.org/vocab/unit/THM_US-PER-HR")
    IN_H2O = URIRef("http://qudt.org/vocab/unit/IN_H2O")
    NanoM_PER_CentiM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-MegaPA")
    KiloGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-BAR")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    PERCENT_PER_DektoKiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DektoKiloCount")
    DEGREE_BAUME_US_LIGHT = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_LIGHT")
    DeciM2 = URIRef("http://qudt.org/vocab/unit/DeciM2")
    KiloCAL_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM")
    L_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/L-PER-MicroMOL")
    GAL_US_DRY = URIRef("http://qudt.org/vocab/unit/GAL_US_DRY")
    OZ_F = URIRef("http://qudt.org/vocab/unit/OZ_F")
    TONNE_PER_HA = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA")
    SLUG_PER_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-SEC")
    KiloPA_A = URIRef("http://qudt.org/vocab/unit/KiloPA_A")
    TON_Metric_PER_M3_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3-K")
    PPTR_VOL = URIRef("http://qudt.org/vocab/unit/PPTR_VOL")
    MegaBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaBTU_IT-PER-HR")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    PicoMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M3")
    LB_MIN_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-IN3")
    M_PER_K = URIRef("http://qudt.org/vocab/unit/M-PER-K")
    DEG_F_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC2")
    MicroN = URIRef("http://qudt.org/vocab/unit/MicroN")
    BTU_TH_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-HR-DEG_F")
    ST = URIRef("http://qudt.org/vocab/unit/ST")
    LB_FT2_PER_GAL_UK_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-GAL_UK-LB_F-SEC")
    IN3_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN3-PER-MIN")
    MilliGM_SEC_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L-CentiM3")
    BU_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-HR")
    FT2_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT2-PER-SEC")
    MicroN = URIRef("http://qudt.org/vocab/unit/MicroN")
    DeciTONNE = URIRef("http://qudt.org/vocab/unit/DeciTONNE")
    NanoFARAD = URIRef("http://qudt.org/vocab/unit/NanoFARAD")
    PINT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-SEC")
    LB_F_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-FT2")
    PERCENT_SEC_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-FT3")
    CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3")
    CentiM3_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN-BAR")
    TON_Metric_PER_M3 = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3")
    N_M2_PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/N-M2-PER-KiloGM2")
    A_HR_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-DeciM3")
    KiloW = URIRef("http://qudt.org/vocab/unit/KiloW")
    BTU_IT_PER_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL-DEG_F")
    PPB = URIRef("http://qudt.org/vocab/unit/PPB")
    W_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-SEC-PER-M2")
    OHM_CentiM = URIRef("http://qudt.org/vocab/unit/OHM-CentiM")
    BTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR")
    N_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M3")
    YD_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD-PER-DEG_F")
    GRAIN = URIRef("http://qudt.org/vocab/unit/GRAIN")
    MilliGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-CentiM2")
    RHE = URIRef("http://qudt.org/vocab/unit/RHE")
    R = URIRef("http://qudt.org/vocab/unit/R")
    DAY_Sidereal = URIRef("http://qudt.org/vocab/unit/DAY_Sidereal")
    MilliGRAY = URIRef("http://qudt.org/vocab/unit/MilliGRAY")
    MOL_PER_M3_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-PA")
    MicroOHM_M = URIRef("http://qudt.org/vocab/unit/MicroOHM-M")
    MOL_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-DeciM3")
    OERSTED = URIRef("http://qudt.org/vocab/unit/OERSTED")
    PERM_0DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_0DEG_C")
    CAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-K")
    KiloCi = URIRef("http://qudt.org/vocab/unit/KiloCi")
    KiloM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM2-PER-SEC2")
    NanoGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M2-PA-SEC")
    MilliN_M = URIRef("http://qudt.org/vocab/unit/MilliN-M")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    ZettaC = URIRef("http://qudt.org/vocab/unit/ZettaC")
    DEG_F_HR_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_TH")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    TeraC = URIRef("http://qudt.org/vocab/unit/TeraC")
    KiloGM_PER_M_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-MIN")
    TONNE_PER_MIN = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    A_PER_MilliM = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM")
    PER_MIN = URIRef("http://qudt.org/vocab/unit/PER-MIN")
    KiloGM_PER_M2_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC2")
    Stone_UK = URIRef("http://qudt.org/vocab/unit/Stone_UK")
    PINT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-SEC")
    PERCENT_PER_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MilliPA-SEC")
    DEG_C_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-K")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    MegaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M2")
    MilliGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN")
    M_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-PA")
    FemtoMOL = URIRef("http://qudt.org/vocab/unit/FemtoMOL")
    OZ_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ-PER-SEC")
    V_PER_MilliM = URIRef("http://qudt.org/vocab/unit/V-PER-MilliM")
    DeciB_Z = URIRef("http://qudt.org/vocab/unit/DeciB_Z")
    BTU_IT_PER_LB_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F")
    MegaL = URIRef("http://qudt.org/vocab/unit/MegaL")
    TONNE_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC-BAR")
    PER_T_SEC = URIRef("http://qudt.org/vocab/unit/PER-T-SEC")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    L_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/L-PER-KiloGM")
    DEGREE_BAUME = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME")
    LB_PER_YD2 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD2")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    MOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC")
    TONNE_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC-K")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    KiloEV = URIRef("http://qudt.org/vocab/unit/KiloEV")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    KiloHZ_M = URIRef("http://qudt.org/vocab/unit/KiloHZ-M")
    MilliDEG_C = URIRef("http://qudt.org/vocab/unit/MilliDEG_C")
    KiloBTU_TH = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH")
    MegaPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-L-PER-SEC")
    GM_Carbon_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Carbon-PER-M2-DAY")
    M3_PER_KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM-SEC2")
    MicroMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM")
    KiloGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloGM")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    SV_PER_SEC = URIRef("http://qudt.org/vocab/unit/SV-PER-SEC")
    MilliA_HR = URIRef("http://qudt.org/vocab/unit/MilliA-HR")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    LB_MIN_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US2")
    LB_PER_GAL = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL")
    W_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M3")
    PERCENT_SEC_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-GAL_UK")
    GM_PER_CentiM2_YR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2-YR")
    CentiM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY")
    BTU_TH_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT3")
    DEGREE_BRIX = URIRef("http://qudt.org/vocab/unit/DEGREE_BRIX")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    BU_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-MIN")
    OZ_IN = URIRef("http://qudt.org/vocab/unit/OZ-IN")
    NUM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NUM-PER-M3")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    CentiM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC")
    OZ_F_IN = URIRef("http://qudt.org/vocab/unit/OZ_F-IN")
    ERG_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM")
    IN4 = URIRef("http://qudt.org/vocab/unit/IN4")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    DeciB_C = URIRef("http://qudt.org/vocab/unit/DeciB_C")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    MilliM3 = URIRef("http://qudt.org/vocab/unit/MilliM3")
    PA_PER_K = URIRef("http://qudt.org/vocab/unit/PA-PER-K")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    BTU_TH_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_R")
    GM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC-BAR")
    PERM_0DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_0DEG_C")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    A = URIRef("http://qudt.org/vocab/unit/A")
    TON_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_US-PER-DAY")
    CAL_20DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_20DEG_C")
    BU_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-SEC")
    KiloGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC")
    MilliL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    KiloGM_PER_M2_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC2")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    AT_PER_IN = URIRef("http://qudt.org/vocab/unit/AT-PER-IN")
    C4_M4_PER_J3 = URIRef("http://qudt.org/vocab/unit/C4-M4-PER-J3")
    CFU = URIRef("http://qudt.org/vocab/unit/CFU")
    DEG_F_HR_FT2_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH")
    NanoGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-HR")
    DeciM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-SEC")
    CentiM3_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-K")
    QT_UK = URIRef("http://qudt.org/vocab/unit/QT_UK")
    K_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-M-PER-SEC")
    W = URIRef("http://qudt.org/vocab/unit/W")
    ATM_M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/ATM-M3-PER-MOL")
    PicoL = URIRef("http://qudt.org/vocab/unit/PicoL")
    NanoSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-SEC")
    LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC")
    MegaOHM_KiloM = URIRef("http://qudt.org/vocab/unit/MegaOHM-KiloM")
    FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-DEG_F")
    MicroA = URIRef("http://qudt.org/vocab/unit/MicroA")
    L = URIRef("http://qudt.org/vocab/unit/L")
    PlanckLength = URIRef("http://qudt.org/vocab/unit/PlanckLength")
    BTU_IT_PER_HR_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_R")
    FARAD_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/FARAD_Ab-PER-CentiM")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    LA_FT = URIRef("http://qudt.org/vocab/unit/LA_FT")
    MilliA_HR = URIRef("http://qudt.org/vocab/unit/MilliA-HR")
    MilliGM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR")
    MebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M2")
    DEG_F_HR_FT2_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    W_PER_K = URIRef("http://qudt.org/vocab/unit/W-PER-K")
    LB_F = URIRef("http://qudt.org/vocab/unit/LB_F")
    YD3_PER_DAY = URIRef("http://qudt.org/vocab/unit/YD3-PER-DAY")
    PERCENT_PER_HectoBAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-HectoBAR")
    PicoW_PER_CentiM2_L = URIRef("http://qudt.org/vocab/unit/PicoW-PER-CentiM2-L")
    PERCENT_IN2_PER_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-IN2-PER-LB_F-SEC")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    PERCENT_PER_DecaK = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaK")
    LB_IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN-PER-SEC")
    MACH = URIRef("http://qudt.org/vocab/unit/MACH")
    BTU_TH = URIRef("http://qudt.org/vocab/unit/BTU_TH")
    DEG_F_HR_FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT-IN")
    GM_PER_L = URIRef("http://qudt.org/vocab/unit/GM-PER-L")
    TON_LONG_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_LONG-PER-YD3")
    CentiM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-M3")
    L_PER_DAY = URIRef("http://qudt.org/vocab/unit/L-PER-DAY")
    OHM_Ab = URIRef("http://qudt.org/vocab/unit/OHM_Ab")
    CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3")
    KiloCi = URIRef("http://qudt.org/vocab/unit/KiloCi")
    NanoMOL_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL")
    M = URIRef("http://qudt.org/vocab/unit/M")
    KiloGM_PER_GigaJ = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-GigaJ")
    MicroMOL_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM-SEC")
    A = URIRef("http://qudt.org/vocab/unit/A")
    C_Ab = URIRef("http://qudt.org/vocab/unit/C_Ab")
    NUM_PER_L = URIRef("http://qudt.org/vocab/unit/NUM-PER-L")
    DeciM = URIRef("http://qudt.org/vocab/unit/DeciM")
    HeartBeat = URIRef("http://qudt.org/vocab/unit/HeartBeat")
    PER_MegaPA = URIRef("http://qudt.org/vocab/unit/PER-MegaPA")
    MicroG_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroG-PER-CentiM2")
    PDL_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-SEC-PER-FT2")
    LB_F_IN_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN-PER-IN")
    V_Ab = URIRef("http://qudt.org/vocab/unit/V_Ab")
    SUSCEPTIBILITY_MAG = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_MAG")
    LB_F_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN")
    PA_PER_K = URIRef("http://qudt.org/vocab/unit/PA-PER-K")
    OZ_VOL_UK = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK")
    MilliM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-HR")
    PPB = URIRef("http://qudt.org/vocab/unit/PPB")
    LB_F_PER_IN2_DEG_F = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-DEG_F")
    MicroJ = URIRef("http://qudt.org/vocab/unit/MicroJ")
    KiloOHM_PER_K = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-K")
    CentiM3_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN-BAR")
    MicroN = URIRef("http://qudt.org/vocab/unit/MicroN")
    N_M_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-M")
    MicroPA = URIRef("http://qudt.org/vocab/unit/MicroPA")
    GigaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-HR")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    MOL_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-K")
    A_M2 = URIRef("http://qudt.org/vocab/unit/A-M2")
    ERG = URIRef("http://qudt.org/vocab/unit/ERG")
    PicoS = URIRef("http://qudt.org/vocab/unit/PicoS")
    OZ_SEC_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-YD3")
    MicroM = URIRef("http://qudt.org/vocab/unit/MicroM")
    V_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/V-A_Reactive-PER-K")
    PicoMOL_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L-DAY")
    PA_M0pt5 = URIRef("http://qudt.org/vocab/unit/PA-M0pt5")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    PicoH = URIRef("http://qudt.org/vocab/unit/PicoH")
    BBL_UK_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-HR")
    M4 = URIRef("http://qudt.org/vocab/unit/M4")
    PlanckImpedance = URIRef("http://qudt.org/vocab/unit/PlanckImpedance")
    AU = URIRef("http://qudt.org/vocab/unit/AU")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    PER_OZ = URIRef("http://qudt.org/vocab/unit/PER-OZ")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    KiloCAL_IT_PER_HR_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-HR-M-DEG_C")
    MegaBQ = URIRef("http://qudt.org/vocab/unit/MegaBQ")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    LB_SEC_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-GAL_UK")
    KiloGM_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MOL")
    LA = URIRef("http://qudt.org/vocab/unit/LA")
    MilliCD = URIRef("http://qudt.org/vocab/unit/MilliCD")
    LA = URIRef("http://qudt.org/vocab/unit/LA")
    LB_PER_IN3_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3-PSI")
    KN = URIRef("http://qudt.org/vocab/unit/KN")
    MegaTOE = URIRef("http://qudt.org/vocab/unit/MegaTOE")
    FT2 = URIRef("http://qudt.org/vocab/unit/FT2")
    HectoGM = URIRef("http://qudt.org/vocab/unit/HectoGM")
    HP_Brake = URIRef("http://qudt.org/vocab/unit/HP_Brake")
    H_PER_OHM = URIRef("http://qudt.org/vocab/unit/H-PER-OHM")
    MilliL_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-BAR")
    TONNE_PER_MIN = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN")
    C = URIRef("http://qudt.org/vocab/unit/C")
    MilliH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-OHM")
    LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC")
    PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/PER-ANGSTROM")
    DEG_C_WK = URIRef("http://qudt.org/vocab/unit/DEG_C-WK")
    W_PER_SR = URIRef("http://qudt.org/vocab/unit/W-PER-SR")
    GM_PER_M2 = URIRef("http://qudt.org/vocab/unit/GM-PER-M2")
    T = URIRef("http://qudt.org/vocab/unit/T")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    REV_PER_HR = URIRef("http://qudt.org/vocab/unit/REV-PER-HR")
    TONNE_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN-K")
    CAL_TH_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2-SEC")
    A_Ab = URIRef("http://qudt.org/vocab/unit/A_Ab")
    MicroGAL_PER_M = URIRef("http://qudt.org/vocab/unit/MicroGAL-PER-M")
    KiloGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-PA-SEC")
    MilliGM_HR_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L-M3")
    LB_PER_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-PSI")
    KiloM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC")
    OZ_SEC_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN6")
    PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/PER-KiloGM2")
    Denier = URIRef("http://qudt.org/vocab/unit/Denier")
    MicroW = URIRef("http://qudt.org/vocab/unit/MicroW")
    C = URIRef("http://qudt.org/vocab/unit/C")
    FemtoC = URIRef("http://qudt.org/vocab/unit/FemtoC")
    MilliL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-MIN")
    BTU_MEAN = URIRef("http://qudt.org/vocab/unit/BTU_MEAN")
    PH = URIRef("http://qudt.org/vocab/unit/PH")
    PERCENT_FT_SEC_PER_LB = URIRef("http://qudt.org/vocab/unit/PERCENT-FT-SEC-PER-LB")
    PicoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-KiloGM")
    DEG_C_PER_M = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-M")
    BTU_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-MIN")
    KiloLB_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloLB-PER-HR")
    PA2_SEC = URIRef("http://qudt.org/vocab/unit/PA2-SEC")
    KiloYR = URIRef("http://qudt.org/vocab/unit/KiloYR")
    CentiGM = URIRef("http://qudt.org/vocab/unit/CentiGM")
    PERCENT_MIN_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-GAL_UK")
    BIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/BIT-PER-M2")
    MegaOHM_PER_K = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-K")
    CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-GM")
    SEC_PER_M = URIRef("http://qudt.org/vocab/unit/SEC-PER-M")
    M_PER_MIN = URIRef("http://qudt.org/vocab/unit/M-PER-MIN")
    W_PER_SR_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-SR-M2")
    AMU = URIRef("http://qudt.org/vocab/unit/AMU")
    MOL_PER_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-HR")
    PetaJ = URIRef("http://qudt.org/vocab/unit/PetaJ")
    GM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloGM")
    LB_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_US")
    J_PER_M = URIRef("http://qudt.org/vocab/unit/J-PER-M")
    MilliCi = URIRef("http://qudt.org/vocab/unit/MilliCi")
    DYN_SEC_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM")
    PER_K = URIRef("http://qudt.org/vocab/unit/PER-K")
    CentiM = URIRef("http://qudt.org/vocab/unit/CentiM")
    TON_Metric_PER_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-BAR")
    GigaA = URIRef("http://qudt.org/vocab/unit/GigaA")
    J_PER_M4 = URIRef("http://qudt.org/vocab/unit/J-PER-M4")
    KiloCAL_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL")
    IN_PER_2PiRAD = URIRef("http://qudt.org/vocab/unit/IN-PER-2PiRAD")
    PER_DEG_F = URIRef("http://qudt.org/vocab/unit/PER-DEG_F")
    S = URIRef("http://qudt.org/vocab/unit/S")
    MicroM3_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-MilliL")
    NanoOHM_M = URIRef("http://qudt.org/vocab/unit/NanoOHM-M")
    KiloBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloBQ-PER-KiloGM")
    N_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M3")
    OZ_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ-PER-SEC")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    GigaBQ = URIRef("http://qudt.org/vocab/unit/GigaBQ")
    BU_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-MIN")
    BTU_TH_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR-FT2-DEG_F")
    KiloMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3")
    J_PER_M4 = URIRef("http://qudt.org/vocab/unit/J-PER-M4")
    DEG_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-MIN")
    KiloA = URIRef("http://qudt.org/vocab/unit/KiloA")
    PicoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/PicoFARAD-PER-M")
    KiloEV_PER_MicroM = URIRef("http://qudt.org/vocab/unit/KiloEV-PER-MicroM")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    PlanckMomentum = URIRef("http://qudt.org/vocab/unit/PlanckMomentum")
    M2_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-BAR")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    OZ_VOL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-SEC")
    LB_PER_IN3_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3-PSI")
    PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PER-CentiM3")
    KN = URIRef("http://qudt.org/vocab/unit/KN")
    BTU_TH_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_F")
    LB_MIN_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-GAL_US")
    FT2_PER_HR = URIRef("http://qudt.org/vocab/unit/FT2-PER-HR")
    MicroGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-KiloGM")
    PERM_US = URIRef("http://qudt.org/vocab/unit/PERM_US")
    TSP = URIRef("http://qudt.org/vocab/unit/TSP")
    BARN = URIRef("http://qudt.org/vocab/unit/BARN")
    M3_PER_HA = URIRef("http://qudt.org/vocab/unit/M3-PER-HA")
    PERCENT_FT2_PER_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-FT2-PER-LB_F-SEC")
    OZ_PER_YD2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD2")
    KiloOHM_PER_K = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-K")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    FemtoMOL = URIRef("http://qudt.org/vocab/unit/FemtoMOL")
    KiloBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT")
    V_Ab_SEC = URIRef("http://qudt.org/vocab/unit/V_Ab-SEC")
    PERCENT_PER_PA_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-PA-SEC")
    KiloGM_F_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-MilliM2")
    PER_FT3 = URIRef("http://qudt.org/vocab/unit/PER-FT3")
    CAL_IT_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM-K")
    DeciN = URIRef("http://qudt.org/vocab/unit/DeciN")
    V_Stat_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-CentiM")
    LB_PER_M3 = URIRef("http://qudt.org/vocab/unit/LB-PER-M3")
    TON_Metric_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC-K")
    MO_MeanGREGORIAN = URIRef("http://qudt.org/vocab/unit/MO_MeanGREGORIAN")
    ExaBIT_PER_M = URIRef("http://qudt.org/vocab/unit/ExaBIT-PER-M")
    SEC2 = URIRef("http://qudt.org/vocab/unit/SEC2")
    J_PER_HR = URIRef("http://qudt.org/vocab/unit/J-PER-HR")
    DEGREE_BALLING = URIRef("http://qudt.org/vocab/unit/DEGREE_BALLING")
    MI_US2 = URIRef("http://qudt.org/vocab/unit/MI_US2")
    MilliW_PER_CentiM2_MicroM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-CentiM2-MicroM-SR")
    LB_F_FT = URIRef("http://qudt.org/vocab/unit/LB_F-FT")
    KiloFARAD = URIRef("http://qudt.org/vocab/unit/KiloFARAD")
    EV = URIRef("http://qudt.org/vocab/unit/EV")
    TON_UK = URIRef("http://qudt.org/vocab/unit/TON_UK")
    V_Stat_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-CentiM")
    FR = URIRef("http://qudt.org/vocab/unit/FR")
    PERCENT_PER_IN = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-IN")
    GigaV_A = URIRef("http://qudt.org/vocab/unit/GigaV-A")
    N_M_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-M")
    V_M = URIRef("http://qudt.org/vocab/unit/V-M")
    NanoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/NanoW-PER-M2")
    KiloCAL_PER_MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL-DEG_C")
    LB_PER_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-HR-DEG_F")
    ERG_PER_G = URIRef("http://qudt.org/vocab/unit/ERG-PER-G")
    LB_F_IN_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN-PER-IN")
    OZ_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ-PER-SEC")
    TEX = URIRef("http://qudt.org/vocab/unit/TEX")
    NanoM_PER_CentiM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-MegaPA")
    PSI_YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-YD3-PER-SEC")
    PDL_PER_IN = URIRef("http://qudt.org/vocab/unit/PDL-PER-IN")
    DEG_C_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-HR")
    ExbiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M2")
    MicroFARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-KiloM")
    TON_Metric_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC-K")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    PicoSEC = URIRef("http://qudt.org/vocab/unit/PicoSEC")
    Hundredweight_UK = URIRef("http://qudt.org/vocab/unit/Hundredweight_UK")
    ExaBYTE = URIRef("http://qudt.org/vocab/unit/ExaBYTE")
    FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-DEG_F")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    PA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M3-PER-SEC")
    FT3_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT3-PER-SEC")
    KiloCAL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-SEC")
    MilliBAR_PER_K = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-K")
    MilliM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliM-PER-MIN")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    GM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2")
    GM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC")
    IN_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-DEG_F")
    MegaHZ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-K")
    MicroMHO = URIRef("http://qudt.org/vocab/unit/MicroMHO")
    CAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC")
    PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PER-KiloGM")
    M4 = URIRef("http://qudt.org/vocab/unit/M4")
    L_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-K")
    TON_SHORT_PER_PSI = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-PSI")
    ExaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/ExaJ-PER-SEC")
    J_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2-DAY")
    DRAM_US = URIRef("http://qudt.org/vocab/unit/DRAM_US")
    THM_US_PER_HR = URIRef("http://qudt.org/vocab/unit/THM_US-PER-HR")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    MilliA_HR_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliA-HR-PER-GM")
    KibiBIT = URIRef("http://qudt.org/vocab/unit/KibiBIT")
    CFU = URIRef("http://qudt.org/vocab/unit/CFU")
    OZ_VOL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-MIN")
    PER_RAD = URIRef("http://qudt.org/vocab/unit/PER-RAD")
    MilliC = URIRef("http://qudt.org/vocab/unit/MilliC")
    PER_SEC_M2_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2-SR")
    MilliA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/MilliA-PER-MilliM")
    CAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-MIN")
    HR_PER_FT2 = URIRef("http://qudt.org/vocab/unit/HR-PER-FT2")
    CentiM = URIRef("http://qudt.org/vocab/unit/CentiM")
    KiloGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-K")
    GM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM")
    DECADE = URIRef("http://qudt.org/vocab/unit/DECADE")
    LUX_HR = URIRef("http://qudt.org/vocab/unit/LUX-HR")
    GM_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM2")
    OZ_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ-PER-SEC")
    IN3_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN3-PER-MIN")
    LB_MIN_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-YD3")
    KiloW_PER_M_K = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M-K")
    OZ_SEC_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-FT3")
    TON_Metric_PER_HA = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HA")
    K = URIRef("http://qudt.org/vocab/unit/K")
    T_Ab = URIRef("http://qudt.org/vocab/unit/T_Ab")
    ARCMIN = URIRef("http://qudt.org/vocab/unit/ARCMIN")
    MicroM2 = URIRef("http://qudt.org/vocab/unit/MicroM2")
    MebiBIT = URIRef("http://qudt.org/vocab/unit/MebiBIT")
    T = URIRef("http://qudt.org/vocab/unit/T")
    PER_MOL = URIRef("http://qudt.org/vocab/unit/PER-MOL")
    HP = URIRef("http://qudt.org/vocab/unit/HP")
    CAL_TH_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-DEG_C")
    KiloHZ_M = URIRef("http://qudt.org/vocab/unit/KiloHZ-M")
    FT = URIRef("http://qudt.org/vocab/unit/FT")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    MOL_K = URIRef("http://qudt.org/vocab/unit/MOL-K")
    PlanckEnergy = URIRef("http://qudt.org/vocab/unit/PlanckEnergy")
    PER_IN3 = URIRef("http://qudt.org/vocab/unit/PER-IN3")
    FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC")
    KiloGM_F_M = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M")
    BTU_IT_PER_MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB-DEG_F")
    YD = URIRef("http://qudt.org/vocab/unit/YD")
    MilliCD = URIRef("http://qudt.org/vocab/unit/MilliCD")
    KiloGM_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-YR")
    PetaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/PetaBIT-PER-SEC")
    KiloN_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M2")
    MilliA_PER_K = URIRef("http://qudt.org/vocab/unit/MilliA-PER-K")
    V_PER_BAR = URIRef("http://qudt.org/vocab/unit/V-PER-BAR")
    N_PER_CentiM = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM")
    PetaC = URIRef("http://qudt.org/vocab/unit/PetaC")
    MicroL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroL-PER-L")
    DEATHS_PER_KiloINDIV_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-KiloINDIV-YR")
    BTU_IT_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-SEC-DEG_F")
    QT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-DAY")
    MilliA = URIRef("http://qudt.org/vocab/unit/MilliA")
    J_PER_GM_K = URIRef("http://qudt.org/vocab/unit/J-PER-GM-K")
    MilliGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-K")
    BIOT = URIRef("http://qudt.org/vocab/unit/BIOT")
    TeraJ = URIRef("http://qudt.org/vocab/unit/TeraJ")
    MIN_Angle = URIRef("http://qudt.org/vocab/unit/MIN_Angle")
    PERCENT_PER_DecaK = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaK")
    C_M2_PER_V = URIRef("http://qudt.org/vocab/unit/C-M2-PER-V")
    IN2_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN2-PER-SEC")
    M3_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-BAR")
    MilliL_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-K")
    NanoJ = URIRef("http://qudt.org/vocab/unit/NanoJ")
    DEG_C_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-MIN")
    KiloPA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-M")
    MicroL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroL-PER-L")
    M3_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-M2")
    FARAD_Stat = URIRef("http://qudt.org/vocab/unit/FARAD_Stat")
    Standard = URIRef("http://qudt.org/vocab/unit/Standard")
    CentiPOISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-BAR")
    V_PER_SEC = URIRef("http://qudt.org/vocab/unit/V-PER-SEC")
    NanoMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL")
    LB_PER_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-DAY")
    MilliN_M = URIRef("http://qudt.org/vocab/unit/MilliN-M")
    MilliPA = URIRef("http://qudt.org/vocab/unit/MilliPA")
    DEG_C_PER_BAR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-BAR")
    LB_PER_IN3_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3-DEG_F")
    DEG_R_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-HR")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    NanoMOL_PER_CentiM3_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-CentiM3-HR")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    MilliL_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-BAR")
    BTU_IT_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT3")
    PPTR_VOL = URIRef("http://qudt.org/vocab/unit/PPTR_VOL")
    CAL_TH_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM")
    EV_PER_K = URIRef("http://qudt.org/vocab/unit/EV-PER-K")
    LB_MIN_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-IN3")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    OHM_Ab = URIRef("http://qudt.org/vocab/unit/OHM_Ab")
    V_PER_SEC = URIRef("http://qudt.org/vocab/unit/V-PER-SEC")
    C4_M4_PER_J3 = URIRef("http://qudt.org/vocab/unit/C4-M4-PER-J3")
    ONE_PER_ONE = URIRef("http://qudt.org/vocab/unit/ONE-PER-ONE")
    DeciM = URIRef("http://qudt.org/vocab/unit/DeciM")
    KiloGM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3")
    J_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-M2-PER-KiloGM")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    DEGREE_PLATO = URIRef("http://qudt.org/vocab/unit/DEGREE_PLATO")
    THERM_EC = URIRef("http://qudt.org/vocab/unit/THERM_EC")
    QT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_US-PER-SEC")
    DEG_F_SEC_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-SEC-PER-BTU_IT")
    MicroIN = URIRef("http://qudt.org/vocab/unit/MicroIN")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    A = URIRef("http://qudt.org/vocab/unit/A")
    FR = URIRef("http://qudt.org/vocab/unit/FR")
    KiloW_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloW-HR-PER-M2")
    MegaC = URIRef("http://qudt.org/vocab/unit/MegaC")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    MicroMOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-SEC")
    T = URIRef("http://qudt.org/vocab/unit/T")
    J_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K")
    DeciM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MIN")
    N_PER_MilliM = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM")
    M2_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/M2-SEC-PER-RAD")
    N_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-PER-RAD")
    BTU_IT_PER_LB_F_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_R")
    PERCENT_HR_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-FT3")
    V_PER_K = URIRef("http://qudt.org/vocab/unit/V-PER-K")
    CASES_PER_KiloINDIV_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-KiloINDIV-YR")
    MOL_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-K")
    PINT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-HR")
    MilliM_H2O = URIRef("http://qudt.org/vocab/unit/MilliM_H2O")
    WB_PER_MilliM = URIRef("http://qudt.org/vocab/unit/WB-PER-MilliM")
    BU_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-DAY")
    A_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-PER-CentiM2")
    MOL_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB")
    PER_M_K = URIRef("http://qudt.org/vocab/unit/PER-M-K")
    MilliW_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM-SR")
    TeraOHM = URIRef("http://qudt.org/vocab/unit/TeraOHM")
    GM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM")
    MO_Synodic = URIRef("http://qudt.org/vocab/unit/MO_Synodic")
    J_M2 = URIRef("http://qudt.org/vocab/unit/J-M2")
    CAL_TH_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2-SEC")
    MilliBAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-M3-PER-SEC")
    TebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M2")
    CentiM_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-HR")
    MegaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M2")
    DEG_F_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-K")
    KiloYR = URIRef("http://qudt.org/vocab/unit/KiloYR")
    IN3_PER_LB = URIRef("http://qudt.org/vocab/unit/IN3-PER-LB")
    KiloGM_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-M2")
    PA2_SEC = URIRef("http://qudt.org/vocab/unit/PA2-SEC")
    GM_Nitrogen_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Nitrogen-PER-M2-DAY")
    PicoA = URIRef("http://qudt.org/vocab/unit/PicoA")
    MilliGM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-BAR")
    M_KiloGM = URIRef("http://qudt.org/vocab/unit/M-KiloGM")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN3-PER-SEC")
    A_PER_CentiM = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/PER-MilliM3")
    MicroJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroJ-PER-SEC")
    NanoH_PER_M = URIRef("http://qudt.org/vocab/unit/NanoH-PER-M")
    KiloC = URIRef("http://qudt.org/vocab/unit/KiloC")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    NanoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/NanoW-PER-M2")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    MilliL_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-BAR")
    A_Ab = URIRef("http://qudt.org/vocab/unit/A_Ab")
    OZ_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ-PER-MIN")
    KiloLB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-IN2")
    FARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/FARAD-PER-KiloM")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    PER_MegaPA = URIRef("http://qudt.org/vocab/unit/PER-MegaPA")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    CentiM3_PER_HR_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR-K")
    KiloGM_M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M2-PER-SEC")
    ERLANG = URIRef("http://qudt.org/vocab/unit/ERLANG")
    KiloGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC")
    PA_M0pt5 = URIRef("http://qudt.org/vocab/unit/PA-M0pt5")
    W_PER_M_K = URIRef("http://qudt.org/vocab/unit/W-PER-M-K")
    TORR_PER_M = URIRef("http://qudt.org/vocab/unit/TORR-PER-M")
    C = URIRef("http://qudt.org/vocab/unit/C")
    GigaHZ = URIRef("http://qudt.org/vocab/unit/GigaHZ")
    LB_FT2_PER_GAL_UK_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-GAL_UK-LB_F-SEC")
    GAL_US = URIRef("http://qudt.org/vocab/unit/GAL_US")
    PER_PlanckMass2 = URIRef("http://qudt.org/vocab/unit/PER-PlanckMass2")
    V_PER_PA = URIRef("http://qudt.org/vocab/unit/V-PER-PA")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    PER_MilliSEC = URIRef("http://qudt.org/vocab/unit/PER-MilliSEC")
    EV_PER_M = URIRef("http://qudt.org/vocab/unit/EV-PER-M")
    CentiM = URIRef("http://qudt.org/vocab/unit/CentiM")
    OZ_VOL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-SEC")
    ZettaC = URIRef("http://qudt.org/vocab/unit/ZettaC")
    LM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LM-PER-FT2")
    MegaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-HR")
    PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PER-CentiM3")
    ExaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/ExaJ-PER-SEC")
    MegaJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-KiloGM")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    R = URIRef("http://qudt.org/vocab/unit/R")
    KiloGM_PER_M3_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-PA")
    KiloBAR = URIRef("http://qudt.org/vocab/unit/KiloBAR")
    PER_SEC_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    KiloGM_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM2")
    AC_FT = URIRef("http://qudt.org/vocab/unit/AC-FT")
    W_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-PER-M3")
    CentiM = URIRef("http://qudt.org/vocab/unit/CentiM")
    CAL_IT_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM2-K")
    N_M2_PER_A = URIRef("http://qudt.org/vocab/unit/N-M2-PER-A")
    KiloGM_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-YR")
    MilliGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-BAR")
    CAL_TH_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM")
    KiloGM_F_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-SEC")
    MicroMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MOL")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    MicroGRAY = URIRef("http://qudt.org/vocab/unit/MicroGRAY")
    KiloLB_F_FT_PER_A = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-A")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    M2_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-BAR")
    C_M2_PER_V = URIRef("http://qudt.org/vocab/unit/C-M2-PER-V")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    PER_MIN = URIRef("http://qudt.org/vocab/unit/PER-MIN")
    BQ_PER_L = URIRef("http://qudt.org/vocab/unit/BQ-PER-L")
    IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN3-PER-SEC")
    QT_US_DRY = URIRef("http://qudt.org/vocab/unit/QT_US_DRY")
    L_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/L-PER-KiloGM")
    K_PER_BAR = URIRef("http://qudt.org/vocab/unit/K-PER-BAR")
    K_PER_MIN = URIRef("http://qudt.org/vocab/unit/K-PER-MIN")
    ERG_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM3")
    OZ_VOL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-MIN")
    OZ_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ-PER-DAY")
    C = URIRef("http://qudt.org/vocab/unit/C")
    NanoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MilliL")
    MilliMOL = URIRef("http://qudt.org/vocab/unit/MilliMOL")
    GRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/GRAY-PER-SEC")
    KiloGM_F_M_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-CentiM2")
    DeciM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-M3")
    BTU_IT_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_R")
    PER_CentiM = URIRef("http://qudt.org/vocab/unit/PER-CentiM")
    HP_Brake = URIRef("http://qudt.org/vocab/unit/HP_Brake")
    S = URIRef("http://qudt.org/vocab/unit/S")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    J = URIRef("http://qudt.org/vocab/unit/J")
    CentiM3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-K")
    V_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/V-A_Reactive-HR")
    BTU_TH = URIRef("http://qudt.org/vocab/unit/BTU_TH")
    DeciTON_Metric = URIRef("http://qudt.org/vocab/unit/DeciTON_Metric")
    FT_SEC_PER_IN3 = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-IN3")
    PK_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-SEC")
    TON_F_US = URIRef("http://qudt.org/vocab/unit/TON_F_US")
    ST_PER_K = URIRef("http://qudt.org/vocab/unit/ST-PER-K")
    NanoW = URIRef("http://qudt.org/vocab/unit/NanoW")
    TON_FG_HR = URIRef("http://qudt.org/vocab/unit/TON_FG-HR")
    MilliGAL = URIRef("http://qudt.org/vocab/unit/MilliGAL")
    TON_UK = URIRef("http://qudt.org/vocab/unit/TON_UK")
    CentiM_PER_YR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-YR")
    QUAD = URIRef("http://qudt.org/vocab/unit/QUAD")
    CAL_TH_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM-K")
    BIOT = URIRef("http://qudt.org/vocab/unit/BIOT")
    PERM_Metric_23DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_Metric_23DEG_C")
    PPM_PER_K = URIRef("http://qudt.org/vocab/unit/PPM-PER-K")
    ERG_PER_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-SEC")
    ZOLL = URIRef("http://qudt.org/vocab/unit/ZOLL")
    L_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-M2")
    KiloGM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC2")
    KiloGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-BAR")
    LB_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC-DEG_F")
    OZ_M = URIRef("http://qudt.org/vocab/unit/OZ_M")
    HART = URIRef("http://qudt.org/vocab/unit/HART")
    KiloGM_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-YR")
    M2_HR_DEG_C_PER_KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/M2-HR-DEG_C-PER-KiloCAL_IT")
    PSI_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-M3-PER-SEC")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    PER_V_A_SEC = URIRef("http://qudt.org/vocab/unit/PER-V-A-SEC")
    N_M_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-RAD")
    N_M_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-RAD")
    MicroT = URIRef("http://qudt.org/vocab/unit/MicroT")
    KiloGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-BAR")
    MilliBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-L")
    KiloR = URIRef("http://qudt.org/vocab/unit/KiloR")
    PERCENT_MIN_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-FT3")
    Standard = URIRef("http://qudt.org/vocab/unit/Standard")
    CWT_SHORT = URIRef("http://qudt.org/vocab/unit/CWT_SHORT")
    GM_PER_MilliL_K = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL-K")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    A_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-M3")
    MilliM_HGA = URIRef("http://qudt.org/vocab/unit/MilliM_HGA")
    MilliGAL = URIRef("http://qudt.org/vocab/unit/MilliGAL")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    IN2_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN2-PER-SEC")
    V = URIRef("http://qudt.org/vocab/unit/V")
    CORD = URIRef("http://qudt.org/vocab/unit/CORD")
    MicroH_PER_M = URIRef("http://qudt.org/vocab/unit/MicroH-PER-M")
    MOL_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-BAR")
    ERLANG = URIRef("http://qudt.org/vocab/unit/ERLANG")
    MOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM")
    PlanckFrequency_Ang = URIRef("http://qudt.org/vocab/unit/PlanckFrequency_Ang")
    GigaW = URIRef("http://qudt.org/vocab/unit/GigaW")
    BTU_IT_PER_SEC_FT_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT-DEG_R")
    T_Ab = URIRef("http://qudt.org/vocab/unit/T_Ab")
    OZ_PER_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD3")
    PK_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-SEC")
    LB_PER_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-HR")
    CAL_15_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_15_DEG_C")
    PER_TONNE = URIRef("http://qudt.org/vocab/unit/PER-TONNE")
    KiloMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-KiloGM")
    C_M2_PER_V = URIRef("http://qudt.org/vocab/unit/C-M2-PER-V")
    ST_PER_BAR = URIRef("http://qudt.org/vocab/unit/ST-PER-BAR")
    GibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M3")
    MilliOHM = URIRef("http://qudt.org/vocab/unit/MilliOHM")
    A_MIN = URIRef("http://qudt.org/vocab/unit/A-MIN")
    M2_PER_GM_DRY = URIRef("http://qudt.org/vocab/unit/M2-PER-GM_DRY")
    MilliA_PER_IN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-IN")
    MegaJ_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M3")
    GigaHZ = URIRef("http://qudt.org/vocab/unit/GigaHZ")
    NanoGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M2-PA-SEC")
    KiloHZ_M = URIRef("http://qudt.org/vocab/unit/KiloHZ-M")
    PER_M_NanoM = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM")
    CentiM_H2O_4DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_H2O_4DEG_C")
    DEG_C_CentiM = URIRef("http://qudt.org/vocab/unit/DEG_C-CentiM")
    MicroGM_PER_CentiM2_WK = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2-WK")
    AC_FT_US = URIRef("http://qudt.org/vocab/unit/AC-FT_US")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    MilliS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MilliS-PER-CentiM")
    DYN_SEC_PER_CentiM5 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM5")
    BTU_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC")
    KiloM = URIRef("http://qudt.org/vocab/unit/KiloM")
    MegaPA_M0dot5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0dot5")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    ERG_CentiM2 = URIRef("http://qudt.org/vocab/unit/ERG-CentiM2")
    M3_PER_MIN = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN")
    W_PER_M = URIRef("http://qudt.org/vocab/unit/W-PER-M")
    CAL_TH_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM")
    GAL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-MIN")
    MilliN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliN-M-PER-M2")
    CAL_TH = URIRef("http://qudt.org/vocab/unit/CAL_TH")
    CM_H2O = URIRef("http://qudt.org/vocab/unit/CM_H2O")
    FT3_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN")
    TON_LONG_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_LONG-PER-YD3")
    MegaW = URIRef("http://qudt.org/vocab/unit/MegaW")
    PlanckFrequency = URIRef("http://qudt.org/vocab/unit/PlanckFrequency")
    BARN = URIRef("http://qudt.org/vocab/unit/BARN")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    PPB = URIRef("http://qudt.org/vocab/unit/PPB")
    EV_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/EV-M2-PER-KiloGM")
    MOL_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-L-BAR")
    HP_Boiler = URIRef("http://qudt.org/vocab/unit/HP_Boiler")
    BTU_IT_IN_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-SEC-FT2-DEG_F")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    K_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-M-PER-SEC")
    KiloC_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M2")
    OZ_TROY = URIRef("http://qudt.org/vocab/unit/OZ_TROY")
    V_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Ab-PER-CentiM")
    DEG_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC2")
    PER_YR = URIRef("http://qudt.org/vocab/unit/PER-YR")
    MicroN_M = URIRef("http://qudt.org/vocab/unit/MicroN-M")
    GM_PER_HR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR")
    A = URIRef("http://qudt.org/vocab/unit/A")
    IN_H2O = URIRef("http://qudt.org/vocab/unit/IN_H2O")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    KIP_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KIP_F-PER-IN2")
    LB_HR_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-GAL_US")
    OZ_SEC_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-GAL_US")
    MegaGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-HA")
    LB_F_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-IN2")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    GM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3")
    PDL_IN = URIRef("http://qudt.org/vocab/unit/PDL-IN")
    PlanckPower = URIRef("http://qudt.org/vocab/unit/PlanckPower")
    PER_IN2 = URIRef("http://qudt.org/vocab/unit/PER-IN2")
    HectoM = URIRef("http://qudt.org/vocab/unit/HectoM")
    CAL_MEAN = URIRef("http://qudt.org/vocab/unit/CAL_MEAN")
    M2_HR_DEG_C_PER_KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/M2-HR-DEG_C-PER-KiloCAL_IT")
    CAL_IT_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM")
    GM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN-BAR")
    KiloOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-BAR")
    MilliL_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-BAR")
    A_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM2")
    BTU_59DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_59DEG_F")
    C_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM2")
    LB_HR_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT6")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    M2_K_PER_W = URIRef("http://qudt.org/vocab/unit/M2-K-PER-W")
    MicroFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-M")
    BTU_TH_PER_FT2_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-MIN")
    M_PER_K = URIRef("http://qudt.org/vocab/unit/M-PER-K")
    TeraOHM = URIRef("http://qudt.org/vocab/unit/TeraOHM")
    MilliM_PER_YR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-YR")
    KiloGM_PER_M_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC")
    A_M2 = URIRef("http://qudt.org/vocab/unit/A-M2")
    KiloMOL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-HR")
    PA_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M")
    OZ_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ-PER-MIN")
    ANGSTROM = URIRef("http://qudt.org/vocab/unit/ANGSTROM")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    MicroMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-SEC")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    KiloGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC")
    RHE = URIRef("http://qudt.org/vocab/unit/RHE")
    MegaW_HR = URIRef("http://qudt.org/vocab/unit/MegaW-HR")
    MilliM_H2O = URIRef("http://qudt.org/vocab/unit/MilliM_H2O")
    WB_M = URIRef("http://qudt.org/vocab/unit/WB-M")
    BTU_IT_IN_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-HR-FT2-DEG_F")
    GM_MIN_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M3-L")
    LB_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC-DEG_F")
    NanoGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M3")
    H_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/H-PER-KiloOHM")
    YR_Metrology = URIRef("http://qudt.org/vocab/unit/YR_Metrology")
    DeciM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-M3")
    ERG_PER_G = URIRef("http://qudt.org/vocab/unit/ERG-PER-G")
    LB_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC-PSI")
    MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/MOL-DEG_C")
    MilliGM_HR_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L2")
    LB_T = URIRef("http://qudt.org/vocab/unit/LB_T")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    POISE = URIRef("http://qudt.org/vocab/unit/POISE")
    PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/PER-ANGSTROM")
    HectoGM = URIRef("http://qudt.org/vocab/unit/HectoGM")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    LB_MIN_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-IN3")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    QT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-HR")
    MegaOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-BAR")
    YD_PER_HR = URIRef("http://qudt.org/vocab/unit/YD-PER-HR")
    LB_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-DEG_F")
    MOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-SEC")
    MegaTONNE = URIRef("http://qudt.org/vocab/unit/MegaTONNE")
    BTU_IT_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_R")
    KiloGM_M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M2-PER-SEC")
    TeraJ = URIRef("http://qudt.org/vocab/unit/TeraJ")
    OZ_HR_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-GAL_US")
    J_M2 = URIRef("http://qudt.org/vocab/unit/J-M2")
    MilliDARCY = URIRef("http://qudt.org/vocab/unit/MilliDARCY")
    Kilo_FT3 = URIRef("http://qudt.org/vocab/unit/Kilo-FT3")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    C_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Ab-PER-CentiM2")
    LB_SEC_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-YD3")
    NanoH_PER_M = URIRef("http://qudt.org/vocab/unit/NanoH-PER-M")
    MilliGM = URIRef("http://qudt.org/vocab/unit/MilliGM")
    MicroMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L-HR")
    KiloCAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-MIN")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    KiloGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-BAR")
    LB_IN = URIRef("http://qudt.org/vocab/unit/LB-IN")
    LB_PER_FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-LB_F-SEC")
    GM_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/GM-PER-DEG_C")
    J_PER_HR = URIRef("http://qudt.org/vocab/unit/J-PER-HR")
    MilliGM_MIN_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M3-CentiM3")
    J_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K")
    MilliIN = URIRef("http://qudt.org/vocab/unit/MilliIN")
    OZ_VOL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-HR")
    KiloGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-K")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    L_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-BAR")
    MegaLB_F = URIRef("http://qudt.org/vocab/unit/MegaLB_F")
    BTU_IT = URIRef("http://qudt.org/vocab/unit/BTU_IT")
    MilliL_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-BAR")
    PicoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/PicoKAT-PER-L")
    BAR_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/BAR-PER-DEG_C")
    C_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM2")
    N_PER_MilliM = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM")
    V = URIRef("http://qudt.org/vocab/unit/V")
    KiloMOL_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3-BAR")
    PicoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-MilliL")
    V_A_HR = URIRef("http://qudt.org/vocab/unit/V-A-HR")
    YoctoC = URIRef("http://qudt.org/vocab/unit/YoctoC")
    TON_SHORT = URIRef("http://qudt.org/vocab/unit/TON_SHORT")
    J_PER_M4 = URIRef("http://qudt.org/vocab/unit/J-PER-M4")
    KiloM3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM3-PER-SEC2")
    PetaA = URIRef("http://qudt.org/vocab/unit/PetaA")
    V_PER_IN = URIRef("http://qudt.org/vocab/unit/V-PER-IN")
    ERG_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM-SEC")
    YoctoC = URIRef("http://qudt.org/vocab/unit/YoctoC")
    DEG_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    MilliGM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-K")
    DEG_F_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-HR")
    PK_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-HR")
    MilliGRAY = URIRef("http://qudt.org/vocab/unit/MilliGRAY")
    A_HR = URIRef("http://qudt.org/vocab/unit/A-HR")
    J_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2")
    M3_PER_MIN = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN")
    BU_US = URIRef("http://qudt.org/vocab/unit/BU_US")
    CentiM = URIRef("http://qudt.org/vocab/unit/CentiM")
    LB_F_PER_LB = URIRef("http://qudt.org/vocab/unit/LB_F-PER-LB")
    J_PER_MOL_K = URIRef("http://qudt.org/vocab/unit/J-PER-MOL-K")
    OHM_KiloM = URIRef("http://qudt.org/vocab/unit/OHM-KiloM")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    MilliA_HR = URIRef("http://qudt.org/vocab/unit/MilliA-HR")
    M_PER_HR = URIRef("http://qudt.org/vocab/unit/M-PER-HR")
    TON_Metric_PER_MIN = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN")
    MicroH_PER_M = URIRef("http://qudt.org/vocab/unit/MicroH-PER-M")
    ZeptoC = URIRef("http://qudt.org/vocab/unit/ZeptoC")
    MilliGM_PER_M3_POISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-POISE")
    DEG_R_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-HR")
    LB_SEC_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-YD3")
    LB_MIN_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-GAL_US")
    MicroM_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/MicroM-PER-L-DAY")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    PERCENT_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEG_C")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC")
    PK_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-SEC")
    FT3_PER_MIN_FT2 = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN-FT2")
    MilliGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    PER_MegaK = URIRef("http://qudt.org/vocab/unit/PER-MegaK")
    TeraC = URIRef("http://qudt.org/vocab/unit/TeraC")
    BTU_IT_PER_SEC_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_R")
    KiloN_M_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-M")
    DEG_C2_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C2-PER-SEC")
    MicroS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MicroS-PER-CentiM")
    L_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/L-PER-MicroMOL")
    KiloCAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-GM-K")
    GibiBIT = URIRef("http://qudt.org/vocab/unit/GibiBIT")
    KiloA_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M2")
    PicoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/PicoKAT-PER-L")
    NanoBQ_PER_L = URIRef("http://qudt.org/vocab/unit/NanoBQ-PER-L")
    MilliGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-MIN")
    NanoSEC = URIRef("http://qudt.org/vocab/unit/NanoSEC")
    LB_T = URIRef("http://qudt.org/vocab/unit/LB_T")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    FT3_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT3-PER-SEC")
    M2_PER_SR_J = URIRef("http://qudt.org/vocab/unit/M2-PER-SR-J")
    KiloOHM = URIRef("http://qudt.org/vocab/unit/KiloOHM")
    N_M_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-RAD")
    KiloCAL_PER_MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL-DEG_C")
    UnitPole = URIRef("http://qudt.org/vocab/unit/UnitPole")
    MilliJ = URIRef("http://qudt.org/vocab/unit/MilliJ")
    FR = URIRef("http://qudt.org/vocab/unit/FR")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    M_PER_HR = URIRef("http://qudt.org/vocab/unit/M-PER-HR")
    KiloA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloA-PER-K")
    PSU = URIRef("http://qudt.org/vocab/unit/PSU")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    GM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3")
    MilliGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-CentiM2")
    J_PER_M3_K = URIRef("http://qudt.org/vocab/unit/J-PER-M3-K")
    Ci = URIRef("http://qudt.org/vocab/unit/Ci")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    FT3_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT3-PER-SEC")
    M_PER_FARAD = URIRef("http://qudt.org/vocab/unit/M-PER-FARAD")
    MilliMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3")
    T = URIRef("http://qudt.org/vocab/unit/T")
    C4_M4_PER_J3 = URIRef("http://qudt.org/vocab/unit/C4-M4-PER-J3")
    GM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-L-BAR")
    OZ_PER_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD3")
    N_M_PER_DEG_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG-M")
    GRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/GRAY-PER-HR")
    A_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-M2")
    OZ_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ-PER-DAY")
    OZ_FT = URIRef("http://qudt.org/vocab/unit/OZ-FT")
    YD3 = URIRef("http://qudt.org/vocab/unit/YD3")
    PER_IN = URIRef("http://qudt.org/vocab/unit/PER-IN")
    MI_N_PER_HR = URIRef("http://qudt.org/vocab/unit/MI_N-PER-HR")
    NanoGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2")
    MicroGM_PER_CentiM2_WK = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2-WK")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    N_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M3")
    C_PER_MOL = URIRef("http://qudt.org/vocab/unit/C-PER-MOL")
    PERCENT_HR_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-CentiM3")
    MilliGM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-K")
    S_PER_CentiM = URIRef("http://qudt.org/vocab/unit/S-PER-CentiM")
    CH = URIRef("http://qudt.org/vocab/unit/CH")
    LB_PER_FT = URIRef("http://qudt.org/vocab/unit/LB-PER-FT")
    GAL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-SEC")
    N_PER_C = URIRef("http://qudt.org/vocab/unit/N-PER-C")
    DeciM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-SEC")
    KiloJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    KiloCAL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MIN")
    TeraC = URIRef("http://qudt.org/vocab/unit/TeraC")
    J_PER_KiloGM_K_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-M3")
    TeraBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/TeraBIT-PER-SEC")
    PER_TON = URIRef("http://qudt.org/vocab/unit/PER-TON")
    NP = URIRef("http://qudt.org/vocab/unit/NP")
    MOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM")
    PA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-L-PER-SEC")
    GM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN-BAR")
    FRACTION = URIRef("http://qudt.org/vocab/unit/FRACTION")
    OZ_VOL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-MIN")
    TONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-YR")
    W_HR = URIRef("http://qudt.org/vocab/unit/W-HR")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    PicoMOL_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M3-SEC")
    MilliGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN")
    LM_HR = URIRef("http://qudt.org/vocab/unit/LM-HR")
    V = URIRef("http://qudt.org/vocab/unit/V")
    BAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-M3-PER-SEC")
    M2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2")
    V = URIRef("http://qudt.org/vocab/unit/V")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    MilliT = URIRef("http://qudt.org/vocab/unit/MilliT")
    MilliA_PER_LB_F_IN2 = URIRef("http://qudt.org/vocab/unit/MilliA-PER-LB_F-IN2")
    KiloTONNE = URIRef("http://qudt.org/vocab/unit/KiloTONNE")
    GigaFLOPS = URIRef("http://qudt.org/vocab/unit/GigaFLOPS")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    DEG_C_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-SEC")
    IN_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC-DEG_F")
    M3_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-BAR")
    PSI = URIRef("http://qudt.org/vocab/unit/PSI")
    OZ_PER_IN2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN2")
    V_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/V-A_Reactive-PER-K")
    PicoC = URIRef("http://qudt.org/vocab/unit/PicoC")
    MicroA_PER_K = URIRef("http://qudt.org/vocab/unit/MicroA-PER-K")
    IU_PER_MilliL = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliL")
    PER_MilliGM = URIRef("http://qudt.org/vocab/unit/PER-MilliGM")
    GigaHZ = URIRef("http://qudt.org/vocab/unit/GigaHZ")
    KiloGM_PER_M_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC2")
    KiloGM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-CentiM2")
    A = URIRef("http://qudt.org/vocab/unit/A")
    MilliGM_HR_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M3-CentiM3")
    MegaEV = URIRef("http://qudt.org/vocab/unit/MegaEV")
    SEC_PER_M3_RAD = URIRef("http://qudt.org/vocab/unit/SEC-PER-M3-RAD")
    NanoM2 = URIRef("http://qudt.org/vocab/unit/NanoM2")
    KiloJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-SEC")
    LM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LM-PER-FT2")
    PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2")
    FT3 = URIRef("http://qudt.org/vocab/unit/FT3")
    SEC_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-FT2")
    C_Ab = URIRef("http://qudt.org/vocab/unit/C_Ab")
    TONNE_PER_DAY = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY")
    GAL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-MIN")
    CentiM3_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN-BAR")
    PA_PER_K = URIRef("http://qudt.org/vocab/unit/PA-PER-K")
    FT_LB_F_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-HR")
    N_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM2")
    KiloJ = URIRef("http://qudt.org/vocab/unit/KiloJ")
    MegaJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-KiloGM")
    J = URIRef("http://qudt.org/vocab/unit/J")
    MilliGM_HR_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M3-L")
    DEATHS_PER_MegaINDIV_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-MegaINDIV-YR")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    GM = URIRef("http://qudt.org/vocab/unit/GM")
    MilliS = URIRef("http://qudt.org/vocab/unit/MilliS")
    MicroM3 = URIRef("http://qudt.org/vocab/unit/MicroM3")
    OZ_M = URIRef("http://qudt.org/vocab/unit/OZ_M")
    OZ_PER_YD2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD2")
    KiloBD = URIRef("http://qudt.org/vocab/unit/KiloBD")
    RPK = URIRef("http://qudt.org/vocab/unit/RPK")
    CLO = URIRef("http://qudt.org/vocab/unit/CLO")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    PERCENT_FT2_PER_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-FT2-PER-LB_F-SEC")
    PER_KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/PER-KiloV-A-HR")
    PetaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/PetaBIT-PER-SEC")
    J_PER_GM = URIRef("http://qudt.org/vocab/unit/J-PER-GM")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    KiloGM_PER_M_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC2")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    MegaSEC = URIRef("http://qudt.org/vocab/unit/MegaSEC")
    RAD_PER_MIN = URIRef("http://qudt.org/vocab/unit/RAD-PER-MIN")
    DPI = URIRef("http://qudt.org/vocab/unit/DPI")
    GALILEO = URIRef("http://qudt.org/vocab/unit/GALILEO")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    MESH = URIRef("http://qudt.org/vocab/unit/MESH")
    N_M_PER_DEG_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG-M")
    DeciM = URIRef("http://qudt.org/vocab/unit/DeciM")
    GM_SEC_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L-CentiM3")
    ElementaryCharge = URIRef("http://qudt.org/vocab/unit/ElementaryCharge")
    GM_PER_CentiM2_YR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2-YR")
    FT3_PER_PSI = URIRef("http://qudt.org/vocab/unit/FT3-PER-PSI")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    FA = URIRef("http://qudt.org/vocab/unit/FA")
    CentiPOISE = URIRef("http://qudt.org/vocab/unit/CentiPOISE")
    MegaN = URIRef("http://qudt.org/vocab/unit/MegaN")
    PicoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-MilliL")
    CentiN = URIRef("http://qudt.org/vocab/unit/CentiN")
    M3_PER_KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM-SEC2")
    KiloL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloL-PER-HR")
    LB_F = URIRef("http://qudt.org/vocab/unit/LB_F")
    J_PER_GM_K = URIRef("http://qudt.org/vocab/unit/J-PER-GM-K")
    J_PER_M4 = URIRef("http://qudt.org/vocab/unit/J-PER-M4")
    W_PER_M2_PA = URIRef("http://qudt.org/vocab/unit/W-PER-M2-PA")
    GM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2")
    CAL_MEAN = URIRef("http://qudt.org/vocab/unit/CAL_MEAN")
    POISE_PER_PA = URIRef("http://qudt.org/vocab/unit/POISE-PER-PA")
    GigaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBYTE-PER-SEC")
    KiloW_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloW-HR-PER-M2")
    TONNE = URIRef("http://qudt.org/vocab/unit/TONNE")
    KiloGM_PER_MegaBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MegaBTU_IT")
    MicroGM_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L-HR")
    W_HR_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-HR-PER-KiloGM")
    FT_H2O = URIRef("http://qudt.org/vocab/unit/FT_H2O")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    CAL_TH_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2")
    KiloGM_PER_L = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L")
    DeciM = URIRef("http://qudt.org/vocab/unit/DeciM")
    GAL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-DAY")
    HP_Brake = URIRef("http://qudt.org/vocab/unit/HP_Brake")
    N_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M")
    PH = URIRef("http://qudt.org/vocab/unit/PH")
    MHO = URIRef("http://qudt.org/vocab/unit/MHO")
    MilliMOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2-SEC")
    BTU_IT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MIN")
    MicroGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M2-DAY")
    H = URIRef("http://qudt.org/vocab/unit/H")
    CentiM3_PER_HR_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR-K")
    YD_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD-PER-SEC")
    MicroV = URIRef("http://qudt.org/vocab/unit/MicroV")
    KiloEV_PER_MicroM = URIRef("http://qudt.org/vocab/unit/KiloEV-PER-MicroM")
    KiloN = URIRef("http://qudt.org/vocab/unit/KiloN")
    PicoPA = URIRef("http://qudt.org/vocab/unit/PicoPA")
    GM_PER_MilliL_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL-BAR")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    K_PER_T = URIRef("http://qudt.org/vocab/unit/K-PER-T")
    M2_PER_M2 = URIRef("http://qudt.org/vocab/unit/M2-PER-M2")
    NanoGM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MicroL")
    BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN")
    A_HR_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-DeciM3")
    H_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/H-PER-KiloOHM")
    LB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT")
    DeciC = URIRef("http://qudt.org/vocab/unit/DeciC")
    MegaHZ_PER_T = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-T")
    GigaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-SEC")
    PERCENT_PER_MilliM = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MilliM")
    MilliM4 = URIRef("http://qudt.org/vocab/unit/MilliM4")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    DeciM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-DAY")
    OZ_VOL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-SEC")
    NanoGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M2-PA-SEC")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    PDL_FT = URIRef("http://qudt.org/vocab/unit/PDL-FT")
    PERCENT_PER_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MilliPA-SEC")
    MegaSEC = URIRef("http://qudt.org/vocab/unit/MegaSEC")
    M_PER_MIN = URIRef("http://qudt.org/vocab/unit/M-PER-MIN")
    MegaJ_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M3")
    BU_UK = URIRef("http://qudt.org/vocab/unit/BU_UK")
    KiloM = URIRef("http://qudt.org/vocab/unit/KiloM")
    PERCENT_PER_BAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-BAR")
    W_HR_PER_L = URIRef("http://qudt.org/vocab/unit/W-HR-PER-L")
    PERCENT_PER_DecaKiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaKiloCount")
    S_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/S-M2-PER-MOL")
    GM_MIN_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L-CentiM3")
    PERCENT_PER_M = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-M")
    TeraW = URIRef("http://qudt.org/vocab/unit/TeraW")
    GM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM")
    DecaC = URIRef("http://qudt.org/vocab/unit/DecaC")
    MegaBQ = URIRef("http://qudt.org/vocab/unit/MegaBQ")
    MicroM_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/MicroM-PER-L-DAY")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    KiloM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC")
    IN2 = URIRef("http://qudt.org/vocab/unit/IN2")
    FT_HR_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-GAL_UK")
    GigaBIT = URIRef("http://qudt.org/vocab/unit/GigaBIT")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    GAL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-HR")
    M2_HZ4 = URIRef("http://qudt.org/vocab/unit/M2-HZ4")
    BTU_IT_IN_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-SEC-FT2-DEG_F")
    PlanckCurrent = URIRef("http://qudt.org/vocab/unit/PlanckCurrent")
    M2_PER_SR = URIRef("http://qudt.org/vocab/unit/M2-PER-SR")
    PINT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-DAY")
    OZ_SEC_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-YD3")
    PetaV_A = URIRef("http://qudt.org/vocab/unit/PetaV-A")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    MOL_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-L-BAR")
    MegaC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M2")
    KiloL = URIRef("http://qudt.org/vocab/unit/KiloL")
    HectoBAR = URIRef("http://qudt.org/vocab/unit/HectoBAR")
    MilliARCSEC = URIRef("http://qudt.org/vocab/unit/MilliARCSEC")
    NanoM2 = URIRef("http://qudt.org/vocab/unit/NanoM2")
    DEG_F_HR_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_TH")
    DEG_R = URIRef("http://qudt.org/vocab/unit/DEG_R")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    MilliPA_PER_M = URIRef("http://qudt.org/vocab/unit/MilliPA-PER-M")
    FUR_Long = URIRef("http://qudt.org/vocab/unit/FUR_Long")
    KiloCAL_IT_PER_HR_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-HR-M-DEG_C")
    MilliM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    KiloGM_PER_J = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-J")
    IN_H2O_39dot2DEG_F = URIRef("http://qudt.org/vocab/unit/IN_H2O_39dot2DEG_F")
    M_PER_MIN = URIRef("http://qudt.org/vocab/unit/M-PER-MIN")
    M3_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-BAR")
    PicoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/PicoW-PER-M2")
    PERCENT_IN2_PER_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-IN2-PER-LB_F-SEC")
    CentiM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN")
    MilliH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-KiloOHM")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    DIOPTER = URIRef("http://qudt.org/vocab/unit/DIOPTER")
    PER_HR = URIRef("http://qudt.org/vocab/unit/PER-HR")
    NanoM_PER_MilliM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-MilliM-MegaPA")
    ERG_SEC = URIRef("http://qudt.org/vocab/unit/ERG-SEC")
    L_PER_MOL = URIRef("http://qudt.org/vocab/unit/L-PER-MOL")
    DecaM3 = URIRef("http://qudt.org/vocab/unit/DecaM3")
    MilliARCSEC = URIRef("http://qudt.org/vocab/unit/MilliARCSEC")
    BU_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-DAY")
    ARE = URIRef("http://qudt.org/vocab/unit/ARE")
    DAY_Sidereal = URIRef("http://qudt.org/vocab/unit/DAY_Sidereal")
    MOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3")
    PA_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M")
    THM_US_PER_HR = URIRef("http://qudt.org/vocab/unit/THM_US-PER-HR")
    MilliMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-KiloGM")
    AttoJ_SEC = URIRef("http://qudt.org/vocab/unit/AttoJ-SEC")
    REV_PER_HR = URIRef("http://qudt.org/vocab/unit/REV-PER-HR")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    C_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-M2-PER-KiloGM")
    K = URIRef("http://qudt.org/vocab/unit/K")
    LB_PER_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-HR")
    T = URIRef("http://qudt.org/vocab/unit/T")
    TONNE_PER_HA = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA")
    KiloGM_PER_GigaJ = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-GigaJ")
    MegaTON = URIRef("http://qudt.org/vocab/unit/MegaTON")
    YD3_PER_HR = URIRef("http://qudt.org/vocab/unit/YD3-PER-HR")
    KiloGM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    ERG_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM")
    GM_PER_M3 = URIRef("http://qudt.org/vocab/unit/GM-PER-M3")
    FemtoMOL = URIRef("http://qudt.org/vocab/unit/FemtoMOL")
    GigaC = URIRef("http://qudt.org/vocab/unit/GigaC")
    MilliWB = URIRef("http://qudt.org/vocab/unit/MilliWB")
    PER_DEG_C = URIRef("http://qudt.org/vocab/unit/PER-DEG_C")
    PER_M2 = URIRef("http://qudt.org/vocab/unit/PER-M2")
    KiloGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-BAR")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    KiloW_HR = URIRef("http://qudt.org/vocab/unit/KiloW-HR")
    MegaA = URIRef("http://qudt.org/vocab/unit/MegaA")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    MilliJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-SEC")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    BAR_PER_K = URIRef("http://qudt.org/vocab/unit/BAR-PER-K")
    MilliGM_PER_M3_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-MilliPA-SEC")
    MHO = URIRef("http://qudt.org/vocab/unit/MHO")
    MilliM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliM-PER-K")
    PDL_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-FT2")
    PFUND = URIRef("http://qudt.org/vocab/unit/PFUND")
    KiloCAL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-SEC")
    LB_PER_IN = URIRef("http://qudt.org/vocab/unit/LB-PER-IN")
    GM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloM")
    V_IN2_PER_LB_F = URIRef("http://qudt.org/vocab/unit/V-IN2-PER-LB_F")
    MilliM_HG = URIRef("http://qudt.org/vocab/unit/MilliM_HG")
    PERCENT_MIN_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-CentiM3")
    MilliJ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-GM")
    N_M_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-RAD")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    LB_PER_YD = URIRef("http://qudt.org/vocab/unit/LB-PER-YD")
    LB = URIRef("http://qudt.org/vocab/unit/LB")
    KiloCAL_Mean = URIRef("http://qudt.org/vocab/unit/KiloCAL_Mean")
    MilliM_PER_YR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-YR")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    MilliGM_MIN_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L-CentiM3")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    REV_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC2")
    GibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M")
    DYN_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-CentiM")
    MicroSV = URIRef("http://qudt.org/vocab/unit/MicroSV")
    EU_PER_L = URIRef("http://qudt.org/vocab/unit/EU-PER-L")
    MicroM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-M3")
    FemtoSEC = URIRef("http://qudt.org/vocab/unit/FemtoSEC")
    ENZ = URIRef("http://qudt.org/vocab/unit/ENZ")
    KiloV_A = URIRef("http://qudt.org/vocab/unit/KiloV-A")
    DeciB_W = URIRef("http://qudt.org/vocab/unit/DeciB-W")
    BTU_IT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_F")
    M2_PER_J = URIRef("http://qudt.org/vocab/unit/M2-PER-J")
    MicroM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM-PER-MilliL")
    RAD_PER_HR = URIRef("http://qudt.org/vocab/unit/RAD-PER-HR")
    TON_Metric_PER_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-BAR")
    PicoV = URIRef("http://qudt.org/vocab/unit/PicoV")
    GM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3")
    KiloGM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR")
    YD3_PER_HR = URIRef("http://qudt.org/vocab/unit/YD3-PER-HR")
    PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-PSI")
    MicroN = URIRef("http://qudt.org/vocab/unit/MicroN")
    Gamma = URIRef("http://qudt.org/vocab/unit/Gamma")
    KiloGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-K")
    BTU_TH_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_F")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    FT3_PER_PSI = URIRef("http://qudt.org/vocab/unit/FT3-PER-PSI")
    GM_PER_GM = URIRef("http://qudt.org/vocab/unit/GM-PER-GM")
    LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN")
    A_Ab_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-CentiM2")
    FemtoC = URIRef("http://qudt.org/vocab/unit/FemtoC")
    LB_PER_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-PSI")
    MilliW = URIRef("http://qudt.org/vocab/unit/MilliW")
    V_A_PER_K = URIRef("http://qudt.org/vocab/unit/V-A-PER-K")
    GM_PER_M3 = URIRef("http://qudt.org/vocab/unit/GM-PER-M3")
    BIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/BIT-PER-M3")
    GigaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-HR")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    LM_PER_M2 = URIRef("http://qudt.org/vocab/unit/LM-PER-M2")
    M2_PER_SEC2_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2-K")
    MilliGM_SEC_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L-CentiM3")
    OZ_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ-PER-DAY")
    SPIN_QUANTUM_NUMBER = URIRef("http://qudt.org/vocab/unit/SPIN_QUANTUM_NUMBER")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    M4 = URIRef("http://qudt.org/vocab/unit/M4")
    MegaGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-HA")
    TONNE_PER_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-K")
    ExaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/ExaBIT-PER-SEC")
    IN4 = URIRef("http://qudt.org/vocab/unit/IN4")
    CAL_TH_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2-SEC")
    LA = URIRef("http://qudt.org/vocab/unit/LA")
    PER_PERCENT = URIRef("http://qudt.org/vocab/unit/PER-PERCENT")
    KiloLB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-IN2")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    TON_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_US-PER-DAY")
    LB_M = URIRef("http://qudt.org/vocab/unit/LB_M")
    MicroMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MOL")
    MilliM_H2O = URIRef("http://qudt.org/vocab/unit/MilliM_H2O")
    LB_HR_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-YD3")
    PER_DEG_C = URIRef("http://qudt.org/vocab/unit/PER-DEG_C")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    MilliGM_HR_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L2")
    GI_UK = URIRef("http://qudt.org/vocab/unit/GI_UK")
    CentiL = URIRef("http://qudt.org/vocab/unit/CentiL")
    NUM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/NUM-PER-KiloM2")
    MilliGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-BAR")
    MilliL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-GM")
    M2_PER_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ2")
    NanoMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-M2-DAY")
    RAD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC2")
    KiloCAL_PER_MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL-DEG_C")
    MilliDEG_C = URIRef("http://qudt.org/vocab/unit/MilliDEG_C")
    M3_PER_DAY = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY")
    HA = URIRef("http://qudt.org/vocab/unit/HA")
    K_PER_HR = URIRef("http://qudt.org/vocab/unit/K-PER-HR")
    MilliL_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY")
    GRAIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL_US")
    CentiM_H2O = URIRef("http://qudt.org/vocab/unit/CentiM_H2O")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    POISE_PER_K = URIRef("http://qudt.org/vocab/unit/POISE-PER-K")
    GM_MIN_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M3-CentiM3")
    DEGREE_API = URIRef("http://qudt.org/vocab/unit/DEGREE_API")
    Gamma = URIRef("http://qudt.org/vocab/unit/Gamma")
    W_PER_M = URIRef("http://qudt.org/vocab/unit/W-PER-M")
    MilliC = URIRef("http://qudt.org/vocab/unit/MilliC")
    FT3_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN")
    PlanckTemperature = URIRef("http://qudt.org/vocab/unit/PlanckTemperature")
    YD2 = URIRef("http://qudt.org/vocab/unit/YD2")
    KiloN_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M")
    TeraC = URIRef("http://qudt.org/vocab/unit/TeraC")
    FT_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC2")
    W_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M2")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    W_PER_IN2 = URIRef("http://qudt.org/vocab/unit/W-PER-IN2")
    OZ_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN3")
    GM_PER_HR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR")
    PER_EV2 = URIRef("http://qudt.org/vocab/unit/PER-EV2")
    KiloTON_Metric = URIRef("http://qudt.org/vocab/unit/KiloTON_Metric")
    GM_PER_L = URIRef("http://qudt.org/vocab/unit/GM-PER-L")
    CentiM_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-BAR")
    HectoM = URIRef("http://qudt.org/vocab/unit/HectoM")
    DeciB_ISO = URIRef("http://qudt.org/vocab/unit/DeciB_ISO")
    AttoJ_SEC = URIRef("http://qudt.org/vocab/unit/AttoJ-SEC")
    MilliW = URIRef("http://qudt.org/vocab/unit/MilliW")
    KiloGM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM")
    FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-SEC-DEG_F")
    HP_Metric = URIRef("http://qudt.org/vocab/unit/HP_Metric")
    PER_T_SEC = URIRef("http://qudt.org/vocab/unit/PER-T-SEC")
    GM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2")
    GM_PER_M2 = URIRef("http://qudt.org/vocab/unit/GM-PER-M2")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    K_PER_K = URIRef("http://qudt.org/vocab/unit/K-PER-K")
    N_PER_CentiM = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM")
    CAL_TH_PER_G = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-G")
    MilliGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3")
    DYN = URIRef("http://qudt.org/vocab/unit/DYN")
    CentiM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC")
    MicroV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/MicroV-A_Reactive-PER-K")
    CentiM_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-BAR")
    M2_PER_M2 = URIRef("http://qudt.org/vocab/unit/M2-PER-M2")
    NanoS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/NanoS-PER-CentiM")
    MegaJ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-K")
    MegaGM = URIRef("http://qudt.org/vocab/unit/MegaGM")
    Flight = URIRef("http://qudt.org/vocab/unit/Flight")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    N_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M")
    HART = URIRef("http://qudt.org/vocab/unit/HART")
    MilliS = URIRef("http://qudt.org/vocab/unit/MilliS")
    OZ_HR_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-FT3")
    DEG2 = URIRef("http://qudt.org/vocab/unit/DEG2")
    PicoM = URIRef("http://qudt.org/vocab/unit/PicoM")
    PER_MO = URIRef("http://qudt.org/vocab/unit/PER-MO")
    V_PER_PA = URIRef("http://qudt.org/vocab/unit/V-PER-PA")
    HART = URIRef("http://qudt.org/vocab/unit/HART")
    MegaV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive")
    MicroGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M2-DAY")
    FT_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC2")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    MilliGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2")
    PERMEABILITY_EM_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_EM_REL")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    W_PER_FT2 = URIRef("http://qudt.org/vocab/unit/W-PER-FT2")
    DECADE = URIRef("http://qudt.org/vocab/unit/DECADE")
    KiloCAL_TH = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    DeciM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MIN")
    NanoGM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MicroL")
    YD3 = URIRef("http://qudt.org/vocab/unit/YD3")
    KiloGM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM-PER-SEC")
    GM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY-K")
    MicroSEC = URIRef("http://qudt.org/vocab/unit/MicroSEC")
    MilliGM_PER_M3_CentiPOISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-CentiPOISE")
    PA_PER_MIN = URIRef("http://qudt.org/vocab/unit/PA-PER-MIN")
    V_A_HR = URIRef("http://qudt.org/vocab/unit/V-A-HR")
    GigaA = URIRef("http://qudt.org/vocab/unit/GigaA")
    MicroL = URIRef("http://qudt.org/vocab/unit/MicroL")
    M2_PER_J = URIRef("http://qudt.org/vocab/unit/M2-PER-J")
    S = URIRef("http://qudt.org/vocab/unit/S")
    ATM_PER_M = URIRef("http://qudt.org/vocab/unit/ATM-PER-M")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    K = URIRef("http://qudt.org/vocab/unit/K")
    NanoBQ = URIRef("http://qudt.org/vocab/unit/NanoBQ")
    KiloTONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloTONNE-PER-YR")
    OZ_VOL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-MIN")
    HA = URIRef("http://qudt.org/vocab/unit/HA")
    N_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-RAD")
    PER_SEC_SR_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR-M2")
    ERG_PER_G = URIRef("http://qudt.org/vocab/unit/ERG-PER-G")
    TON_Metric = URIRef("http://qudt.org/vocab/unit/TON_Metric")
    MilliPA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-BAR")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    IU_PER_MilliL = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliL")
    NanoT = URIRef("http://qudt.org/vocab/unit/NanoT")
    CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3")
    LA = URIRef("http://qudt.org/vocab/unit/LA")
    FemtoJ = URIRef("http://qudt.org/vocab/unit/FemtoJ")
    K = URIRef("http://qudt.org/vocab/unit/K")
    V_PER_K = URIRef("http://qudt.org/vocab/unit/V-PER-K")
    LB_HR_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-FT3")
    MicroBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-KiloGM")
    OZ_HR_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-YD3")
    MicroGRAY = URIRef("http://qudt.org/vocab/unit/MicroGRAY")
    K_PER_W = URIRef("http://qudt.org/vocab/unit/K-PER-W")
    MilliGRAY = URIRef("http://qudt.org/vocab/unit/MilliGRAY")
    GM_Nitrogen_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Nitrogen-PER-M2-DAY")
    FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/FT2-PER-BTU_IT-IN")
    IN3_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN3-PER-MIN")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    CI_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CI-PER-KiloGM")
    BTU_IT_PER_LB_F_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_R")
    MHO = URIRef("http://qudt.org/vocab/unit/MHO")
    ERG_CentiM2 = URIRef("http://qudt.org/vocab/unit/ERG-CentiM2")
    GM_HR_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M6")
    PicoW_PER_CentiM2_L = URIRef("http://qudt.org/vocab/unit/PicoW-PER-CentiM2-L")
    Standard = URIRef("http://qudt.org/vocab/unit/Standard")
    MilliCi = URIRef("http://qudt.org/vocab/unit/MilliCi")
    PER_MOL = URIRef("http://qudt.org/vocab/unit/PER-MOL")
    W_SEC = URIRef("http://qudt.org/vocab/unit/W-SEC")
    BU_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-SEC")
    OHM_Stat = URIRef("http://qudt.org/vocab/unit/OHM_Stat")
    LB_T = URIRef("http://qudt.org/vocab/unit/LB_T")
    BTU_TH_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-FT2-HR-DEG_F")
    L_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-HR-BAR")
    CentiM3_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN-BAR")
    MegaV_PER_M = URIRef("http://qudt.org/vocab/unit/MegaV-PER-M")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    FRAME_PER_SEC = URIRef("http://qudt.org/vocab/unit/FRAME-PER-SEC")
    BU_UK = URIRef("http://qudt.org/vocab/unit/BU_UK")
    PicoPA = URIRef("http://qudt.org/vocab/unit/PicoPA")
    GM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN-K")
    SEC2 = URIRef("http://qudt.org/vocab/unit/SEC2")
    A_PER_A_HR = URIRef("http://qudt.org/vocab/unit/A-PER-A-HR")
    PlanckMass = URIRef("http://qudt.org/vocab/unit/PlanckMass")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    NanoGM = URIRef("http://qudt.org/vocab/unit/NanoGM")
    MicroC = URIRef("http://qudt.org/vocab/unit/MicroC")
    MicroM2 = URIRef("http://qudt.org/vocab/unit/MicroM2")
    CentiM_H2O_4DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_H2O_4DEG_C")
    KiloGM_PER_M_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC")
    MegaGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-M3")
    PicoMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L-HR")
    MilliM2 = URIRef("http://qudt.org/vocab/unit/MilliM2")
    MIN = URIRef("http://qudt.org/vocab/unit/MIN")
    FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC")
    TON_Metric_PER_SEC = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC")
    MicroIN = URIRef("http://qudt.org/vocab/unit/MicroIN")
    NAT_PER_SEC = URIRef("http://qudt.org/vocab/unit/NAT-PER-SEC")
    V_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/V-A_Reactive-HR")
    KiloGM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3")
    M_H2O = URIRef("http://qudt.org/vocab/unit/M_H2O")
    KibiBYTE = URIRef("http://qudt.org/vocab/unit/KibiBYTE")
    DEG_C_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-SEC")
    LB_HR_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-YD3")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    C_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM3")
    MilliMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-KiloGM")
    HZ_PER_V = URIRef("http://qudt.org/vocab/unit/HZ-PER-V")
    HART = URIRef("http://qudt.org/vocab/unit/HART")
    MilliA_PER_LB_F_IN2 = URIRef("http://qudt.org/vocab/unit/MilliA-PER-LB_F-IN2")
    PA_PER_HR = URIRef("http://qudt.org/vocab/unit/PA-PER-HR")
    MilliGRAY = URIRef("http://qudt.org/vocab/unit/MilliGRAY")
    N_PER_MilliM = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM")
    DRAM_US = URIRef("http://qudt.org/vocab/unit/DRAM_US")
    GALILEO = URIRef("http://qudt.org/vocab/unit/GALILEO")
    GAUSS = URIRef("http://qudt.org/vocab/unit/GAUSS")
    BQ_PER_M2 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M2")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    EUR_PER_KiloW_HR = URIRef("http://qudt.org/vocab/unit/EUR-PER-KiloW-HR")
    KiloW_HR = URIRef("http://qudt.org/vocab/unit/KiloW-HR")
    MilliGM_PER_M3_PA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-PA-SEC")
    K = URIRef("http://qudt.org/vocab/unit/K")
    GM_MilliM = URIRef("http://qudt.org/vocab/unit/GM-MilliM")
    TONNE_PER_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-BAR")
    MicroRAD = URIRef("http://qudt.org/vocab/unit/MicroRAD")
    MilliGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-HR")
    QT_US = URIRef("http://qudt.org/vocab/unit/QT_US")
    KiloGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM2")
    KiloN_M_PER_DEG_M = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-DEG-M")
    PER_MIN = URIRef("http://qudt.org/vocab/unit/PER-MIN")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    SLUG_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT-SEC")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    C_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    MilliL = URIRef("http://qudt.org/vocab/unit/MilliL")
    SEC2 = URIRef("http://qudt.org/vocab/unit/SEC2")
    HR_FT2 = URIRef("http://qudt.org/vocab/unit/HR-FT2")
    PER_MIN = URIRef("http://qudt.org/vocab/unit/PER-MIN")
    DeciBAR = URIRef("http://qudt.org/vocab/unit/DeciBAR")
    BTU_IT_PER_MOL_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB")
    M3_PER_HA = URIRef("http://qudt.org/vocab/unit/M3-PER-HA")
    L_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/L-PER-MicroMOL")
    KN = URIRef("http://qudt.org/vocab/unit/KN")
    OZ_TROY = URIRef("http://qudt.org/vocab/unit/OZ_TROY")
    IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN3-PER-SEC")
    HART_PER_SEC = URIRef("http://qudt.org/vocab/unit/HART-PER-SEC")
    L_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/L-PER-KiloGM")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    A = URIRef("http://qudt.org/vocab/unit/A")
    KiloN_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M")
    KiloBIT = URIRef("http://qudt.org/vocab/unit/KiloBIT")
    GM_SEC_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L-CentiM3")
    PA_PER_HR = URIRef("http://qudt.org/vocab/unit/PA-PER-HR")
    PicoH = URIRef("http://qudt.org/vocab/unit/PicoH")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    MilliM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-HR")
    CentiM3_PER_HR_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR-K")
    MOL_LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-MIN")
    KiloM3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM3-PER-SEC2")
    PER_MOL = URIRef("http://qudt.org/vocab/unit/PER-MOL")
    NUM_PER_CentiM_KiloYR = URIRef("http://qudt.org/vocab/unit/NUM-PER-CentiM-KiloYR")
    PER_MILLE_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PSI")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    SLUG_PER_DAY = URIRef("http://qudt.org/vocab/unit/SLUG-PER-DAY")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    TOE = URIRef("http://qudt.org/vocab/unit/TOE")
    KiloW_HR = URIRef("http://qudt.org/vocab/unit/KiloW-HR")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    MicroS = URIRef("http://qudt.org/vocab/unit/MicroS")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    FT_LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2")
    MilliGM_SEC_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L-CentiM3")
    BARN = URIRef("http://qudt.org/vocab/unit/BARN")
    AttoSEC = URIRef("http://qudt.org/vocab/unit/AttoSEC")
    LB_PER_FT = URIRef("http://qudt.org/vocab/unit/LB-PER-FT")
    PCA = URIRef("http://qudt.org/vocab/unit/PCA")
    THERM_US = URIRef("http://qudt.org/vocab/unit/THERM_US")
    MilliDARCY = URIRef("http://qudt.org/vocab/unit/MilliDARCY")
    MegaV = URIRef("http://qudt.org/vocab/unit/MegaV")
    DeciB_Z = URIRef("http://qudt.org/vocab/unit/DeciB_Z")
    L_PER_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-SEC")
    KiloGM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MilliM")
    TeraBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/TeraBIT-PER-SEC")
    MOL_LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-MIN")
    GT = URIRef("http://qudt.org/vocab/unit/GT")
    MicroGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-GM")
    PA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-L-PER-SEC")
    MilliGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-KiloGM")
    TON = URIRef("http://qudt.org/vocab/unit/TON")
    YR_TROPICAL = URIRef("http://qudt.org/vocab/unit/YR_TROPICAL")
    MicroFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-M")
    MilliCi = URIRef("http://qudt.org/vocab/unit/MilliCi")
    BTU_IT_PER_MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB-DEG_F")
    M3_PER_K = URIRef("http://qudt.org/vocab/unit/M3-PER-K")
    MI_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI-PER-MIN")
    MilliJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-M2")
    DEATHS_PER_1000000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000000I-YR")
    MilliGM_SEC_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L-CentiM3")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    MOL_PER_L = URIRef("http://qudt.org/vocab/unit/MOL-PER-L")
    GM_PER_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY")
    L_PER_MOL = URIRef("http://qudt.org/vocab/unit/L-PER-MOL")
    CentiM = URIRef("http://qudt.org/vocab/unit/CentiM")
    M2_PER_M2 = URIRef("http://qudt.org/vocab/unit/M2-PER-M2")
    L_PER_L = URIRef("http://qudt.org/vocab/unit/L-PER-L")
    LB_PER_FT3 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3")
    CentiM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL")
    KiloC_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M2")
    KibiBYTE = URIRef("http://qudt.org/vocab/unit/KibiBYTE")
    GR = URIRef("http://qudt.org/vocab/unit/GR")
    MilliGM_PER_M3_PA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-PA-SEC")
    BBL_US_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-HR")
    FT_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC-PSI")
    PlanckVolume = URIRef("http://qudt.org/vocab/unit/PlanckVolume")
    PPT = URIRef("http://qudt.org/vocab/unit/PPT")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    GI_US = URIRef("http://qudt.org/vocab/unit/GI_US")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    IN2_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN2-PER-SEC")
    PERCENT_PER_K = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-K")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    OZ_VOL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-DAY")
    BU_UK = URIRef("http://qudt.org/vocab/unit/BU_UK")
    ATM_T = URIRef("http://qudt.org/vocab/unit/ATM_T")
    DeciGM = URIRef("http://qudt.org/vocab/unit/DeciGM")
    PFUND = URIRef("http://qudt.org/vocab/unit/PFUND")
    OZ_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_US")
    LB_SEC_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-YD3")
    MilliR = URIRef("http://qudt.org/vocab/unit/MilliR")
    N_M_PER_DEG_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG-M")
    GAL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-DAY")
    LB_SEC_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-IN3")
    Gs = URIRef("http://qudt.org/vocab/unit/Gs")
    MilliBAR = URIRef("http://qudt.org/vocab/unit/MilliBAR")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    FT3 = URIRef("http://qudt.org/vocab/unit/FT3")
    MegaJ_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M3")
    GM_HR_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L2")
    MilliBAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-M3-PER-SEC")
    YD3_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD3-PER-MIN")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    FemtoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-KiloGM")
    M3_PER_DAY = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    C_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM")
    V_M = URIRef("http://qudt.org/vocab/unit/V-M")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    GM_PER_MIN = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN")
    ERG_PER_CentiM = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM")
    GRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/GRAY-PER-SEC")
    CentiM = URIRef("http://qudt.org/vocab/unit/CentiM")
    HP_Boiler = URIRef("http://qudt.org/vocab/unit/HP_Boiler")
    L_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-BAR")
    DeciN = URIRef("http://qudt.org/vocab/unit/DeciN")
    KiloGM_PER_KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloMOL")
    BAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-L-PER-SEC")
    NUM_PER_HR = URIRef("http://qudt.org/vocab/unit/NUM-PER-HR")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    MilliM_PER_YR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-YR")
    FARAD_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/FARAD_Ab-PER-CentiM")
    FT_LB_F = URIRef("http://qudt.org/vocab/unit/FT-LB_F")
    TON_Metric_PER_HR_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR-K")
    M2_HZ4 = URIRef("http://qudt.org/vocab/unit/M2-HZ4")
    BBL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-DAY")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    GM_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM2")
    MegaW_HR = URIRef("http://qudt.org/vocab/unit/MegaW-HR")
    OZ_FT = URIRef("http://qudt.org/vocab/unit/OZ-FT")
    MicroM3 = URIRef("http://qudt.org/vocab/unit/MicroM3")
    OCTET_PER_SEC = URIRef("http://qudt.org/vocab/unit/OCTET-PER-SEC")
    TON = URIRef("http://qudt.org/vocab/unit/TON")
    MilliH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-OHM")
    DEG_C_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-K")
    LB_HR_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US2")
    LB_HR_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US2")
    DARCY = URIRef("http://qudt.org/vocab/unit/DARCY")
    GRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/GRAY-PER-HR")
    LB_SEC_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-YD3")
    PA_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M")
    C_Stat = URIRef("http://qudt.org/vocab/unit/C_Stat")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    C_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM3")
    IN_HG = URIRef("http://qudt.org/vocab/unit/IN_HG")
    PINT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-HR")
    KiloGM_PER_M2_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC2")
    J_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-GM-DEG_C")
    PERMEABILITY_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_REL")
    BTU_IT_IN_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-HR-FT2-DEG_F")
    J_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2")
    MegaPSI = URIRef("http://qudt.org/vocab/unit/MegaPSI")
    KiloV_A = URIRef("http://qudt.org/vocab/unit/KiloV-A")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    CAL_TH_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2-SEC")
    KiloS_PER_M = URIRef("http://qudt.org/vocab/unit/KiloS-PER-M")
    OZ_SEC_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-GAL_US")
    TON_FG = URIRef("http://qudt.org/vocab/unit/TON_FG")
    PERCENT_MIN_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-L")
    CAL_IT_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM-K")
    KiloA_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M2")
    KiloGM_PER_CentiM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-BAR")
    NanoN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/NanoN-M-PER-M2")
    J_PER_MIN = URIRef("http://qudt.org/vocab/unit/J-PER-MIN")
    KiloL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloL-PER-HR")
    GM_PER_M = URIRef("http://qudt.org/vocab/unit/GM-PER-M")
    DEG_F_HR_FT2_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH")
    SLUG_PER_FT3 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT3")
    PA2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA2-PER-SEC2")
    C_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Ab-PER-CentiM2")
    LB_SEC_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-FT3")
    GM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY-BAR")
    FT_US = URIRef("http://qudt.org/vocab/unit/FT_US")
    A_Ab = URIRef("http://qudt.org/vocab/unit/A_Ab")
    DeciB_ISO = URIRef("http://qudt.org/vocab/unit/DeciB_ISO")
    KiloTONNE = URIRef("http://qudt.org/vocab/unit/KiloTONNE")
    BTU_IT_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC-DEG_F")
    BBL_US_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-SEC")
    BAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/BAR-PER-BAR")
    CentiC = URIRef("http://qudt.org/vocab/unit/CentiC")
    OZ_MIN_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN6")
    MicroSV = URIRef("http://qudt.org/vocab/unit/MicroSV")
    MOL_PER_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-HR")
    RAD_PER_MIN = URIRef("http://qudt.org/vocab/unit/RAD-PER-MIN")
    YoctoC = URIRef("http://qudt.org/vocab/unit/YoctoC")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    MIL_Circ = URIRef("http://qudt.org/vocab/unit/MIL_Circ")
    KAT_PER_MicroL = URIRef("http://qudt.org/vocab/unit/KAT-PER-MicroL")
    C_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Ab-PER-CentiM2")
    BTU_IT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR-DEG_F")
    M = URIRef("http://qudt.org/vocab/unit/M")
    N_PER_CentiM = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    AC_FT = URIRef("http://qudt.org/vocab/unit/AC-FT")
    ElementaryCharge = URIRef("http://qudt.org/vocab/unit/ElementaryCharge")
    GM_PER_HR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR")
    LB_PER_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-DAY")
    FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC")
    KiloMOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-MIN")
    MilliWB = URIRef("http://qudt.org/vocab/unit/MilliWB")
    PERCENT_HR_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-IN3")
    MegaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-SEC")
    KiloGM_PER_M2_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC2")
    MilliN_M = URIRef("http://qudt.org/vocab/unit/MilliN-M")
    V_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-PER-CentiM")
    G = URIRef("http://qudt.org/vocab/unit/G")
    MegaOHM = URIRef("http://qudt.org/vocab/unit/MegaOHM")
    MOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2")
    TeraHZ = URIRef("http://qudt.org/vocab/unit/TeraHZ")
    M_PER_MIN = URIRef("http://qudt.org/vocab/unit/M-PER-MIN")
    TON_Register = URIRef("http://qudt.org/vocab/unit/TON_Register")
    W_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-PER-M3")
    KiloGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-K")
    IN2 = URIRef("http://qudt.org/vocab/unit/IN2")
    MilliW_PER_CentiM2_MicroM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-CentiM2-MicroM-SR")
    TON_Register = URIRef("http://qudt.org/vocab/unit/TON_Register")
    OZ_FT = URIRef("http://qudt.org/vocab/unit/OZ-FT")
    TONNE_PER_DAY = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY")
    MilliG = URIRef("http://qudt.org/vocab/unit/MilliG")
    MicroT = URIRef("http://qudt.org/vocab/unit/MicroT")
    N_M_PER_M_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-M-RAD")
    A_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Stat-PER-CentiM2")
    PER_PERCENT = URIRef("http://qudt.org/vocab/unit/PER-PERCENT")
    BU_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-MIN")
    BTU_IT_PER_LB_MOL = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-MOL")
    BAN = URIRef("http://qudt.org/vocab/unit/BAN")
    REM = URIRef("http://qudt.org/vocab/unit/REM")
    OZ_VOL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-MIN")
    MilliGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-BAR")
    OZ_TROY = URIRef("http://qudt.org/vocab/unit/OZ_TROY")
    AC_FT_US = URIRef("http://qudt.org/vocab/unit/AC-FT_US")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    BTU_TH_PER_FT2_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-MIN")
    NUM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NUM-PER-MicroL")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    KiloGM_PER_L = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    A = URIRef("http://qudt.org/vocab/unit/A")
    MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/MOL_LB-DEG_F")
    KiloCAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-MIN")
    FT = URIRef("http://qudt.org/vocab/unit/FT")
    TON_FG = URIRef("http://qudt.org/vocab/unit/TON_FG")
    DEG_PER_M = URIRef("http://qudt.org/vocab/unit/DEG-PER-M")
    GI = URIRef("http://qudt.org/vocab/unit/GI")
    B = URIRef("http://qudt.org/vocab/unit/B")
    LB_F_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN")
    GigaHZ = URIRef("http://qudt.org/vocab/unit/GigaHZ")
    KiloFARAD = URIRef("http://qudt.org/vocab/unit/KiloFARAD")
    TON_Metric_PER_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-K")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    OZ_F = URIRef("http://qudt.org/vocab/unit/OZ_F")
    IN_HG_32DEG_F = URIRef("http://qudt.org/vocab/unit/IN_HG_32DEG_F")
    PER_CentiM = URIRef("http://qudt.org/vocab/unit/PER-CentiM")
    K_PER_MIN = URIRef("http://qudt.org/vocab/unit/K-PER-MIN")
    BTU_IT_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT-PER-FT2-HR-DEG_F")
    V_PER_M2 = URIRef("http://qudt.org/vocab/unit/V-PER-M2")
    GM_MIN_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M3-L")
    PetaHZ = URIRef("http://qudt.org/vocab/unit/PetaHZ")
    PER_MOL = URIRef("http://qudt.org/vocab/unit/PER-MOL")
    GM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3")
    LA = URIRef("http://qudt.org/vocab/unit/LA")
    DeciL = URIRef("http://qudt.org/vocab/unit/DeciL")
    GI_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_US-PER-HR")
    PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/PER-M2-SEC")
    GM_HR_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M3-L")
    KiloGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM2")
    HectoL = URIRef("http://qudt.org/vocab/unit/HectoL")
    GM_PER_L = URIRef("http://qudt.org/vocab/unit/GM-PER-L")
    CentiL = URIRef("http://qudt.org/vocab/unit/CentiL")
    BTU_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC")
    PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2")
    ERG_SEC = URIRef("http://qudt.org/vocab/unit/ERG-SEC")
    IN_HG_60DEG_F = URIRef("http://qudt.org/vocab/unit/IN_HG_60DEG_F")
    KiloGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-K")
    BU_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-MIN")
    L_PER_DAY = URIRef("http://qudt.org/vocab/unit/L-PER-DAY")
    V_IN2_PER_LB_F = URIRef("http://qudt.org/vocab/unit/V-IN2-PER-LB_F")
    KiloA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloA-PER-K")
    CUP = URIRef("http://qudt.org/vocab/unit/CUP")
    KiloGM_F_M = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M")
    A_PER_K = URIRef("http://qudt.org/vocab/unit/A-PER-K")
    KiloGM_PER_M_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC2")
    MilliS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MilliS-PER-CentiM")
    MI_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI-PER-MIN")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    MicroM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-M3")
    DEG_C_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-MIN")
    HZ_M = URIRef("http://qudt.org/vocab/unit/HZ-M")
    KiloCAL_PER_MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL-DEG_C")
    CentiM2_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-CentiM3")
    MOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2")
    MilliGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-BAR")
    LB_MIN_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-FT3")
    KiloP = URIRef("http://qudt.org/vocab/unit/KiloP")
    GM_PER_M3 = URIRef("http://qudt.org/vocab/unit/GM-PER-M3")
    QT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-SEC")
    W_PER_M = URIRef("http://qudt.org/vocab/unit/W-PER-M")
    PlanckFrequency_Ang = URIRef("http://qudt.org/vocab/unit/PlanckFrequency_Ang")
    MicroM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-M3")
    BARAD = URIRef("http://qudt.org/vocab/unit/BARAD")
    KiloGM_PER_M_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC")
    GM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC-BAR")
    M3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM")
    N_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-PER-RAD")
    DIOPTER = URIRef("http://qudt.org/vocab/unit/DIOPTER")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    MilliGM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-K")
    K_PER_MIN = URIRef("http://qudt.org/vocab/unit/K-PER-MIN")
    KiloBQ = URIRef("http://qudt.org/vocab/unit/KiloBQ")
    MilliH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-KiloOHM")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    MicroGM_PER_IN2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-IN2")
    FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/FT2-PER-BTU_IT-IN")
    FemtoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-KiloGM")
    KiloCAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-SEC")
    ATM_M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/ATM-M3-PER-MOL")
    GRAIN = URIRef("http://qudt.org/vocab/unit/GRAIN")
    GigaBasePair = URIRef("http://qudt.org/vocab/unit/GigaBasePair")
    POISE_PER_PA = URIRef("http://qudt.org/vocab/unit/POISE-PER-PA")
    V2_PER_K2 = URIRef("http://qudt.org/vocab/unit/V2-PER-K2")
    IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC")
    HectoM = URIRef("http://qudt.org/vocab/unit/HectoM")
    CentiC = URIRef("http://qudt.org/vocab/unit/CentiC")
    MOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-SEC")
    KiloTON_Metric = URIRef("http://qudt.org/vocab/unit/KiloTON_Metric")
    MegaC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M2")
    YR_Sidereal = URIRef("http://qudt.org/vocab/unit/YR_Sidereal")
    YD3_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD3-PER-MIN")
    DEG_C_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-SEC")
    BTU_IT_PER_SEC_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_R")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    IN_PER_PSI = URIRef("http://qudt.org/vocab/unit/IN-PER-PSI")
    N_PER_CentiM = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM")
    KiloC = URIRef("http://qudt.org/vocab/unit/KiloC")
    S_Ab = URIRef("http://qudt.org/vocab/unit/S_Ab")
    LB_HR_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US2")
    AMU = URIRef("http://qudt.org/vocab/unit/AMU")
    GM_F = URIRef("http://qudt.org/vocab/unit/GM_F")
    HectoPA = URIRef("http://qudt.org/vocab/unit/HectoPA")
    KiloPA_A = URIRef("http://qudt.org/vocab/unit/KiloPA_A")
    PK_UK = URIRef("http://qudt.org/vocab/unit/PK_UK")
    IN_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-DEG_F")
    DEG_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG-PER-HR")
    NanoA_PER_K = URIRef("http://qudt.org/vocab/unit/NanoA-PER-K")
    LM_SEC = URIRef("http://qudt.org/vocab/unit/LM-SEC")
    TON_Metric_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY")
    KiloPA_A = URIRef("http://qudt.org/vocab/unit/KiloPA_A")
    TON_FG_HR = URIRef("http://qudt.org/vocab/unit/TON_FG-HR")
    Hundredweight_US = URIRef("http://qudt.org/vocab/unit/Hundredweight_US")
    A_SEC2 = URIRef("http://qudt.org/vocab/unit/A-SEC2")
    LM_PER_W = URIRef("http://qudt.org/vocab/unit/LM-PER-W")
    NanoL = URIRef("http://qudt.org/vocab/unit/NanoL")
    LB_PER_FT3 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3")
    V_PER_K = URIRef("http://qudt.org/vocab/unit/V-PER-K")
    REV_PER_HR = URIRef("http://qudt.org/vocab/unit/REV-PER-HR")
    PPT = URIRef("http://qudt.org/vocab/unit/PPT")
    GigaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-PER-M")
    W_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-PER-M3")
    KiloGM_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-M2")
    BTU_IT_FT = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT")
    KiloPA_M2_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloPA-M2-PER-GM")
    A_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-PER-CentiM2")
    KiloCAL_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2")
    Gs = URIRef("http://qudt.org/vocab/unit/Gs")
    LB_IN2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-IN3-LB_F-SEC")
    PER_RAD = URIRef("http://qudt.org/vocab/unit/PER-RAD")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    KiloW = URIRef("http://qudt.org/vocab/unit/KiloW")
    KiloM = URIRef("http://qudt.org/vocab/unit/KiloM")
    GM_PER_MilliM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM-BAR")
    QT_US = URIRef("http://qudt.org/vocab/unit/QT_US")
    MegaEV_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-CentiM")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    PER_J2 = URIRef("http://qudt.org/vocab/unit/PER-J2")
    IN3_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN3-PER-MIN")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    C_Ab = URIRef("http://qudt.org/vocab/unit/C_Ab")
    ERG_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM3")
    ARCMIN = URIRef("http://qudt.org/vocab/unit/ARCMIN")
    MIL_Circ = URIRef("http://qudt.org/vocab/unit/MIL_Circ")
    DYN_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM2")
    DEG_R_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-MIN")
    EUR_PER_KiloW = URIRef("http://qudt.org/vocab/unit/EUR-PER-KiloW")
    failures_in_time = URIRef("http://qudt.org/vocab/unit/failures-in-time")
    KiloM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC")
    KiloGM_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-M2")
    MI = URIRef("http://qudt.org/vocab/unit/MI")
    MilliGM_HR_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M3-CentiM3")
    FT3 = URIRef("http://qudt.org/vocab/unit/FT3")
    MicroBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-KiloGM")
    PER_KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/PER-KiloV-A-HR")
    KiloA_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M2")
    DeciM = URIRef("http://qudt.org/vocab/unit/DeciM")
    M2_PER_M2 = URIRef("http://qudt.org/vocab/unit/M2-PER-M2")
    PER_MIN = URIRef("http://qudt.org/vocab/unit/PER-MIN")
    TON_Metric_PER_HR_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR-K")
    MilliL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliL-PER-L")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    PERCENT_SEC_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-IN3")
    NUM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NUM-PER-MicroL")
    HP_H2O = URIRef("http://qudt.org/vocab/unit/HP_H2O")
    CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CentiM2-MIN")
    N_PER_CentiM = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM")
    TON_Metric_PER_M3_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3-K")
    MilliA = URIRef("http://qudt.org/vocab/unit/MilliA")
    C_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM")
    LB_MIN_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-GAL_UK")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    MilliGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-BAR")
    TON_Metric_PER_HR_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR-K")
    KiloGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-K")
    PER_M_NanoM = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM")
    A_HR_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-DeciM3")
    KiloCAL_Mean = URIRef("http://qudt.org/vocab/unit/KiloCAL_Mean")
    M3_PER_C = URIRef("http://qudt.org/vocab/unit/M3-PER-C")
    NanoGM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MicroL")
    LB_F_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-SEC")
    SUSCEPTIBILITY_ELEC = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_ELEC")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT2")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    GM_PER_MOL = URIRef("http://qudt.org/vocab/unit/GM-PER-MOL")
    IN2 = URIRef("http://qudt.org/vocab/unit/IN2")
    PDL = URIRef("http://qudt.org/vocab/unit/PDL")
    MilliGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2")
    PER_BAR = URIRef("http://qudt.org/vocab/unit/PER-BAR")
    PINT_US = URIRef("http://qudt.org/vocab/unit/PINT_US")
    DEG_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC")
    MicroRAD = URIRef("http://qudt.org/vocab/unit/MicroRAD")
    GAL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-MIN")
    LB_MIN_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-YD3")
    M3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-BAR")
    M_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-BAR")
    DeciC = URIRef("http://qudt.org/vocab/unit/DeciC")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    SLUG_PER_HR = URIRef("http://qudt.org/vocab/unit/SLUG-PER-HR")
    KiloPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-BAR")
    NTU = URIRef("http://qudt.org/vocab/unit/NTU")
    KiloCAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-GM-K")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    MegaGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-M3")
    HZ_PER_V = URIRef("http://qudt.org/vocab/unit/HZ-PER-V")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    MI_PER_HR = URIRef("http://qudt.org/vocab/unit/MI-PER-HR")
    ExaW = URIRef("http://qudt.org/vocab/unit/ExaW")
    BTU_IT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MIN")
    J_PER_HR = URIRef("http://qudt.org/vocab/unit/J-PER-HR")
    PARSEC = URIRef("http://qudt.org/vocab/unit/PARSEC")
    M2_PER_SR_J = URIRef("http://qudt.org/vocab/unit/M2-PER-SR-J")
    MilliL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliL-PER-L")
    KiloMIL_Circ = URIRef("http://qudt.org/vocab/unit/KiloMIL_Circ")
    DEG_F_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-HR")
    HectoPA_PER_M = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-M")
    KiloGM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM2-PER-SEC2")
    MilliGM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M")
    PicoMOL_PER_M_W_SEC = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M-W-SEC")
    CORD = URIRef("http://qudt.org/vocab/unit/CORD")
    UnitPole = URIRef("http://qudt.org/vocab/unit/UnitPole")
    KiloGM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC2")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    AttoSEC = URIRef("http://qudt.org/vocab/unit/AttoSEC")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    C_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM3")
    MicroGM_PER_CentiM2_WK = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2-WK")
    DEG_F_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC2")
    LB_DEG_R = URIRef("http://qudt.org/vocab/unit/LB-DEG_R")
    MilliL_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR")
    BTU_TH_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-SEC")
    LB_SEC_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-GAL_UK")
    BAN = URIRef("http://qudt.org/vocab/unit/BAN")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    STILB = URIRef("http://qudt.org/vocab/unit/STILB")
    TONNE_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN-K")
    C_M2_PER_V = URIRef("http://qudt.org/vocab/unit/C-M2-PER-V")
    MO_Synodic = URIRef("http://qudt.org/vocab/unit/MO_Synodic")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    PER_SEC_M3 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M3")
    MilliJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-M2")
    PER_L = URIRef("http://qudt.org/vocab/unit/PER-L")
    C_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM2")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    HART_PER_SEC = URIRef("http://qudt.org/vocab/unit/HART-PER-SEC")
    GM_HR_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L2")
    YD_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD-PER-SEC")
    QT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_US-PER-HR")
    GAUSS = URIRef("http://qudt.org/vocab/unit/GAUSS")
    KiloJ_PER_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-K")
    PDL_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-FT2")
    M2_HZ4 = URIRef("http://qudt.org/vocab/unit/M2-HZ4")
    KiloBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-HR")
    BTU_IT_PER_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL-DEG_F")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    MegaPA_PER_K = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-K")
    M2_HZ4 = URIRef("http://qudt.org/vocab/unit/M2-HZ4")
    PER_MO = URIRef("http://qudt.org/vocab/unit/PER-MO")
    KiloGM_F_M = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M")
    MOL_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB")
    GM_PER_MilliL_K = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL-K")
    MilliL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M3")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    NanoA_PER_K = URIRef("http://qudt.org/vocab/unit/NanoA-PER-K")
    TON_Assay = URIRef("http://qudt.org/vocab/unit/TON_Assay")
    BTU_IT_PER_MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB-DEG_F")
    W = URIRef("http://qudt.org/vocab/unit/W")
    MI_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI-PER-MIN")
    MebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M2")
    GM_PER_CentiM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM-BAR")
    CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-GM")
    PlanckTemperature = URIRef("http://qudt.org/vocab/unit/PlanckTemperature")
    KAT_PER_L = URIRef("http://qudt.org/vocab/unit/KAT-PER-L")
    W_PER_GM = URIRef("http://qudt.org/vocab/unit/W-PER-GM")
    OZ_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ-PER-MIN")
    SolarMass = URIRef("http://qudt.org/vocab/unit/SolarMass")
    W_HR_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-HR-PER-KiloGM")
    ST_PER_K = URIRef("http://qudt.org/vocab/unit/ST-PER-K")
    MicroS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MicroS-PER-CentiM")
    MilliV_PER_M = URIRef("http://qudt.org/vocab/unit/MilliV-PER-M")
    GigaW_HR = URIRef("http://qudt.org/vocab/unit/GigaW-HR")
    MI_PER_SEC = URIRef("http://qudt.org/vocab/unit/MI-PER-SEC")
    GI_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-SEC")
    MicroGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-DeciL")
    KiloPA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-MilliM")
    MOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3")
    OZ_F_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ_F-PER-IN3")
    GAUSS = URIRef("http://qudt.org/vocab/unit/GAUSS")
    KiloTON_Metric = URIRef("http://qudt.org/vocab/unit/KiloTON_Metric")
    V_PER_MilliM = URIRef("http://qudt.org/vocab/unit/V-PER-MilliM")
    PERCENT_PER_MilliM = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MilliM")
    CentiN = URIRef("http://qudt.org/vocab/unit/CentiN")
    CASES_PER_KiloINDIV_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-KiloINDIV-YR")
    TON_UK_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-YD3")
    HA = URIRef("http://qudt.org/vocab/unit/HA")
    T = URIRef("http://qudt.org/vocab/unit/T")
    MicroGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M2-DAY")
    J_PER_T2 = URIRef("http://qudt.org/vocab/unit/J-PER-T2")
    CAL_TH_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM-K")
    J_PER_MOL_K = URIRef("http://qudt.org/vocab/unit/J-PER-MOL-K")
    GigaC = URIRef("http://qudt.org/vocab/unit/GigaC")
    KiloJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM")
    T = URIRef("http://qudt.org/vocab/unit/T")
    GAL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-HR")
    CORD = URIRef("http://qudt.org/vocab/unit/CORD")
    V_PER_K = URIRef("http://qudt.org/vocab/unit/V-PER-K")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    W_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-SEC-PER-M2")
    J_PER_GM_K = URIRef("http://qudt.org/vocab/unit/J-PER-GM-K")
    PER_HR = URIRef("http://qudt.org/vocab/unit/PER-HR")
    HectoPA = URIRef("http://qudt.org/vocab/unit/HectoPA")
    MilliL = URIRef("http://qudt.org/vocab/unit/MilliL")
    MilliPA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-BAR")
    MOL_PER_M2_SEC_M_SR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-M-SR")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    NanoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L")
    CentiM3_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN-BAR")
    KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloM2")
    MilliMOL = URIRef("http://qudt.org/vocab/unit/MilliMOL")
    N_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG")
    NanoSV_PER_HR = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-HR")
    OHM_Ab = URIRef("http://qudt.org/vocab/unit/OHM_Ab")
    BU_UK = URIRef("http://qudt.org/vocab/unit/BU_UK")
    DeciM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-SEC")
    KiloGM_PER_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-K")
    PER_LB = URIRef("http://qudt.org/vocab/unit/PER-LB")
    FT2_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT2-PER-SEC")
    KiloBD = URIRef("http://qudt.org/vocab/unit/KiloBD")
    TONNE = URIRef("http://qudt.org/vocab/unit/TONNE")
    KiloGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-PA-SEC")
    CentiM3_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-K")
    MicroM = URIRef("http://qudt.org/vocab/unit/MicroM")
    DeciM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-KiloGM")
    MegaPA = URIRef("http://qudt.org/vocab/unit/MegaPA")
    DECADE = URIRef("http://qudt.org/vocab/unit/DECADE")
    OZ_SEC_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-YD3")
    PER_PA_SEC = URIRef("http://qudt.org/vocab/unit/PER-PA-SEC")
    MilliGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-HR")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    KiloJ_PER_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-K")
    DeciB_M = URIRef("http://qudt.org/vocab/unit/DeciB_M")
    MicroH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-OHM")
    LB_IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN-PER-SEC")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-DEG_F")
    MegaJ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-K")
    MilliC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M2")
    OZ_FT = URIRef("http://qudt.org/vocab/unit/OZ-FT")
    PPB = URIRef("http://qudt.org/vocab/unit/PPB")
    V = URIRef("http://qudt.org/vocab/unit/V")
    BTU_TH_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2")
    Flight = URIRef("http://qudt.org/vocab/unit/Flight")
    YR_Common = URIRef("http://qudt.org/vocab/unit/YR_Common")
    OZ_PER_FT2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-FT2")
    PER_KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/PER-KiloV-A-HR")
    N_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-M-PER-M2")
    TeraBQ = URIRef("http://qudt.org/vocab/unit/TeraBQ")
    KiloGM_F_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-MilliM2")
    BTU_TH_PER_FT2_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-HR")
    KiloJ_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MOL")
    CentiM3_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN-K")
    FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-SEC")
    TeraHZ = URIRef("http://qudt.org/vocab/unit/TeraHZ")
    LB_F_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-FT2")
    A = URIRef("http://qudt.org/vocab/unit/A")
    MilliGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-K")
    LB_HR_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK2")
    M2_PER_K = URIRef("http://qudt.org/vocab/unit/M2-PER-K")
    KiloGM_PER_J = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-J")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    GI_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_US-PER-DAY")
    C_M2_PER_V = URIRef("http://qudt.org/vocab/unit/C-M2-PER-V")
    OZ_MIN_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-GAL_US")
    BTU_60DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_60DEG_F")
    PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PER-M3-SEC")
    N_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM2")
    N_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG")
    BARN_PER_SR_EV = URIRef("http://qudt.org/vocab/unit/BARN-PER-SR-EV")
    MDOLLAR_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MDOLLAR-PER-FLIGHT")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    NanoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/NanoFARAD-PER-M")
    LB_PER_FT3 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3")
    MegaV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive")
    ERG_CentiM2 = URIRef("http://qudt.org/vocab/unit/ERG-CentiM2")
    LB_T = URIRef("http://qudt.org/vocab/unit/LB_T")
    M2_PER_HA = URIRef("http://qudt.org/vocab/unit/M2-PER-HA")
    L_PER_HR_K = URIRef("http://qudt.org/vocab/unit/L-PER-HR-K")
    MilliGM_PER_L = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L")
    MicroJ = URIRef("http://qudt.org/vocab/unit/MicroJ")
    NanoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-KiloGM")
    BTU_IT = URIRef("http://qudt.org/vocab/unit/BTU_IT")
    DeciN = URIRef("http://qudt.org/vocab/unit/DeciN")
    HZ_PER_V = URIRef("http://qudt.org/vocab/unit/HZ-PER-V")
    GM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciL")
    MegaV_A_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A-HR")
    GM_PER_CentiM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM-BAR")
    TONNE_PER_HA = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA")
    CentiM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY")
    KiloGM_M = URIRef("http://qudt.org/vocab/unit/KiloGM-M")
    BTU_39DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_39DEG_F")
    LB_SEC_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-FT3")
    CAL_TH_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM-K")
    MegaEV_FemtoM = URIRef("http://qudt.org/vocab/unit/MegaEV-FemtoM")
    DeciSEC = URIRef("http://qudt.org/vocab/unit/DeciSEC")
    PER_YD3 = URIRef("http://qudt.org/vocab/unit/PER-YD3")
    MilliGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-GM")
    BTU_TH_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-HR-DEG_F")
    MilliL_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR")
    C_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM3")
    K_PER_HR = URIRef("http://qudt.org/vocab/unit/K-PER-HR")
    DRAM_US = URIRef("http://qudt.org/vocab/unit/DRAM_US")
    MicroH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-OHM")
    N_M_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-M")
    N_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M3")
    LB_SEC_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-GAL_US")
    MicroH = URIRef("http://qudt.org/vocab/unit/MicroH")
    PERM_Metric = URIRef("http://qudt.org/vocab/unit/PERM_Metric")
    DeciM3 = URIRef("http://qudt.org/vocab/unit/DeciM3")
    BQ_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-SEC-PER-M3")
    PINT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-MIN")
    KiloGM_PER_J = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-J")
    OHM_KiloM = URIRef("http://qudt.org/vocab/unit/OHM-KiloM")
    W_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-PER-M3")
    LB_PER_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-HR-DEG_F")
    PINT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-DAY")
    PetaJ = URIRef("http://qudt.org/vocab/unit/PetaJ")
    PERCENT_SEC_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-YD3")
    PER_M_NanoM = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM")
    LB_PER_FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-LB_F-SEC")
    N_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-PER-M3")
    HectoC = URIRef("http://qudt.org/vocab/unit/HectoC")
    MI_PER_HR = URIRef("http://qudt.org/vocab/unit/MI-PER-HR")
    BYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/BYTE-PER-SEC")
    LB_SEC_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-YD3")
    M3_PER_C = URIRef("http://qudt.org/vocab/unit/M3-PER-C")
    DeciM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-DAY")
    BTU_TH = URIRef("http://qudt.org/vocab/unit/BTU_TH")
    PINT_US = URIRef("http://qudt.org/vocab/unit/PINT_US")
    R_man = URIRef("http://qudt.org/vocab/unit/R_man")
    Quarter_UK = URIRef("http://qudt.org/vocab/unit/Quarter_UK")
    PER_OZ = URIRef("http://qudt.org/vocab/unit/PER-OZ")
    KiloBTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-FT2")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    KiloW_PER_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M-DEG_C")
    DEG_C_PER_M = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-M")
    MilliL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliL-PER-L")
    PER_EV_M3 = URIRef("http://qudt.org/vocab/unit/PER-EV-M3")
    GR = URIRef("http://qudt.org/vocab/unit/GR")
    LB_HR_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK2")
    U = URIRef("http://qudt.org/vocab/unit/U")
    NAT = URIRef("http://qudt.org/vocab/unit/NAT")
    BAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-L-PER-SEC")
    BAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-M3-PER-SEC")
    MilliL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M3")
    KiloGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-SEC")
    MIN_Angle = URIRef("http://qudt.org/vocab/unit/MIN_Angle")
    L_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-M2")
    FT_LB_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-M2")
    GM_PER_CentiM_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM-SEC")
    PINT = URIRef("http://qudt.org/vocab/unit/PINT")
    MegaGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-M3")
    OHM_Ab = URIRef("http://qudt.org/vocab/unit/OHM_Ab")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    PINT_US = URIRef("http://qudt.org/vocab/unit/PINT_US")
    DecaARE = URIRef("http://qudt.org/vocab/unit/DecaARE")
    ERLANG = URIRef("http://qudt.org/vocab/unit/ERLANG")
    GM_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/GM-PER-DEG_C")
    KiloM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-HR")
    CentiST = URIRef("http://qudt.org/vocab/unit/CentiST")
    MilliC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliC-PER-KiloGM")
    ANGSTROM = URIRef("http://qudt.org/vocab/unit/ANGSTROM")
    DeciSEC = URIRef("http://qudt.org/vocab/unit/DeciSEC")
    J_PER_KiloGM_K_PA = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-PA")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    TON_Metric_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR")
    MI_N_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI_N-PER-MIN")
    IN3 = URIRef("http://qudt.org/vocab/unit/IN3")
    B_PER_M = URIRef("http://qudt.org/vocab/unit/B-PER-M")
    MilliM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-BAR")
    MilliJ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-GM")
    BTU_IT_PER_HR_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2")
    PERCENT_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-M3")
    BFT = URIRef("http://qudt.org/vocab/unit/BFT")
    LB_PER_FT_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-HR")
    W_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M2")
    KiloGM_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-MilliM2")
    REM = URIRef("http://qudt.org/vocab/unit/REM")
    SUSCEPTIBILITY_ELEC = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_ELEC")
    S_Ab = URIRef("http://qudt.org/vocab/unit/S_Ab")
    TONNE_PER_DAY = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY")
    G = URIRef("http://qudt.org/vocab/unit/G")
    BTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2")
    KiloN_M_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-M")
    MicroC = URIRef("http://qudt.org/vocab/unit/MicroC")
    PetaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/PetaJ-PER-SEC")
    EUR_PER_W = URIRef("http://qudt.org/vocab/unit/EUR-PER-W")
    DEATHS_PER_1000000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000000I-YR")
    M_K_PER_W = URIRef("http://qudt.org/vocab/unit/M-K-PER-W")
    W_PER_M2_K4 = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K4")
    GM_PER_M3 = URIRef("http://qudt.org/vocab/unit/GM-PER-M3")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    TONNE_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3-BAR")
    NanoBQ = URIRef("http://qudt.org/vocab/unit/NanoBQ")
    PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2")
    Megahertz_KiloM = URIRef("http://qudt.org/vocab/unit/Megahertz-KiloM")
    CentiM3_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR")
    WK = URIRef("http://qudt.org/vocab/unit/WK")
    KiloCAL_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-HR")
    PDL_IN = URIRef("http://qudt.org/vocab/unit/PDL-IN")
    W_PER_K = URIRef("http://qudt.org/vocab/unit/W-PER-K")
    PA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M3-PER-SEC")
    MilliA_SEC = URIRef("http://qudt.org/vocab/unit/MilliA-SEC")
    MilliGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2")
    L_PER_MIN = URIRef("http://qudt.org/vocab/unit/L-PER-MIN")
    PicoGM = URIRef("http://qudt.org/vocab/unit/PicoGM")
    MilliDARCY = URIRef("http://qudt.org/vocab/unit/MilliDARCY")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    N_M_PER_W0dot5 = URIRef("http://qudt.org/vocab/unit/N-M-PER-W0dot5")
    MilliGM_PER_M3_PA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-PA-SEC")
    CentiST = URIRef("http://qudt.org/vocab/unit/CentiST")
    KiloMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-KiloGM")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    DEG_R_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-SEC")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    Megahertz_KiloM = URIRef("http://qudt.org/vocab/unit/Megahertz-KiloM")
    BTU_IT_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_R")
    NUM_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/NUM-PER-MilliGM")
    N_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-PER-RAD")
    MilliH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-OHM")
    MilliL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC")
    M2_K = URIRef("http://qudt.org/vocab/unit/M2-K")
    LB_PER_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-HR-DEG_F")
    PERCENT_HR_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-FT3")
    MilliL_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-BAR")
    SON = URIRef("http://qudt.org/vocab/unit/SON")
    PA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-L-PER-SEC")
    LB_PER_FT3 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3")
    BTU_TH = URIRef("http://qudt.org/vocab/unit/BTU_TH")
    KiloSEC = URIRef("http://qudt.org/vocab/unit/KiloSEC")
    MicroKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MicroKAT-PER-L")
    MilliPA = URIRef("http://qudt.org/vocab/unit/MilliPA")
    NanoT = URIRef("http://qudt.org/vocab/unit/NanoT")
    CentiST = URIRef("http://qudt.org/vocab/unit/CentiST")
    PER_T_M = URIRef("http://qudt.org/vocab/unit/PER-T-M")
    FT_LB_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-MIN")
    MO_Synodic = URIRef("http://qudt.org/vocab/unit/MO_Synodic")
    LB_HR_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-YD3")
    J_PER_KiloGM_K_PA = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-PA")
    PlanckCharge = URIRef("http://qudt.org/vocab/unit/PlanckCharge")
    GAL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-SEC")
    KiloGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-K")
    KiloGM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR")
    M3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL-SEC")
    A_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/A-PER-KiloGM")
    BAN = URIRef("http://qudt.org/vocab/unit/BAN")
    NanoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-KiloGM")
    MilliMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-MOL")
    MilliM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DAY")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    TON_Metric_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN-K")
    MilliGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3")
    NanoGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DAY")
    TON_SHORT_PER_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR-DEG_F")
    M_SEC2 = URIRef("http://qudt.org/vocab/unit/M-SEC2")
    OCTET_PER_SEC = URIRef("http://qudt.org/vocab/unit/OCTET-PER-SEC")
    MicroGM_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L-HR")
    W = URIRef("http://qudt.org/vocab/unit/W")
    MOL_PER_M3_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-PA")
    CWT_LONG = URIRef("http://qudt.org/vocab/unit/CWT_LONG")
    CentiM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC")
    FT2_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT2-PER-SEC")
    OZ_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_US")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    PER_J2 = URIRef("http://qudt.org/vocab/unit/PER-J2")
    KiloBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBYTE-PER-SEC")
    CH = URIRef("http://qudt.org/vocab/unit/CH")
    CentiPOISE_PER_K = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-K")
    IN3_PER_HR = URIRef("http://qudt.org/vocab/unit/IN3-PER-HR")
    MilliL_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-K")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    MilliSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-HR")
    PER_J = URIRef("http://qudt.org/vocab/unit/PER-J")
    MI_PER_HR = URIRef("http://qudt.org/vocab/unit/MI-PER-HR")
    YD3 = URIRef("http://qudt.org/vocab/unit/YD3")
    ERG_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM3")
    PERCENT_PER_OHM = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-OHM")
    LB_PER_MIN_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN-PSI")
    IN2_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN2-PER-SEC")
    CAL_TH_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2-SEC")
    BTU_IT_PER_HR_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_R")
    PER_PERCENT = URIRef("http://qudt.org/vocab/unit/PER-PERCENT")
    MilliGM_PER_M3_CentiPOISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-CentiPOISE")
    DeciB_MilliW_PER_MegaHZ = URIRef("http://qudt.org/vocab/unit/DeciB-MilliW-PER-MegaHZ")
    KiloN_M_PER_DEG_M = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-DEG-M")
    MicroL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroL-PER-L")
    NanoMOL_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL")
    OHM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/OHM-PER-KiloM")
    MegaOHM_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-M")
    SUSCEPTIBILITY_MAG = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_MAG")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    M3_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-BAR")
    PERCENT_SEC_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-IN3")
    M_PER_BAR = URIRef("http://qudt.org/vocab/unit/M-PER-BAR")
    FemtoL = URIRef("http://qudt.org/vocab/unit/FemtoL")
    KiloMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3")
    MilliM3_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-GM")
    PER_MIN = URIRef("http://qudt.org/vocab/unit/PER-MIN")
    KiloPA_M2_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloPA-M2-PER-GM")
    W = URIRef("http://qudt.org/vocab/unit/W")
    PicoMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M2-DAY")
    BTU_IT_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB")
    M = URIRef("http://qudt.org/vocab/unit/M")
    L_PER_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-SEC")
    BTU_IT_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT-PER-FT2-HR-DEG_F")
    MIN = URIRef("http://qudt.org/vocab/unit/MIN")
    PicoL = URIRef("http://qudt.org/vocab/unit/PicoL")
    TonEnergy = URIRef("http://qudt.org/vocab/unit/TonEnergy")
    HR_FT2 = URIRef("http://qudt.org/vocab/unit/HR-FT2")
    N_CentiM = URIRef("http://qudt.org/vocab/unit/N-CentiM")
    KiloW_PER_M2_K = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M2-K")
    MicroM_PER_K = URIRef("http://qudt.org/vocab/unit/MicroM-PER-K")
    TONNE_PER_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-K")
    CAL_15_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_15_DEG_C")
    PPM_PER_K = URIRef("http://qudt.org/vocab/unit/PPM-PER-K")
    MegaPA_M0pt5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0pt5")
    MilliBAR = URIRef("http://qudt.org/vocab/unit/MilliBAR")
    MilliC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M2")
    DEG_F_SEC_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-SEC-PER-BTU_IT")
    R_PER_SEC = URIRef("http://qudt.org/vocab/unit/R-PER-SEC")
    SLUG_PER_FT3 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT3")
    GM_PER_MilliL_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL-BAR")
    DEGREE_BAUME = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME")
    KiloA_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M2")
    FT_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-PER-MIN")
    K_PER_K = URIRef("http://qudt.org/vocab/unit/K-PER-K")
    S_Ab = URIRef("http://qudt.org/vocab/unit/S_Ab")
    KiloGM_PER_HA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HA")
    MilliGM_MIN_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L-M3")
    PER_MILLE_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PSI")
    DEGREE_BRIX = URIRef("http://qudt.org/vocab/unit/DEGREE_BRIX")
    MegaN = URIRef("http://qudt.org/vocab/unit/MegaN")
    MegaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-HR")
    NanoH_PER_M = URIRef("http://qudt.org/vocab/unit/NanoH-PER-M")
    MilliPA_PER_M = URIRef("http://qudt.org/vocab/unit/MilliPA-PER-M")
    OZ_F = URIRef("http://qudt.org/vocab/unit/OZ_F")
    GM_PER_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY")
    NanoGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-HR")
    V_Ab = URIRef("http://qudt.org/vocab/unit/V_Ab")
    MegaPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-M3-PER-SEC")
    DeciM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MOL")
    MilliC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M3")
    J_M_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-M-PER-MOL")
    PERCENT_IN2_PER_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-IN2-PER-LB_F-SEC")
    PER_IN2 = URIRef("http://qudt.org/vocab/unit/PER-IN2")
    KiloGM_PER_M_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC2")
    LB_PER_MIN_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN-DEG_F")
    A_Stat = URIRef("http://qudt.org/vocab/unit/A_Stat")
    TON_Metric_PER_M3 = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    CD_IN = URIRef("http://qudt.org/vocab/unit/CD_IN")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    OZ_FT = URIRef("http://qudt.org/vocab/unit/OZ-FT")
    OZ_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ-PER-SEC")
    M = URIRef("http://qudt.org/vocab/unit/M")
    MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/MOL-DEG_C")
    TonEnergy = URIRef("http://qudt.org/vocab/unit/TonEnergy")
    KiloEV = URIRef("http://qudt.org/vocab/unit/KiloEV")
    MicroL = URIRef("http://qudt.org/vocab/unit/MicroL")
    KiloCAL_IT_PER_HR_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-HR-M-DEG_C")
    DeciM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MIN")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    KiloHZ = URIRef("http://qudt.org/vocab/unit/KiloHZ")
    GM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    TON_SHORT_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-YD3")
    SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-PER-FT2")
    PER_HR = URIRef("http://qudt.org/vocab/unit/PER-HR")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    GigaBasePair = URIRef("http://qudt.org/vocab/unit/GigaBasePair")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    BTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR")
    PPQ = URIRef("http://qudt.org/vocab/unit/PPQ")
    KiloA_HR = URIRef("http://qudt.org/vocab/unit/KiloA-HR")
    MegaEV_FemtoM = URIRef("http://qudt.org/vocab/unit/MegaEV-FemtoM")
    BTU_IT_PER_HR_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2")
    N_M_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-M-PER-KiloGM")
    MilliPA_PER_M = URIRef("http://qudt.org/vocab/unit/MilliPA-PER-M")
    TONNE_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3-BAR")
    FT_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT-PER-DAY")
    GigaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-SEC")
    IN3 = URIRef("http://qudt.org/vocab/unit/IN3")
    R = URIRef("http://qudt.org/vocab/unit/R")
    QT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_US-PER-SEC")
    MegaHZ = URIRef("http://qudt.org/vocab/unit/MegaHZ")
    KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT")
    PK_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-SEC")
    A = URIRef("http://qudt.org/vocab/unit/A")
    CentiM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC-BAR")
    C_M2_PER_V = URIRef("http://qudt.org/vocab/unit/C-M2-PER-V")
    DWT = URIRef("http://qudt.org/vocab/unit/DWT")
    BTU_IT_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-HR-DEG_F")
    C_Stat = URIRef("http://qudt.org/vocab/unit/C_Stat")
    OZ_VOL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-SEC")
    GigaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-PER-M")
    FARAD_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/FARAD_Ab-PER-CentiM")
    DecaARE = URIRef("http://qudt.org/vocab/unit/DecaARE")
    PicoGM_PER_GM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-GM")
    FemtoJ = URIRef("http://qudt.org/vocab/unit/FemtoJ")
    MilliL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-KiloGM")
    PER_MILLE_PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PER-PSI")
    MicroGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-BAR")
    GAL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-HR")
    PPTR_VOL = URIRef("http://qudt.org/vocab/unit/PPTR_VOL")
    PlanckPressure = URIRef("http://qudt.org/vocab/unit/PlanckPressure")
    PicoA = URIRef("http://qudt.org/vocab/unit/PicoA")
    W_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-PER-M3")
    H_Stat = URIRef("http://qudt.org/vocab/unit/H_Stat")
    BTU_IT_PER_HR_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2")
    L = URIRef("http://qudt.org/vocab/unit/L")
    OZ_HR_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-GAL_US")
    HR_Sidereal = URIRef("http://qudt.org/vocab/unit/HR_Sidereal")
    MegaHZ_M = URIRef("http://qudt.org/vocab/unit/MegaHZ-M")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    GI_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_US-PER-DAY")
    TORR = URIRef("http://qudt.org/vocab/unit/TORR")
    PER_H = URIRef("http://qudt.org/vocab/unit/PER-H")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    MicroGM_PER_L = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L")
    LB_PER_HR_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-HR-PSI")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    V_PER_M2 = URIRef("http://qudt.org/vocab/unit/V-PER-M2")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN")
    A_M2 = URIRef("http://qudt.org/vocab/unit/A-M2")
    MicroMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM")
    DYN_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-CentiM")
    EV_SEC = URIRef("http://qudt.org/vocab/unit/EV-SEC")
    PlanckEnergy = URIRef("http://qudt.org/vocab/unit/PlanckEnergy")
    CAL_TH_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-DEG_C")
    BTU_IT_PER_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL-DEG_F")
    MilliMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-KiloGM")
    MegaC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M2")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    MilliM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DAY")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    M3_PER_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-M2")
    W_PER_M_K = URIRef("http://qudt.org/vocab/unit/W-PER-M-K")
    BU_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-HR")
    ERG_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM-SEC")
    ARCSEC = URIRef("http://qudt.org/vocab/unit/ARCSEC")
    V_Ab_SEC = URIRef("http://qudt.org/vocab/unit/V_Ab-SEC")
    GigaHZ = URIRef("http://qudt.org/vocab/unit/GigaHZ")
    KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloM2")
    BU_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-MIN")
    OHM_Ab = URIRef("http://qudt.org/vocab/unit/OHM_Ab")
    SUSCEPTIBILITY_ELEC = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_ELEC")
    GM_PER_M2 = URIRef("http://qudt.org/vocab/unit/GM-PER-M2")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    MicroH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-KiloOHM")
    CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3")
    K_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/K-PER-SEC2")
    MilliJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-M2")
    PERCENT_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-M3")
    MilliGM_MIN_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L2")
    LB_IN2_PER_FT3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-FT3-LB_F-SEC")
    YD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/YD-PER-SEC2")
    BTU_IT_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-HR-DEG_F")
    KiloTONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloTONNE-PER-YR")
    MilliGM = URIRef("http://qudt.org/vocab/unit/MilliGM")
    MicroGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-MilliL")
    KiloS_PER_M = URIRef("http://qudt.org/vocab/unit/KiloS-PER-M")
    MicroV = URIRef("http://qudt.org/vocab/unit/MicroV")
    TON_SHIPPING_UK = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_UK")
    KiloV = URIRef("http://qudt.org/vocab/unit/KiloV")
    MegaOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-BAR")
    Debye = URIRef("http://qudt.org/vocab/unit/Debye")
    M3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM")
    MicroM2 = URIRef("http://qudt.org/vocab/unit/MicroM2")
    MilliRAD_R_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliRAD_R-PER-HR")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    ERLANG = URIRef("http://qudt.org/vocab/unit/ERLANG")
    Gamma = URIRef("http://qudt.org/vocab/unit/Gamma")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    KiloGM_PER_MegaBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MegaBTU_IT")
    MegaPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-M3-PER-SEC")
    NanoMOL_PER_MicroGM_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroGM-HR")
    MicroGM_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L-HR")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    MegaA_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaA-PER-M2")
    WK = URIRef("http://qudt.org/vocab/unit/WK")
    YD2 = URIRef("http://qudt.org/vocab/unit/YD2")
    BTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR")
    TeraV_A = URIRef("http://qudt.org/vocab/unit/TeraV-A")
    NanoGM_PER_L = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-L")
    Ci = URIRef("http://qudt.org/vocab/unit/Ci")
    C_Stat = URIRef("http://qudt.org/vocab/unit/C_Stat")
    GRAIN_PER_GAL = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL")
    KAT_PER_L = URIRef("http://qudt.org/vocab/unit/KAT-PER-L")
    PSI_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-L-PER-SEC")
    A_PER_RAD = URIRef("http://qudt.org/vocab/unit/A-PER-RAD")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    YottaC = URIRef("http://qudt.org/vocab/unit/YottaC")
    DeciM = URIRef("http://qudt.org/vocab/unit/DeciM")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    PA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M3-PER-SEC")
    LB_F_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN")
    OERSTED_CentiM = URIRef("http://qudt.org/vocab/unit/OERSTED-CentiM")
    BTU_TH_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-SEC-DEG_F")
    QT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_US-PER-HR")
    P = URIRef("http://qudt.org/vocab/unit/P")
    ST_PER_BAR = URIRef("http://qudt.org/vocab/unit/ST-PER-BAR")
    LB_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_UK")
    BYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/BYTE-PER-SEC")
    GM_HR_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M6")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    M2_PER_HA = URIRef("http://qudt.org/vocab/unit/M2-PER-HA")
    FT_US = URIRef("http://qudt.org/vocab/unit/FT_US")
    MilliM3_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-GM")
    K_PER_PA = URIRef("http://qudt.org/vocab/unit/K-PER-PA")
    KiloCAL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-MIN")
    LANGLEY = URIRef("http://qudt.org/vocab/unit/LANGLEY")
    MicroS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MicroS-PER-CentiM")
    RAD_R = URIRef("http://qudt.org/vocab/unit/RAD_R")
    CLO = URIRef("http://qudt.org/vocab/unit/CLO")
    GR = URIRef("http://qudt.org/vocab/unit/GR")
    V_A_PER_K = URIRef("http://qudt.org/vocab/unit/V-A-PER-K")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    TON_UK = URIRef("http://qudt.org/vocab/unit/TON_UK")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    GM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC-K")
    V_Stat = URIRef("http://qudt.org/vocab/unit/V_Stat")
    MegaN_M = URIRef("http://qudt.org/vocab/unit/MegaN-M")
    N_M_PER_W0dot5 = URIRef("http://qudt.org/vocab/unit/N-M-PER-W0dot5")
    MilliGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-SEC")
    ExaBYTE = URIRef("http://qudt.org/vocab/unit/ExaBYTE")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    KiloV = URIRef("http://qudt.org/vocab/unit/KiloV")
    NanoGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DAY")
    ERLANG = URIRef("http://qudt.org/vocab/unit/ERLANG")
    W_PER_GM = URIRef("http://qudt.org/vocab/unit/W-PER-GM")
    OZ_M = URIRef("http://qudt.org/vocab/unit/OZ_M")
    POISE = URIRef("http://qudt.org/vocab/unit/POISE")
    FARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/FARAD-PER-KiloM")
    SEC2 = URIRef("http://qudt.org/vocab/unit/SEC2")
    MilliM_H2O = URIRef("http://qudt.org/vocab/unit/MilliM_H2O")
    CAL_IT_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-DEG_C")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    N_M2 = URIRef("http://qudt.org/vocab/unit/N-M2")
    KiloN_M = URIRef("http://qudt.org/vocab/unit/KiloN-M")
    PERCENT_PER_POISE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-POISE")
    C_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM-SEC")
    MicroGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2")
    CUP_US = URIRef("http://qudt.org/vocab/unit/CUP_US")
    KiloW = URIRef("http://qudt.org/vocab/unit/KiloW")
    BU_UK = URIRef("http://qudt.org/vocab/unit/BU_UK")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    W_HR_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-HR-PER-KiloGM")
    GAL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-MIN")
    K_PER_BAR = URIRef("http://qudt.org/vocab/unit/K-PER-BAR")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    PA_SEC_PER_K = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-K")
    DEGREE_TWADDELL = URIRef("http://qudt.org/vocab/unit/DEGREE_TWADDELL")
    FT_LA = URIRef("http://qudt.org/vocab/unit/FT-LA")
    DEG_R_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-SEC")
    FemtoA = URIRef("http://qudt.org/vocab/unit/FemtoA")
    IN_PER_YR = URIRef("http://qudt.org/vocab/unit/IN-PER-YR")
    WK = URIRef("http://qudt.org/vocab/unit/WK")
    DEG_F_HR_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_IT")
    M_PER_YR = URIRef("http://qudt.org/vocab/unit/M-PER-YR")
    MilliGM_SEC_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M6")
    MicroV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/MicroV-A_Reactive-PER-K")
    MilliSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-HR")
    MIL = URIRef("http://qudt.org/vocab/unit/MIL")
    PINT_UK = URIRef("http://qudt.org/vocab/unit/PINT_UK")
    PicoM = URIRef("http://qudt.org/vocab/unit/PicoM")
    PER_V = URIRef("http://qudt.org/vocab/unit/PER-V")
    GM_PER_DeciM3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3-K")
    NUM_PER_GM = URIRef("http://qudt.org/vocab/unit/NUM-PER-GM")
    GM_PER_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-BAR")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    PicoA = URIRef("http://qudt.org/vocab/unit/PicoA")
    DeciL_PER_GM = URIRef("http://qudt.org/vocab/unit/DeciL-PER-GM")
    PER_MO = URIRef("http://qudt.org/vocab/unit/PER-MO")
    KiloGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-K")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    LB_PER_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-DAY")
    J_PER_KiloGM_K_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-M3")
    ExaC = URIRef("http://qudt.org/vocab/unit/ExaC")
    MicroJ = URIRef("http://qudt.org/vocab/unit/MicroJ")
    NanoBQ = URIRef("http://qudt.org/vocab/unit/NanoBQ")
    MegaN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaN-M-PER-M2")
    AC = URIRef("http://qudt.org/vocab/unit/AC")
    MilliGM_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-DAY")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    MI_N_PER_HR = URIRef("http://qudt.org/vocab/unit/MI_N-PER-HR")
    PicoPA = URIRef("http://qudt.org/vocab/unit/PicoPA")
    TONNE_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3-BAR")
    IN_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-DEG_F")
    MicroMOL = URIRef("http://qudt.org/vocab/unit/MicroMOL")
    DEGREE_BALLING = URIRef("http://qudt.org/vocab/unit/DEGREE_BALLING")
    TON_UK_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-YD3")
    KiloV_PER_M = URIRef("http://qudt.org/vocab/unit/KiloV-PER-M")
    PER_EV_M3 = URIRef("http://qudt.org/vocab/unit/PER-EV-M3")
    N_CentiM = URIRef("http://qudt.org/vocab/unit/N-CentiM")
    ERG_CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-CentiM2-PER-GM")
    BTU_IT_PER_SEC_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2")
    OZ_HR_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-YD3")
    NanoM_PER_MilliM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-MilliM-MegaPA")
    GigaEV = URIRef("http://qudt.org/vocab/unit/GigaEV")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    YottaC = URIRef("http://qudt.org/vocab/unit/YottaC")
    MI2 = URIRef("http://qudt.org/vocab/unit/MI2")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    MilLength = URIRef("http://qudt.org/vocab/unit/MilLength")
    DEATHS_PER_1000000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000000I-YR")
    CentiM_HG = URIRef("http://qudt.org/vocab/unit/CentiM_HG")
    NanoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/NanoKAT-PER-L")
    MicroW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroW-PER-M2")
    M3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM")
    SUSCEPTIBILITY_MAG = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_MAG")
    V_Ab_SEC = URIRef("http://qudt.org/vocab/unit/V_Ab-SEC")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    MebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M2")
    KiloV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive-PER-K")
    Stone_UK = URIRef("http://qudt.org/vocab/unit/Stone_UK")
    KiloGM_PER_GigaJ = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-GigaJ")
    C2_M2_PER_J = URIRef("http://qudt.org/vocab/unit/C2-M2-PER-J")
    A_PER_MilliM = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM")
    H_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/H_Stat-PER-CentiM")
    PicoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L")
    TON_Metric_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR-BAR")
    GM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciL")
    MegaPA_M0pt5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0pt5")
    J_M_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-M-PER-MOL")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    NUM_PER_HectoGM = URIRef("http://qudt.org/vocab/unit/NUM-PER-HectoGM")
    GRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/GRAY-PER-SEC")
    C4_M4_PER_J3 = URIRef("http://qudt.org/vocab/unit/C4-M4-PER-J3")
    GM_PER_L_K = URIRef("http://qudt.org/vocab/unit/GM-PER-L-K")
    DYN_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM2")
    NAT = URIRef("http://qudt.org/vocab/unit/NAT")
    W_M_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-M-PER-M2-SR")
    KiloA = URIRef("http://qudt.org/vocab/unit/KiloA")
    LB_SEC_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-IN3")
    W_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M3")
    KiloGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN")
    DEG_C_PER_YR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-YR")
    MicroGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-DeciL")
    ERG_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM2-SEC")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    DYN_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    SEC_PER_M3_RAD = URIRef("http://qudt.org/vocab/unit/SEC-PER-M3-RAD")
    LB_T = URIRef("http://qudt.org/vocab/unit/LB_T")
    MilliM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliM-PER-K")
    M_PER_FARAD = URIRef("http://qudt.org/vocab/unit/M-PER-FARAD")
    GM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloGM")
    YoctoC = URIRef("http://qudt.org/vocab/unit/YoctoC")
    PSU = URIRef("http://qudt.org/vocab/unit/PSU")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-SEC2")
    MilliGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-K")
    PER_V_A_SEC = URIRef("http://qudt.org/vocab/unit/PER-V-A-SEC")
    PDL_PER_IN2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-IN2")
    SEC_PER_RAD_M3 = URIRef("http://qudt.org/vocab/unit/SEC-PER-RAD-M3")
    W_HR_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-HR-PER-KiloGM")
    MilliL_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM-SEC-DEG_C")
    DeciS_PER_M = URIRef("http://qudt.org/vocab/unit/DeciS-PER-M")
    LB_SEC_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-YD3")
    AttoJ_SEC = URIRef("http://qudt.org/vocab/unit/AttoJ-SEC")
    N_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-M-PER-M2")
    MilliM_H2O = URIRef("http://qudt.org/vocab/unit/MilliM_H2O")
    DEG_R = URIRef("http://qudt.org/vocab/unit/DEG_R")
    MIL_Circ = URIRef("http://qudt.org/vocab/unit/MIL_Circ")
    PER_WB = URIRef("http://qudt.org/vocab/unit/PER-WB")
    MegaHZ_PER_T = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-T")
    MicroMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-DAY")
    GM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2")
    MilliGM_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-HR")
    CUP = URIRef("http://qudt.org/vocab/unit/CUP")
    FT_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC-PSI")
    N_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-PER-M3")
    CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-SEC")
    FemtoGM = URIRef("http://qudt.org/vocab/unit/FemtoGM")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    BQ_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-SEC-PER-M3")
    NanoM_PER_CentiM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-MegaPA")
    MilliR_man = URIRef("http://qudt.org/vocab/unit/MilliR_man")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    NanoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/NanoFARAD-PER-M")
    PPTR_VOL = URIRef("http://qudt.org/vocab/unit/PPTR_VOL")
    LY = URIRef("http://qudt.org/vocab/unit/LY")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    DecaL = URIRef("http://qudt.org/vocab/unit/DecaL")
    MilliL_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-BAR")
    DeciM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-DAY")
    LB_PER_FT3_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3-DEG_F")
    EV_PER_K = URIRef("http://qudt.org/vocab/unit/EV-PER-K")
    NanoW = URIRef("http://qudt.org/vocab/unit/NanoW")
    DECADE = URIRef("http://qudt.org/vocab/unit/DECADE")
    KIP_F = URIRef("http://qudt.org/vocab/unit/KIP_F")
    PicoPA_PER_KiloM = URIRef("http://qudt.org/vocab/unit/PicoPA-PER-KiloM")
    MIN = URIRef("http://qudt.org/vocab/unit/MIN")
    DYN_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM2")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    MDOLLAR_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MDOLLAR-PER-FLIGHT")
    RAD_PER_HR = URIRef("http://qudt.org/vocab/unit/RAD-PER-HR")
    CAL_TH_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-K")
    GM_PER_MIN = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN")
    BQ_PER_L = URIRef("http://qudt.org/vocab/unit/BQ-PER-L")
    MOL_PER_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-HR")
    QUAD = URIRef("http://qudt.org/vocab/unit/QUAD")
    MicroJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroJ-PER-SEC")
    PPTM = URIRef("http://qudt.org/vocab/unit/PPTM")
    FT_US = URIRef("http://qudt.org/vocab/unit/FT_US")
    WB_PER_MilliM = URIRef("http://qudt.org/vocab/unit/WB-PER-MilliM")
    N_PER_MilliM = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM")
    R_man = URIRef("http://qudt.org/vocab/unit/R_man")
    N_M_PER_ARCMIN = URIRef("http://qudt.org/vocab/unit/N-M-PER-ARCMIN")
    PERCENT_SEC_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-L")
    TeraV_A_Reactive = URIRef("http://qudt.org/vocab/unit/TeraV-A_Reactive")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    TON_Metric_PER_SEC = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC")
    MilliL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN")
    LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC")
    C = URIRef("http://qudt.org/vocab/unit/C")
    GigaJ = URIRef("http://qudt.org/vocab/unit/GigaJ")
    CD_PER_FT2 = URIRef("http://qudt.org/vocab/unit/CD-PER-FT2")
    MilliL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-GM")
    MicroL = URIRef("http://qudt.org/vocab/unit/MicroL")
    QT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-MIN")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    QT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-HR")
    FT3_PER_PSI = URIRef("http://qudt.org/vocab/unit/FT3-PER-PSI")
    M2_HR_DEG_C_PER_KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/M2-HR-DEG_C-PER-KiloCAL_IT")
    DeciB_PER_M = URIRef("http://qudt.org/vocab/unit/DeciB-PER-M")
    MilliH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-KiloOHM")
    SV_PER_MIN = URIRef("http://qudt.org/vocab/unit/SV-PER-MIN")
    SLUG = URIRef("http://qudt.org/vocab/unit/SLUG")
    CentiM_H2O = URIRef("http://qudt.org/vocab/unit/CentiM_H2O")
    TON_SHIPPING_UK = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_UK")
    MilliC = URIRef("http://qudt.org/vocab/unit/MilliC")
    A_M2 = URIRef("http://qudt.org/vocab/unit/A-M2")
    J_PER_T2 = URIRef("http://qudt.org/vocab/unit/J-PER-T2")
    NanoGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M3")
    LB_HR_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-YD3")
    PicoS_PER_M = URIRef("http://qudt.org/vocab/unit/PicoS-PER-M")
    KiloCAL_PER_MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL-DEG_C")
    KiloN_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M2")
    KiloGM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM2")
    MegaOHM = URIRef("http://qudt.org/vocab/unit/MegaOHM")
    PlanckPower = URIRef("http://qudt.org/vocab/unit/PlanckPower")
    KiloLB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-IN2")
    NanoGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2")
    MilliGM_PER_L_CentiPOISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-CentiPOISE")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    TON_F_US = URIRef("http://qudt.org/vocab/unit/TON_F_US")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    J_PER_SEC = URIRef("http://qudt.org/vocab/unit/J-PER-SEC")
    DEGREE_BAUME_US_HEAVY = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_HEAVY")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    CAL_TH_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-DEG_C")
    LB_HR_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-YD3")
    NAT = URIRef("http://qudt.org/vocab/unit/NAT")
    W_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M3")
    GigaPA = URIRef("http://qudt.org/vocab/unit/GigaPA")
    GigaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBYTE-PER-SEC")
    KiloA = URIRef("http://qudt.org/vocab/unit/KiloA")
    GM_HR_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L-M3")
    KiloC = URIRef("http://qudt.org/vocab/unit/KiloC")
    GigaEV = URIRef("http://qudt.org/vocab/unit/GigaEV")
    LB_PER_YD = URIRef("http://qudt.org/vocab/unit/LB-PER-YD")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    BAR = URIRef("http://qudt.org/vocab/unit/BAR")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    TeraJ = URIRef("http://qudt.org/vocab/unit/TeraJ")
    GAL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-SEC")
    SLUG = URIRef("http://qudt.org/vocab/unit/SLUG")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    J_M2 = URIRef("http://qudt.org/vocab/unit/J-M2")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    KiloV = URIRef("http://qudt.org/vocab/unit/KiloV")
    A_PER_MilliM = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM")
    MilliN = URIRef("http://qudt.org/vocab/unit/MilliN")
    TON_US_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_US-PER-HR")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    K = URIRef("http://qudt.org/vocab/unit/K")
    BTU_IT_PER_MOL_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    PER_IN = URIRef("http://qudt.org/vocab/unit/PER-IN")
    TON_Metric = URIRef("http://qudt.org/vocab/unit/TON_Metric")
    BTU_IT_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT-PER-FT2-HR-DEG_F")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    MilliS = URIRef("http://qudt.org/vocab/unit/MilliS")
    DEG_C_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-K")
    KiloN_M = URIRef("http://qudt.org/vocab/unit/KiloN-M")
    MilliL_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-BAR")
    FARAD_Ab = URIRef("http://qudt.org/vocab/unit/FARAD_Ab")
    KiloW_PER_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M-DEG_C")
    ATM_T = URIRef("http://qudt.org/vocab/unit/ATM_T")
    MilliGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC")
    C_PER_MOL = URIRef("http://qudt.org/vocab/unit/C-PER-MOL")
    PER_DEG_F = URIRef("http://qudt.org/vocab/unit/PER-DEG_F")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    TORR = URIRef("http://qudt.org/vocab/unit/TORR")
    TONNE_PER_HR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR")
    LUX_HR = URIRef("http://qudt.org/vocab/unit/LUX-HR")
    MilliM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC")
    BTU_IT_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC-DEG_F")
    MicroA = URIRef("http://qudt.org/vocab/unit/MicroA")
    IN3_PER_HR = URIRef("http://qudt.org/vocab/unit/IN3-PER-HR")
    GM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC-K")
    BU_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-MIN")
    PER_L = URIRef("http://qudt.org/vocab/unit/PER-L")
    LB_PER_HR_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-HR-PSI")
    MegaBIT = URIRef("http://qudt.org/vocab/unit/MegaBIT")
    KiloGM_PER_HA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HA")
    TON = URIRef("http://qudt.org/vocab/unit/TON")
    SolarMass = URIRef("http://qudt.org/vocab/unit/SolarMass")
    FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/FT2-PER-BTU_IT-IN")
    W_M2 = URIRef("http://qudt.org/vocab/unit/W-M2")
    BTU_TH_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_R")
    ATM = URIRef("http://qudt.org/vocab/unit/ATM")
    QT_US_DRY = URIRef("http://qudt.org/vocab/unit/QT_US_DRY")
    PER_MilliSEC = URIRef("http://qudt.org/vocab/unit/PER-MilliSEC")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    KiloN_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M")
    LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN")
    MilliGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-K")
    ROD = URIRef("http://qudt.org/vocab/unit/ROD")
    MilliC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M2")
    NanoBQ = URIRef("http://qudt.org/vocab/unit/NanoBQ")
    Stone_UK = URIRef("http://qudt.org/vocab/unit/Stone_UK")
    MilliL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC")
    W = URIRef("http://qudt.org/vocab/unit/W")
    PERCENT_MIN_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-GAL_UK")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    MilliBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-KiloGM")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    AWG = URIRef("http://qudt.org/vocab/unit/AWG")
    HectoM = URIRef("http://qudt.org/vocab/unit/HectoM")
    ExaBYTE = URIRef("http://qudt.org/vocab/unit/ExaBYTE")
    N_M2 = URIRef("http://qudt.org/vocab/unit/N-M2")
    KN = URIRef("http://qudt.org/vocab/unit/KN")
    KiloYR = URIRef("http://qudt.org/vocab/unit/KiloYR")
    GM_PER_M3_CentiPOISE = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-CentiPOISE")
    ST = URIRef("http://qudt.org/vocab/unit/ST")
    AttoJ = URIRef("http://qudt.org/vocab/unit/AttoJ")
    KiloGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-SEC")
    N_M_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-RAD")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    MOL_K = URIRef("http://qudt.org/vocab/unit/MOL-K")
    GM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC-BAR")
    MOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM")
    CentiN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/CentiN-M-PER-M2")
    PA_PER_M = URIRef("http://qudt.org/vocab/unit/PA-PER-M")
    PSU = URIRef("http://qudt.org/vocab/unit/PSU")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    BTU_IT_PER_HR_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_R")
    SUSCEPTIBILITY_MAG = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_MAG")
    HP_H2O = URIRef("http://qudt.org/vocab/unit/HP_H2O")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    MilliV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MilliV-A_Reactive")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    MicroSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-MIN")
    LUX_HR = URIRef("http://qudt.org/vocab/unit/LUX-HR")
    PPB = URIRef("http://qudt.org/vocab/unit/PPB")
    AC = URIRef("http://qudt.org/vocab/unit/AC")
    HP_Brake = URIRef("http://qudt.org/vocab/unit/HP_Brake")
    MilliGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-KiloGM")
    KiloPA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-K")
    PK_UK = URIRef("http://qudt.org/vocab/unit/PK_UK")
    PetaFLOPS = URIRef("http://qudt.org/vocab/unit/PetaFLOPS")
    C2_M2_PER_J = URIRef("http://qudt.org/vocab/unit/C2-M2-PER-J")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    BU_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-SEC")
    MilliL_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-BAR")
    MilliA_HR = URIRef("http://qudt.org/vocab/unit/MilliA-HR")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    A = URIRef("http://qudt.org/vocab/unit/A")
    CentiPOISE = URIRef("http://qudt.org/vocab/unit/CentiPOISE")
    LB_MIN_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN6")
    PER_EV2 = URIRef("http://qudt.org/vocab/unit/PER-EV2")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    MilliM3_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-GM")
    KiloR = URIRef("http://qudt.org/vocab/unit/KiloR")
    SLUG = URIRef("http://qudt.org/vocab/unit/SLUG")
    M3_PER_KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM-SEC2")
    AttoJ = URIRef("http://qudt.org/vocab/unit/AttoJ")
    EV_PER_T = URIRef("http://qudt.org/vocab/unit/EV-PER-T")
    M_PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PA-PER-SEC")
    DecaM3 = URIRef("http://qudt.org/vocab/unit/DecaM3")
    MilliV_A_PER_K = URIRef("http://qudt.org/vocab/unit/MilliV-A-PER-K")
    DeciTON_Metric = URIRef("http://qudt.org/vocab/unit/DeciTON_Metric")
    QT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_US-PER-DAY")
    MicroMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    MOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3")
    THM_EEC = URIRef("http://qudt.org/vocab/unit/THM_EEC")
    CAL_15_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_15_DEG_C")
    MilliMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-L")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    BBL_US_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-HR")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    KiloGM_F_M = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M")
    NanoA = URIRef("http://qudt.org/vocab/unit/NanoA")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    PicoGM = URIRef("http://qudt.org/vocab/unit/PicoGM")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    A_PER_GM = URIRef("http://qudt.org/vocab/unit/A-PER-GM")
    BU_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-DAY")
    CAL_15_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_15_DEG_C")
    GigaPA_CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/GigaPA-CentiM3-PER-GM")
    TORR_PER_M = URIRef("http://qudt.org/vocab/unit/TORR-PER-M")
    BU_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-MIN")
    LB_PER_HR_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-HR-PSI")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    MOL_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-DeciM3")
    PER_DAY = URIRef("http://qudt.org/vocab/unit/PER-DAY")
    Quarter_UK = URIRef("http://qudt.org/vocab/unit/Quarter_UK")
    FT_LB_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-MIN")
    L_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/L-PER-KiloGM")
    KiloCAL = URIRef("http://qudt.org/vocab/unit/KiloCAL")
    LB_MIN_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-IN3")
    GM_PER_M3 = URIRef("http://qudt.org/vocab/unit/GM-PER-M3")
    M = URIRef("http://qudt.org/vocab/unit/M")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    J_PER_MOL_K = URIRef("http://qudt.org/vocab/unit/J-PER-MOL-K")
    FT3_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT3-PER-DAY")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    TON = URIRef("http://qudt.org/vocab/unit/TON")
    TebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M3")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    AttoJ = URIRef("http://qudt.org/vocab/unit/AttoJ")
    MegaEV_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-CentiM")
    MicroV = URIRef("http://qudt.org/vocab/unit/MicroV")
    LB_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-DEG_F")
    HA = URIRef("http://qudt.org/vocab/unit/HA")
    M3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM")
    MilliC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M3")
    KiloOHM = URIRef("http://qudt.org/vocab/unit/KiloOHM")
    W_HR = URIRef("http://qudt.org/vocab/unit/W-HR")
    ExbiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M")
    MilliCi = URIRef("http://qudt.org/vocab/unit/MilliCi")
    BTU_IT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR-DEG_F")
    S = URIRef("http://qudt.org/vocab/unit/S")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    KiloM = URIRef("http://qudt.org/vocab/unit/KiloM")
    GM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-CentiM-PER-SEC")
    PER_TON = URIRef("http://qudt.org/vocab/unit/PER-TON")
    GM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-M2-DAY")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    YD3_PER_PSI = URIRef("http://qudt.org/vocab/unit/YD3-PER-PSI")
    N_M_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-M-PER-KiloGM")
    PER_M_NanoM_SR = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM-SR")
    GM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN-K")
    MilliRAD = URIRef("http://qudt.org/vocab/unit/MilliRAD")
    J = URIRef("http://qudt.org/vocab/unit/J")
    PDL_FT = URIRef("http://qudt.org/vocab/unit/PDL-FT")
    PER_EV_M3 = URIRef("http://qudt.org/vocab/unit/PER-EV-M3")
    M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/M2-PER-MOL")
    DeciM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-M3")
    KiloGM_PER_M_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-HR")
    L_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-HR-BAR")
    MI_N_PER_HR = URIRef("http://qudt.org/vocab/unit/MI_N-PER-HR")
    BTU_TH_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-HR-DEG_F")
    MIN = URIRef("http://qudt.org/vocab/unit/MIN")
    CWT_LONG = URIRef("http://qudt.org/vocab/unit/CWT_LONG")
    MilliC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M2")
    BBL_UK_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-HR")
    PPQ = URIRef("http://qudt.org/vocab/unit/PPQ")
    LB_F = URIRef("http://qudt.org/vocab/unit/LB_F")
    LB_F_PER_IN2_DEG_F = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-DEG_F")
    MOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC")
    TON_LONG = URIRef("http://qudt.org/vocab/unit/TON_LONG")
    KibiBIT = URIRef("http://qudt.org/vocab/unit/KibiBIT")
    MilliWB = URIRef("http://qudt.org/vocab/unit/MilliWB")
    TON_LONG = URIRef("http://qudt.org/vocab/unit/TON_LONG")
    GM_PER_M3_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-MilliPA-SEC")
    CentiC = URIRef("http://qudt.org/vocab/unit/CentiC")
    PlanckImpedance = URIRef("http://qudt.org/vocab/unit/PlanckImpedance")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    CentiM_PER_YR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-YR")
    PA_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-PER-BAR")
    EV_M2 = URIRef("http://qudt.org/vocab/unit/EV-M2")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    KiloBTU_TH = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH")
    AC_FT = URIRef("http://qudt.org/vocab/unit/AC-FT")
    GM_PER_L_POISE = URIRef("http://qudt.org/vocab/unit/GM-PER-L-POISE")
    GAL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-HR")
    PER_FT3 = URIRef("http://qudt.org/vocab/unit/PER-FT3")
    A_M2 = URIRef("http://qudt.org/vocab/unit/A-M2")
    TeraW = URIRef("http://qudt.org/vocab/unit/TeraW")
    LB_IN2_PER_GAL_US_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-GAL_US-LB_F-SEC")
    BTU_59DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_59DEG_F")
    KiloV_A_Reactive = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive")
    PERCENT_RH = URIRef("http://qudt.org/vocab/unit/PERCENT_RH")
    ExaBIT_PER_M = URIRef("http://qudt.org/vocab/unit/ExaBIT-PER-M")
    PER_MOL = URIRef("http://qudt.org/vocab/unit/PER-MOL")
    MegaW = URIRef("http://qudt.org/vocab/unit/MegaW")
    CentiN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/CentiN-M-PER-M2")
    PlanckFrequency_Ang = URIRef("http://qudt.org/vocab/unit/PlanckFrequency_Ang")
    A_SEC = URIRef("http://qudt.org/vocab/unit/A-SEC")
    MilliGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-BAR")
    V = URIRef("http://qudt.org/vocab/unit/V")
    M6 = URIRef("http://qudt.org/vocab/unit/M6")
    YR_Sidereal = URIRef("http://qudt.org/vocab/unit/YR_Sidereal")
    KiloGM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3")
    MilliH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-KiloOHM")
    MilliN = URIRef("http://qudt.org/vocab/unit/MilliN")
    YD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/YD-PER-SEC2")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    GRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/GRAY-PER-MIN")
    Da = URIRef("http://qudt.org/vocab/unit/Da")
    CentiM3_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR")
    REV_PER_SEC = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC")
    K_M_PER_W = URIRef("http://qudt.org/vocab/unit/K-M-PER-W")
    DARCY = URIRef("http://qudt.org/vocab/unit/DARCY")
    KiloMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-KiloGM")
    M_KiloGM = URIRef("http://qudt.org/vocab/unit/M-KiloGM")
    IN_H2O = URIRef("http://qudt.org/vocab/unit/IN_H2O")
    KiloV = URIRef("http://qudt.org/vocab/unit/KiloV")
    KiloCi = URIRef("http://qudt.org/vocab/unit/KiloCi")
    MilliN = URIRef("http://qudt.org/vocab/unit/MilliN")
    N_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG")
    MI = URIRef("http://qudt.org/vocab/unit/MI")
    HectoPA_PER_M = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-M")
    DeciN = URIRef("http://qudt.org/vocab/unit/DeciN")
    GI_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_US-PER-SEC")
    DYN_M = URIRef("http://qudt.org/vocab/unit/DYN-M")
    DEG_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG-PER-MIN")
    A_Ab_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-CentiM2")
    MilliA_HR_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliA-HR-PER-GM")
    OZ_VOL_UK = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK")
    PER_T_SEC = URIRef("http://qudt.org/vocab/unit/PER-T-SEC")
    DYN = URIRef("http://qudt.org/vocab/unit/DYN")
    PK_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-HR")
    DEG_F_PER_BAR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-BAR")
    KiloCAL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-MIN")
    POISE = URIRef("http://qudt.org/vocab/unit/POISE")
    PERCENT_SEC_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-GAL_US")
    KiloCAL_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM-DEG_C")
    KiloGM_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-MilliM2")
    KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A-HR")
    PK_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-HR")
    YottaC = URIRef("http://qudt.org/vocab/unit/YottaC")
    DeciM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-DAY")
    KibiBIT = URIRef("http://qudt.org/vocab/unit/KibiBIT")
    EV_SEC = URIRef("http://qudt.org/vocab/unit/EV-SEC")
    IN2 = URIRef("http://qudt.org/vocab/unit/IN2")
    LB_SEC_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT6")
    MilliL_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR")
    DEG_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC")
    GM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-BAR")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    LB_IN2_PER_GAL_UK_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-GAL_UK-LB_F-SEC")
    MicroKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MicroKAT-PER-L")
    NanoH_PER_M = URIRef("http://qudt.org/vocab/unit/NanoH-PER-M")
    ExbiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M3")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    MOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM")
    CASES_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-1000I-YR")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    W_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM")
    MebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M3")
    K_PER_K = URIRef("http://qudt.org/vocab/unit/K-PER-K")
    PH = URIRef("http://qudt.org/vocab/unit/PH")
    BU_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-MIN")
    KiloGM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-BAR")
    OZ_HR_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-GAL_UK")
    ExbiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M2")
    M_SEC2 = URIRef("http://qudt.org/vocab/unit/M-SEC2")
    FUR = URIRef("http://qudt.org/vocab/unit/FUR")
    LB_HR_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-IN3")
    PicoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-KiloGM")
    DEG_C_KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/DEG_C-KiloGM-PER-M2")
    MilliM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliM-PER-MIN")
    MilliV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/MilliV-A_Reactive-PER-K")
    NanoH_PER_M = URIRef("http://qudt.org/vocab/unit/NanoH-PER-M")
    S = URIRef("http://qudt.org/vocab/unit/S")
    CentiMOL_PER_L = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-L")
    PK_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-HR")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    L_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-M2")
    PicoFARAD = URIRef("http://qudt.org/vocab/unit/PicoFARAD")
    W_PER_SR_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-SR-M2")
    ONE_PER_ONE = URIRef("http://qudt.org/vocab/unit/ONE-PER-ONE")
    NanoA = URIRef("http://qudt.org/vocab/unit/NanoA")
    MebiBYTE = URIRef("http://qudt.org/vocab/unit/MebiBYTE")
    PicoMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L-HR")
    HectoM = URIRef("http://qudt.org/vocab/unit/HectoM")
    POISE = URIRef("http://qudt.org/vocab/unit/POISE")
    THM_US = URIRef("http://qudt.org/vocab/unit/THM_US")
    OZ_PER_YD2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD2")
    AttoSEC = URIRef("http://qudt.org/vocab/unit/AttoSEC")
    MicroA = URIRef("http://qudt.org/vocab/unit/MicroA")
    YoctoC = URIRef("http://qudt.org/vocab/unit/YoctoC")
    BTU_IT_PER_LB_F_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_F")
    GAL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-SEC")
    L_PER_L = URIRef("http://qudt.org/vocab/unit/L-PER-L")
    PER_M_K = URIRef("http://qudt.org/vocab/unit/PER-M-K")
    M2_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-PA")
    GM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloM")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    MilliH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-OHM")
    BIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/BIT-PER-M3")
    FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-DEG_F")
    FT3_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT3-PER-SEC")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    PERCENT_SEC_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-GAL_US")
    PDL = URIRef("http://qudt.org/vocab/unit/PDL")
    FT_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC2")
    KiloBTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH-PER-HR")
    BBL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-MIN")
    MilliC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M2")
    MX = URIRef("http://qudt.org/vocab/unit/MX")
    QT_US_DRY = URIRef("http://qudt.org/vocab/unit/QT_US_DRY")
    LB_SEC_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-YD3")
    REV_PER_SEC = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC")
    KiloGM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM")
    OZ_VOL_UK = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK")
    FemtoM = URIRef("http://qudt.org/vocab/unit/FemtoM")
    N_M2 = URIRef("http://qudt.org/vocab/unit/N-M2")
    CentiM2_PER_ERG = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-ERG")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    CentiM_PER_YR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-YR")
    M2_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-K")
    W_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM-SR")
    OZ_F_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ_F-PER-IN3")
    DPI = URIRef("http://qudt.org/vocab/unit/DPI")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    DeciN = URIRef("http://qudt.org/vocab/unit/DeciN")
    NUM_PER_NanoL = URIRef("http://qudt.org/vocab/unit/NUM-PER-NanoL")
    M2_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-HZ2")
    TonEnergy = URIRef("http://qudt.org/vocab/unit/TonEnergy")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC")
    HectoGM = URIRef("http://qudt.org/vocab/unit/HectoGM")
    KiloA_HR = URIRef("http://qudt.org/vocab/unit/KiloA-HR")
    PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-PER-SEC")
    ST_PER_PA = URIRef("http://qudt.org/vocab/unit/ST-PER-PA")
    MicroGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2")
    MegaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-SEC")
    LUX_HR = URIRef("http://qudt.org/vocab/unit/LUX-HR")
    GigaBQ = URIRef("http://qudt.org/vocab/unit/GigaBQ")
    TON_SHORT_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR")
    TON_Metric_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY")
    DEG_C_PER_BAR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-BAR")
    OZ_VOL_US = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US")
    PicoA_PER_MicroMOL_L = URIRef("http://qudt.org/vocab/unit/PicoA-PER-MicroMOL-L")
    TON_Metric_PER_SEC = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC")
    GI_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_US-PER-MIN")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    NanoFARAD = URIRef("http://qudt.org/vocab/unit/NanoFARAD")
    PERM_23DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_23DEG_C")
    PicoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/PicoFARAD-PER-M")
    J = URIRef("http://qudt.org/vocab/unit/J")
    MOL_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-L-BAR")
    PER_PlanckMass2 = URIRef("http://qudt.org/vocab/unit/PER-PlanckMass2")
    MIN_Angle = URIRef("http://qudt.org/vocab/unit/MIN_Angle")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    PERCENT_PER_PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-PERCENT")
    KiloOHM_PER_K = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-K")
    M3_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-BAR")
    KiloGM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MilliM")
    MilliJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-SEC")
    TeraW_HR = URIRef("http://qudt.org/vocab/unit/TeraW-HR")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    CentiM_PER_KiloYR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-KiloYR")
    MilliM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DAY")
    TON_SHIPPING_US = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_US")
    NanoN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/NanoN-M-PER-M2")
    W_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM-SR")
    CentiM2_PER_SR_ERG = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SR-ERG")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    OHM_M2_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-M2-PER-M")
    PA2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA2-PER-SEC2")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    RAD_PER_MIN = URIRef("http://qudt.org/vocab/unit/RAD-PER-MIN")
    CentiGM = URIRef("http://qudt.org/vocab/unit/CentiGM")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    OZ_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_US")
    MOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC")
    M_KiloGM = URIRef("http://qudt.org/vocab/unit/M-KiloGM")
    PicoPA_PER_KiloM = URIRef("http://qudt.org/vocab/unit/PicoPA-PER-KiloM")
    PER_LB = URIRef("http://qudt.org/vocab/unit/PER-LB")
    DEG_C_PER_BAR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-BAR")
    LB_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-SEC")
    K = URIRef("http://qudt.org/vocab/unit/K")
    MebiBIT = URIRef("http://qudt.org/vocab/unit/MebiBIT")
    PER_V = URIRef("http://qudt.org/vocab/unit/PER-V")
    PicoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-KiloGM")
    PIXEL = URIRef("http://qudt.org/vocab/unit/PIXEL")
    BTU_TH_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-SEC-DEG_F")
    DecaC = URIRef("http://qudt.org/vocab/unit/DecaC")
    KiloJ_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MOL")
    NanoSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-MIN")
    MegaHZ = URIRef("http://qudt.org/vocab/unit/MegaHZ")
    PA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-L-PER-SEC")
    CentiM3_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-CentiM3")
    MilliM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM2-PER-SEC")
    FT_LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2")
    GAL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-SEC")
    DeciN_M = URIRef("http://qudt.org/vocab/unit/DeciN-M")
    MicroMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-SEC")
    NanoGM = URIRef("http://qudt.org/vocab/unit/NanoGM")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    MegaOHM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-KiloM")
    GigaPA_CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/GigaPA-CentiM3-PER-GM")
    MOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3")
    W_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M3")
    IN_PER_YR = URIRef("http://qudt.org/vocab/unit/IN-PER-YR")
    M3_PER_DAY = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY")
    WB_M = URIRef("http://qudt.org/vocab/unit/WB-M")
    BTU_IT_PER_SEC_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2")
    HectoPA = URIRef("http://qudt.org/vocab/unit/HectoPA")
    KiloCAL_IT_PER_HR_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-HR-M-DEG_C")
    ST_PER_PA = URIRef("http://qudt.org/vocab/unit/ST-PER-PA")
    DEG_F_HR_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_IT")
    FATH = URIRef("http://qudt.org/vocab/unit/FATH")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    KiloBTU_TH = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH")
    N_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M")
    PicoS = URIRef("http://qudt.org/vocab/unit/PicoS")
    MilliWB = URIRef("http://qudt.org/vocab/unit/MilliWB")
    BBL_US_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-HR")
    MegaN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaN-M-PER-M2")
    MicroGM_PER_IN2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-IN2")
    N_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM2")
    KiloGM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM-PER-SEC")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    DEG_F_SEC_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-SEC-PER-BTU_TH")
    TONNE_PER_HR_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR-K")
    DEG_F_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-HR")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    GM_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM2")
    GigaJ = URIRef("http://qudt.org/vocab/unit/GigaJ")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    MilliGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC")
    MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC")
    TONNE_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY-BAR")
    GigaPA = URIRef("http://qudt.org/vocab/unit/GigaPA")
    GigaOHM_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-M")
    KiloPA_M2_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloPA-M2-PER-GM")
    KiloJ_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MIN")
    MilliGM_MIN_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M3-L")
    MilliM3 = URIRef("http://qudt.org/vocab/unit/MilliM3")
    CentiM3_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-CentiM3")
    MilliW_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM")
    PERCENT_PER_HR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-HR")
    V_PER_MilliM = URIRef("http://qudt.org/vocab/unit/V-PER-MilliM")
    CentiC = URIRef("http://qudt.org/vocab/unit/CentiC")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    M2_PER_GM_DRY = URIRef("http://qudt.org/vocab/unit/M2-PER-GM_DRY")
    CentiM_HG_0DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_HG_0DEG_C")
    N_M_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-RAD")
    DYN_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM3")
    PERCENT_PER_WK = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-WK")
    KIP_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KIP_F-PER-IN2")
    MegaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-SEC")
    GRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/GRAY-PER-SEC")
    PER_IN = URIRef("http://qudt.org/vocab/unit/PER-IN")
    MilliJ = URIRef("http://qudt.org/vocab/unit/MilliJ")
    K_PER_MIN = URIRef("http://qudt.org/vocab/unit/K-PER-MIN")
    KiloBAR = URIRef("http://qudt.org/vocab/unit/KiloBAR")
    N_M_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-M-PER-KiloGM")
    LB_HR_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-IN3")
    IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC")
    CORD = URIRef("http://qudt.org/vocab/unit/CORD")
    KiloSEC = URIRef("http://qudt.org/vocab/unit/KiloSEC")
    DEG_C_WK = URIRef("http://qudt.org/vocab/unit/DEG_C-WK")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    DEG_F_HR_FT2_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT")
    DEG_F_HR_FT2_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT")
    KiloWB_PER_M = URIRef("http://qudt.org/vocab/unit/KiloWB-PER-M")
    PERCENT_PER_BAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-BAR")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    PINT_US = URIRef("http://qudt.org/vocab/unit/PINT_US")
    PER_SEC_SR_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR-M2")
    PPT = URIRef("http://qudt.org/vocab/unit/PPT")
    V_PER_IN = URIRef("http://qudt.org/vocab/unit/V-PER-IN")
    LUX_HR = URIRef("http://qudt.org/vocab/unit/LUX-HR")
    DEG_C_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-HR")
    MilliH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-KiloOHM")
    YD_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD-PER-MIN")
    BU_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-MIN")
    MilliFARAD = URIRef("http://qudt.org/vocab/unit/MilliFARAD")
    PERM_US = URIRef("http://qudt.org/vocab/unit/PERM_US")
    CH = URIRef("http://qudt.org/vocab/unit/CH")
    PPTH_PER_HR = URIRef("http://qudt.org/vocab/unit/PPTH-PER-HR")
    GM = URIRef("http://qudt.org/vocab/unit/GM")
    PPTR = URIRef("http://qudt.org/vocab/unit/PPTR")
    M3_PER_HR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR")
    DeciL_PER_GM = URIRef("http://qudt.org/vocab/unit/DeciL-PER-GM")
    MilliL_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-BAR")
    KiloGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-K")
    PSI = URIRef("http://qudt.org/vocab/unit/PSI")
    ExaC = URIRef("http://qudt.org/vocab/unit/ExaC")
    FT_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-PER-HR")
    MHO = URIRef("http://qudt.org/vocab/unit/MHO")
    FemtoGM_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-L")
    W_PER_SR = URIRef("http://qudt.org/vocab/unit/W-PER-SR")
    GM_PER_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY")
    FemtoSEC = URIRef("http://qudt.org/vocab/unit/FemtoSEC")
    MilliN_PER_M = URIRef("http://qudt.org/vocab/unit/MilliN-PER-M")
    MilliGM_SEC_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L2")
    ATM = URIRef("http://qudt.org/vocab/unit/ATM")
    MHO_Stat = URIRef("http://qudt.org/vocab/unit/MHO_Stat")
    DYN_M = URIRef("http://qudt.org/vocab/unit/DYN-M")
    KiloHZ = URIRef("http://qudt.org/vocab/unit/KiloHZ")
    GAL_US = URIRef("http://qudt.org/vocab/unit/GAL_US")
    KiloJ_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-DAY")
    L_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-K")
    PINT_US_DRY = URIRef("http://qudt.org/vocab/unit/PINT_US_DRY")
    TeraBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/TeraBIT-PER-SEC")
    M6 = URIRef("http://qudt.org/vocab/unit/M6")
    MilliC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliC-PER-KiloGM")
    FT2 = URIRef("http://qudt.org/vocab/unit/FT2")
    N_M_PER_A = URIRef("http://qudt.org/vocab/unit/N-M-PER-A")
    MegaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBIT-PER-SEC")
    CD_PER_M2 = URIRef("http://qudt.org/vocab/unit/CD-PER-M2")
    PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2")
    CAL_TH_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-DEG_C")
    NUM_PER_L = URIRef("http://qudt.org/vocab/unit/NUM-PER-L")
    C = URIRef("http://qudt.org/vocab/unit/C")
    J_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2-DAY")
    M2_HR_DEG_C_PER_KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/M2-HR-DEG_C-PER-KiloCAL_IT")
    MilliM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DAY")
    DeciGM = URIRef("http://qudt.org/vocab/unit/DeciGM")
    NanoS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/NanoS-PER-CentiM")
    DEG_C_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-K")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    BTU_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC")
    KiloW_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloW-HR-PER-M2")
    DecaC = URIRef("http://qudt.org/vocab/unit/DecaC")
    GM_PER_CentiM2_YR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2-YR")
    GR = URIRef("http://qudt.org/vocab/unit/GR")
    BTU_IT_FT = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT")
    EV_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/EV-M2-PER-KiloGM")
    NanoFARAD = URIRef("http://qudt.org/vocab/unit/NanoFARAD")
    BTU_IT_IN_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-HR-FT2-DEG_F")
    FT_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC-DEG_F")
    LB_PER_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-HR")
    TON_Metric = URIRef("http://qudt.org/vocab/unit/TON_Metric")
    NanoT = URIRef("http://qudt.org/vocab/unit/NanoT")
    Kilo_FT3 = URIRef("http://qudt.org/vocab/unit/Kilo-FT3")
    MilliRAD_R_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliRAD_R-PER-HR")
    NanoH_PER_M = URIRef("http://qudt.org/vocab/unit/NanoH-PER-M")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    MI_US2 = URIRef("http://qudt.org/vocab/unit/MI_US2")
    M2_PER_J = URIRef("http://qudt.org/vocab/unit/M2-PER-J")
    NanoSEC = URIRef("http://qudt.org/vocab/unit/NanoSEC")
    SLUG_PER_DAY = URIRef("http://qudt.org/vocab/unit/SLUG-PER-DAY")
    MilliW_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-MilliGM")
    PER_YR = URIRef("http://qudt.org/vocab/unit/PER-YR")
    DecaARE = URIRef("http://qudt.org/vocab/unit/DecaARE")
    Quarter_UK = URIRef("http://qudt.org/vocab/unit/Quarter_UK")
    QT_US = URIRef("http://qudt.org/vocab/unit/QT_US")
    GM_HR_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M6")
    KiloCAL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MIN")
    FT_LB_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-SEC")
    GM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY-K")
    GI_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_US-PER-DAY")
    AttoSEC = URIRef("http://qudt.org/vocab/unit/AttoSEC")
    HA = URIRef("http://qudt.org/vocab/unit/HA")
    KiloPA = URIRef("http://qudt.org/vocab/unit/KiloPA")
    PERCENT_PER_DecaCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaCount")
    PicoSEC = URIRef("http://qudt.org/vocab/unit/PicoSEC")
    MegaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M2")
    PA_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC")
    V_Ab = URIRef("http://qudt.org/vocab/unit/V_Ab")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    MegaOHM_PER_K = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-K")
    DEG_F_HR_FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT-IN")
    NUM_PER_HA = URIRef("http://qudt.org/vocab/unit/NUM-PER-HA")
    KiloJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM")
    MilliM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-BAR")
    MilliKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MilliKAT-PER-L")
    MilliC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M3")
    BTU_IT_IN_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-HR-FT2-DEG_F")
    SLUG_PER_MIN = URIRef("http://qudt.org/vocab/unit/SLUG-PER-MIN")
    KiloM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC")
    MilliM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-KiloGM")
    MOL_PER_M2_SEC_M = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-M")
    PlanckLength = URIRef("http://qudt.org/vocab/unit/PlanckLength")
    M2_PER_GM = URIRef("http://qudt.org/vocab/unit/M2-PER-GM")
    KiloLB_F_FT_PER_A = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-A")
    MegaHZ_M = URIRef("http://qudt.org/vocab/unit/MegaHZ-M")
    MilliHZ = URIRef("http://qudt.org/vocab/unit/MilliHZ")
    PER_IN = URIRef("http://qudt.org/vocab/unit/PER-IN")
    MilliRAD = URIRef("http://qudt.org/vocab/unit/MilliRAD")
    KiloM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC")
    HP_H2O = URIRef("http://qudt.org/vocab/unit/HP_H2O")
    CentiST = URIRef("http://qudt.org/vocab/unit/CentiST")
    PER_MOL = URIRef("http://qudt.org/vocab/unit/PER-MOL")
    V_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V-PER-CentiM")
    GM_PER_CentiM3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3-BAR")
    PSI = URIRef("http://qudt.org/vocab/unit/PSI")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    M2_PER_GM = URIRef("http://qudt.org/vocab/unit/M2-PER-GM")
    MicroMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L-HR")
    DeciB_PER_M = URIRef("http://qudt.org/vocab/unit/DeciB-PER-M")
    V_PER_L_MIN = URIRef("http://qudt.org/vocab/unit/V-PER-L-MIN")
    MilliGM_SEC_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L2")
    KiloM3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM3-PER-SEC2")
    PER_RAD = URIRef("http://qudt.org/vocab/unit/PER-RAD")
    MilliL_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-K")
    MilliM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliM-PER-MIN")
    TONNE_PER_DAY = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY")
    MicroGM = URIRef("http://qudt.org/vocab/unit/MicroGM")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    PK_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-HR")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    FT_PDL = URIRef("http://qudt.org/vocab/unit/FT-PDL")
    IN2 = URIRef("http://qudt.org/vocab/unit/IN2")
    MilliL_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-BAR")
    MilliBAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-BAR")
    KibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M3")
    MilliV_A = URIRef("http://qudt.org/vocab/unit/MilliV-A")
    GigaN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaN-M-PER-M2")
    PER_GigaEV2 = URIRef("http://qudt.org/vocab/unit/PER-GigaEV2")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    HR_FT2 = URIRef("http://qudt.org/vocab/unit/HR-FT2")
    CentiM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL")
    HectoPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-M3-PER-SEC")
    PERCENT_HR_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-L")
    ZeptoC = URIRef("http://qudt.org/vocab/unit/ZeptoC")
    PER_V = URIRef("http://qudt.org/vocab/unit/PER-V")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    EV_PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/EV-PER-ANGSTROM")
    MicroM2 = URIRef("http://qudt.org/vocab/unit/MicroM2")
    NanoM2 = URIRef("http://qudt.org/vocab/unit/NanoM2")
    BTU_IT_PER_SEC_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2")
    AttoJ = URIRef("http://qudt.org/vocab/unit/AttoJ")
    Debye = URIRef("http://qudt.org/vocab/unit/Debye")
    MegaJ_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M3")
    PSU = URIRef("http://qudt.org/vocab/unit/PSU")
    Ci = URIRef("http://qudt.org/vocab/unit/Ci")
    MilliGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-BAR")
    PlanckPressure = URIRef("http://qudt.org/vocab/unit/PlanckPressure")
    A_HR_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/A-HR-PER-KiloGM")
    HART_PER_SEC = URIRef("http://qudt.org/vocab/unit/HART-PER-SEC")
    DecaL = URIRef("http://qudt.org/vocab/unit/DecaL")
    LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN")
    BTU_IT_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB")
    MIN_Angle = URIRef("http://qudt.org/vocab/unit/MIN_Angle")
    DEG_C_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-SEC")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    NanoV_A_Reactive = URIRef("http://qudt.org/vocab/unit/NanoV-A_Reactive")
    MegaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBYTE-PER-SEC")
    PDL = URIRef("http://qudt.org/vocab/unit/PDL")
    V_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Ab-PER-CentiM")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    M_SEC = URIRef("http://qudt.org/vocab/unit/M-SEC")
    PERCENT_HR_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-L")
    CAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-K")
    DEGREE_TWADDELL = URIRef("http://qudt.org/vocab/unit/DEGREE_TWADDELL")
    PPT = URIRef("http://qudt.org/vocab/unit/PPT")
    KiloBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBIT-PER-SEC")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    DeciN_M = URIRef("http://qudt.org/vocab/unit/DeciN-M")
    TONNE = URIRef("http://qudt.org/vocab/unit/TONNE")
    IU_PER_L = URIRef("http://qudt.org/vocab/unit/IU-PER-L")
    C_PER_MOL = URIRef("http://qudt.org/vocab/unit/C-PER-MOL")
    LB_HR_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-YD3")
    PER_MILLE_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PSI")
    PicoFARAD = URIRef("http://qudt.org/vocab/unit/PicoFARAD")
    MegaC = URIRef("http://qudt.org/vocab/unit/MegaC")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    M3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM")
    PicoMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M3")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    PERCENT_PER_WK = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-WK")
    PicoL = URIRef("http://qudt.org/vocab/unit/PicoL")
    MIN = URIRef("http://qudt.org/vocab/unit/MIN")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    DEGREE_BAUME = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME")
    TON_SHORT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-DEG_F")
    PetaBIT = URIRef("http://qudt.org/vocab/unit/PetaBIT")
    MicroS = URIRef("http://qudt.org/vocab/unit/MicroS")
    NanoGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-MIN")
    KiloJ_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-DAY")
    IN_HG = URIRef("http://qudt.org/vocab/unit/IN_HG")
    BTU_TH_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC-FT2-DEG_F")
    CAL_IT_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-DEG_C")
    GigaW = URIRef("http://qudt.org/vocab/unit/GigaW")
    CASES_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-1000I-YR")
    PERCENT_HR_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-L")
    ATM_PER_M = URIRef("http://qudt.org/vocab/unit/ATM-PER-M")
    NanoC = URIRef("http://qudt.org/vocab/unit/NanoC")
    LM_PER_W = URIRef("http://qudt.org/vocab/unit/LM-PER-W")
    MicroBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-KiloGM")
    BTU_IT_PER_LB_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F")
    MilliC = URIRef("http://qudt.org/vocab/unit/MilliC")
    MicroM_PER_N = URIRef("http://qudt.org/vocab/unit/MicroM-PER-N")
    FT3_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT3-PER-SEC")
    M_SEC2 = URIRef("http://qudt.org/vocab/unit/M-SEC2")
    M3_PER_KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM-SEC2")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    W_M_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-M-PER-M2-SR")
    LB_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-SEC")
    FT3_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT3-PER-SEC")
    KiloCAL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-MIN")
    LB_HR_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-YD3")
    ST = URIRef("http://qudt.org/vocab/unit/ST")
    V_M = URIRef("http://qudt.org/vocab/unit/V-M")
    HR_FT2 = URIRef("http://qudt.org/vocab/unit/HR-FT2")
    OHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/OHM-PER-BAR")
    M3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC2")
    MilliHZ = URIRef("http://qudt.org/vocab/unit/MilliHZ")
    PA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-BAR")
    M2_K_PER_W = URIRef("http://qudt.org/vocab/unit/M2-K-PER-W")
    OZ_VOL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-DAY")
    FUR = URIRef("http://qudt.org/vocab/unit/FUR")
    MilliL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-MIN")
    DeciB_ISO = URIRef("http://qudt.org/vocab/unit/DeciB_ISO")
    GM_PER_L_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-L-MilliPA-SEC")
    OZ = URIRef("http://qudt.org/vocab/unit/OZ")
    PlanckArea = URIRef("http://qudt.org/vocab/unit/PlanckArea")
    DEG_R_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-MIN")
    KiloGM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MilliM")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    KiloPA = URIRef("http://qudt.org/vocab/unit/KiloPA")
    PlanckPressure = URIRef("http://qudt.org/vocab/unit/PlanckPressure")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    A_Ab_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-CentiM2")
    BTU_IT_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-SEC-DEG_F")
    KiloHZ = URIRef("http://qudt.org/vocab/unit/KiloHZ")
    MicroGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    MilliGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2")
    PPQ = URIRef("http://qudt.org/vocab/unit/PPQ")
    MOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-SEC")
    V_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-PER-CentiM")
    W_PER_M2_PA = URIRef("http://qudt.org/vocab/unit/W-PER-M2-PA")
    MilliT = URIRef("http://qudt.org/vocab/unit/MilliT")
    PK_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-HR")
    LB_HR_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK2")
    GigaBasePair = URIRef("http://qudt.org/vocab/unit/GigaBasePair")
    TON_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-DAY")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    LB_FT2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-IN3-LB_F-SEC")
    BTU_TH_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB")
    W_PER_SR = URIRef("http://qudt.org/vocab/unit/W-PER-SR")
    CentiMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-KiloGM")
    OZ_HR_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-GAL_US")
    BTU_IT_IN_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-SEC-FT2-DEG_F")
    BBL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-DAY")
    CFU = URIRef("http://qudt.org/vocab/unit/CFU")
    PERM_Metric_23DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_Metric_23DEG_C")
    KiloS_PER_M = URIRef("http://qudt.org/vocab/unit/KiloS-PER-M")
    CD_PER_FT2 = URIRef("http://qudt.org/vocab/unit/CD-PER-FT2")
    DEG_C_CentiM = URIRef("http://qudt.org/vocab/unit/DEG_C-CentiM")
    KiloBD = URIRef("http://qudt.org/vocab/unit/KiloBD")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD3-PER-SEC")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    LB_F_PER_YD = URIRef("http://qudt.org/vocab/unit/LB_F-PER-YD")
    NanoBQ_PER_L = URIRef("http://qudt.org/vocab/unit/NanoBQ-PER-L")
    GM_HR_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L-M3")
    KiloCAL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-MIN")
    LB_PER_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-HR-DEG_F")
    DEG_F_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-K")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    GI_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-DAY")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    GAL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-DAY")
    C_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM")
    J_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2-DAY")
    NanoFARAD = URIRef("http://qudt.org/vocab/unit/NanoFARAD")
    U = URIRef("http://qudt.org/vocab/unit/U")
    OZ_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_US")
    MegaHZ_M = URIRef("http://qudt.org/vocab/unit/MegaHZ-M")
    OZ_VOL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-HR")
    TON_UK = URIRef("http://qudt.org/vocab/unit/TON_UK")
    CM_H2O = URIRef("http://qudt.org/vocab/unit/CM_H2O")
    GAL_US_DRY = URIRef("http://qudt.org/vocab/unit/GAL_US_DRY")
    TON_Metric_PER_HR_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR-K")
    MilliOHM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-M")
    W_PER_FT2 = URIRef("http://qudt.org/vocab/unit/W-PER-FT2")
    GRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/GRAY-PER-SEC")
    BTU_IT_PER_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL-DEG_F")
    MegaHZ_M = URIRef("http://qudt.org/vocab/unit/MegaHZ-M")
    KiloGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC")
    GM_PER_MIN = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN")
    KiloBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-HR")
    BTU_IT_IN_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-SEC-FT2-DEG_F")
    MilliW_PER_CentiM2_MicroM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-CentiM2-MicroM-SR")
    KiloBAR = URIRef("http://qudt.org/vocab/unit/KiloBAR")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    ST = URIRef("http://qudt.org/vocab/unit/ST")
    GM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciL")
    BTU_IT = URIRef("http://qudt.org/vocab/unit/BTU_IT")
    BTU_IT_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT3")
    BTU_IT_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB")
    TebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M2")
    PERCENT_PER_HR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-HR")
    NanoBQ_PER_L = URIRef("http://qudt.org/vocab/unit/NanoBQ-PER-L")
    PicoPA_PER_KiloM = URIRef("http://qudt.org/vocab/unit/PicoPA-PER-KiloM")
    LB_HR_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT6")
    PERCENT_PER_M = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-M")
    KiloP = URIRef("http://qudt.org/vocab/unit/KiloP")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    FUR = URIRef("http://qudt.org/vocab/unit/FUR")
    KiloM = URIRef("http://qudt.org/vocab/unit/KiloM")
    MOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL-PER-MIN")
    N_M_PER_A = URIRef("http://qudt.org/vocab/unit/N-M-PER-A")
    NanoM = URIRef("http://qudt.org/vocab/unit/NanoM")
    FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC")
    CentiPOISE = URIRef("http://qudt.org/vocab/unit/CentiPOISE")
    PERCENT_PER_HectoBAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-HectoBAR")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    MilliA_PER_IN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-IN")
    LB_IN2_PER_GAL_US_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-GAL_US-LB_F-SEC")
    BTU_39DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_39DEG_F")
    MicroS = URIRef("http://qudt.org/vocab/unit/MicroS")
    MegaPA_PER_K = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-K")
    PER_MicroMOL_L = URIRef("http://qudt.org/vocab/unit/PER-MicroMOL-L")
    L_PER_HR = URIRef("http://qudt.org/vocab/unit/L-PER-HR")
    PicoV_A = URIRef("http://qudt.org/vocab/unit/PicoV-A")
    CentiM_PER_YR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-YR")
    PER_TONNE = URIRef("http://qudt.org/vocab/unit/PER-TONNE")
    MicroJ = URIRef("http://qudt.org/vocab/unit/MicroJ")
    M_K_PER_W = URIRef("http://qudt.org/vocab/unit/M-K-PER-W")
    A = URIRef("http://qudt.org/vocab/unit/A")
    GM_SEC_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L2")
    MegaV_A_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A-HR")
    DeciL = URIRef("http://qudt.org/vocab/unit/DeciL")
    NanoC = URIRef("http://qudt.org/vocab/unit/NanoC")
    L_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-HR-BAR")
    BEAT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BEAT-PER-MIN")
    GAL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-SEC")
    HectoGM = URIRef("http://qudt.org/vocab/unit/HectoGM")
    N_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-PER-KiloGM")
    PER_TON = URIRef("http://qudt.org/vocab/unit/PER-TON")
    GAL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-DAY")
    PA_PER_HR = URIRef("http://qudt.org/vocab/unit/PA-PER-HR")
    KiloPOND = URIRef("http://qudt.org/vocab/unit/KiloPOND")
    TONNE_PER_MIN = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN")
    NanoGM = URIRef("http://qudt.org/vocab/unit/NanoGM")
    MilliC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M3")
    KiloTONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloTONNE-PER-YR")
    GM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3-BAR")
    IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN3-PER-SEC")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    POISE = URIRef("http://qudt.org/vocab/unit/POISE")
    BTU_IT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_F")
    GM_PER_M = URIRef("http://qudt.org/vocab/unit/GM-PER-M")
    MegaS_PER_M = URIRef("http://qudt.org/vocab/unit/MegaS-PER-M")
    CentiM3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-K")
    OZ_MIN_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-GAL_UK")
    PPT = URIRef("http://qudt.org/vocab/unit/PPT")
    A_PER_CentiM = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM")
    N_PER_C = URIRef("http://qudt.org/vocab/unit/N-PER-C")
    PERM_US = URIRef("http://qudt.org/vocab/unit/PERM_US")
    GM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciL")
    GigaBQ = URIRef("http://qudt.org/vocab/unit/GigaBQ")
    J_PER_M = URIRef("http://qudt.org/vocab/unit/J-PER-M")
    S_PER_CentiM = URIRef("http://qudt.org/vocab/unit/S-PER-CentiM")
    IU_PER_MilliL = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliL")
    DeciB_PER_M = URIRef("http://qudt.org/vocab/unit/DeciB-PER-M")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    V_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/V-SEC-PER-M")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC")
    OHM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/OHM-PER-KiloM")
    MicroGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-KiloGM")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    KiloM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-HR")
    TON_Metric_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR")
    BTU_IT_PER_HR_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_R")
    M3_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-K")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    ATM_T = URIRef("http://qudt.org/vocab/unit/ATM_T")
    DYN = URIRef("http://qudt.org/vocab/unit/DYN")
    MicroH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-OHM")
    IN_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC-PSI")
    PERCENT_RH = URIRef("http://qudt.org/vocab/unit/PERCENT_RH")
    TONNE_PER_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-BAR")
    MegaPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-L-PER-SEC")
    LB_PER_YD3 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD3")
    LB_M = URIRef("http://qudt.org/vocab/unit/LB_M")
    A_PER_PA = URIRef("http://qudt.org/vocab/unit/A-PER-PA")
    OZ_VOL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-MIN")
    TON_US = URIRef("http://qudt.org/vocab/unit/TON_US")
    FT3_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT3-PER-DAY")
    CentiN = URIRef("http://qudt.org/vocab/unit/CentiN")
    DEGREE_BAUME_US_HEAVY = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_HEAVY")
    KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloGM-K")
    LB_HR_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-FT3")
    GM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-CentiM-PER-SEC")
    IU_PER_L = URIRef("http://qudt.org/vocab/unit/IU-PER-L")
    DeciM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-M3")
    SHANNON_PER_SEC = URIRef("http://qudt.org/vocab/unit/SHANNON-PER-SEC")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    MOL_PER_L = URIRef("http://qudt.org/vocab/unit/MOL-PER-L")
    CAL_TH_PER_G = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-G")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    A_PER_PA = URIRef("http://qudt.org/vocab/unit/A-PER-PA")
    KiloGM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM2-PER-SEC2")
    GRAIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-M3")
    GM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloGM")
    AttoFARAD = URIRef("http://qudt.org/vocab/unit/AttoFARAD")
    T_SEC = URIRef("http://qudt.org/vocab/unit/T-SEC")
    MilliM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-M3")
    A_PER_A_HR = URIRef("http://qudt.org/vocab/unit/A-PER-A-HR")
    DEG_F_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-K")
    PHON = URIRef("http://qudt.org/vocab/unit/PHON")
    MilliGM_HR_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L2")
    A_PER_GM = URIRef("http://qudt.org/vocab/unit/A-PER-GM")
    YD3_PER_DAY = URIRef("http://qudt.org/vocab/unit/YD3-PER-DAY")
    K_PER_PA = URIRef("http://qudt.org/vocab/unit/K-PER-PA")
    GI_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_US-PER-MIN")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    DeciM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MOL")
    KiloHZ_M = URIRef("http://qudt.org/vocab/unit/KiloHZ-M")
    MegaPA_M0pt5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0pt5")
    MilliC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M3")
    LB_HR_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-FT3")
    CentiM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC-BAR")
    BBL_US_DRY = URIRef("http://qudt.org/vocab/unit/BBL_US_DRY")
    MicroGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-KiloGM")
    PicoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-KiloGM")
    R_PER_SEC = URIRef("http://qudt.org/vocab/unit/R-PER-SEC")
    MegaN_M = URIRef("http://qudt.org/vocab/unit/MegaN-M")
    LB_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-MOL-DEG_F")
    GigaV_A_Reactive = URIRef("http://qudt.org/vocab/unit/GigaV-A_Reactive")
    DeciM3 = URIRef("http://qudt.org/vocab/unit/DeciM3")
    QT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_US-PER-MIN")
    SAMPLE_PER_SEC = URIRef("http://qudt.org/vocab/unit/SAMPLE-PER-SEC")
    M_K_PER_W = URIRef("http://qudt.org/vocab/unit/M-K-PER-W")
    LB_F_PER_LB = URIRef("http://qudt.org/vocab/unit/LB_F-PER-LB")
    KiloBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBIT-PER-SEC")
    RAD_PER_MIN = URIRef("http://qudt.org/vocab/unit/RAD-PER-MIN")
    OHM_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-PER-M")
    TebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    QT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-DAY")
    MicroM_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/MicroM-PER-L-DAY")
    OZ_F_IN = URIRef("http://qudt.org/vocab/unit/OZ_F-IN")
    A_Stat = URIRef("http://qudt.org/vocab/unit/A_Stat")
    CAL_TH_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM")
    MicroBQ = URIRef("http://qudt.org/vocab/unit/MicroBQ")
    IN_HG = URIRef("http://qudt.org/vocab/unit/IN_HG")
    TONNE_PER_MIN = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN")
    MegaN = URIRef("http://qudt.org/vocab/unit/MegaN")
    L_PER_DAY = URIRef("http://qudt.org/vocab/unit/L-PER-DAY")
    HART_PER_SEC = URIRef("http://qudt.org/vocab/unit/HART-PER-SEC")
    AT_PER_IN = URIRef("http://qudt.org/vocab/unit/AT-PER-IN")
    GM_MIN_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M6")
    MegaHZ = URIRef("http://qudt.org/vocab/unit/MegaHZ")
    HP = URIRef("http://qudt.org/vocab/unit/HP")
    GM_PER_K = URIRef("http://qudt.org/vocab/unit/GM-PER-K")
    NanoMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL")
    PK_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-SEC")
    GAL_UK = URIRef("http://qudt.org/vocab/unit/GAL_UK")
    BTU_TH_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC-FT2-DEG_F")
    MOL_LB_PER_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-LB")
    FT_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC-DEG_F")
    TON_SHORT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-DEG_F")
    KiloCAL_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM-SEC-DEG_C")
    MilliL_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR")
    unit = URIRef("http://qudt.org/vocab/unit")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-GM")
    MilliGM_PER_L_POISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-POISE")
    MicroMHO = URIRef("http://qudt.org/vocab/unit/MicroMHO")
    TON_Metric_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY-BAR")
    DecaC = URIRef("http://qudt.org/vocab/unit/DecaC")
    TONNE_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC-K")
    MilliGM_SEC_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L-M3")
    TON_Metric = URIRef("http://qudt.org/vocab/unit/TON_Metric")
    CP = URIRef("http://qudt.org/vocab/unit/CP")
    MicroJ = URIRef("http://qudt.org/vocab/unit/MicroJ")
    BTU_IT = URIRef("http://qudt.org/vocab/unit/BTU_IT")
    TeraFLOPS = URIRef("http://qudt.org/vocab/unit/TeraFLOPS")
    MilliL_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-K")
    MegaPA_M0dot5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0dot5")
    MilliM3_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-GM")
    KiloM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-HR")
    LM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LM-PER-FT2")
    ONE_PER_ONE = URIRef("http://qudt.org/vocab/unit/ONE-PER-ONE")
    FARAD_Ab = URIRef("http://qudt.org/vocab/unit/FARAD_Ab")
    PA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-BAR")
    KiloMOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-MIN")
    KiloCAL_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM-DEG_C")
    DYN_SEC_PER_CentiM5 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM5")
    NanoS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/NanoS-PER-CentiM")
    V_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/V-SEC-PER-M")
    EV_PER_M = URIRef("http://qudt.org/vocab/unit/EV-PER-M")
    TONNE_PER_MO = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MO")
    MilliM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-BAR")
    GM_PER_MilliM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM-BAR")
    KiloW_PER_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M-DEG_C")
    V_Ab_SEC = URIRef("http://qudt.org/vocab/unit/V_Ab-SEC")
    KiloN = URIRef("http://qudt.org/vocab/unit/KiloN")
    MegaHZ = URIRef("http://qudt.org/vocab/unit/MegaHZ")
    GAL_IMP = URIRef("http://qudt.org/vocab/unit/GAL_IMP")
    TON_Metric_PER_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-K")
    BTU_TH_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-HR-DEG_F")
    YD_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD-PER-SEC")
    CentiMOL = URIRef("http://qudt.org/vocab/unit/CentiMOL")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    PA2_SEC = URIRef("http://qudt.org/vocab/unit/PA2-SEC")
    BTU_IT_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC-DEG_F")
    GM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM")
    CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-GM")
    CentiM3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-K")
    MicroN_M = URIRef("http://qudt.org/vocab/unit/MicroN-M")
    PSI = URIRef("http://qudt.org/vocab/unit/PSI")
    WK = URIRef("http://qudt.org/vocab/unit/WK")
    BTU_IT_PER_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL-DEG_F")
    LB_HR_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-IN3")
    LB_PER_IN3_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3-PSI")
    MegaOHM = URIRef("http://qudt.org/vocab/unit/MegaOHM")
    C_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM-SEC")
    MegaL = URIRef("http://qudt.org/vocab/unit/MegaL")
    MegaHZ_M = URIRef("http://qudt.org/vocab/unit/MegaHZ-M")
    BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN")
    KiloJ_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MOL")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    PINT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-MIN")
    MilliM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-M3")
    PicoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-KiloGM")
    FRACTION = URIRef("http://qudt.org/vocab/unit/FRACTION")
    N_PER_A = URIRef("http://qudt.org/vocab/unit/N-PER-A")
    Denier = URIRef("http://qudt.org/vocab/unit/Denier")
    YD2 = URIRef("http://qudt.org/vocab/unit/YD2")
    PA_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC2")
    M3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC2")
    MilliMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-L")
    PK_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-SEC")
    W_PER_M2_K4 = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K4")
    K_PER_T = URIRef("http://qudt.org/vocab/unit/K-PER-T")
    SLUG_PER_HR = URIRef("http://qudt.org/vocab/unit/SLUG-PER-HR")
    DEGREE_API = URIRef("http://qudt.org/vocab/unit/DEGREE_API")
    GigaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-SEC")
    M2_PER_N = URIRef("http://qudt.org/vocab/unit/M2-PER-N")
    PARSEC = URIRef("http://qudt.org/vocab/unit/PARSEC")
    LB_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_UK")
    KiloN = URIRef("http://qudt.org/vocab/unit/KiloN")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    Debye = URIRef("http://qudt.org/vocab/unit/Debye")
    BTU_IT_FT = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT")
    PicoL = URIRef("http://qudt.org/vocab/unit/PicoL")
    PSI_YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-YD3-PER-SEC")
    IN_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-DEG_F")
    PSI_PER_PSI = URIRef("http://qudt.org/vocab/unit/PSI-PER-PSI")
    MilliCi = URIRef("http://qudt.org/vocab/unit/MilliCi")
    M2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2")
    MilliGM_HR_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M3-CentiM3")
    MilliGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-K")
    CentiM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC")
    EV = URIRef("http://qudt.org/vocab/unit/EV")
    YD3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD3-PER-DEG_F")
    DEG_F_HR_FT2_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH")
    DEATHS_PER_MegaINDIV_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-MegaINDIV-YR")
    KiloCAL_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM-DEG_C")
    MDOLLAR_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MDOLLAR-PER-FLIGHT")
    MilliGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-K")
    M4_PER_SEC = URIRef("http://qudt.org/vocab/unit/M4-PER-SEC")
    J_PER_KiloGM_K_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-M3")
    KiloOHM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-M")
    BTU_IT_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-IN2-SEC")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    MicroM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-M3")
    KiloGAUSS = URIRef("http://qudt.org/vocab/unit/KiloGAUSS")
    CentiN_M = URIRef("http://qudt.org/vocab/unit/CentiN-M")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN3-PER-SEC")
    C3_M_PER_J2 = URIRef("http://qudt.org/vocab/unit/C3-M-PER-J2")
    G = URIRef("http://qudt.org/vocab/unit/G")
    N_M_PER_A = URIRef("http://qudt.org/vocab/unit/N-M-PER-A")
    AT_PER_M = URIRef("http://qudt.org/vocab/unit/AT-PER-M")
    KiloLB_F_FT_PER_A = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-A")
    ExbiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M2")
    ONE_PER_ONE = URIRef("http://qudt.org/vocab/unit/ONE-PER-ONE")
    IN_HG_60DEG_F = URIRef("http://qudt.org/vocab/unit/IN_HG_60DEG_F")
    L_PER_MIN = URIRef("http://qudt.org/vocab/unit/L-PER-MIN")
    GI_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-DAY")
    DeciB_M = URIRef("http://qudt.org/vocab/unit/DeciB_M")
    CAL_IT = URIRef("http://qudt.org/vocab/unit/CAL_IT")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    V_Ab_SEC = URIRef("http://qudt.org/vocab/unit/V_Ab-SEC")
    M3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM")
    K_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-M-PER-SEC")
    PER_WB = URIRef("http://qudt.org/vocab/unit/PER-WB")
    GM_PER_DeciM3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3-K")
    EUR_PER_W_HR = URIRef("http://qudt.org/vocab/unit/EUR-PER-W-HR")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    MegaPA_PER_K = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-K")
    DeciM = URIRef("http://qudt.org/vocab/unit/DeciM")
    KiloGM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-BAR")
    OZ_MIN_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-FT3")
    IN3 = URIRef("http://qudt.org/vocab/unit/IN3")
    MicroGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-KiloGM")
    MicroGRAY = URIRef("http://qudt.org/vocab/unit/MicroGRAY")
    GM_MIN_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L-M3")
    J = URIRef("http://qudt.org/vocab/unit/J")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    J_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2")
    BFT = URIRef("http://qudt.org/vocab/unit/BFT")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    CentiM4 = URIRef("http://qudt.org/vocab/unit/CentiM4")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    KIP_F = URIRef("http://qudt.org/vocab/unit/KIP_F")
    NanoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/NanoFARAD-PER-M")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    MicroM_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/MicroM-PER-L-DAY")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    C3_M_PER_J2 = URIRef("http://qudt.org/vocab/unit/C3-M-PER-J2")
    BBL_US_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-SEC")
    W_PER_IN2 = URIRef("http://qudt.org/vocab/unit/W-PER-IN2")
    FT_LB_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-SEC")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    KIP_F = URIRef("http://qudt.org/vocab/unit/KIP_F")
    BTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2")
    AttoJ_SEC = URIRef("http://qudt.org/vocab/unit/AttoJ-SEC")
    PER_J_M3 = URIRef("http://qudt.org/vocab/unit/PER-J-M3")
    BU_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-HR")
    KiloGM_PER_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA")
    MilliMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-GM")
    PA_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC")
    GRAIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL_US")
    LB_MIN_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT6")
    LUX_HR = URIRef("http://qudt.org/vocab/unit/LUX-HR")
    FemtoC = URIRef("http://qudt.org/vocab/unit/FemtoC")
    V_Stat = URIRef("http://qudt.org/vocab/unit/V_Stat")
    H_Ab = URIRef("http://qudt.org/vocab/unit/H_Ab")
    E_h = URIRef("http://qudt.org/vocab/unit/E_h")
    CAL_TH_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-DEG_C")
    MOL_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-DeciM3")
    RAD_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-KiloGM")
    PicoC = URIRef("http://qudt.org/vocab/unit/PicoC")
    V = URIRef("http://qudt.org/vocab/unit/V")
    V = URIRef("http://qudt.org/vocab/unit/V")
    W_PER_M_DEG_C = URIRef("http://qudt.org/vocab/unit/W-PER-M-DEG_C")
    EV_PER_T = URIRef("http://qudt.org/vocab/unit/EV-PER-T")
    KiloGM_PER_KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloMOL")
    J_PER_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-DAY")
    LB_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN2")
    LB_PER_FT = URIRef("http://qudt.org/vocab/unit/LB-PER-FT")
    KiloGM_PER_DeciM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-K")
    M4 = URIRef("http://qudt.org/vocab/unit/M4")
    PERMEABILITY_EM_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_EM_REL")
    PSI_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-L-PER-SEC")
    MegaBIT = URIRef("http://qudt.org/vocab/unit/MegaBIT")
    TON_US_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_US-PER-YD3")
    W_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-PER-M3")
    MicroMOL_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-HR")
    DeciM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MOL")
    LB_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_US")
    N_CentiM = URIRef("http://qudt.org/vocab/unit/N-CentiM")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    NanoSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-SEC")
    BTU_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-MIN")
    A_PER_RAD = URIRef("http://qudt.org/vocab/unit/A-PER-RAD")
    GigaPA_CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/GigaPA-CentiM3-PER-GM")
    PER_MilliL = URIRef("http://qudt.org/vocab/unit/PER-MilliL")
    NanoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MilliL")
    ATM_T_PER_M = URIRef("http://qudt.org/vocab/unit/ATM_T-PER-M")
    MicroGM_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L-HR")
    BTU_TH_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB")
    KiloMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3")
    CAL_IT_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM2-K")
    KiloA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloA-PER-K")
    MegaBQ = URIRef("http://qudt.org/vocab/unit/MegaBQ")
    FT3_PER_HR = URIRef("http://qudt.org/vocab/unit/FT3-PER-HR")
    MilliGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-BAR")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    LB_F_FT_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-FT-PER-IN")
    V_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-PER-CentiM")
    LunarMass = URIRef("http://qudt.org/vocab/unit/LunarMass")
    MilliL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M3")
    CAL_TH = URIRef("http://qudt.org/vocab/unit/CAL_TH")
    DEGREE_API = URIRef("http://qudt.org/vocab/unit/DEGREE_API")
    CAL_15_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_15_DEG_C")
    BTU_IT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MIN")
    SHANNON_PER_SEC = URIRef("http://qudt.org/vocab/unit/SHANNON-PER-SEC")
    TONNE_PER_HA_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA-YR")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    DeciM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MIN")
    C_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM2")
    MilliGM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR")
    PlanckMomentum = URIRef("http://qudt.org/vocab/unit/PlanckMomentum")
    GM_SEC_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L2")
    MegaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-HR")
    LB_HR_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-YD3")
    A_Stat = URIRef("http://qudt.org/vocab/unit/A_Stat")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    PicoPA = URIRef("http://qudt.org/vocab/unit/PicoPA")
    MilliSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-HR")
    GM_HR_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M3-L")
    CentiM_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-K")
    MegaBAUD = URIRef("http://qudt.org/vocab/unit/MegaBAUD")
    CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-SEC")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    MegaHZ_M = URIRef("http://qudt.org/vocab/unit/MegaHZ-M")
    DEG_F_HR_FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT-IN")
    N_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-PER-KiloGM")
    QUAD = URIRef("http://qudt.org/vocab/unit/QUAD")
    POISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/POISE-PER-BAR")
    FT3_PER_HR = URIRef("http://qudt.org/vocab/unit/FT3-PER-HR")
    LB_F_PER_IN2_DEG_F = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-DEG_F")
    MilliGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-CentiM2")
    MOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3")
    TON_Metric_PER_MIN = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN")
    C_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM3")
    IN = URIRef("http://qudt.org/vocab/unit/IN")
    ANGSTROM3 = URIRef("http://qudt.org/vocab/unit/ANGSTROM3")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    OZ_VOL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-HR")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    OZ_HR_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN6")
    LB_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-MOL-DEG_F")
    T_Ab = URIRef("http://qudt.org/vocab/unit/T_Ab")
    PlanckVolt = URIRef("http://qudt.org/vocab/unit/PlanckVolt")
    KiloSEC = URIRef("http://qudt.org/vocab/unit/KiloSEC")
    PERCENT_PER_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MilliPA-SEC")
    FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC")
    KiloW_PER_M_K = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M-K")
    LB_F_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN")
    NUM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NUM-PER-M3")
    PERCENT_PER_KiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-KiloCount")
    MicroGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-MIN")
    OZ_VOL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-HR")
    MilliC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M2")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    DecaM = URIRef("http://qudt.org/vocab/unit/DecaM")
    NUM_PER_L = URIRef("http://qudt.org/vocab/unit/NUM-PER-L")
    MilliC = URIRef("http://qudt.org/vocab/unit/MilliC")
    GM_PER_M2 = URIRef("http://qudt.org/vocab/unit/GM-PER-M2")
    LB_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_UK")
    KiloM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-HR")
    N = URIRef("http://qudt.org/vocab/unit/N")
    FT_PER_PSI = URIRef("http://qudt.org/vocab/unit/FT-PER-PSI")
    IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    GAL_US_DRY = URIRef("http://qudt.org/vocab/unit/GAL_US_DRY")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    KAT_PER_L = URIRef("http://qudt.org/vocab/unit/KAT-PER-L")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    M3_PER_MIN = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN")
    BTU_IT_PER_HR_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2")
    MilliA_IN2_PER_LB_F = URIRef("http://qudt.org/vocab/unit/MilliA-IN2-PER-LB_F")
    TON_Metric_PER_SEC = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC")
    KiloGM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC2")
    PHOT = URIRef("http://qudt.org/vocab/unit/PHOT")
    KiloGM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-BAR")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    FemtoM = URIRef("http://qudt.org/vocab/unit/FemtoM")
    CentiPOISE = URIRef("http://qudt.org/vocab/unit/CentiPOISE")
    BU_US = URIRef("http://qudt.org/vocab/unit/BU_US")
    PA_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PA-M2-PER-KiloGM")
    TON_SHIPPING_US = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_US")
    NUM_PER_M = URIRef("http://qudt.org/vocab/unit/NUM-PER-M")
    CentiM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN")
    GRAIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-M3")
    SEC_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-FT2")
    FT_LB_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-MIN")
    PA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-BAR")
    DEG_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-MIN")
    FemtoGM_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-L")
    PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PER-M3-SEC")
    A_Ab = URIRef("http://qudt.org/vocab/unit/A_Ab")
    N_PER_C = URIRef("http://qudt.org/vocab/unit/N-PER-C")
    SLUG = URIRef("http://qudt.org/vocab/unit/SLUG")
    M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/M2-PER-MOL")
    FT_H2O = URIRef("http://qudt.org/vocab/unit/FT_H2O")
    MicroT = URIRef("http://qudt.org/vocab/unit/MicroT")
    PSI = URIRef("http://qudt.org/vocab/unit/PSI")
    CAL_15_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_15_DEG_C")
    DEGREE_OECHSLE = URIRef("http://qudt.org/vocab/unit/DEGREE_OECHSLE")
    MilliFARAD = URIRef("http://qudt.org/vocab/unit/MilliFARAD")
    KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloGM-K")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    ERG = URIRef("http://qudt.org/vocab/unit/ERG")
    NanoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MilliL")
    W = URIRef("http://qudt.org/vocab/unit/W")
    M3_PER_C = URIRef("http://qudt.org/vocab/unit/M3-PER-C")
    NUM_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/NUM-PER-MilliGM")
    GM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-K")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    M3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC2")
    BBL_US_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-HR")
    LB_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC-PSI")
    MilliGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-MIN")
    MegaEV_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-CentiM")
    PK_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-MIN")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    LB_SEC_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT6")
    N_M2_PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/N-M2-PER-KiloGM2")
    SLUG_PER_DAY = URIRef("http://qudt.org/vocab/unit/SLUG-PER-DAY")
    BTU_IT_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_F")
    MilliA_IN2_PER_LB_F = URIRef("http://qudt.org/vocab/unit/MilliA-IN2-PER-LB_F")
    KiloBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-HR")
    PicoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/PicoKAT-PER-L")
    GigaBQ = URIRef("http://qudt.org/vocab/unit/GigaBQ")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    GigaEV = URIRef("http://qudt.org/vocab/unit/GigaEV")
    LB_MIN_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-YD3")
    PicoPA = URIRef("http://qudt.org/vocab/unit/PicoPA")
    PK_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-SEC")
    ROD = URIRef("http://qudt.org/vocab/unit/ROD")
    GM_PER_L_CentiPOISE = URIRef("http://qudt.org/vocab/unit/GM-PER-L-CentiPOISE")
    GI_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-MIN")
    EV = URIRef("http://qudt.org/vocab/unit/EV")
    PER_MilliGM = URIRef("http://qudt.org/vocab/unit/PER-MilliGM")
    CentiM2_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-CentiM3")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    QT_US = URIRef("http://qudt.org/vocab/unit/QT_US")
    KiloGM_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-YR")
    DYN_SEC_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM")
    FT_PDL = URIRef("http://qudt.org/vocab/unit/FT-PDL")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    MicroH_PER_M = URIRef("http://qudt.org/vocab/unit/MicroH-PER-M")
    DYN_M = URIRef("http://qudt.org/vocab/unit/DYN-M")
    EUR_PER_W_HR = URIRef("http://qudt.org/vocab/unit/EUR-PER-W-HR")
    KiloHZ = URIRef("http://qudt.org/vocab/unit/KiloHZ")
    CD_PER_M2 = URIRef("http://qudt.org/vocab/unit/CD-PER-M2")
    KiloJ = URIRef("http://qudt.org/vocab/unit/KiloJ")
    SAMPLE_PER_SEC = URIRef("http://qudt.org/vocab/unit/SAMPLE-PER-SEC")
    LB_HR_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK2")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    MilliGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC")
    DYN_M = URIRef("http://qudt.org/vocab/unit/DYN-M")
    KiloGM_F_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-SEC")
    GI_UK = URIRef("http://qudt.org/vocab/unit/GI_UK")
    GM = URIRef("http://qudt.org/vocab/unit/GM")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloGM-K")
    TeraFLOPS = URIRef("http://qudt.org/vocab/unit/TeraFLOPS")
    J_PER_SEC = URIRef("http://qudt.org/vocab/unit/J-PER-SEC")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    GI_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_US-PER-MIN")
    S = URIRef("http://qudt.org/vocab/unit/S")
    MebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M3")
    GM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN-BAR")
    DYN_SEC_PER_CentiM5 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM5")
    FT_SEC_PER_IN3 = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-IN3")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    M_PER_PA = URIRef("http://qudt.org/vocab/unit/M-PER-PA")
    MicroH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-OHM")
    KiloW_PER_M_K = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M-K")
    J_PER_HR = URIRef("http://qudt.org/vocab/unit/J-PER-HR")
    GRAIN_PER_GAL = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL")
    MicroM3_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-MilliL")
    H_PER_M = URIRef("http://qudt.org/vocab/unit/H-PER-M")
    PERCENT_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-M3")
    MilliMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-KiloGM")
    M2_SR = URIRef("http://qudt.org/vocab/unit/M2-SR")
    BREATH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BREATH-PER-MIN")
    KiloGM_PER_DeciM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-K")
    OZ = URIRef("http://qudt.org/vocab/unit/OZ")
    MilliRAD_R = URIRef("http://qudt.org/vocab/unit/MilliRAD_R")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    PER_IN3 = URIRef("http://qudt.org/vocab/unit/PER-IN3")
    KiloGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC")
    KiloGM_M = URIRef("http://qudt.org/vocab/unit/KiloGM-M")
    PicoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-MilliL")
    CentiM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN")
    J_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K")
    YR_TROPICAL = URIRef("http://qudt.org/vocab/unit/YR_TROPICAL")
    GM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-M2-DAY")
    GigaC = URIRef("http://qudt.org/vocab/unit/GigaC")
    BTU_IT_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_F")
    MicroV_A_PER_K = URIRef("http://qudt.org/vocab/unit/MicroV-A-PER-K")
    DEG_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG-PER-MIN")
    PA_M0dot5 = URIRef("http://qudt.org/vocab/unit/PA-M0dot5")
    N = URIRef("http://qudt.org/vocab/unit/N")
    BTU_IT_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC")
    MilliK_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliK-PER-BAR")
    W_PER_SR = URIRef("http://qudt.org/vocab/unit/W-PER-SR")
    LB_MIN_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US2")
    TON_LONG_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_LONG-PER-YD3")
    DEGREE_BRIX = URIRef("http://qudt.org/vocab/unit/DEGREE_BRIX")
    BTU_TH_FT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-HR-FT2-DEG_F")
    EUR_PER_W = URIRef("http://qudt.org/vocab/unit/EUR-PER-W")
    N_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-PER-M3")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    KiloGM_M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M2-PER-SEC")
    CentiM3_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-K")
    PT_BIG = URIRef("http://qudt.org/vocab/unit/PT_BIG")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    MX = URIRef("http://qudt.org/vocab/unit/MX")
    L_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-K")
    OHM_M2_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-M2-PER-M")
    FT4 = URIRef("http://qudt.org/vocab/unit/FT4")
    N = URIRef("http://qudt.org/vocab/unit/N")
    MilliM2 = URIRef("http://qudt.org/vocab/unit/MilliM2")
    LB_SEC_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-GAL_US")
    M = URIRef("http://qudt.org/vocab/unit/M")
    ST_PER_PA = URIRef("http://qudt.org/vocab/unit/ST-PER-PA")
    CAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC")
    K = URIRef("http://qudt.org/vocab/unit/K")
    ExbiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M")
    KiloGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-BAR")
    Gamma = URIRef("http://qudt.org/vocab/unit/Gamma")
    PERCENT_PER_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MilliPA-SEC")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    FemtoL = URIRef("http://qudt.org/vocab/unit/FemtoL")
    KiloV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive-HR")
    A_PER_RAD = URIRef("http://qudt.org/vocab/unit/A-PER-RAD")
    MicroMOL_PER_MicroMOL_DAY = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MicroMOL-DAY")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    YD3_PER_PSI = URIRef("http://qudt.org/vocab/unit/YD3-PER-PSI")
    PetaHZ = URIRef("http://qudt.org/vocab/unit/PetaHZ")
    KiloPA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-K")
    FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F")
    GigaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-SEC")
    MegaJ = URIRef("http://qudt.org/vocab/unit/MegaJ")
    MilliGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    MilliN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliN-M-PER-M2")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    OHM_Stat = URIRef("http://qudt.org/vocab/unit/OHM_Stat")
    FemtoV = URIRef("http://qudt.org/vocab/unit/FemtoV")
    TON_SHIPPING_US = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_US")
    KY = URIRef("http://qudt.org/vocab/unit/KY")
    PA_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC")
    TONNE_PER_HA_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA-YR")
    S = URIRef("http://qudt.org/vocab/unit/S")
    EV_SEC = URIRef("http://qudt.org/vocab/unit/EV-SEC")
    V_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Ab-PER-CentiM")
    MicroGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-HR")
    AC_FT = URIRef("http://qudt.org/vocab/unit/AC-FT")
    MicroN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroN-M-PER-M2")
    PA_M0pt5 = URIRef("http://qudt.org/vocab/unit/PA-M0pt5")
    STILB = URIRef("http://qudt.org/vocab/unit/STILB")
    KiloGM_PER_M2_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC2")
    BTU_IT_IN_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-HR-FT2-DEG_F")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    LB_HR_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT6")
    MicroC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M2")
    MilliBAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-BAR")
    TONNE_PER_HA = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA")
    WB_M = URIRef("http://qudt.org/vocab/unit/WB-M")
    CentiN_M = URIRef("http://qudt.org/vocab/unit/CentiN-M")
    MOL_PER_KiloGM_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-BAR")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    LB_FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT-PER-SEC")
    L_PER_DAY = URIRef("http://qudt.org/vocab/unit/L-PER-DAY")
    TeraOHM = URIRef("http://qudt.org/vocab/unit/TeraOHM")
    Gs = URIRef("http://qudt.org/vocab/unit/Gs")
    LB_HR_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-IN3")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    N_PER_C = URIRef("http://qudt.org/vocab/unit/N-PER-C")
    OZ_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_US")
    V_Ab_SEC = URIRef("http://qudt.org/vocab/unit/V_Ab-SEC")
    LUX_HR = URIRef("http://qudt.org/vocab/unit/LUX-HR")
    MilliR_man = URIRef("http://qudt.org/vocab/unit/MilliR_man")
    GM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciL")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    LB_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_US")
    MilliM_HGA = URIRef("http://qudt.org/vocab/unit/MilliM_HGA")
    PERCENT_MIN_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-GAL_UK")
    PER_J_M3 = URIRef("http://qudt.org/vocab/unit/PER-J-M3")
    M2_PER_KiloW = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloW")
    LB_MOL = URIRef("http://qudt.org/vocab/unit/LB-MOL")
    MI_US_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/MI_US-PER-SEC2")
    KiloGM_PER_J = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-J")
    MegaPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-M3-PER-SEC")
    SPF = URIRef("http://qudt.org/vocab/unit/SPF")
    PetaA = URIRef("http://qudt.org/vocab/unit/PetaA")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    A_MIN = URIRef("http://qudt.org/vocab/unit/A-MIN")
    PER_IN = URIRef("http://qudt.org/vocab/unit/PER-IN")
    BU_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-MIN")
    LB_PER_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-HR")
    FBM = URIRef("http://qudt.org/vocab/unit/FBM")
    PicoJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/PicoJ-PER-SEC")
    PER_H = URIRef("http://qudt.org/vocab/unit/PER-H")
    C3_M_PER_J2 = URIRef("http://qudt.org/vocab/unit/C3-M-PER-J2")
    OZ_VOL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-MIN")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    ATM = URIRef("http://qudt.org/vocab/unit/ATM")
    NanoSEC = URIRef("http://qudt.org/vocab/unit/NanoSEC")
    MilliGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MilliL")
    GAL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-DAY")
    TON_Metric_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY")
    BTU_IT_PER_HR_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_R")
    GM_PER_L_POISE = URIRef("http://qudt.org/vocab/unit/GM-PER-L-POISE")
    DeciM = URIRef("http://qudt.org/vocab/unit/DeciM")
    DecaM = URIRef("http://qudt.org/vocab/unit/DecaM")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    MilliM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-KiloGM")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    MegaPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-BAR")
    GM_PER_M3_PA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-PA-SEC")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    TONNE = URIRef("http://qudt.org/vocab/unit/TONNE")
    A_PER_K = URIRef("http://qudt.org/vocab/unit/A-PER-K")
    V_PER_SEC = URIRef("http://qudt.org/vocab/unit/V-PER-SEC")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    Ci = URIRef("http://qudt.org/vocab/unit/Ci")
    W_PER_SR_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-SR-M2")
    FM = URIRef("http://qudt.org/vocab/unit/FM")
    TeraJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/TeraJ-PER-SEC")
    BTU_IT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MIN")
    ERG = URIRef("http://qudt.org/vocab/unit/ERG")
    KiloGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-BAR")
    W = URIRef("http://qudt.org/vocab/unit/W")
    KiloGM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM-PER-SEC")
    GM_PER_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-BAR")
    KiloGM_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC2")
    MilliM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliM-PER-M")
    ERG_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM2-SEC")
    TeraHZ = URIRef("http://qudt.org/vocab/unit/TeraHZ")
    IN_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC2")
    KibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M2")
    MegaS_PER_M = URIRef("http://qudt.org/vocab/unit/MegaS-PER-M")
    PT_BIG = URIRef("http://qudt.org/vocab/unit/PT_BIG")
    DeciL = URIRef("http://qudt.org/vocab/unit/DeciL")
    J = URIRef("http://qudt.org/vocab/unit/J")
    TON_Metric_PER_HA = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HA")
    PPM = URIRef("http://qudt.org/vocab/unit/PPM")
    PDL_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/PDL-SEC-PER-IN2")
    GM_MIN_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M6")
    OHM_PER_MI = URIRef("http://qudt.org/vocab/unit/OHM-PER-MI")
    CD_PER_M2 = URIRef("http://qudt.org/vocab/unit/CD-PER-M2")
    KiloCAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-MIN")
    PER_SR = URIRef("http://qudt.org/vocab/unit/PER-SR")
    CAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-MIN")
    TON_Metric_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR-BAR")
    CentiMOL_PER_L = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-L")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    V_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/V-SEC-PER-M")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    MegaA_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaA-PER-M2")
    MilliA_PER_K = URIRef("http://qudt.org/vocab/unit/MilliA-PER-K")
    GI_US = URIRef("http://qudt.org/vocab/unit/GI_US")
    CentiM3_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-CentiM3")
    PDL_FT = URIRef("http://qudt.org/vocab/unit/PDL-FT")
    PDL_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-FT2")
    LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    MilliTORR = URIRef("http://qudt.org/vocab/unit/MilliTORR")
    C4_M4_PER_J3 = URIRef("http://qudt.org/vocab/unit/C4-M4-PER-J3")
    REM = URIRef("http://qudt.org/vocab/unit/REM")
    S_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/S-M2-PER-MOL")
    J = URIRef("http://qudt.org/vocab/unit/J")
    J_PER_GM_K = URIRef("http://qudt.org/vocab/unit/J-PER-GM-K")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/M2-PER-MOL")
    M3_PER_C = URIRef("http://qudt.org/vocab/unit/M3-PER-C")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/PER-KiloGM2")
    M_PER_DEG_C_M = URIRef("http://qudt.org/vocab/unit/M-PER-DEG_C-M")
    GigaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-HR")
    MicroL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroL-PER-L")
    CentiM_H2O = URIRef("http://qudt.org/vocab/unit/CentiM_H2O")
    DEG_C_KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/DEG_C-KiloGM-PER-M2")
    MegaPA_M0dot5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0dot5")
    A_M2 = URIRef("http://qudt.org/vocab/unit/A-M2")
    C_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM3")
    OZ_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_US")
    PicoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-MilliL")
    MegaPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-M3-PER-SEC")
    TON_Metric_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC-BAR")
    MilliA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliA-PER-BAR")
    MIN_Angle = URIRef("http://qudt.org/vocab/unit/MIN_Angle")
    ANGSTROM3 = URIRef("http://qudt.org/vocab/unit/ANGSTROM3")
    CARAT = URIRef("http://qudt.org/vocab/unit/CARAT")
    A_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/A-PER-KiloGM")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    MilliM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliM-PER-MIN")
    IU_PER_L = URIRef("http://qudt.org/vocab/unit/IU-PER-L")
    GM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR-BAR")
    KiloGM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-K")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    IU_PER_L = URIRef("http://qudt.org/vocab/unit/IU-PER-L")
    GM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloGM")
    TON_SHORT_PER_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR-DEG_F")
    NanoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MilliL")
    OZ_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ-PER-DAY")
    PetaV_A = URIRef("http://qudt.org/vocab/unit/PetaV-A")
    DRAM_US = URIRef("http://qudt.org/vocab/unit/DRAM_US")
    GigaPA = URIRef("http://qudt.org/vocab/unit/GigaPA")
    KiloGRAY = URIRef("http://qudt.org/vocab/unit/KiloGRAY")
    GigaPA_CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/GigaPA-CentiM3-PER-GM")
    LB_MIN_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-YD3")
    MegaN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaN-M-PER-M2")
    SolarMass = URIRef("http://qudt.org/vocab/unit/SolarMass")
    MicroM_PER_N = URIRef("http://qudt.org/vocab/unit/MicroM-PER-N")
    KiloGM_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-MilliM2")
    MegaA = URIRef("http://qudt.org/vocab/unit/MegaA")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    Kilo_FT3 = URIRef("http://qudt.org/vocab/unit/Kilo-FT3")
    MilliMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-GM")
    KiloCAL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-SEC")
    PER_GM = URIRef("http://qudt.org/vocab/unit/PER-GM")
    NanoM = URIRef("http://qudt.org/vocab/unit/NanoM")
    TON_SHORT = URIRef("http://qudt.org/vocab/unit/TON_SHORT")
    HectoL = URIRef("http://qudt.org/vocab/unit/HectoL")
    W = URIRef("http://qudt.org/vocab/unit/W")
    EV = URIRef("http://qudt.org/vocab/unit/EV")
    NanoGM_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2-DAY")
    MicroS = URIRef("http://qudt.org/vocab/unit/MicroS")
    PA_SEC_PER_L = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-L")
    DEGREE_API = URIRef("http://qudt.org/vocab/unit/DEGREE_API")
    DEGREE_BALLING = URIRef("http://qudt.org/vocab/unit/DEGREE_BALLING")
    MegaV = URIRef("http://qudt.org/vocab/unit/MegaV")
    NanoFARAD = URIRef("http://qudt.org/vocab/unit/NanoFARAD")
    PK_UK = URIRef("http://qudt.org/vocab/unit/PK_UK")
    MicroCi = URIRef("http://qudt.org/vocab/unit/MicroCi")
    LB_MIN_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-FT3")
    MicroPA = URIRef("http://qudt.org/vocab/unit/MicroPA")
    MicroS = URIRef("http://qudt.org/vocab/unit/MicroS")
    MicroMOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-SEC")
    A_SEC = URIRef("http://qudt.org/vocab/unit/A-SEC")
    MilliM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC")
    OZ_VOL_US = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US")
    KiloJ = URIRef("http://qudt.org/vocab/unit/KiloJ")
    LB_MIN_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-FT3")
    MilliA = URIRef("http://qudt.org/vocab/unit/MilliA")
    DEG_C_PER_M = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-M")
    MegaBAUD = URIRef("http://qudt.org/vocab/unit/MegaBAUD")
    PINT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-HR")
    PicoGM = URIRef("http://qudt.org/vocab/unit/PicoGM")
    OCTET = URIRef("http://qudt.org/vocab/unit/OCTET")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    PA_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC2")
    TON_Metric_PER_SEC = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC")
    SEC_PER_M = URIRef("http://qudt.org/vocab/unit/SEC-PER-M")
    A_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Stat-PER-CentiM2")
    IU_PER_MilliL = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliL")
    PINT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-DAY")
    PSI = URIRef("http://qudt.org/vocab/unit/PSI")
    PPT = URIRef("http://qudt.org/vocab/unit/PPT")
    BFT = URIRef("http://qudt.org/vocab/unit/BFT")
    HP_H2O = URIRef("http://qudt.org/vocab/unit/HP_H2O")
    MilliGM_MIN_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M6")
    MilliW = URIRef("http://qudt.org/vocab/unit/MilliW")
    GM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloGM")
    MegaL = URIRef("http://qudt.org/vocab/unit/MegaL")
    BARN_PER_SR = URIRef("http://qudt.org/vocab/unit/BARN-PER-SR")
    J_PER_T2 = URIRef("http://qudt.org/vocab/unit/J-PER-T2")
    CentiM3_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN-K")
    DecaPA = URIRef("http://qudt.org/vocab/unit/DecaPA")
    ATM_T = URIRef("http://qudt.org/vocab/unit/ATM_T")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    NanoM2 = URIRef("http://qudt.org/vocab/unit/NanoM2")
    PA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-BAR")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    GM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3-K")
    Z = URIRef("http://qudt.org/vocab/unit/Z")
    GibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M2")
    PlanckMomentum = URIRef("http://qudt.org/vocab/unit/PlanckMomentum")
    KiloN_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-DEG")
    PebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M3")
    CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3")
    MilliGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-SEC")
    PPTR = URIRef("http://qudt.org/vocab/unit/PPTR")
    FemtoL = URIRef("http://qudt.org/vocab/unit/FemtoL")
    YD3_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD3-PER-MIN")
    MegaOHM_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-M")
    KiloMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-SEC")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    GI_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_US-PER-HR")
    GM_PER_M = URIRef("http://qudt.org/vocab/unit/GM-PER-M")
    LB_SEC_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-YD3")
    NUM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NUM-PER-M3")
    BTU_IT_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT3")
    MegaW_HR = URIRef("http://qudt.org/vocab/unit/MegaW-HR")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    V_PER_V = URIRef("http://qudt.org/vocab/unit/V-PER-V")
    C_M2_PER_V = URIRef("http://qudt.org/vocab/unit/C-M2-PER-V")
    PERCENT_PER_KiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-KiloCount")
    KiloS = URIRef("http://qudt.org/vocab/unit/KiloS")
    PERCENT_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-CentiM3")
    PA_SEC_PER_L = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-L")
    NanoGM = URIRef("http://qudt.org/vocab/unit/NanoGM")
    TEX = URIRef("http://qudt.org/vocab/unit/TEX")
    K = URIRef("http://qudt.org/vocab/unit/K")
    LB_SEC_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-YD3")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    DARCY = URIRef("http://qudt.org/vocab/unit/DARCY")
    PDL = URIRef("http://qudt.org/vocab/unit/PDL")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    REM_PER_SEC = URIRef("http://qudt.org/vocab/unit/REM-PER-SEC")
    A_HR_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-HR-PER-DEG_C")
    TeraC = URIRef("http://qudt.org/vocab/unit/TeraC")
    Denier = URIRef("http://qudt.org/vocab/unit/Denier")
    E_h = URIRef("http://qudt.org/vocab/unit/E_h")
    MicroGM_PER_CentiM2_WK = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2-WK")
    FM = URIRef("http://qudt.org/vocab/unit/FM")
    PicoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/PicoW-PER-M2")
    IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC")
    R_PER_SEC = URIRef("http://qudt.org/vocab/unit/R-PER-SEC")
    KiloGM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC2")
    MACH = URIRef("http://qudt.org/vocab/unit/MACH")
    MilliM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM2-PER-SEC")
    M_PER_FARAD = URIRef("http://qudt.org/vocab/unit/M-PER-FARAD")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    MicroH = URIRef("http://qudt.org/vocab/unit/MicroH")
    CentiM_HG = URIRef("http://qudt.org/vocab/unit/CentiM_HG")
    W_PER_SR = URIRef("http://qudt.org/vocab/unit/W-PER-SR")
    MilliGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-BAR")
    LB_HR_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-YD3")
    DYN_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM")
    PER_BAR = URIRef("http://qudt.org/vocab/unit/PER-BAR")
    PlanckVolt = URIRef("http://qudt.org/vocab/unit/PlanckVolt")
    TON_UK_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-YD3")
    MOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2")
    LB_PER_FT_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-DAY")
    IN_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC2")
    TEX = URIRef("http://qudt.org/vocab/unit/TEX")
    GI_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-HR")
    LB_PER_FT3_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3-PSI")
    KiloPA_M2_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloPA-M2-PER-GM")
    MI_US2 = URIRef("http://qudt.org/vocab/unit/MI_US2")
    HectoL = URIRef("http://qudt.org/vocab/unit/HectoL")
    S = URIRef("http://qudt.org/vocab/unit/S")
    SolarMass = URIRef("http://qudt.org/vocab/unit/SolarMass")
    DEG_F_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-K")
    OZ_VOL_US = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    DeciB_M = URIRef("http://qudt.org/vocab/unit/DeciB_M")
    HectoPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-M3-PER-SEC")
    BTU_IT_IN_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-SEC-FT2-DEG_F")
    KiloP = URIRef("http://qudt.org/vocab/unit/KiloP")
    C_Ab = URIRef("http://qudt.org/vocab/unit/C_Ab")
    Hundredweight_US = URIRef("http://qudt.org/vocab/unit/Hundredweight_US")
    M3_PER_M3 = URIRef("http://qudt.org/vocab/unit/M3-PER-M3")
    MegaOHM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-KiloM")
    GM_PER_MilliL_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL-BAR")
    NanoMOL_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L-DAY")
    MilliGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-K")
    MilliG = URIRef("http://qudt.org/vocab/unit/MilliG")
    N_M_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-RAD")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    ARCSEC = URIRef("http://qudt.org/vocab/unit/ARCSEC")
    LB_MIN_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-YD3")
    MilliC = URIRef("http://qudt.org/vocab/unit/MilliC")
    GM_PER_K = URIRef("http://qudt.org/vocab/unit/GM-PER-K")
    A_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-PER-DEG_C")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    KiloGM_PER_L = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L")
    MilliW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2")
    BAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-L-PER-SEC")
    DecaL = URIRef("http://qudt.org/vocab/unit/DecaL")
    KiloBAR = URIRef("http://qudt.org/vocab/unit/KiloBAR")
    KiloJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-SEC")
    KiloGM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM2")
    KiloBIT = URIRef("http://qudt.org/vocab/unit/KiloBIT")
    MilliMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-GM")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    Pennyweight = URIRef("http://qudt.org/vocab/unit/Pennyweight")
    M5 = URIRef("http://qudt.org/vocab/unit/M5")
    OZ_SEC_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-GAL_US")
    PIXEL = URIRef("http://qudt.org/vocab/unit/PIXEL")
    MilliBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-L")
    MilliGM_PER_M3_POISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-POISE")
    MicroL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroL-PER-L")
    DEG_R_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-SEC")
    TON_F_US = URIRef("http://qudt.org/vocab/unit/TON_F_US")
    MI_US2 = URIRef("http://qudt.org/vocab/unit/MI_US2")
    LB_IN2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-IN3-LB_F-SEC")
    KiloMOL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-HR")
    PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2")
    K_M = URIRef("http://qudt.org/vocab/unit/K-M")
    MicroGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3")
    KiloCD = URIRef("http://qudt.org/vocab/unit/KiloCD")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    CentiM3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-BAR")
    MilliGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-SEC")
    PER_MilliL = URIRef("http://qudt.org/vocab/unit/PER-MilliL")
    W_PER_M2_K = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K")
    MicroH = URIRef("http://qudt.org/vocab/unit/MicroH")
    OHM_Ab = URIRef("http://qudt.org/vocab/unit/OHM_Ab")
    HectoL = URIRef("http://qudt.org/vocab/unit/HectoL")
    MilliM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC")
    FT_SEC_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-GAL_US")
    DEG_F_HR_FT2_PER_BTU_TH_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH-IN")
    H_PER_M = URIRef("http://qudt.org/vocab/unit/H-PER-M")
    PER_WK = URIRef("http://qudt.org/vocab/unit/PER-WK")
    SEC_PER_M = URIRef("http://qudt.org/vocab/unit/SEC-PER-M")
    PPTR = URIRef("http://qudt.org/vocab/unit/PPTR")
    TON_Metric_PER_HA = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HA")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    A_HR = URIRef("http://qudt.org/vocab/unit/A-HR")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    REM = URIRef("http://qudt.org/vocab/unit/REM")
    N_M_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-RAD")
    MilliW = URIRef("http://qudt.org/vocab/unit/MilliW")
    FT2_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT2-PER-SEC")
    DEG_PER_M = URIRef("http://qudt.org/vocab/unit/DEG-PER-M")
    K_PER_K = URIRef("http://qudt.org/vocab/unit/K-PER-K")
    NanoT = URIRef("http://qudt.org/vocab/unit/NanoT")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    PDL_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/PDL-SEC-PER-IN2")
    MilliM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliM-PER-MIN")
    TON_Metric_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR")
    V_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/V-A_Reactive-PER-K")
    LB_SEC_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN6")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    J_PER_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-DAY")
    ONE = URIRef("http://qudt.org/vocab/unit/ONE")
    H_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/H_Stat-PER-CentiM")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    LB_HR_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-FT3")
    FT_HG = URIRef("http://qudt.org/vocab/unit/FT_HG")
    L_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/L-PER-KiloGM")
    PER_SEC_M2_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2-SR")
    PSU = URIRef("http://qudt.org/vocab/unit/PSU")
    MilliGM_MIN_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L-M3")
    PDL_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-SEC-PER-FT2")
    GM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-L-BAR")
    A_Ab_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-CentiM2")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    PER_HR = URIRef("http://qudt.org/vocab/unit/PER-HR")
    MilliJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-M2")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    DeciTON_Metric = URIRef("http://qudt.org/vocab/unit/DeciTON_Metric")
    DEG_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG-PER-HR")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    PERCENT_MIN_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-L")
    CAL_TH_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM2-K")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    PER_M_SEC = URIRef("http://qudt.org/vocab/unit/PER-M-SEC")
    LB_SEC_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-IN3")
    DEGREE_BAUME_US_HEAVY = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_HEAVY")
    FUR = URIRef("http://qudt.org/vocab/unit/FUR")
    MilliPA = URIRef("http://qudt.org/vocab/unit/MilliPA")
    CAL_TH_PER_G = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-G")
    KiloJ_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MIN")
    MegaTONNE = URIRef("http://qudt.org/vocab/unit/MegaTONNE")
    MilliL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-SEC")
    MX = URIRef("http://qudt.org/vocab/unit/MX")
    OZ_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ-PER-DAY")
    LB_MIN_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-YD3")
    A_M2 = URIRef("http://qudt.org/vocab/unit/A-M2")
    KiloEV = URIRef("http://qudt.org/vocab/unit/KiloEV")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    LB_PER_FT_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-MIN")
    M_PER_YR = URIRef("http://qudt.org/vocab/unit/M-PER-YR")
    PERCENT_PER_CentiPOISE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-CentiPOISE")
    CAL_TH_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-K")
    NanoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/NanoKAT-PER-L")
    PER_YR = URIRef("http://qudt.org/vocab/unit/PER-YR")
    KiloGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-K")
    KiloMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3")
    KiloGM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3")
    MilliM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DAY")
    PA_M0dot5 = URIRef("http://qudt.org/vocab/unit/PA-M0dot5")
    KiloMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3")
    PERCENT_PER_CentiPOISE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-CentiPOISE")
    L_PER_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-SEC")
    CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-GM")
    KiloGM_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-M2")
    NanoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-KiloGM")
    MicroS = URIRef("http://qudt.org/vocab/unit/MicroS")
    TeraV_A = URIRef("http://qudt.org/vocab/unit/TeraV-A")
    LB_PER_FT3 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    CP = URIRef("http://qudt.org/vocab/unit/CP")
    W_PER_SR_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-SR-M2")
    MOL_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-DeciM3")
    FT_LB_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-SEC")
    FemtoC = URIRef("http://qudt.org/vocab/unit/FemtoC")
    LB_HR_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-GAL_US")
    M2_HR_DEG_C_PER_KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/M2-HR-DEG_C-PER-KiloCAL_IT")
    L_PER_HR = URIRef("http://qudt.org/vocab/unit/L-PER-HR")
    TON_LONG_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_LONG-PER-YD3")
    PA_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PA-M2-PER-KiloGM")
    L_PER_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-SEC")
    CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-GM")
    THM_US = URIRef("http://qudt.org/vocab/unit/THM_US")
    NanoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/NanoW-PER-M2")
    LB_MIN_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK2")
    GM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloM")
    FemtoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-KiloGM")
    MebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M")
    LB_PER_YD = URIRef("http://qudt.org/vocab/unit/LB-PER-YD")
    KiloOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-BAR")
    MicroH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-OHM")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    FT_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-PER-MIN")
    KiloM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloM-PER-DAY")
    A_HR = URIRef("http://qudt.org/vocab/unit/A-HR")
    BTU_IT_FT = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT")
    RAD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC2")
    PA2_SEC = URIRef("http://qudt.org/vocab/unit/PA2-SEC")
    BTU_TH_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR-FT2-DEG_F")
    NanoM2 = URIRef("http://qudt.org/vocab/unit/NanoM2")
    A_PER_MilliM = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM")
    TON_LONG_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_LONG-PER-YD3")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    FT2_HR_DEG_F_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F-PER-BTU_IT")
    PERCENT_HR_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-YD3")
    TON_Metric_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY")
    LB_IN2_PER_GAL_UK_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-GAL_UK-LB_F-SEC")
    MI = URIRef("http://qudt.org/vocab/unit/MI")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    PlanckDensity = URIRef("http://qudt.org/vocab/unit/PlanckDensity")
    MilliW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2")
    DecaPA = URIRef("http://qudt.org/vocab/unit/DecaPA")
    EV_PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/EV-PER-ANGSTROM")
    PlanckArea = URIRef("http://qudt.org/vocab/unit/PlanckArea")
    CentiPOISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-BAR")
    PPQ = URIRef("http://qudt.org/vocab/unit/PPQ")
    PINT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-HR")
    J_PER_T2 = URIRef("http://qudt.org/vocab/unit/J-PER-T2")
    HART = URIRef("http://qudt.org/vocab/unit/HART")
    TEX = URIRef("http://qudt.org/vocab/unit/TEX")
    S_Stat = URIRef("http://qudt.org/vocab/unit/S_Stat")
    KAT_PER_MicroL = URIRef("http://qudt.org/vocab/unit/KAT-PER-MicroL")
    OZ_PER_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD3")
    LB = URIRef("http://qudt.org/vocab/unit/LB")
    M_PER_K = URIRef("http://qudt.org/vocab/unit/M-PER-K")
    NanoGM = URIRef("http://qudt.org/vocab/unit/NanoGM")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    CARAT = URIRef("http://qudt.org/vocab/unit/CARAT")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    H = URIRef("http://qudt.org/vocab/unit/H")
    PER_IN = URIRef("http://qudt.org/vocab/unit/PER-IN")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    GRAIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL_US")
    A_PER_RAD = URIRef("http://qudt.org/vocab/unit/A-PER-RAD")
    PK_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-DAY")
    KiloGM_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-M2")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    BTU_IT_PER_SEC_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    PSU = URIRef("http://qudt.org/vocab/unit/PSU")
    MicroC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M3")
    MilliL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN")
    PER_MilliSEC = URIRef("http://qudt.org/vocab/unit/PER-MilliSEC")
    LB_SEC_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-FT3")
    KiloOHM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-M")
    KiloYR = URIRef("http://qudt.org/vocab/unit/KiloYR")
    M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/M2-PER-MOL")
    FBM = URIRef("http://qudt.org/vocab/unit/FBM")
    FemtoC = URIRef("http://qudt.org/vocab/unit/FemtoC")
    MilliM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliM-PER-MIN")
    HectoPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-BAR")
    KiloGM_PER_M_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC")
    A_SEC = URIRef("http://qudt.org/vocab/unit/A-SEC")
    OZ_F_IN = URIRef("http://qudt.org/vocab/unit/OZ_F-IN")
    PA_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-PER-BAR")
    TON_Metric_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY")
    PetaJ = URIRef("http://qudt.org/vocab/unit/PetaJ")
    J_PER_M3_K = URIRef("http://qudt.org/vocab/unit/J-PER-M3-K")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    KiloGM_F_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-SEC")
    KiloA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloA-PER-K")
    OZ_SEC_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-GAL_UK")
    PPTM = URIRef("http://qudt.org/vocab/unit/PPTM")
    TeraHZ = URIRef("http://qudt.org/vocab/unit/TeraHZ")
    SEC_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-FT2")
    IU_PER_L = URIRef("http://qudt.org/vocab/unit/IU-PER-L")
    TON_Metric_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN-K")
    KiloBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBYTE-PER-SEC")
    ST_PER_K = URIRef("http://qudt.org/vocab/unit/ST-PER-K")
    MicroFARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-KiloM")
    TONNE_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY-K")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    T_Ab = URIRef("http://qudt.org/vocab/unit/T_Ab")
    MicroMOL_PER_MicroMOL_DAY = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MicroMOL-DAY")
    M_K = URIRef("http://qudt.org/vocab/unit/M-K")
    DEGREE_API = URIRef("http://qudt.org/vocab/unit/DEGREE_API")
    PicoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-MilliL")
    DEG_F_HR_FT2_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT")
    MI_US_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/MI_US-PER-SEC2")
    N_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-PER-RAD")
    BBL_UK_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-SEC")
    PicoC = URIRef("http://qudt.org/vocab/unit/PicoC")
    YR_Common = URIRef("http://qudt.org/vocab/unit/YR_Common")
    KiloOHM_M = URIRef("http://qudt.org/vocab/unit/KiloOHM-M")
    DEG_F_HR_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_IT")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    FM = URIRef("http://qudt.org/vocab/unit/FM")
    NanoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-KiloGM")
    GRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/GRAY-PER-SEC")
    KiloS = URIRef("http://qudt.org/vocab/unit/KiloS")
    MilliGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3")
    MOL_PER_M3_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-PA")
    DecaARE = URIRef("http://qudt.org/vocab/unit/DecaARE")
    KiloLB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-IN2")
    MilliGM_SEC_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M3-CentiM3")
    W_PER_M_DEG_C = URIRef("http://qudt.org/vocab/unit/W-PER-M-DEG_C")
    CAL_IT_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-DEG_C")
    A_HR = URIRef("http://qudt.org/vocab/unit/A-HR")
    BAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-M3-PER-SEC")
    FT_PER_PSI = URIRef("http://qudt.org/vocab/unit/FT-PER-PSI")
    OZ_HR_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-YD3")
    PER_MegaPA = URIRef("http://qudt.org/vocab/unit/PER-MegaPA")
    MI_PER_HR = URIRef("http://qudt.org/vocab/unit/MI-PER-HR")
    MicroV_A_PER_K = URIRef("http://qudt.org/vocab/unit/MicroV-A-PER-K")
    QT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-SEC")
    M = URIRef("http://qudt.org/vocab/unit/M")
    BTU_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-MIN")
    GM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-L-BAR")
    DeciM2 = URIRef("http://qudt.org/vocab/unit/DeciM2")
    TON_SHORT_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR")
    V_Stat = URIRef("http://qudt.org/vocab/unit/V_Stat")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    CAL_IT = URIRef("http://qudt.org/vocab/unit/CAL_IT")
    BTU_IT_PER_HR_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_R")
    MilliBAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-BAR")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    MegaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M2")
    R = URIRef("http://qudt.org/vocab/unit/R")
    A_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Stat-PER-CentiM2")
    CentiM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC-K")
    M_SEC = URIRef("http://qudt.org/vocab/unit/M-SEC")
    PER_M_NanoM_SR = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM-SR")
    BTU_IT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC")
    DYN_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM")
    TON_Metric_PER_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-K")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    GM_MIN_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L-CentiM3")
    MegaPA_PER_K = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-K")
    WB_PER_MilliM = URIRef("http://qudt.org/vocab/unit/WB-PER-MilliM")
    OHM_CIRC_MIL_PER_FT = URIRef("http://qudt.org/vocab/unit/OHM_CIRC-MIL-PER-FT")
    A_Ab = URIRef("http://qudt.org/vocab/unit/A_Ab")
    EarthMass = URIRef("http://qudt.org/vocab/unit/EarthMass")
    MI_PER_SEC = URIRef("http://qudt.org/vocab/unit/MI-PER-SEC")
    MicroMOL_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-HR")
    J_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-M2-PER-KiloGM")
    A_HR = URIRef("http://qudt.org/vocab/unit/A-HR")
    MI_US2 = URIRef("http://qudt.org/vocab/unit/MI_US2")
    MilliGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3")
    TON_Metric_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC-K")
    CentiM_PER_KiloYR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-KiloYR")
    DYN_SEC_PER_CentiM5 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM5")
    PlanckTime = URIRef("http://qudt.org/vocab/unit/PlanckTime")
    GALILEO = URIRef("http://qudt.org/vocab/unit/GALILEO")
    B = URIRef("http://qudt.org/vocab/unit/B")
    J = URIRef("http://qudt.org/vocab/unit/J")
    PT_BIG = URIRef("http://qudt.org/vocab/unit/PT_BIG")
    AC = URIRef("http://qudt.org/vocab/unit/AC")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    DEG_F_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-HR")
    OZ_VOL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-HR")
    IN_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-DEG_F")
    RAD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC2")
    QT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-SEC")
    KiloGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-BAR")
    PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PER-M3-SEC")
    DeciC = URIRef("http://qudt.org/vocab/unit/DeciC")
    KiloGM_F_M_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-CentiM2")
    TON_SHORT_PER_HR_PSI = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR-PSI")
    N_PER_C = URIRef("http://qudt.org/vocab/unit/N-PER-C")
    DYN_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM3")
    MicroH_PER_M = URIRef("http://qudt.org/vocab/unit/MicroH-PER-M")
    MIN_Angle = URIRef("http://qudt.org/vocab/unit/MIN_Angle")
    M_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-V-SEC")
    MilliM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-BAR")
    PER_GM = URIRef("http://qudt.org/vocab/unit/PER-GM")
    NanoGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M2-PA-SEC")
    V_Ab_SEC = URIRef("http://qudt.org/vocab/unit/V_Ab-SEC")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    M3_PER_HR_K = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-K")
    CentiM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL")
    KiloGM_PER_CentiM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-BAR")
    KiloJ_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-DAY")
    CAL_IT_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-DEG_C")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    GM_SEC_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M3-CentiM3")
    BTU_TH_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC-FT2-DEG_F")
    M = URIRef("http://qudt.org/vocab/unit/M")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    TebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M2")
    TON_Metric_PER_M3 = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3")
    MegaA_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaA-PER-M2")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    BTU_IT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_F")
    FemtoJ = URIRef("http://qudt.org/vocab/unit/FemtoJ")
    OZ_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ-PER-HR")
    FemtoGM = URIRef("http://qudt.org/vocab/unit/FemtoGM")
    MilliGM_HR_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M3-L")
    MilliGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-SEC")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-GM")
    NUM_PER_HR = URIRef("http://qudt.org/vocab/unit/NUM-PER-HR")
    BYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/BYTE-PER-SEC")
    MilliL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-GM")
    MOL_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-BAR")
    PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/PER-M2-SEC")
    GM_PER_M3_PA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-PA-SEC")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    MilliBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-L")
    A_SEC2 = URIRef("http://qudt.org/vocab/unit/A-SEC2")
    BTU_IT_PER_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL-DEG_F")
    IN_H2O_60DEG_F = URIRef("http://qudt.org/vocab/unit/IN_H2O_60DEG_F")
    NanoOHM = URIRef("http://qudt.org/vocab/unit/NanoOHM")
    MilliMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-L")
    LB_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT2")
    MOL_PER_M2_SEC_M = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-M")
    W_HR_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-HR-PER-KiloGM")
    MilliA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/MilliA-PER-MilliM")
    DeciL = URIRef("http://qudt.org/vocab/unit/DeciL")
    KiloGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY")
    LB_F_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-IN2")
    OZ_M = URIRef("http://qudt.org/vocab/unit/OZ_M")
    MilliGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DeciL")
    PlanckTime = URIRef("http://qudt.org/vocab/unit/PlanckTime")
    GM_PER_L_CentiPOISE = URIRef("http://qudt.org/vocab/unit/GM-PER-L-CentiPOISE")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    PER_PERCENT = URIRef("http://qudt.org/vocab/unit/PER-PERCENT")
    TeraW = URIRef("http://qudt.org/vocab/unit/TeraW")
    GM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3")
    PERM_Metric_0DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_Metric_0DEG_C")
    MilliM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-M3")
    MilliN_PER_M = URIRef("http://qudt.org/vocab/unit/MilliN-PER-M")
    DEG2 = URIRef("http://qudt.org/vocab/unit/DEG2")
    BTU_IT_PER_MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB-DEG_F")
    W_PER_M2_M_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M-SR")
    KiloMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-KiloGM")
    PERCENT_PER_DecaK = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaK")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    MilliGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HA")
    IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    LB_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_UK")
    PER_WK = URIRef("http://qudt.org/vocab/unit/PER-WK")
    PERCENT_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-M3")
    MegaV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive-HR")
    W_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM-SR")
    BTU_39DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_39DEG_F")
    BTU_TH_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_F")
    YottaC = URIRef("http://qudt.org/vocab/unit/YottaC")
    PlanckImpedance = URIRef("http://qudt.org/vocab/unit/PlanckImpedance")
    BTU_IT_IN_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-HR-FT2-DEG_F")
    GigaW = URIRef("http://qudt.org/vocab/unit/GigaW")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    BTU_IT_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-IN2-SEC")
    MilliBQ_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-M2-DAY")
    GM_PER_L_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-L-MilliPA-SEC")
    PA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-L-PER-SEC")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    MicroJ = URIRef("http://qudt.org/vocab/unit/MicroJ")
    YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD3-PER-SEC")
    PicoGM = URIRef("http://qudt.org/vocab/unit/PicoGM")
    M2_HR_DEG_C_PER_KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/M2-HR-DEG_C-PER-KiloCAL_IT")
    K_M_PER_W = URIRef("http://qudt.org/vocab/unit/K-M-PER-W")
    M3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-K")
    MilliL_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-BAR")
    PA_M0dot5 = URIRef("http://qudt.org/vocab/unit/PA-M0dot5")
    ZeptoC = URIRef("http://qudt.org/vocab/unit/ZeptoC")
    MicroSV = URIRef("http://qudt.org/vocab/unit/MicroSV")
    L_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-K")
    H_PER_M = URIRef("http://qudt.org/vocab/unit/H-PER-M")
    KiloGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM2")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    NanoSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-MIN")
    V_PER_BAR = URIRef("http://qudt.org/vocab/unit/V-PER-BAR")
    V_Ab = URIRef("http://qudt.org/vocab/unit/V_Ab")
    PK_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-SEC")
    PDL_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-FT2")
    LB_PER_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-HR")
    KiloN_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M3")
    A_PER_MilliM = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/MOL-DEG_C")
    PicoMOL_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M3-SEC")
    PicoL = URIRef("http://qudt.org/vocab/unit/PicoL")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    PlanckVolt = URIRef("http://qudt.org/vocab/unit/PlanckVolt")
    KAT_PER_M3 = URIRef("http://qudt.org/vocab/unit/KAT-PER-M3")
    A_M2 = URIRef("http://qudt.org/vocab/unit/A-M2")
    LY = URIRef("http://qudt.org/vocab/unit/LY")
    CARAT = URIRef("http://qudt.org/vocab/unit/CARAT")
    M2_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-K")
    NanoMOL_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL")
    PER_T_M = URIRef("http://qudt.org/vocab/unit/PER-T-M")
    OZ_FT_SEC_PER_IN3_LB = URIRef("http://qudt.org/vocab/unit/OZ-FT-SEC-PER-IN3-LB")
    PINT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-DAY")
    W_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-PER-KiloGM")
    MicroPA = URIRef("http://qudt.org/vocab/unit/MicroPA")
    LB_HR_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US2")
    PER_YD3 = URIRef("http://qudt.org/vocab/unit/PER-YD3")
    S_PER_CentiM = URIRef("http://qudt.org/vocab/unit/S-PER-CentiM")
    BTU_IT_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB")
    FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC")
    PERCENT_PER_V = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-V")
    CWT_SHORT = URIRef("http://qudt.org/vocab/unit/CWT_SHORT")
    MegaL = URIRef("http://qudt.org/vocab/unit/MegaL")
    NanoOHM_M = URIRef("http://qudt.org/vocab/unit/NanoOHM-M")
    CentiM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SEC")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    MilliOHM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-M")
    OZ_FT2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/OZ-FT2-PER-IN3-LB_F-SEC")
    CAL_IT_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM-K")
    V = URIRef("http://qudt.org/vocab/unit/V")
    LB_PER_IN = URIRef("http://qudt.org/vocab/unit/LB-PER-IN")
    LM_PER_M2 = URIRef("http://qudt.org/vocab/unit/LM-PER-M2")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    MilliL_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-BAR")
    TONNE_PER_HR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR")
    GM_PER_L_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-L-MilliPA-SEC")
    OERSTED = URIRef("http://qudt.org/vocab/unit/OERSTED")
    PA_M0dot5 = URIRef("http://qudt.org/vocab/unit/PA-M0dot5")
    PicoJ = URIRef("http://qudt.org/vocab/unit/PicoJ")
    KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloMOL")
    BTU_TH_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB")
    OZ_IN2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/OZ-IN2-PER-IN3-LB_F-SEC")
    KiloM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC")
    NUM_PER_YR = URIRef("http://qudt.org/vocab/unit/NUM-PER-YR")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    MicroMOL = URIRef("http://qudt.org/vocab/unit/MicroMOL")
    PINT_US = URIRef("http://qudt.org/vocab/unit/PINT_US")
    N_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M")
    GM_PER_HZ = URIRef("http://qudt.org/vocab/unit/GM-PER-HZ")
    MegaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-M")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    PetaW = URIRef("http://qudt.org/vocab/unit/PetaW")
    GigaOHM_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-M")
    YD_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD-PER-MIN")
    CentiM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC-K")
    W = URIRef("http://qudt.org/vocab/unit/W")
    GRAIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-M3")
    MilliL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-KiloGM")
    MilliBAR = URIRef("http://qudt.org/vocab/unit/MilliBAR")
    BU_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-HR")
    PA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-BAR")
    ZettaC = URIRef("http://qudt.org/vocab/unit/ZettaC")
    MilliGM_PER_M3_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-MilliPA-SEC")
    KiloGM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3")
    KibiBYTE = URIRef("http://qudt.org/vocab/unit/KibiBYTE")
    KiloSEC = URIRef("http://qudt.org/vocab/unit/KiloSEC")
    MegaJ_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M3")
    M_PER_MIN = URIRef("http://qudt.org/vocab/unit/M-PER-MIN")
    MicroGAL_PER_M = URIRef("http://qudt.org/vocab/unit/MicroGAL-PER-M")
    MilliGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3")
    L_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-K")
    U = URIRef("http://qudt.org/vocab/unit/U")
    YD3_PER_HR = URIRef("http://qudt.org/vocab/unit/YD3-PER-HR")
    MilliV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliV-PER-MIN")
    KiloCAL_PER_MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL-DEG_C")
    ENZ = URIRef("http://qudt.org/vocab/unit/ENZ")
    KiloLB_F_FT_PER_A = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-A")
    CentiM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC-K")
    YD = URIRef("http://qudt.org/vocab/unit/YD")
    BAN = URIRef("http://qudt.org/vocab/unit/BAN")
    CentiM3_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY-K")
    KiloCAL_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL")
    KiloM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-HR")
    KiloBTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH-PER-HR")
    KiloGAUSS = URIRef("http://qudt.org/vocab/unit/KiloGAUSS")
    MilliOHM = URIRef("http://qudt.org/vocab/unit/MilliOHM")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    PlanckLength = URIRef("http://qudt.org/vocab/unit/PlanckLength")
    IN3_PER_HR = URIRef("http://qudt.org/vocab/unit/IN3-PER-HR")
    PicoGM_PER_L = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-L")
    W_PER_K = URIRef("http://qudt.org/vocab/unit/W-PER-K")
    PER_J_M3 = URIRef("http://qudt.org/vocab/unit/PER-J-M3")
    PK_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-MIN")
    MOL_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-DeciM3")
    PERCENT_PER_DAY = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DAY")
    BAN = URIRef("http://qudt.org/vocab/unit/BAN")
    MOL_PER_GM_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-GM-HR")
    RPK = URIRef("http://qudt.org/vocab/unit/RPK")
    FA = URIRef("http://qudt.org/vocab/unit/FA")
    BBL_UK_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-SEC")
    W_PER_K = URIRef("http://qudt.org/vocab/unit/W-PER-K")
    LB_IN2 = URIRef("http://qudt.org/vocab/unit/LB-IN2")
    MilliGM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M")
    MilliOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-BAR")
    IN_HG_60DEG_F = URIRef("http://qudt.org/vocab/unit/IN_HG_60DEG_F")
    EV_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/EV-M2-PER-KiloGM")
    MilliM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliM-PER-M")
    DEG_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC2")
    MicroC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M2")
    AttoC = URIRef("http://qudt.org/vocab/unit/AttoC")
    BIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BIT-PER-SEC")
    LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT2")
    TeraC = URIRef("http://qudt.org/vocab/unit/TeraC")
    M2_HZ = URIRef("http://qudt.org/vocab/unit/M2-HZ")
    H = URIRef("http://qudt.org/vocab/unit/H")
    MicroGM = URIRef("http://qudt.org/vocab/unit/MicroGM")
    TONNE_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY-BAR")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    MicroRAD = URIRef("http://qudt.org/vocab/unit/MicroRAD")
    MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC")
    FRAME_PER_SEC = URIRef("http://qudt.org/vocab/unit/FRAME-PER-SEC")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    MicroMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L")
    MilliPA = URIRef("http://qudt.org/vocab/unit/MilliPA")
    CUP_US = URIRef("http://qudt.org/vocab/unit/CUP_US")
    PINT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-MIN")
    TeraJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/TeraJ-PER-SEC")
    MilliTORR = URIRef("http://qudt.org/vocab/unit/MilliTORR")
    GM_F = URIRef("http://qudt.org/vocab/unit/GM_F")
    B = URIRef("http://qudt.org/vocab/unit/B")
    KiloGM_PER_M_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-HR")
    MilliGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-DAY")
    PebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M")
    MilliL_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-BAR")
    MegaC = URIRef("http://qudt.org/vocab/unit/MegaC")
    NanoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L")
    OHM_PER_MI = URIRef("http://qudt.org/vocab/unit/OHM-PER-MI")
    Kilo_FT3 = URIRef("http://qudt.org/vocab/unit/Kilo-FT3")
    PER_MOL = URIRef("http://qudt.org/vocab/unit/PER-MOL")
    PPTM_PER_K = URIRef("http://qudt.org/vocab/unit/PPTM-PER-K")
    BTU_TH_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT3")
    J_PER_GM = URIRef("http://qudt.org/vocab/unit/J-PER-GM")
    HectoPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-L-PER-SEC")
    GM_SEC_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M6")
    MilliC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliC-PER-KiloGM")
    L_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/L-PER-KiloGM")
    MilliA_PER_IN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-IN")
    MilliC = URIRef("http://qudt.org/vocab/unit/MilliC")
    MicroW = URIRef("http://qudt.org/vocab/unit/MicroW")
    MegaPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-BAR")
    BU_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-MIN")
    ATM_T_PER_M = URIRef("http://qudt.org/vocab/unit/ATM_T-PER-M")
    C_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM3")
    V_A_HR = URIRef("http://qudt.org/vocab/unit/V-A-HR")
    KiloGM_PER_M_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-HR")
    M_K = URIRef("http://qudt.org/vocab/unit/M-K")
    MicroKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MicroKAT-PER-L")
    ATM_T_PER_M = URIRef("http://qudt.org/vocab/unit/ATM_T-PER-M")
    LB_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC-DEG_F")
    M_KiloGM = URIRef("http://qudt.org/vocab/unit/M-KiloGM")
    DYN_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-CentiM")
    TOE = URIRef("http://qudt.org/vocab/unit/TOE")
    DEG_F_HR_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_TH")
    LB_FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT-PER-SEC")
    LB = URIRef("http://qudt.org/vocab/unit/LB")
    MicroA_PER_K = URIRef("http://qudt.org/vocab/unit/MicroA-PER-K")
    KiloPA = URIRef("http://qudt.org/vocab/unit/KiloPA")
    MilliW_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-MilliGM")
    KiloCi = URIRef("http://qudt.org/vocab/unit/KiloCi")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    PERCENT_PER_WK = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-WK")
    CentiL = URIRef("http://qudt.org/vocab/unit/CentiL")
    MegaBQ = URIRef("http://qudt.org/vocab/unit/MegaBQ")
    MilliGM_SEC_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L-M3")
    BIT_PER_M = URIRef("http://qudt.org/vocab/unit/BIT-PER-M")
    W_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/W-PER-CentiM2")
    FM = URIRef("http://qudt.org/vocab/unit/FM")
    PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/PER-MilliM3")
    PERCENT_PER_IN = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-IN")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    MilliOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-BAR")
    T = URIRef("http://qudt.org/vocab/unit/T")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    MicroGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-KiloGM")
    N_M_PER_A = URIRef("http://qudt.org/vocab/unit/N-M-PER-A")
    YR_TROPICAL = URIRef("http://qudt.org/vocab/unit/YR_TROPICAL")
    NanoGM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MicroL")
    PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/PER-ANGSTROM")
    HP_Metric = URIRef("http://qudt.org/vocab/unit/HP_Metric")
    FemtoJ = URIRef("http://qudt.org/vocab/unit/FemtoJ")
    PicoC = URIRef("http://qudt.org/vocab/unit/PicoC")
    ERG_CentiM2 = URIRef("http://qudt.org/vocab/unit/ERG-CentiM2")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    KiloV_A = URIRef("http://qudt.org/vocab/unit/KiloV-A")
    MegaC = URIRef("http://qudt.org/vocab/unit/MegaC")
    U = URIRef("http://qudt.org/vocab/unit/U")
    NanoGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M2-PA-SEC")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    DWT = URIRef("http://qudt.org/vocab/unit/DWT")
    MicroM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-M3")
    DeciL = URIRef("http://qudt.org/vocab/unit/DeciL")
    GM_PER_GM = URIRef("http://qudt.org/vocab/unit/GM-PER-GM")
    M2_K_PER_W = URIRef("http://qudt.org/vocab/unit/M2-K-PER-W")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    PPTR_VOL = URIRef("http://qudt.org/vocab/unit/PPTR_VOL")
    TON_Metric_PER_HA = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HA")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    DeciC = URIRef("http://qudt.org/vocab/unit/DeciC")
    KiloBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-HR")
    MilliM_HG = URIRef("http://qudt.org/vocab/unit/MilliM_HG")
    K_PER_BAR = URIRef("http://qudt.org/vocab/unit/K-PER-BAR")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    BTU_IT_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_R")
    KiloP = URIRef("http://qudt.org/vocab/unit/KiloP")
    DeciM = URIRef("http://qudt.org/vocab/unit/DeciM")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-GM")
    CentiM_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-K")
    LB_F_FT = URIRef("http://qudt.org/vocab/unit/LB_F-FT")
    PDL_PER_IN = URIRef("http://qudt.org/vocab/unit/PDL-PER-IN")
    LB_MIN_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN6")
    BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN")
    ExaV_A = URIRef("http://qudt.org/vocab/unit/ExaV-A")
    LB_HR_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-YD3")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    LB_HR_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-GAL_US")
    RAD_PER_HR = URIRef("http://qudt.org/vocab/unit/RAD-PER-HR")
    LB = URIRef("http://qudt.org/vocab/unit/LB")
    MegaJ_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M3")
    GM_PER_L = URIRef("http://qudt.org/vocab/unit/GM-PER-L")
    MegaFLOPS = URIRef("http://qudt.org/vocab/unit/MegaFLOPS")
    MI_US2 = URIRef("http://qudt.org/vocab/unit/MI_US2")
    MicroC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M2")
    LB_F_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN")
    N_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M2")
    L_PER_HR = URIRef("http://qudt.org/vocab/unit/L-PER-HR")
    M2_K_PER_W = URIRef("http://qudt.org/vocab/unit/M2-K-PER-W")
    MilliGM_SEC_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M3-CentiM3")
    BTU_IT = URIRef("http://qudt.org/vocab/unit/BTU_IT")
    M2_SR = URIRef("http://qudt.org/vocab/unit/M2-SR")
    GI_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-SEC")
    MicroS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MicroS-PER-CentiM")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    MACH = URIRef("http://qudt.org/vocab/unit/MACH")
    J = URIRef("http://qudt.org/vocab/unit/J")
    TONNE_PER_HA_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA-YR")
    MicroGRAY = URIRef("http://qudt.org/vocab/unit/MicroGRAY")
    MegaV = URIRef("http://qudt.org/vocab/unit/MegaV")
    PER_DAY = URIRef("http://qudt.org/vocab/unit/PER-DAY")
    Denier = URIRef("http://qudt.org/vocab/unit/Denier")
    DeciB_A = URIRef("http://qudt.org/vocab/unit/DeciB_A")
    BTU_IT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC")
    CentiM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC-BAR")
    GM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-L-BAR")
    BBL_UK_PET = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET")
    FT_LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2")
    KibiBYTE = URIRef("http://qudt.org/vocab/unit/KibiBYTE")
    DEGREE_PLATO = URIRef("http://qudt.org/vocab/unit/DEGREE_PLATO")
    GigaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/GigaC-PER-M3")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    EV_PER_K = URIRef("http://qudt.org/vocab/unit/EV-PER-K")
    FT_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC2")
    GM_PER_MilliL_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL-BAR")
    J_PER_M3_K = URIRef("http://qudt.org/vocab/unit/J-PER-M3-K")
    AttoC = URIRef("http://qudt.org/vocab/unit/AttoC")
    LB_HR_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-YD3")
    OZ_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_UK")
    MicroMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MOL")
    BTU_IT_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_R")
    MegaGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-M3")
    MicroMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2")
    KiloGM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3")
    M = URIRef("http://qudt.org/vocab/unit/M")
    HectoPA_PER_HR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-HR")
    DYN_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM2")
    KiloCAL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-MIN")
    PA_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M")
    SLUG_PER_FT = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT")
    KiloGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    FR = URIRef("http://qudt.org/vocab/unit/FR")
    MilliGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DeciL")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    GM_MIN_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M3-CentiM3")
    MilliGM_SEC_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M6")
    L_PER_HR = URIRef("http://qudt.org/vocab/unit/L-PER-HR")
    RAD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC2")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    PER_M2 = URIRef("http://qudt.org/vocab/unit/PER-M2")
    W = URIRef("http://qudt.org/vocab/unit/W")
    PERCENT_HR_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-YD3")
    MegaV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive")
    CLO = URIRef("http://qudt.org/vocab/unit/CLO")
    TON_Metric_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR-BAR")
    GM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-BAR")
    PER_TONNE = URIRef("http://qudt.org/vocab/unit/PER-TONNE")
    DeciB_MilliW = URIRef("http://qudt.org/vocab/unit/DeciB-MilliW")
    TON_Metric = URIRef("http://qudt.org/vocab/unit/TON_Metric")
    MilliGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MilliL")
    M3_PER_DAY = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY")
    MegaV_A = URIRef("http://qudt.org/vocab/unit/MegaV-A")
    LB_PER_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-PSI")
    MilliM_PER_YR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-YR")
    ERG_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM3")
    OZ = URIRef("http://qudt.org/vocab/unit/OZ")
    N_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM2")
    KiloW_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloW-HR-PER-M2")
    K_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/K-PER-SEC2")
    LB_F_PER_IN2_DEG_F = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-DEG_F")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    OZ_SEC_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-GAL_UK")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    MicroM_PER_N = URIRef("http://qudt.org/vocab/unit/MicroM-PER-N")
    AC_FT = URIRef("http://qudt.org/vocab/unit/AC-FT")
    PER_T_M = URIRef("http://qudt.org/vocab/unit/PER-T-M")
    GM_Nitrogen_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Nitrogen-PER-M2-DAY")
    KiloMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-SEC")
    MilliL_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-BAR")
    SEC_PER_M = URIRef("http://qudt.org/vocab/unit/SEC-PER-M")
    OZ_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN3")
    MilliPA_SEC_PER_K = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-K")
    CH = URIRef("http://qudt.org/vocab/unit/CH")
    OZ_PER_GAL = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL")
    GM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC")
    KiloGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-K")
    GR = URIRef("http://qudt.org/vocab/unit/GR")
    PlanckVolt = URIRef("http://qudt.org/vocab/unit/PlanckVolt")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    YR_Sidereal = URIRef("http://qudt.org/vocab/unit/YR_Sidereal")
    ATM_T_PER_M = URIRef("http://qudt.org/vocab/unit/ATM_T-PER-M")
    MegaHZ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-K")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    MegaGRAY = URIRef("http://qudt.org/vocab/unit/MegaGRAY")
    N_PER_CentiM = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM")
    DAY_Sidereal = URIRef("http://qudt.org/vocab/unit/DAY_Sidereal")
    HP = URIRef("http://qudt.org/vocab/unit/HP")
    MilliW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2")
    GigaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/GigaC-PER-M3")
    MOL_LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-MIN")
    QT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_US-PER-DAY")
    GAL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-DAY")
    Gamma = URIRef("http://qudt.org/vocab/unit/Gamma")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    KAT_PER_L = URIRef("http://qudt.org/vocab/unit/KAT-PER-L")
    M3_PER_PA = URIRef("http://qudt.org/vocab/unit/M3-PER-PA")
    KiloMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3")
    CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-SEC")
    KIP_F = URIRef("http://qudt.org/vocab/unit/KIP_F")
    CAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-K")
    PDL_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-FT2")
    DeciN_M = URIRef("http://qudt.org/vocab/unit/DeciN-M")
    TON_SHORT_PER_PSI = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-PSI")
    V_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/V-SEC-PER-M")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    PlanckArea = URIRef("http://qudt.org/vocab/unit/PlanckArea")
    GM_SEC_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M3-CentiM3")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    PER_MilliSEC = URIRef("http://qudt.org/vocab/unit/PER-MilliSEC")
    LB_HR_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN6")
    S = URIRef("http://qudt.org/vocab/unit/S")
    GM_HR_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M3-CentiM3")
    KiloBAUD = URIRef("http://qudt.org/vocab/unit/KiloBAUD")
    BTU_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-MIN")
    MegaJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-KiloGM")
    M3_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-M2")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    PK_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-MIN")
    ATM_PER_M = URIRef("http://qudt.org/vocab/unit/ATM-PER-M")
    PebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M3")
    PicoW = URIRef("http://qudt.org/vocab/unit/PicoW")
    Da = URIRef("http://qudt.org/vocab/unit/Da")
    KiloGM_PER_M_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC2")
    NanoM_PER_MilliM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-MilliM-MegaPA")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    OZ_HR_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-GAL_UK")
    LB_SEC_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-GAL_US")
    PlanckTime = URIRef("http://qudt.org/vocab/unit/PlanckTime")
    ERG = URIRef("http://qudt.org/vocab/unit/ERG")
    LB_MIN_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-FT3")
    BTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR")
    M3_PER_M3 = URIRef("http://qudt.org/vocab/unit/M3-PER-M3")
    YD3 = URIRef("http://qudt.org/vocab/unit/YD3")
    M = URIRef("http://qudt.org/vocab/unit/M")
    GigaN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaN-M-PER-M2")
    M3_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-BAR")
    MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC")
    YR_TROPICAL = URIRef("http://qudt.org/vocab/unit/YR_TROPICAL")
    GM_PER_L_POISE = URIRef("http://qudt.org/vocab/unit/GM-PER-L-POISE")
    V_PER_M2 = URIRef("http://qudt.org/vocab/unit/V-PER-M2")
    LB_SEC_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT6")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    GigaW = URIRef("http://qudt.org/vocab/unit/GigaW")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    LB_MIN_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-GAL_US")
    TON_Metric_PER_MIN = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN")
    DEG_F_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-K")
    B = URIRef("http://qudt.org/vocab/unit/B")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    LB_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_US")
    YD_PER_PSI = URIRef("http://qudt.org/vocab/unit/YD-PER-PSI")
    CentiM_H2O = URIRef("http://qudt.org/vocab/unit/CentiM_H2O")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-SEC-DEG_F")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    PER_MILLE_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PSI")
    DEGREE_BAUME_US_LIGHT = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_LIGHT")
    PicoGM_PER_L = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-L")
    NanoH_PER_M = URIRef("http://qudt.org/vocab/unit/NanoH-PER-M")
    IU = URIRef("http://qudt.org/vocab/unit/IU")
    IN_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC2")
    LB_PER_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-HR")
    GM_PER_MOL = URIRef("http://qudt.org/vocab/unit/GM-PER-MOL")
    GM_PER_MilliL_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL-BAR")
    PER_SEC_M2_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2-SR")
    TONNE_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC-BAR")
    DEG_F_HR_FT2_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH")
    MilliGM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR")
    BTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR")
    K_SEC = URIRef("http://qudt.org/vocab/unit/K-SEC")
    TeraOHM = URIRef("http://qudt.org/vocab/unit/TeraOHM")
    KiloN_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-DEG")
    A_PER_RAD = URIRef("http://qudt.org/vocab/unit/A-PER-RAD")
    MilliM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-M3")
    YR = URIRef("http://qudt.org/vocab/unit/YR")
    KiloBQ = URIRef("http://qudt.org/vocab/unit/KiloBQ")
    R_man = URIRef("http://qudt.org/vocab/unit/R_man")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    QT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_US-PER-MIN")
    MilliM4 = URIRef("http://qudt.org/vocab/unit/MilliM4")
    DeciB_W = URIRef("http://qudt.org/vocab/unit/DeciB-W")
    MegaPA_M0pt5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0pt5")
    M3_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-M2")
    MegaBQ = URIRef("http://qudt.org/vocab/unit/MegaBQ")
    BARYE = URIRef("http://qudt.org/vocab/unit/BARYE")
    KiloN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-M2")
    DecaPA = URIRef("http://qudt.org/vocab/unit/DecaPA")
    PlanckTime = URIRef("http://qudt.org/vocab/unit/PlanckTime")
    FT_LB_F_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-HR")
    YD3_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD3-PER-MIN")
    KiloEV_PER_MicroM = URIRef("http://qudt.org/vocab/unit/KiloEV-PER-MicroM")
    AC = URIRef("http://qudt.org/vocab/unit/AC")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    KiloGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-PA-SEC")
    MilliBQ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-GM")
    KiloGM_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-M2")
    CWT_SHORT = URIRef("http://qudt.org/vocab/unit/CWT_SHORT")
    TON_Metric_PER_M3 = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3")
    MilliDARCY = URIRef("http://qudt.org/vocab/unit/MilliDARCY")
    LB_F_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-FT2")
    FT_LB_F = URIRef("http://qudt.org/vocab/unit/FT-LB_F")
    PK_UK = URIRef("http://qudt.org/vocab/unit/PK_UK")
    MegaJ = URIRef("http://qudt.org/vocab/unit/MegaJ")
    DEG_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC")
    N_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM2")
    CentiN_M = URIRef("http://qudt.org/vocab/unit/CentiN-M")
    KiloCAL_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-HR")
    PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/PER-MilliM3")
    KiloV_A = URIRef("http://qudt.org/vocab/unit/KiloV-A")
    unit = URIRef("http://qudt.org/vocab/unit")
    PERCENT_PER_DecaCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaCount")
    MilliGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-KiloGM")
    PERCENT_MIN_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-IN3")
    GibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M3")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    NUM_PER_PicoL = URIRef("http://qudt.org/vocab/unit/NUM-PER-PicoL")
    KiloOHM = URIRef("http://qudt.org/vocab/unit/KiloOHM")
    MegaPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-BAR")
    MilliL = URIRef("http://qudt.org/vocab/unit/MilliL")
    M2_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-BAR")
    NanoL = URIRef("http://qudt.org/vocab/unit/NanoL")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    KiloTON_Metric = URIRef("http://qudt.org/vocab/unit/KiloTON_Metric")
    REV_PER_SEC = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC")
    L_PER_L = URIRef("http://qudt.org/vocab/unit/L-PER-L")
    BBL_US_DRY = URIRef("http://qudt.org/vocab/unit/BBL_US_DRY")
    KiloGM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR")
    FT_LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2")
    KiloMOL_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3-BAR")
    PERCENT_PER_POISE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-POISE")
    W_HR_PER_L = URIRef("http://qudt.org/vocab/unit/W-HR-PER-L")
    BTU_TH_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2")
    M2_PER_J = URIRef("http://qudt.org/vocab/unit/M2-PER-J")
    BU_US = URIRef("http://qudt.org/vocab/unit/BU_US")
    M_SEC = URIRef("http://qudt.org/vocab/unit/M-SEC")
    YottaC = URIRef("http://qudt.org/vocab/unit/YottaC")
    M_PER_DEG_C_M = URIRef("http://qudt.org/vocab/unit/M-PER-DEG_C-M")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    FT3_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT3-PER-DAY")
    T_Ab = URIRef("http://qudt.org/vocab/unit/T_Ab")
    MOL_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-BAR")
    NanoT = URIRef("http://qudt.org/vocab/unit/NanoT")
    CentiBAR = URIRef("http://qudt.org/vocab/unit/CentiBAR")
    PPTM = URIRef("http://qudt.org/vocab/unit/PPTM")
    FT_PDL = URIRef("http://qudt.org/vocab/unit/FT-PDL")
    PicoMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M2-DAY")
    MilliBAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-BAR")
    M4 = URIRef("http://qudt.org/vocab/unit/M4")
    MegaGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-HA")
    DEG_F_HR_FT2_PER_BTU_TH_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH-IN")
    PA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-L-PER-SEC")
    ExaBYTE = URIRef("http://qudt.org/vocab/unit/ExaBYTE")
    C_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM")
    PER_MILLE_PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PER-PSI")
    LY = URIRef("http://qudt.org/vocab/unit/LY")
    LB_PER_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-HR")
    DEG_F_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-HR")
    DEG_F_HR_FT2_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH")
    MI3 = URIRef("http://qudt.org/vocab/unit/MI3")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    MilliL_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-BAR")
    MilliL_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY")
    M4_PER_SEC = URIRef("http://qudt.org/vocab/unit/M4-PER-SEC")
    BARN_PER_EV = URIRef("http://qudt.org/vocab/unit/BARN-PER-EV")
    J_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-GM-DEG_C")
    GM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL")
    MilliL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC")
    W_PER_GM = URIRef("http://qudt.org/vocab/unit/W-PER-GM")
    YD3_PER_HR = URIRef("http://qudt.org/vocab/unit/YD3-PER-HR")
    FT3 = URIRef("http://qudt.org/vocab/unit/FT3")
    TONNE_PER_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-K")
    A_PER_MilliM = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM")
    Debye = URIRef("http://qudt.org/vocab/unit/Debye")
    M_H2O = URIRef("http://qudt.org/vocab/unit/M_H2O")
    DecaC = URIRef("http://qudt.org/vocab/unit/DecaC")
    PER_EV2 = URIRef("http://qudt.org/vocab/unit/PER-EV2")
    GM_MilliM = URIRef("http://qudt.org/vocab/unit/GM-MilliM")
    FT_HG = URIRef("http://qudt.org/vocab/unit/FT_HG")
    IN_HG_32DEG_F = URIRef("http://qudt.org/vocab/unit/IN_HG_32DEG_F")
    TeraJ = URIRef("http://qudt.org/vocab/unit/TeraJ")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    KiloV_A_PER_K = URIRef("http://qudt.org/vocab/unit/KiloV-A-PER-K")
    C = URIRef("http://qudt.org/vocab/unit/C")
    HZ_PER_V = URIRef("http://qudt.org/vocab/unit/HZ-PER-V")
    IN = URIRef("http://qudt.org/vocab/unit/IN")
    CAL_IT_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM-K")
    MilliBAR = URIRef("http://qudt.org/vocab/unit/MilliBAR")
    N_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M3")
    PERMITTIVITY_REL = URIRef("http://qudt.org/vocab/unit/PERMITTIVITY_REL")
    GAUSS = URIRef("http://qudt.org/vocab/unit/GAUSS")
    GigaBasePair = URIRef("http://qudt.org/vocab/unit/GigaBasePair")
    MilliM_H2O = URIRef("http://qudt.org/vocab/unit/MilliM_H2O")
    N_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-PER-M3")
    MicroBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-KiloGM")
    CentiM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    MicroPA = URIRef("http://qudt.org/vocab/unit/MicroPA")
    PicoS_PER_M = URIRef("http://qudt.org/vocab/unit/PicoS-PER-M")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CentiM2-MIN")
    PINT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-MIN")
    LB_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-DEG_F")
    MilliV = URIRef("http://qudt.org/vocab/unit/MilliV")
    MilliGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-K")
    M4_PER_SEC = URIRef("http://qudt.org/vocab/unit/M4-PER-SEC")
    BTU_TH_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT3")
    DEG2 = URIRef("http://qudt.org/vocab/unit/DEG2")
    ARCMIN = URIRef("http://qudt.org/vocab/unit/ARCMIN")
    NanoM2 = URIRef("http://qudt.org/vocab/unit/NanoM2")
    MOL_PER_TONNE = URIRef("http://qudt.org/vocab/unit/MOL-PER-TONNE")
    N_M_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-M-PER-KiloGM")
    PicoMOL_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L-DAY")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    MilliL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-SEC")
    BIOT = URIRef("http://qudt.org/vocab/unit/BIOT")
    GigaPA = URIRef("http://qudt.org/vocab/unit/GigaPA")
    N_PER_MilliM = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM")
    KiloGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    TSP = URIRef("http://qudt.org/vocab/unit/TSP")
    MOL_PER_M2_SEC_M_SR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-M-SR")
    PK_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-MIN")
    ZeptoC = URIRef("http://qudt.org/vocab/unit/ZeptoC")
    M2_PER_J = URIRef("http://qudt.org/vocab/unit/M2-PER-J")
    DeciB_C = URIRef("http://qudt.org/vocab/unit/DeciB_C")
    V_PER_K = URIRef("http://qudt.org/vocab/unit/V-PER-K")
    LB_SEC_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK2")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    M2_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-K")
    MicroV_A_PER_K = URIRef("http://qudt.org/vocab/unit/MicroV-A-PER-K")
    PER_PlanckMass2 = URIRef("http://qudt.org/vocab/unit/PER-PlanckMass2")
    CARAT = URIRef("http://qudt.org/vocab/unit/CARAT")
    MegaOHM_PER_K = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-K")
    KiloPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-BAR")
    ExaC = URIRef("http://qudt.org/vocab/unit/ExaC")
    PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2")
    KiloCi = URIRef("http://qudt.org/vocab/unit/KiloCi")
    KAT_PER_L = URIRef("http://qudt.org/vocab/unit/KAT-PER-L")
    GAL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-HR")
    BTU_IT_PER_HR_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2")
    HectoPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-L-PER-SEC")
    M2_PER_SR_J = URIRef("http://qudt.org/vocab/unit/M2-PER-SR-J")
    BBL_US_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-HR")
    DEATHS_PER_KiloINDIV_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-KiloINDIV-YR")
    MicroGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-SEC")
    CD_IN = URIRef("http://qudt.org/vocab/unit/CD_IN")
    FT_LB_F = URIRef("http://qudt.org/vocab/unit/FT-LB_F")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    MilliV_A_PER_K = URIRef("http://qudt.org/vocab/unit/MilliV-A-PER-K")
    BIOT = URIRef("http://qudt.org/vocab/unit/BIOT")
    BTU_TH_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-SEC-DEG_F")
    PERCENT_MIN_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-CentiM3")
    LB_F = URIRef("http://qudt.org/vocab/unit/LB_F")
    EV_M2 = URIRef("http://qudt.org/vocab/unit/EV-M2")
    PicoW_PER_CentiM2_L = URIRef("http://qudt.org/vocab/unit/PicoW-PER-CentiM2-L")
    PER_IN = URIRef("http://qudt.org/vocab/unit/PER-IN")
    J_PER_HR = URIRef("http://qudt.org/vocab/unit/J-PER-HR")
    KiloBTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-FT2")
    HART = URIRef("http://qudt.org/vocab/unit/HART")
    CentiMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-KiloGM")
    TONNE_PER_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-BAR")
    M2_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-PA")
    MilliC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M3")
    CAL_TH = URIRef("http://qudt.org/vocab/unit/CAL_TH")
    A_PER_CentiM = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM")
    M_PER_MIN = URIRef("http://qudt.org/vocab/unit/M-PER-MIN")
    W_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M2")
    PERM_Metric = URIRef("http://qudt.org/vocab/unit/PERM_Metric")
    W_SEC = URIRef("http://qudt.org/vocab/unit/W-SEC")
    CD_PER_M2 = URIRef("http://qudt.org/vocab/unit/CD-PER-M2")
    NanoS = URIRef("http://qudt.org/vocab/unit/NanoS")
    H_PER_OHM = URIRef("http://qudt.org/vocab/unit/H-PER-OHM")
    DEG_F_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC2")
    M_PER_HR = URIRef("http://qudt.org/vocab/unit/M-PER-HR")
    LB_PER_FT_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-MIN")
    PicoMOL_PER_M_W_SEC = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M-W-SEC")
    TON_SHORT_PER_PSI = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-PSI")
    HP_H2O = URIRef("http://qudt.org/vocab/unit/HP_H2O")
    M3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-BAR")
    KiloH = URIRef("http://qudt.org/vocab/unit/KiloH")
    MicroOHM_M = URIRef("http://qudt.org/vocab/unit/MicroOHM-M")
    MilliGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-DAY")
    NUM_PER_NanoL = URIRef("http://qudt.org/vocab/unit/NUM-PER-NanoL")
    SEC2 = URIRef("http://qudt.org/vocab/unit/SEC2")
    NUM_PER_YR = URIRef("http://qudt.org/vocab/unit/NUM-PER-YR")
    BTU_IT_PER_LB_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F")
    OZ_SEC_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-GAL_UK")
    MilliGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-SEC")
    TON_F_US = URIRef("http://qudt.org/vocab/unit/TON_F_US")
    GRAIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-M3")
    J_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-M2-PER-KiloGM")
    PERCENT_PER_K = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-K")
    J_PER_GM = URIRef("http://qudt.org/vocab/unit/J-PER-GM")
    C_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM2")
    FT_PER_PSI = URIRef("http://qudt.org/vocab/unit/FT-PER-PSI")
    MilliL = URIRef("http://qudt.org/vocab/unit/MilliL")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    MilLength = URIRef("http://qudt.org/vocab/unit/MilLength")
    DeciM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-DAY")
    MilliM_HG = URIRef("http://qudt.org/vocab/unit/MilliM_HG")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    KiloGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN")
    DEGREE_API = URIRef("http://qudt.org/vocab/unit/DEGREE_API")
    ERG_SEC = URIRef("http://qudt.org/vocab/unit/ERG-SEC")
    KIP_F = URIRef("http://qudt.org/vocab/unit/KIP_F")
    NanoGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2")
    MOHM = URIRef("http://qudt.org/vocab/unit/MOHM")
    FRACTION = URIRef("http://qudt.org/vocab/unit/FRACTION")
    K_DAY = URIRef("http://qudt.org/vocab/unit/K-DAY")
    KibiBYTE = URIRef("http://qudt.org/vocab/unit/KibiBYTE")
    OZ_HR_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-FT3")
    REV_PER_MIN = URIRef("http://qudt.org/vocab/unit/REV-PER-MIN")
    THM_EEC = URIRef("http://qudt.org/vocab/unit/THM_EEC")
    PERCENT_SEC_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-IN3")
    FT2_PER_HR = URIRef("http://qudt.org/vocab/unit/FT2-PER-HR")
    MOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC")
    GI = URIRef("http://qudt.org/vocab/unit/GI")
    PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/PER-ANGSTROM")
    LB_PER_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-HR")
    HP_Metric = URIRef("http://qudt.org/vocab/unit/HP_Metric")
    KiloW = URIRef("http://qudt.org/vocab/unit/KiloW")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    GigaW_HR = URIRef("http://qudt.org/vocab/unit/GigaW-HR")
    CentiM = URIRef("http://qudt.org/vocab/unit/CentiM")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    MilliN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliN-M-PER-M2")
    NanoM2 = URIRef("http://qudt.org/vocab/unit/NanoM2")
    MilliN_M = URIRef("http://qudt.org/vocab/unit/MilliN-M")
    CAL_IT_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM-K")
    GigaJ = URIRef("http://qudt.org/vocab/unit/GigaJ")
    KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloMOL")
    LB_PER_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-DAY")
    MicroV_PER_M = URIRef("http://qudt.org/vocab/unit/MicroV-PER-M")
    BTU_IT_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_F")
    GM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3")
    PicoH = URIRef("http://qudt.org/vocab/unit/PicoH")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    V_A_HR = URIRef("http://qudt.org/vocab/unit/V-A-HR")
    LB_HR_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-GAL_US")
    MilliA_PER_IN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-IN")
    THM_US = URIRef("http://qudt.org/vocab/unit/THM_US")
    HectoC = URIRef("http://qudt.org/vocab/unit/HectoC")
    NanoM_PER_MilliM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-MilliM-MegaPA")
    TONNE_PER_SEC = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC")
    MilliMOL = URIRef("http://qudt.org/vocab/unit/MilliMOL")
    GAUGE_FR = URIRef("http://qudt.org/vocab/unit/GAUGE_FR")
    PARSEC = URIRef("http://qudt.org/vocab/unit/PARSEC")
    CentiM3_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY-BAR")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    MegaTONNE = URIRef("http://qudt.org/vocab/unit/MegaTONNE")
    V_PER_M2 = URIRef("http://qudt.org/vocab/unit/V-PER-M2")
    KiloBD = URIRef("http://qudt.org/vocab/unit/KiloBD")
    A_HR = URIRef("http://qudt.org/vocab/unit/A-HR")
    PK_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-MIN")
    GigaC = URIRef("http://qudt.org/vocab/unit/GigaC")
    ERG_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM3")
    NAT_PER_SEC = URIRef("http://qudt.org/vocab/unit/NAT-PER-SEC")
    BAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/BAR-PER-BAR")
    PER_CentiM = URIRef("http://qudt.org/vocab/unit/PER-CentiM")
    PINT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-DAY")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    GigaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/GigaC-PER-M3")
    W_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM-SR")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    Kilo_FT3 = URIRef("http://qudt.org/vocab/unit/Kilo-FT3")
    KiloGM_PER_J = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-J")
    IN3_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN3-PER-MIN")
    KiloGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-BAR")
    KiloGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC")
    OZ_FT_HR_PER_IN3_LB = URIRef("http://qudt.org/vocab/unit/OZ-FT-HR-PER-IN3-LB")
    QT_UK = URIRef("http://qudt.org/vocab/unit/QT_UK")
    AC = URIRef("http://qudt.org/vocab/unit/AC")
    AT_PER_M = URIRef("http://qudt.org/vocab/unit/AT-PER-M")
    IN_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-DEG_F")
    BU_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-HR")
    N_M2_PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/N-M2-PER-KiloGM2")
    GI_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_US-PER-HR")
    NanoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/NanoKAT-PER-L")
    KiloGM_PER_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-K")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    BTU_TH_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_F")
    MilliW_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM")
    NUM_PER_M2 = URIRef("http://qudt.org/vocab/unit/NUM-PER-M2")
    J_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-M2-PER-KiloGM")
    DYN_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM2")
    KiloGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-BAR")
    MilliL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M2-DAY")
    LB_PER_HR_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-HR-PSI")
    PSI_PER_IN = URIRef("http://qudt.org/vocab/unit/PSI-PER-IN")
    TONNE_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC-BAR")
    KiloLB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-FT")
    V_Ab = URIRef("http://qudt.org/vocab/unit/V_Ab")
    KiloPOND = URIRef("http://qudt.org/vocab/unit/KiloPOND")
    KiloGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-PA-SEC")
    PER_SEC_M2_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2-SR")
    LB_PER_M3 = URIRef("http://qudt.org/vocab/unit/LB-PER-M3")
    LB_MIN_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-GAL_US")
    M2_SR = URIRef("http://qudt.org/vocab/unit/M2-SR")
    ERG_PER_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-SEC")
    KiloV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive-PER-K")
    TON_SHIPPING_US = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_US")
    DYN = URIRef("http://qudt.org/vocab/unit/DYN")
    KiloWB_PER_M = URIRef("http://qudt.org/vocab/unit/KiloWB-PER-M")
    MilliL_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-BAR")
    GI_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_US-PER-HR")
    LB_MIN_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN6")
    KiloW_HR = URIRef("http://qudt.org/vocab/unit/KiloW-HR")
    POND = URIRef("http://qudt.org/vocab/unit/POND")
    GM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-CentiM-PER-SEC")
    Quarter_UK = URIRef("http://qudt.org/vocab/unit/Quarter_UK")
    KiloGM_PER_L_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-K")
    MOL_PER_L_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-L-K")
    LB_PER_IN3_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3-PSI")
    GM_PER_M2 = URIRef("http://qudt.org/vocab/unit/GM-PER-M2")
    J = URIRef("http://qudt.org/vocab/unit/J")
    MilliGM_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-HR")
    N_M_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-M-PER-KiloGM")
    PER_FT3 = URIRef("http://qudt.org/vocab/unit/PER-FT3")
    NanoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-KiloGM")
    NanoS = URIRef("http://qudt.org/vocab/unit/NanoS")
    OHM_Ab = URIRef("http://qudt.org/vocab/unit/OHM_Ab")
    MicroM2 = URIRef("http://qudt.org/vocab/unit/MicroM2")
    H = URIRef("http://qudt.org/vocab/unit/H")
    MilliK_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliK-PER-BAR")
    PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/PER-M2-SEC")
    DEG_F_HR_FT2_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT")
    NUM_PER_NanoL = URIRef("http://qudt.org/vocab/unit/NUM-PER-NanoL")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    M_PER_MIN = URIRef("http://qudt.org/vocab/unit/M-PER-MIN")
    PER_MO = URIRef("http://qudt.org/vocab/unit/PER-MO")
    PERCENT_HR_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-GAL_UK")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    TON_Metric_PER_HA = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HA")
    MilliL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M2-DAY")
    A_SEC = URIRef("http://qudt.org/vocab/unit/A-SEC")
    RPK = URIRef("http://qudt.org/vocab/unit/RPK")
    BAR = URIRef("http://qudt.org/vocab/unit/BAR")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    C_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM-SEC")
    NTU = URIRef("http://qudt.org/vocab/unit/NTU")
    FT_PDL = URIRef("http://qudt.org/vocab/unit/FT-PDL")
    L = URIRef("http://qudt.org/vocab/unit/L")
    FARAD_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/FARAD_Ab-PER-CentiM")
    FT2_PER_HR = URIRef("http://qudt.org/vocab/unit/FT2-PER-HR")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    YD_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD-PER-DEG_F")
    LB_SEC_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US2")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    RPK = URIRef("http://qudt.org/vocab/unit/RPK")
    SLUG_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT-SEC")
    TONNE_PER_HA_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA-YR")
    LB_PER_FT3_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3-DEG_F")
    J_PER_T2 = URIRef("http://qudt.org/vocab/unit/J-PER-T2")
    GA_Charriere = URIRef("http://qudt.org/vocab/unit/GA_Charriere")
    LANGLEY = URIRef("http://qudt.org/vocab/unit/LANGLEY")
    LB_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_UK")
    KiloGM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-CentiM2")
    MilliV_A = URIRef("http://qudt.org/vocab/unit/MilliV-A")
    LB_HR_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-IN3")
    GigaBIT = URIRef("http://qudt.org/vocab/unit/GigaBIT")
    MilliA_PER_L_MIN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-L-MIN")
    SEC_PER_M = URIRef("http://qudt.org/vocab/unit/SEC-PER-M")
    KiloPA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-MilliM")
    MegaGRAY = URIRef("http://qudt.org/vocab/unit/MegaGRAY")
    DeciN = URIRef("http://qudt.org/vocab/unit/DeciN")
    LB_MIN_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT6")
    KiloPA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-K")
    C_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-CentiM2")
    MilliRAD = URIRef("http://qudt.org/vocab/unit/MilliRAD")
    PERCENT_PER_IN = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-IN")
    MegaL = URIRef("http://qudt.org/vocab/unit/MegaL")
    ATM_T = URIRef("http://qudt.org/vocab/unit/ATM_T")
    M_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-V-SEC")
    PicoFARAD = URIRef("http://qudt.org/vocab/unit/PicoFARAD")
    A2_SEC = URIRef("http://qudt.org/vocab/unit/A2-SEC")
    AC = URIRef("http://qudt.org/vocab/unit/AC")
    MilliR = URIRef("http://qudt.org/vocab/unit/MilliR")
    BTU_IT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_F")
    DEGREE_BAUME = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME")
    T_M = URIRef("http://qudt.org/vocab/unit/T-M")
    MicroM3 = URIRef("http://qudt.org/vocab/unit/MicroM3")
    MilliV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliV-PER-MIN")
    OZ_FT = URIRef("http://qudt.org/vocab/unit/OZ-FT")
    DeciM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-SEC")
    PK_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-SEC")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    C_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM3")
    MicroGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-HR")
    J_PER_KiloGM_K_PA = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-PA")
    PicoMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M2-DAY")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    M2_HZ = URIRef("http://qudt.org/vocab/unit/M2-HZ")
    PERCENT_PER_PA_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-PA-SEC")
    GM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3")
    KiloGM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR")
    GigaPA = URIRef("http://qudt.org/vocab/unit/GigaPA")
    LB_MIN_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-FT3")
    HectoC = URIRef("http://qudt.org/vocab/unit/HectoC")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    PERMITTIVITY_REL = URIRef("http://qudt.org/vocab/unit/PERMITTIVITY_REL")
    V_PER_MilliM = URIRef("http://qudt.org/vocab/unit/V-PER-MilliM")
    MegaN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaN-M-PER-M2")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    N_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM2")
    RichterMagnitude = URIRef("http://qudt.org/vocab/unit/RichterMagnitude")
    M3_PER_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-M2")
    MicroJ = URIRef("http://qudt.org/vocab/unit/MicroJ")
    PA2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA2-PER-SEC2")
    TeraW_HR = URIRef("http://qudt.org/vocab/unit/TeraW-HR")
    BTU_TH_PER_FT2_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-MIN")
    C_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM2")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    IN2_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN2-PER-SEC")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    PER_DEG_F = URIRef("http://qudt.org/vocab/unit/PER-DEG_F")
    RAD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC2")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    MilliV_PER_M = URIRef("http://qudt.org/vocab/unit/MilliV-PER-M")
    DRAM_UK = URIRef("http://qudt.org/vocab/unit/DRAM_UK")
    W_PER_M2_K = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K")
    MDOLLAR_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MDOLLAR-PER-FLIGHT")
    DeciB_PER_KiloM = URIRef("http://qudt.org/vocab/unit/DeciB-PER-KiloM")
    KiloLB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-FT")
    MilliM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-HR")
    PERCENT_MIN_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-L")
    MilliOHM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-M")
    PicoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-MilliL")
    V_A_HR = URIRef("http://qudt.org/vocab/unit/V-A-HR")
    PetaJ = URIRef("http://qudt.org/vocab/unit/PetaJ")
    TONNE_PER_M3 = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3")
    N_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M")
    J_M2 = URIRef("http://qudt.org/vocab/unit/J-M2")
    V_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/V-SEC-PER-M")
    IN4 = URIRef("http://qudt.org/vocab/unit/IN4")
    C = URIRef("http://qudt.org/vocab/unit/C")
    LB_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_US")
    MilliGM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M")
    AttoJ_SEC = URIRef("http://qudt.org/vocab/unit/AttoJ-SEC")
    KiloEV = URIRef("http://qudt.org/vocab/unit/KiloEV")
    L_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-BAR")
    MHO = URIRef("http://qudt.org/vocab/unit/MHO")
    GM_SEC_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M6")
    MicroGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-SEC")
    MilliL_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-BAR")
    C_Ab = URIRef("http://qudt.org/vocab/unit/C_Ab")
    PERCENT_PER_M = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-M")
    MOL_PER_M2_SEC_SR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-SR")
    LB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT")
    KiloGM_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC2")
    MegaPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-BAR")
    K_PER_T = URIRef("http://qudt.org/vocab/unit/K-PER-T")
    CentiGM = URIRef("http://qudt.org/vocab/unit/CentiGM")
    BTU_IT_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_F")
    PSI_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-L-PER-SEC")
    PER_K = URIRef("http://qudt.org/vocab/unit/PER-K")
    N_M_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-M")
    CAL_IT_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM2-K")
    CUP_US = URIRef("http://qudt.org/vocab/unit/CUP_US")
    J_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2")
    LB_MIN_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-IN3")
    PebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M3")
    KiloGM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3")
    failures_in_time = URIRef("http://qudt.org/vocab/unit/failures-in-time")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    GM_HR_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L-CentiM3")
    OHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/OHM-PER-BAR")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    TeraHZ = URIRef("http://qudt.org/vocab/unit/TeraHZ")
    PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2")
    MicroGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-BAR")
    HectoPA = URIRef("http://qudt.org/vocab/unit/HectoPA")
    PCA = URIRef("http://qudt.org/vocab/unit/PCA")
    MilliK_PER_K = URIRef("http://qudt.org/vocab/unit/MilliK-PER-K")
    BTU_IT_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_F")
    MicroGM = URIRef("http://qudt.org/vocab/unit/MicroGM")
    PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/PER-ANGSTROM")
    MilliGM_PER_L_POISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-POISE")
    PPM = URIRef("http://qudt.org/vocab/unit/PPM")
    CentiM3_PER_HR_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR-K")
    OZ_F_IN = URIRef("http://qudt.org/vocab/unit/OZ_F-IN")
    MegaV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive")
    M2_PER_KiloW = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloW")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    FT_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-PER-HR")
    CAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC")
    KiloCAL_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL")
    H_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/H-PER-KiloOHM")
    H_PER_OHM = URIRef("http://qudt.org/vocab/unit/H-PER-OHM")
    J_PER_M = URIRef("http://qudt.org/vocab/unit/J-PER-M")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    GM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM_F-PER-CentiM2")
    GM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3")
    FT2_HR_DEG_F_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F-PER-BTU_IT")
    DeciM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-DAY")
    OCTET = URIRef("http://qudt.org/vocab/unit/OCTET")
    RAD_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-MOL")
    MicroSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-SEC")
    DPI = URIRef("http://qudt.org/vocab/unit/DPI")
    BBL_UK_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-SEC")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    NanoA_PER_K = URIRef("http://qudt.org/vocab/unit/NanoA-PER-K")
    W_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-SEC-PER-M2")
    N = URIRef("http://qudt.org/vocab/unit/N")
    LB_HR_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-IN3")
    GM_PER_CentiM3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3-BAR")
    MilliL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-KiloGM")
    PicoSEC = URIRef("http://qudt.org/vocab/unit/PicoSEC")
    OZ_SEC_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN6")
    DeciL = URIRef("http://qudt.org/vocab/unit/DeciL")
    RHE = URIRef("http://qudt.org/vocab/unit/RHE")
    KiloCAL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-SEC")
    MicroN_M = URIRef("http://qudt.org/vocab/unit/MicroN-M")
    AttoC = URIRef("http://qudt.org/vocab/unit/AttoC")
    IN_H2O = URIRef("http://qudt.org/vocab/unit/IN_H2O")
    S = URIRef("http://qudt.org/vocab/unit/S")
    MI_N_PER_HR = URIRef("http://qudt.org/vocab/unit/MI_N-PER-HR")
    BTU_IT_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB")
    OZ_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_UK")
    GT = URIRef("http://qudt.org/vocab/unit/GT")
    BAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-M3-PER-SEC")
    MicroGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-GM")
    TON_SHORT_PER_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR-DEG_F")
    PetaC = URIRef("http://qudt.org/vocab/unit/PetaC")
    M_PER_HR = URIRef("http://qudt.org/vocab/unit/M-PER-HR")
    MebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M2")
    MicroGM_PER_IN2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-IN2")
    LB_F_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN")
    NanoGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DeciL")
    MilliJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-M2")
    GRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/GRAY-PER-HR")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    CLO = URIRef("http://qudt.org/vocab/unit/CLO")
    MicroOHM_M = URIRef("http://qudt.org/vocab/unit/MicroOHM-M")
    A = URIRef("http://qudt.org/vocab/unit/A")
    MOL_PER_M3_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-PA")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    GA_Charriere = URIRef("http://qudt.org/vocab/unit/GA_Charriere")
    KiloGM_F_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-SEC")
    V_PER_M2 = URIRef("http://qudt.org/vocab/unit/V-PER-M2")
    PER_DEG_F = URIRef("http://qudt.org/vocab/unit/PER-DEG_F")
    OZ_SEC_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN6")
    MegaJ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-K")
    PFERDESTAERKE = URIRef("http://qudt.org/vocab/unit/PFERDESTAERKE")
    KiloCAL_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM-SEC-DEG_C")
    KiloV = URIRef("http://qudt.org/vocab/unit/KiloV")
    KiloGM_PER_M_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-MIN")
    NanoV_A = URIRef("http://qudt.org/vocab/unit/NanoV-A")
    YD3 = URIRef("http://qudt.org/vocab/unit/YD3")
    DecaGM = URIRef("http://qudt.org/vocab/unit/DecaGM")
    J_PER_GM_K = URIRef("http://qudt.org/vocab/unit/J-PER-GM-K")
    A_HR_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-DeciM3")
    W_PER_M2_PA = URIRef("http://qudt.org/vocab/unit/W-PER-M2-PA")
    LB_PER_FT = URIRef("http://qudt.org/vocab/unit/LB-PER-FT")
    ANGSTROM3 = URIRef("http://qudt.org/vocab/unit/ANGSTROM3")
    YD = URIRef("http://qudt.org/vocab/unit/YD")
    CARAT = URIRef("http://qudt.org/vocab/unit/CARAT")
    PA_M0pt5 = URIRef("http://qudt.org/vocab/unit/PA-M0pt5")
    DeciM3 = URIRef("http://qudt.org/vocab/unit/DeciM3")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    DeciTONNE = URIRef("http://qudt.org/vocab/unit/DeciTONNE")
    QT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-MIN")
    J_PER_T2 = URIRef("http://qudt.org/vocab/unit/J-PER-T2")
    PERCENT_PER_MilliM = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MilliM")
    BTU_IT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MIN")
    KiloBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBYTE-PER-SEC")
    MIL = URIRef("http://qudt.org/vocab/unit/MIL")
    N_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG")
    PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/PER-MilliM3")
    PER_MilliSEC = URIRef("http://qudt.org/vocab/unit/PER-MilliSEC")
    MicroC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M3")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    KiloGM_M = URIRef("http://qudt.org/vocab/unit/KiloGM-M")
    PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PER-M3-SEC")
    GigaHZ = URIRef("http://qudt.org/vocab/unit/GigaHZ")
    BTU_TH_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB")
    IN3_PER_HR = URIRef("http://qudt.org/vocab/unit/IN3-PER-HR")
    M2_PER_K = URIRef("http://qudt.org/vocab/unit/M2-PER-K")
    BU_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-SEC")
    MHO_Stat = URIRef("http://qudt.org/vocab/unit/MHO_Stat")
    MilliH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-KiloOHM")
    LB_T = URIRef("http://qudt.org/vocab/unit/LB_T")
    M_PER_BAR = URIRef("http://qudt.org/vocab/unit/M-PER-BAR")
    CentiC = URIRef("http://qudt.org/vocab/unit/CentiC")
    MilliGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HA")
    J_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-M2-PER-KiloGM")
    MilliGM_MIN_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L-CentiM3")
    KiloC_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M3")
    K_PER_T = URIRef("http://qudt.org/vocab/unit/K-PER-T")
    KiloGM_PER_MegaBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MegaBTU_IT")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    TeraHZ = URIRef("http://qudt.org/vocab/unit/TeraHZ")
    MicroMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MOL")
    TON_Metric_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR-BAR")
    B_PER_M = URIRef("http://qudt.org/vocab/unit/B-PER-M")
    M_K = URIRef("http://qudt.org/vocab/unit/M-K")
    CentiM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SEC")
    LB_PER_GAL = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL")
    MegaPA_M0pt5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0pt5")
    DecaARE = URIRef("http://qudt.org/vocab/unit/DecaARE")
    TON_SHORT_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-YD3")
    GM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN-BAR")
    TONNE_PER_SEC = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    GM_PER_L_PA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-L-PA-SEC")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    LB_MIN_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-GAL_UK")
    PicoMOL_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L-DAY")
    MilliDEG_C = URIRef("http://qudt.org/vocab/unit/MilliDEG_C")
    FT_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT-PER-DAY")
    J_M_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-M-PER-MOL")
    BBL_UK_PET_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-DAY")
    TeraW = URIRef("http://qudt.org/vocab/unit/TeraW")
    YD3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD3-PER-DEG_F")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    HP_Brake = URIRef("http://qudt.org/vocab/unit/HP_Brake")
    GM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC")
    GigaBIT_PER_M = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-M")
    FT_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT-PER-DAY")
    CAL_IT_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM-K")
    N_M_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-M")
    BARN_PER_EV = URIRef("http://qudt.org/vocab/unit/BARN-PER-EV")
    PERCENT_SEC_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-FT3")
    PicoA_PER_HectoPA = URIRef("http://qudt.org/vocab/unit/PicoA-PER-HectoPA")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    KiloV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive-HR")
    TONNE_PER_M3_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3-K")
    MilliA_HR = URIRef("http://qudt.org/vocab/unit/MilliA-HR")
    FT_LB_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-MIN")
    MegaPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-M3-PER-SEC")
    DEG_F_HR_FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT-IN")
    LB_PER_MIN_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN-PSI")
    PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/PER-ANGSTROM")
    GAL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-MIN")
    MegaPA_M0dot5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0dot5")
    YD_PER_HR = URIRef("http://qudt.org/vocab/unit/YD-PER-HR")
    BARN_PER_SR_EV = URIRef("http://qudt.org/vocab/unit/BARN-PER-SR-EV")
    NUM_PER_HR = URIRef("http://qudt.org/vocab/unit/NUM-PER-HR")
    OZ_IN = URIRef("http://qudt.org/vocab/unit/OZ-IN")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    BU_US = URIRef("http://qudt.org/vocab/unit/BU_US")
    L_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-BAR")
    PERCENT_PER_POISE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-POISE")
    Denier = URIRef("http://qudt.org/vocab/unit/Denier")
    J_PER_M4 = URIRef("http://qudt.org/vocab/unit/J-PER-M4")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    EU_PER_L = URIRef("http://qudt.org/vocab/unit/EU-PER-L")
    KiloGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN")
    NanoM_PER_CentiM_PSI = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-PSI")
    LunarMass = URIRef("http://qudt.org/vocab/unit/LunarMass")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    KiloPA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-MilliM")
    MicroGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2")
    CentiM3_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR-BAR")
    CentiM_H2O = URIRef("http://qudt.org/vocab/unit/CentiM_H2O")
    MilliBAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-L-PER-SEC")
    KN = URIRef("http://qudt.org/vocab/unit/KN")
    BTU_IT_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT-PER-FT2-HR-DEG_F")
    A_PER_RAD = URIRef("http://qudt.org/vocab/unit/A-PER-RAD")
    N_PER_A = URIRef("http://qudt.org/vocab/unit/N-PER-A")
    BTU_TH_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    S_Ab = URIRef("http://qudt.org/vocab/unit/S_Ab")
    KiloGM_PER_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA")
    ExbiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M3")
    PlanckLength = URIRef("http://qudt.org/vocab/unit/PlanckLength")
    BIOT = URIRef("http://qudt.org/vocab/unit/BIOT")
    LB_SEC_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-YD3")
    MI_N_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI_N-PER-MIN")
    CAL_TH_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2")
    KiloA_HR = URIRef("http://qudt.org/vocab/unit/KiloA-HR")
    ATM = URIRef("http://qudt.org/vocab/unit/ATM")
    H_Ab = URIRef("http://qudt.org/vocab/unit/H_Ab")
    IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN3-PER-SEC")
    MegaHZ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-K")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    BFT = URIRef("http://qudt.org/vocab/unit/BFT")
    CAL_IT = URIRef("http://qudt.org/vocab/unit/CAL_IT")
    YD3_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD3-PER-MIN")
    K_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PER-SEC")
    TONNE_PER_HR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR")
    L_PER_L = URIRef("http://qudt.org/vocab/unit/L-PER-L")
    MilliM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliM-PER-MIN")
    PK_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-HR")
    K2 = URIRef("http://qudt.org/vocab/unit/K2")
    PlanckPressure = URIRef("http://qudt.org/vocab/unit/PlanckPressure")
    BTU_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-MIN")
    CAL_TH_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM2-K")
    KiloM3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM3-PER-SEC2")
    GRAIN = URIRef("http://qudt.org/vocab/unit/GRAIN")
    M2_HR_DEG_C_PER_KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/M2-HR-DEG_C-PER-KiloCAL_IT")
    GM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY-BAR")
    C_M2_PER_V = URIRef("http://qudt.org/vocab/unit/C-M2-PER-V")
    DeciSEC = URIRef("http://qudt.org/vocab/unit/DeciSEC")
    MicroG_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroG-PER-CentiM2")
    MilliA_PER_IN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-IN")
    TONNE_PER_MO = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MO")
    DEG_F_PER_BAR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-BAR")
    DAY_Sidereal = URIRef("http://qudt.org/vocab/unit/DAY_Sidereal")
    M2_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-V-SEC")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    THERM_US = URIRef("http://qudt.org/vocab/unit/THERM_US")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    J_PER_M = URIRef("http://qudt.org/vocab/unit/J-PER-M")
    OZ_F = URIRef("http://qudt.org/vocab/unit/OZ_F")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    GAL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-DAY")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    MilliM3 = URIRef("http://qudt.org/vocab/unit/MilliM3")
    OHM_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-PER-M")
    C_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM3")
    MilliA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliA-PER-BAR")
    LB_F_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN")
    MilliV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliV-PER-MIN")
    KiloBTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH-PER-HR")
    H_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/H_Stat-PER-CentiM")
    PetaJ = URIRef("http://qudt.org/vocab/unit/PetaJ")
    MicroM = URIRef("http://qudt.org/vocab/unit/MicroM")
    CentiM3_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-BAR")
    MicroL = URIRef("http://qudt.org/vocab/unit/MicroL")
    PERCENT_RH = URIRef("http://qudt.org/vocab/unit/PERCENT_RH")
    KiloV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive-HR")
    FT = URIRef("http://qudt.org/vocab/unit/FT")
    IN2_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN2-PER-SEC")
    GM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY-K")
    KiloEV_PER_MicroM = URIRef("http://qudt.org/vocab/unit/KiloEV-PER-MicroM")
    KibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M")
    M3_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-K")
    CASES_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-1000I-YR")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    KiloGM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM-PER-SEC")
    BBL = URIRef("http://qudt.org/vocab/unit/BBL")
    GigaHZ = URIRef("http://qudt.org/vocab/unit/GigaHZ")
    GI_UK = URIRef("http://qudt.org/vocab/unit/GI_UK")
    PK_UK = URIRef("http://qudt.org/vocab/unit/PK_UK")
    AttoJ_SEC = URIRef("http://qudt.org/vocab/unit/AttoJ-SEC")
    CentiM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SEC")
    ExaC = URIRef("http://qudt.org/vocab/unit/ExaC")
    OZ_M = URIRef("http://qudt.org/vocab/unit/OZ_M")
    N_PER_MilliM = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM")
    PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2")
    TON_LONG = URIRef("http://qudt.org/vocab/unit/TON_LONG")
    CAL_TH_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM")
    V_A_PER_K = URIRef("http://qudt.org/vocab/unit/V-A-PER-K")
    SLUG_PER_DAY = URIRef("http://qudt.org/vocab/unit/SLUG-PER-DAY")
    PERM_US = URIRef("http://qudt.org/vocab/unit/PERM_US")
    OZ = URIRef("http://qudt.org/vocab/unit/OZ")
    KiloM3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM3-PER-SEC2")
    NanoMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL")
    GRAIN_PER_GAL = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL")
    MilliGM_PER_L = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L")
    PicoPA = URIRef("http://qudt.org/vocab/unit/PicoPA")
    MicroG = URIRef("http://qudt.org/vocab/unit/MicroG")
    PK_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-HR")
    KiloPA_A = URIRef("http://qudt.org/vocab/unit/KiloPA_A")
    MilliGM_HR_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M3-L")
    PERCENT_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEG_C")
    PebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M")
    THM_US_PER_HR = URIRef("http://qudt.org/vocab/unit/THM_US-PER-HR")
    BTU_IT_IN_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-HR-FT2-DEG_F")
    KiloGM_PER_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-K")
    MOL_PER_KiloGM_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-BAR")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    MilliN_M = URIRef("http://qudt.org/vocab/unit/MilliN-M")
    L_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-MOL-SEC")
    GAUGE_FR = URIRef("http://qudt.org/vocab/unit/GAUGE_FR")
    MicroGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-MilliL")
    KiloM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM2-PER-SEC2")
    FemtoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-KiloGM")
    FT2_HR_DEG_F_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F-PER-BTU_IT")
    LB_SEC_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-GAL_US")
    MicroMOL = URIRef("http://qudt.org/vocab/unit/MicroMOL")
    N_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M")
    GigaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-SEC")
    MilliL_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR")
    PERM_Metric = URIRef("http://qudt.org/vocab/unit/PERM_Metric")
    MHO = URIRef("http://qudt.org/vocab/unit/MHO")
    GM_F = URIRef("http://qudt.org/vocab/unit/GM_F")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    TON_SHORT_PER_PSI = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-PSI")
    LB_MIN_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-IN3")
    S = URIRef("http://qudt.org/vocab/unit/S")
    N_M_PER_M_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-M-RAD")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    HectoGM = URIRef("http://qudt.org/vocab/unit/HectoGM")
    DeciC = URIRef("http://qudt.org/vocab/unit/DeciC")
    CAL_IT_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM")
    H = URIRef("http://qudt.org/vocab/unit/H")
    PPM = URIRef("http://qudt.org/vocab/unit/PPM")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    CentiGM = URIRef("http://qudt.org/vocab/unit/CentiGM")
    M_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-PA")
    MicroGM_PER_CentiM2_WK = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2-WK")
    ANGSTROM = URIRef("http://qudt.org/vocab/unit/ANGSTROM")
    KiloBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBIT-PER-SEC")
    FT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-DEG_F")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    OZ_VOL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-HR")
    PicoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L")
    LB_SEC_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-GAL_UK")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    DeciM2 = URIRef("http://qudt.org/vocab/unit/DeciM2")
    DEGREE_OECHSLE = URIRef("http://qudt.org/vocab/unit/DEGREE_OECHSLE")
    OCTET_PER_SEC = URIRef("http://qudt.org/vocab/unit/OCTET-PER-SEC")
    OZ_FT_SEC_PER_IN3_LB = URIRef("http://qudt.org/vocab/unit/OZ-FT-SEC-PER-IN3-LB")
    GigaV_A_Reactive = URIRef("http://qudt.org/vocab/unit/GigaV-A_Reactive")
    GM_PER_GM = URIRef("http://qudt.org/vocab/unit/GM-PER-GM")
    PINT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-MIN")
    MicroCi = URIRef("http://qudt.org/vocab/unit/MicroCi")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    TON_Metric_PER_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-BAR")
    TeraA = URIRef("http://qudt.org/vocab/unit/TeraA")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    DEG_R = URIRef("http://qudt.org/vocab/unit/DEG_R")
    HR_FT2 = URIRef("http://qudt.org/vocab/unit/HR-FT2")
    MicroW = URIRef("http://qudt.org/vocab/unit/MicroW")
    IN_PER_2PiRAD = URIRef("http://qudt.org/vocab/unit/IN-PER-2PiRAD")
    W_M_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-M-PER-M2-SR")
    J = URIRef("http://qudt.org/vocab/unit/J")
    HP_Electric = URIRef("http://qudt.org/vocab/unit/HP_Electric")
    PA_PER_HR = URIRef("http://qudt.org/vocab/unit/PA-PER-HR")
    KiloMOL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-HR")
    KiloMOL_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3-K")
    N_M_PER_ARCMIN = URIRef("http://qudt.org/vocab/unit/N-M-PER-ARCMIN")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    MilliM_PER_YR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-YR")
    IN_H2O = URIRef("http://qudt.org/vocab/unit/IN_H2O")
    PERM_Metric = URIRef("http://qudt.org/vocab/unit/PERM_Metric")
    KiloCAL_TH = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH")
    MilliGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-K")
    BTU_IT_PER_FT2_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR")
    FT_LB_F_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2-SEC")
    KiloGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC")
    MegaPA_PER_K = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-K")
    BTU_IT_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_F")
    M_PER_K = URIRef("http://qudt.org/vocab/unit/M-PER-K")
    MicroJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroJ-PER-SEC")
    TONNE_PER_M3_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3-K")
    GigaBasePair = URIRef("http://qudt.org/vocab/unit/GigaBasePair")
    PPT = URIRef("http://qudt.org/vocab/unit/PPT")
    LB_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN2")
    PlanckDensity = URIRef("http://qudt.org/vocab/unit/PlanckDensity")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    ST = URIRef("http://qudt.org/vocab/unit/ST")
    BTU_IT_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC-DEG_F")
    EV_PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/EV-PER-ANGSTROM")
    MegaTON = URIRef("http://qudt.org/vocab/unit/MegaTON")
    KiloGM_F_M_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-CentiM2")
    MilliGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-GM")
    MOMME_Textile = URIRef("http://qudt.org/vocab/unit/MOMME_Textile")
    PER_FT3 = URIRef("http://qudt.org/vocab/unit/PER-FT3")
    CM_H2O = URIRef("http://qudt.org/vocab/unit/CM_H2O")
    C2_M2_PER_J = URIRef("http://qudt.org/vocab/unit/C2-M2-PER-J")
    N_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-M-PER-M2")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    L_PER_K = URIRef("http://qudt.org/vocab/unit/L-PER-K")
    KiloA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M")
    KiloGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY")
    TON_SHORT_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    GALILEO = URIRef("http://qudt.org/vocab/unit/GALILEO")
    KiloCAL_PER_MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL-DEG_C")
    MicroM_PER_N = URIRef("http://qudt.org/vocab/unit/MicroM-PER-N")
    MegaGM = URIRef("http://qudt.org/vocab/unit/MegaGM")
    AT_PER_IN = URIRef("http://qudt.org/vocab/unit/AT-PER-IN")
    PebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M2")
    KiloGM_PER_J = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-J")
    PA_SEC_PER_L = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-L")
    CFU = URIRef("http://qudt.org/vocab/unit/CFU")
    RAD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC2")
    PERCENT_MIN_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-IN3")
    MegaEV_FemtoM = URIRef("http://qudt.org/vocab/unit/MegaEV-FemtoM")
    HectoM = URIRef("http://qudt.org/vocab/unit/HectoM")
    PetaC = URIRef("http://qudt.org/vocab/unit/PetaC")
    CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM-SEC-DEG_C")
    MilliV_PER_V = URIRef("http://qudt.org/vocab/unit/MilliV-PER-V")
    MilliM_H2O = URIRef("http://qudt.org/vocab/unit/MilliM_H2O")
    PFUND = URIRef("http://qudt.org/vocab/unit/PFUND")
    LB_IN = URIRef("http://qudt.org/vocab/unit/LB-IN")
    PER_H = URIRef("http://qudt.org/vocab/unit/PER-H")
    NanoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L")
    ERG_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM")
    FT_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC2")
    W_PER_IN2 = URIRef("http://qudt.org/vocab/unit/W-PER-IN2")
    PER_K = URIRef("http://qudt.org/vocab/unit/PER-K")
    LB_PER_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-HR-DEG_F")
    BIOT = URIRef("http://qudt.org/vocab/unit/BIOT")
    NanoGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M3")
    MilliW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2")
    ExaJ = URIRef("http://qudt.org/vocab/unit/ExaJ")
    GigaPA = URIRef("http://qudt.org/vocab/unit/GigaPA")
    DEG_F_PER_BAR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-BAR")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    PA_PER_MIN = URIRef("http://qudt.org/vocab/unit/PA-PER-MIN")
    N_M_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-M-PER-KiloGM")
    KiloW = URIRef("http://qudt.org/vocab/unit/KiloW")
    OZ_PER_GAL = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL")
    LB_SEC_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-GAL_UK")
    ExbiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M2")
    GI_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-HR")
    KiloCAL_TH = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH")
    MegaPA_M0dot5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0dot5")
    FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-DEG_F")
    PicoPA = URIRef("http://qudt.org/vocab/unit/PicoPA")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    M3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL-SEC")
    GigaOHM = URIRef("http://qudt.org/vocab/unit/GigaOHM")
    MilliDEG_C = URIRef("http://qudt.org/vocab/unit/MilliDEG_C")
    MilliBAR_PER_K = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-K")
    MicroATM = URIRef("http://qudt.org/vocab/unit/MicroATM")
    BTU_TH_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_F")
    KiloC_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M3")
    PER_K = URIRef("http://qudt.org/vocab/unit/PER-K")
    TON_Metric = URIRef("http://qudt.org/vocab/unit/TON_Metric")
    LB_HR_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT6")
    M_SEC2 = URIRef("http://qudt.org/vocab/unit/M-SEC2")
    M3_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-M2")
    MilliARCSEC = URIRef("http://qudt.org/vocab/unit/MilliARCSEC")
    MilliBAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-M3-PER-SEC")
    KiloGM_F_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-MilliM2")
    CentiM3_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-BAR")
    OZ_HR_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-GAL_US")
    TON_Metric_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR")
    KiloN_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M2")
    STILB = URIRef("http://qudt.org/vocab/unit/STILB")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    PicoMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M3")
    MilliGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-GM")
    MOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC")
    MilliL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN")
    MicroM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroM-PER-SEC")
    V_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/V-A_Reactive-HR")
    FT3_PER_MIN_FT2 = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN-FT2")
    GRAIN = URIRef("http://qudt.org/vocab/unit/GRAIN")
    CAL_15_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_15_DEG_C")
    LB_F_PER_IN2_DEG_F = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-DEG_F")
    BTU_TH_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-FT2-HR-DEG_F")
    PER_MegaK = URIRef("http://qudt.org/vocab/unit/PER-MegaK")
    LB_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC-PSI")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    YoctoC = URIRef("http://qudt.org/vocab/unit/YoctoC")
    MicroC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M2")
    M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/M2-PER-MOL")
    C_Stat_PER_MOL = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-MOL")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    MegaN_M = URIRef("http://qudt.org/vocab/unit/MegaN-M")
    MI_N_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI_N-PER-MIN")
    DEG_C2_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C2-PER-SEC")
    GM_HR_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M3-CentiM3")
    HZ_PER_V = URIRef("http://qudt.org/vocab/unit/HZ-PER-V")
    PERCENT_PER_OHM = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-OHM")
    GM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloGM")
    LB_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC-PSI")
    DEGREE_TWADDELL = URIRef("http://qudt.org/vocab/unit/DEGREE_TWADDELL")
    GM_PER_M3_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-MilliPA-SEC")
    KibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M3")
    LB_HR_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-YD3")
    PA_PER_K = URIRef("http://qudt.org/vocab/unit/PA-PER-K")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    MilliL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M3")
    MilliL_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-K")
    KiloGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-SEC")
    L_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-M2")
    NanoGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-MIN")
    V_A_Reactive = URIRef("http://qudt.org/vocab/unit/V-A_Reactive")
    MilliGM_HR_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L-CentiM3")
    BYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/BYTE-PER-SEC")
    CentiM3_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-K")
    GI_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_US-PER-SEC")
    LB_M = URIRef("http://qudt.org/vocab/unit/LB_M")
    MegaV_A = URIRef("http://qudt.org/vocab/unit/MegaV-A")
    FT3_PER_HR = URIRef("http://qudt.org/vocab/unit/FT3-PER-HR")
    MOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM")
    MilliL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-GM")
    TebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M3")
    PERCENT_PER_10KiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-10KiloCount")
    C4_M4_PER_J3 = URIRef("http://qudt.org/vocab/unit/C4-M4-PER-J3")
    KiloPOND = URIRef("http://qudt.org/vocab/unit/KiloPOND")
    MicroC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M2")
    GM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-M2-DAY")
    LB_F_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-FT2")
    CAL_TH_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    SEC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/SEC-PER-KiloGM")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    MilliBQ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-GM")
    MilliHZ = URIRef("http://qudt.org/vocab/unit/MilliHZ")
    KiloGM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    MilliC = URIRef("http://qudt.org/vocab/unit/MilliC")
    PERCENT_PER_DEGREE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEGREE")
    YD3_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD3-PER-MIN")
    C_PER_MOL = URIRef("http://qudt.org/vocab/unit/C-PER-MOL")
    FT_HG = URIRef("http://qudt.org/vocab/unit/FT_HG")
    A_PER_MilliM = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM")
    MilliL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliL-PER-L")
    KiloGM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3")
    PINT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-SEC")
    GI_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_US-PER-DAY")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    MilliM_PER_YR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-YR")
    LB_SEC_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-GAL_US")
    C_Stat = URIRef("http://qudt.org/vocab/unit/C_Stat")
    L_PER_L = URIRef("http://qudt.org/vocab/unit/L-PER-L")
    POISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/POISE-PER-BAR")
    KiloCAL_PER_MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL-DEG_C")
    MilliC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M3")
    MicroM3 = URIRef("http://qudt.org/vocab/unit/MicroM3")
    TON_FG = URIRef("http://qudt.org/vocab/unit/TON_FG")
    CentiPOISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-BAR")
    MilliL_PER_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-K")
    ERG_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM3")
    DecaL = URIRef("http://qudt.org/vocab/unit/DecaL")
    GM_HR_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M3-L")
    NanoW = URIRef("http://qudt.org/vocab/unit/NanoW")
    DeciTONNE = URIRef("http://qudt.org/vocab/unit/DeciTONNE")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    OHM_PER_K = URIRef("http://qudt.org/vocab/unit/OHM-PER-K")
    TONNE_PER_HR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    BAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-L-PER-SEC")
    KiloGM_PER_L = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L")
    CP = URIRef("http://qudt.org/vocab/unit/CP")
    MilliBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-KiloGM")
    KiloBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBYTE-PER-SEC")
    H_PER_M = URIRef("http://qudt.org/vocab/unit/H-PER-M")
    OHM_CentiM = URIRef("http://qudt.org/vocab/unit/OHM-CentiM")
    FT_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-PER-MIN")
    J_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    YD3 = URIRef("http://qudt.org/vocab/unit/YD3")
    DRAM_UK = URIRef("http://qudt.org/vocab/unit/DRAM_UK")
    M_PER_MIN = URIRef("http://qudt.org/vocab/unit/M-PER-MIN")
    MicroKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MicroKAT-PER-L")
    H_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/H-PER-KiloOHM")
    EV_PER_T = URIRef("http://qudt.org/vocab/unit/EV-PER-T")
    LB_MIN_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK2")
    PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PER-CentiM3")
    BIOT = URIRef("http://qudt.org/vocab/unit/BIOT")
    KiloV = URIRef("http://qudt.org/vocab/unit/KiloV")
    HR_PER_FT2 = URIRef("http://qudt.org/vocab/unit/HR-PER-FT2")
    MilliGM_HR_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M3-CentiM3")
    TON_Metric_PER_M3 = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    BBL = URIRef("http://qudt.org/vocab/unit/BBL")
    FT_LA = URIRef("http://qudt.org/vocab/unit/FT-LA")
    GAL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-HR")
    DEG_F_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-K")
    KiloW = URIRef("http://qudt.org/vocab/unit/KiloW")
    PERCENT_PER_CentiPOISE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-CentiPOISE")
    GM_HR_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M6")
    PicoSEC = URIRef("http://qudt.org/vocab/unit/PicoSEC")
    GI_US = URIRef("http://qudt.org/vocab/unit/GI_US")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    MilliN_PER_M = URIRef("http://qudt.org/vocab/unit/MilliN-PER-M")
    CUP = URIRef("http://qudt.org/vocab/unit/CUP")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    MOL_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-K")
    TON_Metric_PER_MIN = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN")
    FC = URIRef("http://qudt.org/vocab/unit/FC")
    KiloOHM_PER_K = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-K")
    V_PER_V = URIRef("http://qudt.org/vocab/unit/V-PER-V")
    KiloBTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-FT2")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    M5 = URIRef("http://qudt.org/vocab/unit/M5")
    TeraOHM = URIRef("http://qudt.org/vocab/unit/TeraOHM")
    FemtoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-L")
    CAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-K")
    MegaHZ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-K")
    NanoGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DAY")
    M4 = URIRef("http://qudt.org/vocab/unit/M4")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    KiloGM_PER_M_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC2")
    KiloW_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloW-HR-PER-M2")
    CAL_TH_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM-SEC-DEG_C")
    KiloGM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MilliM")
    H = URIRef("http://qudt.org/vocab/unit/H")
    MIL_Circ = URIRef("http://qudt.org/vocab/unit/MIL_Circ")
    FemtoA = URIRef("http://qudt.org/vocab/unit/FemtoA")
    BTU_IT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR-DEG_F")
    DecaGM = URIRef("http://qudt.org/vocab/unit/DecaGM")
    PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PER-CentiM3")
    J_PER_M = URIRef("http://qudt.org/vocab/unit/J-PER-M")
    KiloH = URIRef("http://qudt.org/vocab/unit/KiloH")
    KN = URIRef("http://qudt.org/vocab/unit/KN")
    FT_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-PER-HR")
    MicroC = URIRef("http://qudt.org/vocab/unit/MicroC")
    LB_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_UK")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    TON_Register = URIRef("http://qudt.org/vocab/unit/TON_Register")
    KiloGM_M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M2-PER-SEC")
    R_PER_SEC = URIRef("http://qudt.org/vocab/unit/R-PER-SEC")
    MegaOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-BAR")
    PPTR = URIRef("http://qudt.org/vocab/unit/PPTR")
    ExaC = URIRef("http://qudt.org/vocab/unit/ExaC")
    KiloV_A_Reactive = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    MIN_Sidereal = URIRef("http://qudt.org/vocab/unit/MIN_Sidereal")
    CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-GM")
    M_PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PA-PER-SEC")
    TON_US_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_US-PER-HR")
    MegaPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-L-PER-SEC")
    KiloN = URIRef("http://qudt.org/vocab/unit/KiloN")
    TONNE = URIRef("http://qudt.org/vocab/unit/TONNE")
    ERG_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM")
    KIP_F = URIRef("http://qudt.org/vocab/unit/KIP_F")
    GAL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-DAY")
    KiloM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-HR")
    BTU_TH = URIRef("http://qudt.org/vocab/unit/BTU_TH")
    BAR_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/BAR-PER-DEG_C")
    V_A_PER_K = URIRef("http://qudt.org/vocab/unit/V-A-PER-K")
    QT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-SEC")
    L_PER_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-BAR")
    MOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MOL-PER-MOL")
    BU_US = URIRef("http://qudt.org/vocab/unit/BU_US")
    CentiM_HG_0DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_HG_0DEG_C")
    LB_IN2_PER_FT3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-FT3-LB_F-SEC")
    PK_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-DAY")
    MicroM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM-PER-MilliL")
    GM_MIN_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L2")
    M3_PER_MIN = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN")
    OZ_VOL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-SEC")
    KiloGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloGM")
    DEG_F_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-HR")
    PERCENT_MIN_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-GAL_UK")
    ARCSEC = URIRef("http://qudt.org/vocab/unit/ARCSEC")
    KiloJ_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-HR")
    MegaHZ_M = URIRef("http://qudt.org/vocab/unit/MegaHZ-M")
    MicroM_PER_N = URIRef("http://qudt.org/vocab/unit/MicroM-PER-N")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    CAL_20DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_20DEG_C")
    PERCENT_MIN_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-IN3")
    N_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG")
    LM_SEC = URIRef("http://qudt.org/vocab/unit/LM-SEC")
    MOL_PER_M2_SEC_M_SR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-M-SR")
    THM_US_PER_HR = URIRef("http://qudt.org/vocab/unit/THM_US-PER-HR")
    TONNE_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC-K")
    EV_PER_T = URIRef("http://qudt.org/vocab/unit/EV-PER-T")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    ERG_PER_G = URIRef("http://qudt.org/vocab/unit/ERG-PER-G")
    QT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_US-PER-HR")
    J_PER_MIN = URIRef("http://qudt.org/vocab/unit/J-PER-MIN")
    MOL_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB")
    PicoA_PER_MicroMOL_L = URIRef("http://qudt.org/vocab/unit/PicoA-PER-MicroMOL-L")
    MegaN = URIRef("http://qudt.org/vocab/unit/MegaN")
    MilliM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliM-PER-MIN")
    AT_PER_M = URIRef("http://qudt.org/vocab/unit/AT-PER-M")
    PER_M_K = URIRef("http://qudt.org/vocab/unit/PER-M-K")
    M2_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/M2-SEC-PER-RAD")
    BQ_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-SEC-PER-M3")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    BYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/BYTE-PER-SEC")
    PERMITTIVITY_REL = URIRef("http://qudt.org/vocab/unit/PERMITTIVITY_REL")
    PicoS = URIRef("http://qudt.org/vocab/unit/PicoS")
    CAL_IT = URIRef("http://qudt.org/vocab/unit/CAL_IT")
    KiloM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC2")
    J_PER_M4 = URIRef("http://qudt.org/vocab/unit/J-PER-M4")
    KiloGM_PER_M_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC2")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    M2_PER_SR = URIRef("http://qudt.org/vocab/unit/M2-PER-SR")
    M3_PER_M3 = URIRef("http://qudt.org/vocab/unit/M3-PER-M3")
    LB_PER_FT_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-HR")
    NanoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MilliL")
    MI_PER_SEC = URIRef("http://qudt.org/vocab/unit/MI-PER-SEC")
    GAL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-HR")
    J = URIRef("http://qudt.org/vocab/unit/J")
    KiloN_M_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-M")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    QT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_US-PER-SEC")
    K_PER_K = URIRef("http://qudt.org/vocab/unit/K-PER-K")
    PERCENT_PER_POISE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-POISE")
    A_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM2")
    KiloMOL_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3-BAR")
    NTU = URIRef("http://qudt.org/vocab/unit/NTU")
    M3_PER_MIN = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN")
    NanoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/NanoKAT-PER-L")
    PPB = URIRef("http://qudt.org/vocab/unit/PPB")
    CentiC = URIRef("http://qudt.org/vocab/unit/CentiC")
    NanoS = URIRef("http://qudt.org/vocab/unit/NanoS")
    CAL_TH_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM-K")
    GM_PER_M3_POISE = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-POISE")
    MOL_PER_KiloGM_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-PA")
    FemtoGM_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-L")
    OZ_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ-PER-MIN")
    PERMITTIVITY_REL = URIRef("http://qudt.org/vocab/unit/PERMITTIVITY_REL")
    FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC")
    M2_PER_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ2")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    PERCENT_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-CentiM3")
    DecaGM = URIRef("http://qudt.org/vocab/unit/DecaGM")
    MegaV_PER_M = URIRef("http://qudt.org/vocab/unit/MegaV-PER-M")
    TONNE_PER_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-BAR")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    PINT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-MIN")
    V_M = URIRef("http://qudt.org/vocab/unit/V-M")
    BBL_US_DRY = URIRef("http://qudt.org/vocab/unit/BBL_US_DRY")
    GM_PER_MilliL_K = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL-K")
    PER_J2 = URIRef("http://qudt.org/vocab/unit/PER-J2")
    M3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL-SEC")
    MegaV_A_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A-HR")
    FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-SEC")
    DEG_F_HR_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_TH")
    NanoH = URIRef("http://qudt.org/vocab/unit/NanoH")
    MilliGM = URIRef("http://qudt.org/vocab/unit/MilliGM")
    TebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M2")
    PERMITTIVITY_REL = URIRef("http://qudt.org/vocab/unit/PERMITTIVITY_REL")
    NUM_PER_YR = URIRef("http://qudt.org/vocab/unit/NUM-PER-YR")
    DeciS_PER_M = URIRef("http://qudt.org/vocab/unit/DeciS-PER-M")
    PERCENT_PER_DEGREE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEGREE")
    L_PER_MOL = URIRef("http://qudt.org/vocab/unit/L-PER-MOL")
    LB_PER_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-DAY")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    MegaGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-M3")
    MicroGRAY = URIRef("http://qudt.org/vocab/unit/MicroGRAY")
    AC_FT_US = URIRef("http://qudt.org/vocab/unit/AC-FT_US")
    SPF = URIRef("http://qudt.org/vocab/unit/SPF")
    BARN_PER_SR = URIRef("http://qudt.org/vocab/unit/BARN-PER-SR")
    DecaM3 = URIRef("http://qudt.org/vocab/unit/DecaM3")
    C_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM3")
    L = URIRef("http://qudt.org/vocab/unit/L")
    PER_K = URIRef("http://qudt.org/vocab/unit/PER-K")
    BTU_IT_PER_SEC_FT_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT-DEG_R")
    IU_PER_MilliL = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliL")
    NanoSEC = URIRef("http://qudt.org/vocab/unit/NanoSEC")
    LB_F_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-FT2")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    PER_DAY = URIRef("http://qudt.org/vocab/unit/PER-DAY")
    MIN_Sidereal = URIRef("http://qudt.org/vocab/unit/MIN_Sidereal")
    NUM_PER_SEC = URIRef("http://qudt.org/vocab/unit/NUM-PER-SEC")
    A_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/A-PER-KiloGM")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    V = URIRef("http://qudt.org/vocab/unit/V")
    PER_WK = URIRef("http://qudt.org/vocab/unit/PER-WK")
    PA_PER_M = URIRef("http://qudt.org/vocab/unit/PA-PER-M")
    DeciM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-DAY")
    BTU_IT_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT3")
    MicroM_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/MicroM-PER-L-DAY")
    Quarter_UK = URIRef("http://qudt.org/vocab/unit/Quarter_UK")
    CAL_TH_PER_G = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-G")
    J_PER_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-DAY")
    CWT_SHORT = URIRef("http://qudt.org/vocab/unit/CWT_SHORT")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    DecaC = URIRef("http://qudt.org/vocab/unit/DecaC")
    MegaC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M2")
    PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/PER-KiloGM-SEC")
    GM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3")
    PicoGM_PER_L = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-L")
    L_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-HR-BAR")
    DEG_C2_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C2-PER-SEC")
    PER_T_SEC = URIRef("http://qudt.org/vocab/unit/PER-T-SEC")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    MegaBQ = URIRef("http://qudt.org/vocab/unit/MegaBQ")
    A_HR_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/A-HR-PER-KiloGM")
    LB_MIN_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-YD3")
    CentiM3_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    BTU_TH_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-SEC")
    MI_UK3 = URIRef("http://qudt.org/vocab/unit/MI_UK3")
    CentiM_H2O = URIRef("http://qudt.org/vocab/unit/CentiM_H2O")
    L_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-BAR")
    KiloC = URIRef("http://qudt.org/vocab/unit/KiloC")
    DecaL = URIRef("http://qudt.org/vocab/unit/DecaL")
    PSI_PER_IN = URIRef("http://qudt.org/vocab/unit/PSI-PER-IN")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    KiloV_A = URIRef("http://qudt.org/vocab/unit/KiloV-A")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    NanoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-KiloGM")
    TON_Metric_PER_M3_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3-K")
    MicroH_PER_M = URIRef("http://qudt.org/vocab/unit/MicroH-PER-M")
    L_PER_K = URIRef("http://qudt.org/vocab/unit/L-PER-K")
    PERCENT_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-CentiM3")
    IU = URIRef("http://qudt.org/vocab/unit/IU")
    EV_M2 = URIRef("http://qudt.org/vocab/unit/EV-M2")
    MilliGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-HR")
    BTU_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC")
    GM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM_F-PER-CentiM2")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    L_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-HR-BAR")
    M = URIRef("http://qudt.org/vocab/unit/M")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    KiloCAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-MIN")
    BU_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-MIN")
    LB_HR_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-FT3")
    TON_SHORT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-DEG_F")
    LB_IN2 = URIRef("http://qudt.org/vocab/unit/LB-IN2")
    DAY_Sidereal = URIRef("http://qudt.org/vocab/unit/DAY_Sidereal")
    DEG_R = URIRef("http://qudt.org/vocab/unit/DEG_R")
    GM_SEC_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L-M3")
    LB_PER_M3 = URIRef("http://qudt.org/vocab/unit/LB-PER-M3")
    W_M2_PER_SR = URIRef("http://qudt.org/vocab/unit/W-M2-PER-SR")
    GI_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-HR")
    M2_HR_DEG_C_PER_KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/M2-HR-DEG_C-PER-KiloCAL_IT")
    AT = URIRef("http://qudt.org/vocab/unit/AT")
    YD = URIRef("http://qudt.org/vocab/unit/YD")
    OZ_VOL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-HR")
    DeciB_A = URIRef("http://qudt.org/vocab/unit/DeciB_A")
    KiloW_PER_M_K = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M-K")
    HectoPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-L-PER-SEC")
    FemtoC = URIRef("http://qudt.org/vocab/unit/FemtoC")
    MilliMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-MOL")
    MilliGM_PER_L_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-MilliPA-SEC")
    GRAIN_PER_GAL = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    THM_US_PER_HR = URIRef("http://qudt.org/vocab/unit/THM_US-PER-HR")
    L_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-BAR")
    BAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-L-PER-SEC")
    LB_F_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-IN2")
    MilliBAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-M3-PER-SEC")
    PERCENT_PER_M = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-M")
    MilliGAL_PER_MO = URIRef("http://qudt.org/vocab/unit/MilliGAL-PER-MO")
    MicroM_PER_K = URIRef("http://qudt.org/vocab/unit/MicroM-PER-K")
    TON_US_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_US-PER-HR")
    K_PER_W = URIRef("http://qudt.org/vocab/unit/K-PER-W")
    W = URIRef("http://qudt.org/vocab/unit/W")
    LB_PER_HR_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-HR-PSI")
    GAL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-HR")
    MegaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M3")
    NanoJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoJ-PER-SEC")
    MilliMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3")
    FARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/FARAD-PER-KiloM")
    C4_M4_PER_J3 = URIRef("http://qudt.org/vocab/unit/C4-M4-PER-J3")
    MilliGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-BAR")
    MOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL-PER-MIN")
    C_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Ab-PER-CentiM2")
    KiloGM_F_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-SEC")
    PERMITTIVITY_REL = URIRef("http://qudt.org/vocab/unit/PERMITTIVITY_REL")
    CM_H2O = URIRef("http://qudt.org/vocab/unit/CM_H2O")
    FT3_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN")
    KiloOHM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-M")
    PPQ = URIRef("http://qudt.org/vocab/unit/PPQ")
    MilliM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-M3")
    GM_MIN_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M3-L")
    Ci = URIRef("http://qudt.org/vocab/unit/Ci")
    PlanckTemperature = URIRef("http://qudt.org/vocab/unit/PlanckTemperature")
    MilliM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC")
    LB_IN = URIRef("http://qudt.org/vocab/unit/LB-IN")
    M3_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-M2")
    Megahertz_KiloM = URIRef("http://qudt.org/vocab/unit/Megahertz-KiloM")
    CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM-SEC-DEG_C")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PER-M3-SEC")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    PER_IN = URIRef("http://qudt.org/vocab/unit/PER-IN")
    OZ_MIN_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-FT3")
    A_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM2")
    LB_MIN_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-IN3")
    S = URIRef("http://qudt.org/vocab/unit/S")
    EV = URIRef("http://qudt.org/vocab/unit/EV")
    PER_WB = URIRef("http://qudt.org/vocab/unit/PER-WB")
    BU_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-HR")
    BU_US = URIRef("http://qudt.org/vocab/unit/BU_US")
    DEG_C_PER_M = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-M")
    GAL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-SEC")
    MilliGAL_PER_MO = URIRef("http://qudt.org/vocab/unit/MilliGAL-PER-MO")
    KiloA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloA-PER-K")
    BBL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-DAY")
    KiloMOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-MIN")
    MI_UK3 = URIRef("http://qudt.org/vocab/unit/MI_UK3")
    PicoS = URIRef("http://qudt.org/vocab/unit/PicoS")
    DEG2 = URIRef("http://qudt.org/vocab/unit/DEG2")
    K = URIRef("http://qudt.org/vocab/unit/K")
    J_M_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-M-PER-MOL")
    DEGREE_TWADDELL = URIRef("http://qudt.org/vocab/unit/DEGREE_TWADDELL")
    DEGREE_BRIX = URIRef("http://qudt.org/vocab/unit/DEGREE_BRIX")
    MO_MeanJulian = URIRef("http://qudt.org/vocab/unit/MO_MeanJulian")
    KiloMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-KiloGM")
    W_PER_M2_M_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M-SR")
    KiloCAL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MIN")
    MicroM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM-PER-MilliL")
    LB_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_UK")
    MegaOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-BAR")
    MilliGM_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-DAY")
    AttoC = URIRef("http://qudt.org/vocab/unit/AttoC")
    LB_PER_IN3_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3-DEG_F")
    MicroFARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-KiloM")
    FR = URIRef("http://qudt.org/vocab/unit/FR")
    MI = URIRef("http://qudt.org/vocab/unit/MI")
    M3_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-BAR")
    BTU_IT_PER_HR_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2")
    PicoV = URIRef("http://qudt.org/vocab/unit/PicoV")
    MegaL = URIRef("http://qudt.org/vocab/unit/MegaL")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    BTU_TH_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_F")
    GigaEV = URIRef("http://qudt.org/vocab/unit/GigaEV")
    MicroCi = URIRef("http://qudt.org/vocab/unit/MicroCi")
    PK_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-MIN")
    YD2 = URIRef("http://qudt.org/vocab/unit/YD2")
    KiloGM_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-BAR")
    LB_PER_FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-LB_F-SEC")
    KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloM2")
    BTU_IT_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB")
    OZ_VOL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-HR")
    MegaBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaBQ-PER-KiloGM")
    PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/PER-MilliM3")
    POND = URIRef("http://qudt.org/vocab/unit/POND")
    MicroMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-KiloGM")
    DEATHS_PER_MegaINDIV_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-MegaINDIV-YR")
    LunarMass = URIRef("http://qudt.org/vocab/unit/LunarMass")
    FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-SEC-DEG_F")
    MicroM_PER_M = URIRef("http://qudt.org/vocab/unit/MicroM-PER-M")
    CentiM_H2O = URIRef("http://qudt.org/vocab/unit/CentiM_H2O")
    IN2 = URIRef("http://qudt.org/vocab/unit/IN2")
    W = URIRef("http://qudt.org/vocab/unit/W")
    FT3_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT3-PER-DAY")
    DEG_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC")
    K_PER_W = URIRef("http://qudt.org/vocab/unit/K-PER-W")
    PER_M_SR = URIRef("http://qudt.org/vocab/unit/PER-M-SR")
    AttoC = URIRef("http://qudt.org/vocab/unit/AttoC")
    AU = URIRef("http://qudt.org/vocab/unit/AU")
    M3_PER_PA = URIRef("http://qudt.org/vocab/unit/M3-PER-PA")
    J_SEC_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-SEC-PER-MOL")
    PINT_UK = URIRef("http://qudt.org/vocab/unit/PINT_UK")
    BTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR")
    MI_PER_HR = URIRef("http://qudt.org/vocab/unit/MI-PER-HR")
    BTU_IT_PER_LB_F_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_F")
    TON_US_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_US-PER-HR")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    HectoC = URIRef("http://qudt.org/vocab/unit/HectoC")
    IN_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN-PER-MIN")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    MegaV_A = URIRef("http://qudt.org/vocab/unit/MegaV-A")
    MilliMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3")
    MilliA_IN2_PER_LB_F = URIRef("http://qudt.org/vocab/unit/MilliA-IN2-PER-LB_F")
    GigaW = URIRef("http://qudt.org/vocab/unit/GigaW")
    K = URIRef("http://qudt.org/vocab/unit/K")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    W_M_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-M-PER-M2-SR")
    DEG_C_GROWING_CEREAL_DAY = URIRef("http://qudt.org/vocab/unit/DEG_C_GROWING_CEREAL-DAY")
    PT = URIRef("http://qudt.org/vocab/unit/PT")
    MegaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-SEC")
    MicroRAD = URIRef("http://qudt.org/vocab/unit/MicroRAD")
    J_PER_MOL_K = URIRef("http://qudt.org/vocab/unit/J-PER-MOL-K")
    SEC2 = URIRef("http://qudt.org/vocab/unit/SEC2")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    CentiM_PER_KiloYR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-KiloYR")
    DecaM3 = URIRef("http://qudt.org/vocab/unit/DecaM3")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    LB_HR_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-GAL_UK")
    LB_F_PER_IN2_DEG_F = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-DEG_F")
    DECADE = URIRef("http://qudt.org/vocab/unit/DECADE")
    BTU_IT_PER_SEC_FT_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT-DEG_R")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    KiloCAL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MIN")
    RAD_R = URIRef("http://qudt.org/vocab/unit/RAD_R")
    GM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM")
    BTU_TH_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_F")
    N_M2 = URIRef("http://qudt.org/vocab/unit/N-M2")
    MegaV_PER_M = URIRef("http://qudt.org/vocab/unit/MegaV-PER-M")
    M3_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-M2")
    CentiM_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-K")
    FT3_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT3-PER-DAY")
    MicroMHO = URIRef("http://qudt.org/vocab/unit/MicroMHO")
    MilliDEG_C = URIRef("http://qudt.org/vocab/unit/MilliDEG_C")
    MicroGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-K")
    MicroRAD = URIRef("http://qudt.org/vocab/unit/MicroRAD")
    IU_PER_MilliL = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliL")
    DEG2 = URIRef("http://qudt.org/vocab/unit/DEG2")
    KibiBYTE = URIRef("http://qudt.org/vocab/unit/KibiBYTE")
    LB_IN = URIRef("http://qudt.org/vocab/unit/LB-IN")
    KiloPOND = URIRef("http://qudt.org/vocab/unit/KiloPOND")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    MicroW = URIRef("http://qudt.org/vocab/unit/MicroW")
    IN_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN-PER-MIN")
    FT_LB_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-SEC")
    NanoGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M3")
    CAL_TH_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-K")
    EarthMass = URIRef("http://qudt.org/vocab/unit/EarthMass")
    MicroGRAY = URIRef("http://qudt.org/vocab/unit/MicroGRAY")
    MI_UK3 = URIRef("http://qudt.org/vocab/unit/MI_UK3")
    A_HR_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-HR-PER-DEG_C")
    MilliM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DAY")
    V_Stat = URIRef("http://qudt.org/vocab/unit/V_Stat")
    K_PER_PA = URIRef("http://qudt.org/vocab/unit/K-PER-PA")
    KiloMOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-MIN")
    PER_L = URIRef("http://qudt.org/vocab/unit/PER-L")
    Ci = URIRef("http://qudt.org/vocab/unit/Ci")
    BTU_TH_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR-FT2-DEG_F")
    FATH = URIRef("http://qudt.org/vocab/unit/FATH")
    DeciL_PER_GM = URIRef("http://qudt.org/vocab/unit/DeciL-PER-GM")
    BU_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-SEC")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    MilliL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-SEC")
    C_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM3")
    PicoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/PicoKAT-PER-L")
    DEG_F_HR_FT2_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT")
    KiloGM_M = URIRef("http://qudt.org/vocab/unit/KiloGM-M")
    NanoMOL_PER_MicroMOL_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL-DAY")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    V_Stat_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-CentiM")
    BTU_IT_PER_SEC_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_R")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    N_M_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-RAD")
    B = URIRef("http://qudt.org/vocab/unit/B")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    GM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL")
    MicroMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM")
    DEG_F_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-HR")
    H_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/H-PER-KiloOHM")
    PPTR = URIRef("http://qudt.org/vocab/unit/PPTR")
    LB_PER_MIN_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN-DEG_F")
    MegaC = URIRef("http://qudt.org/vocab/unit/MegaC")
    K_SEC = URIRef("http://qudt.org/vocab/unit/K-SEC")
    LB_IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN-PER-SEC")
    MegaV = URIRef("http://qudt.org/vocab/unit/MegaV")
    MilliW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    ST = URIRef("http://qudt.org/vocab/unit/ST")
    FT_HR_PER_IN3 = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-IN3")
    OZ_SEC_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-YD3")
    DYN = URIRef("http://qudt.org/vocab/unit/DYN")
    MilliM3_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-GM")
    W_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-PER-M3")
    MOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM")
    PicoPA = URIRef("http://qudt.org/vocab/unit/PicoPA")
    DYN_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM2")
    MicroMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-SEC")
    M2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2")
    KiloV_PER_M = URIRef("http://qudt.org/vocab/unit/KiloV-PER-M")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    TON_SHIPPING_US = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_US")
    B = URIRef("http://qudt.org/vocab/unit/B")
    DEGREE_OECHSLE = URIRef("http://qudt.org/vocab/unit/DEGREE_OECHSLE")
    KiloGRAY = URIRef("http://qudt.org/vocab/unit/KiloGRAY")
    PERCENT_MIN_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-YD3")
    L_PER_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-BAR")
    PER_YR = URIRef("http://qudt.org/vocab/unit/PER-YR")
    MegaOHM_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-M")
    GM_SEC_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L-M3")
    RAD_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-MOL")
    N_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-PER-KiloGM")
    M2_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-PA")
    GM_SEC_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L-M3")
    BTU_IT_PER_SEC_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_R")
    PINT_US_DRY = URIRef("http://qudt.org/vocab/unit/PINT_US_DRY")
    PicoS = URIRef("http://qudt.org/vocab/unit/PicoS")
    MilliM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC")
    MegaLB_F = URIRef("http://qudt.org/vocab/unit/MegaLB_F")
    KiloTONNE = URIRef("http://qudt.org/vocab/unit/KiloTONNE")
    DeciM3_PER_HR = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-HR")
    MicroTORR = URIRef("http://qudt.org/vocab/unit/MicroTORR")
    PA_PER_M = URIRef("http://qudt.org/vocab/unit/PA-PER-M")
    KN_PER_SEC = URIRef("http://qudt.org/vocab/unit/KN-PER-SEC")
    KiloCAL_TH = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH")
    KiloGM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM2")
    CentiM6 = URIRef("http://qudt.org/vocab/unit/CentiM6")
    H = URIRef("http://qudt.org/vocab/unit/H")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    OERSTED = URIRef("http://qudt.org/vocab/unit/OERSTED")
    PicoW = URIRef("http://qudt.org/vocab/unit/PicoW")
    YR_Metrology = URIRef("http://qudt.org/vocab/unit/YR_Metrology")
    NanoGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2")
    C_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-M2-PER-KiloGM")
    LA_FT = URIRef("http://qudt.org/vocab/unit/LA_FT")
    NUM_PER_PicoL = URIRef("http://qudt.org/vocab/unit/NUM-PER-PicoL")
    CASES_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-1000I-YR")
    J_PER_SEC = URIRef("http://qudt.org/vocab/unit/J-PER-SEC")
    LB_FT2_PER_GAL_UK_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-GAL_UK-LB_F-SEC")
    PER_SR = URIRef("http://qudt.org/vocab/unit/PER-SR")
    SLUG_PER_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-SEC")
    PK_US_DRY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY")
    V = URIRef("http://qudt.org/vocab/unit/V")
    DEG_F_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-HR")
    NAT = URIRef("http://qudt.org/vocab/unit/NAT")
    PDL_IN = URIRef("http://qudt.org/vocab/unit/PDL-IN")
    TebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M3")
    MegaC = URIRef("http://qudt.org/vocab/unit/MegaC")
    GM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3-BAR")
    BTU_TH_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_R")
    KiloLB_F_FT_PER_LB = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-LB")
    MilliKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MilliKAT-PER-L")
    MilliH = URIRef("http://qudt.org/vocab/unit/MilliH")
    TeraW_HR = URIRef("http://qudt.org/vocab/unit/TeraW-HR")
    MilliM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DAY")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    A_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-PER-DEG_C")
    YoctoC = URIRef("http://qudt.org/vocab/unit/YoctoC")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    LB_SEC_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN6")
    CentiM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL")
    Pennyweight = URIRef("http://qudt.org/vocab/unit/Pennyweight")
    KiloGM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-BAR")
    TebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M2")
    KiloGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM2")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    BREATH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BREATH-PER-MIN")
    PERCENT_PER_K = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-K")
    PINT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-DAY")
    MegaV_A_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A-HR")
    FT_H2O = URIRef("http://qudt.org/vocab/unit/FT_H2O")
    CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CentiM2-MIN")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    KiloGM_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-BAR")
    PA_PER_M = URIRef("http://qudt.org/vocab/unit/PA-PER-M")
    MegaV_PER_M = URIRef("http://qudt.org/vocab/unit/MegaV-PER-M")
    T = URIRef("http://qudt.org/vocab/unit/T")
    HectoC = URIRef("http://qudt.org/vocab/unit/HectoC")
    CentiM = URIRef("http://qudt.org/vocab/unit/CentiM")
    MicroGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3")
    OHM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/OHM-PER-KiloM")
    MDOLLAR_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MDOLLAR-PER-FLIGHT")
    KiloJ_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-HR")
    MilliC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliC-PER-KiloGM")
    PicoMOL_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L-DAY")
    L_PER_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-SEC")
    GM_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM2")
    MilliL_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-K")
    W_M2_PER_SR = URIRef("http://qudt.org/vocab/unit/W-M2-PER-SR")
    CentiL = URIRef("http://qudt.org/vocab/unit/CentiL")
    MilliA_HR_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliA-HR-PER-GM")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    TON_Metric_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY")
    CentiN = URIRef("http://qudt.org/vocab/unit/CentiN")
    PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/PER-MilliM3")
    KiloLB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-FT")
    KiloBAUD = URIRef("http://qudt.org/vocab/unit/KiloBAUD")
    M2_PER_SEC2_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2-K")
    MDOLLAR_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MDOLLAR-PER-FLIGHT")
    KiloN_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-DEG")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    N_M_PER_A = URIRef("http://qudt.org/vocab/unit/N-M-PER-A")
    IN_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC2")
    MilliS_PER_M = URIRef("http://qudt.org/vocab/unit/MilliS-PER-M")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/FT2-PER-BTU_IT-IN")
    CAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC")
    PER_YD3 = URIRef("http://qudt.org/vocab/unit/PER-YD3")
    V_PER_K = URIRef("http://qudt.org/vocab/unit/V-PER-K")
    KiloBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-HR")
    PERCENT_PER_DecaK = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaK")
    YR_Metrology = URIRef("http://qudt.org/vocab/unit/YR_Metrology")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    KiloBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloBQ-PER-KiloGM")
    GM_PER_CentiM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM-BAR")
    PINT_US = URIRef("http://qudt.org/vocab/unit/PINT_US")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    PER_L = URIRef("http://qudt.org/vocab/unit/PER-L")
    PlanckCurrentDensity = URIRef("http://qudt.org/vocab/unit/PlanckCurrentDensity")
    BQ_PER_M2 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M2")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    NanoW = URIRef("http://qudt.org/vocab/unit/NanoW")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    CentiM = URIRef("http://qudt.org/vocab/unit/CentiM")
    BTU_IT_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT-PER-FT2-HR-DEG_F")
    NanoSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-SEC")
    DEG_R_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-MIN")
    PER_GigaEV2 = URIRef("http://qudt.org/vocab/unit/PER-GigaEV2")
    TeraJ = URIRef("http://qudt.org/vocab/unit/TeraJ")
    HART = URIRef("http://qudt.org/vocab/unit/HART")
    FT_SEC_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-GAL_US")
    DEGREE_BALLING = URIRef("http://qudt.org/vocab/unit/DEGREE_BALLING")
    BU_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-SEC")
    PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PER-M3-SEC")
    GM_PER_K = URIRef("http://qudt.org/vocab/unit/GM-PER-K")
    PER_SR = URIRef("http://qudt.org/vocab/unit/PER-SR")
    V_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-PER-CentiM")
    Hundredweight_UK = URIRef("http://qudt.org/vocab/unit/Hundredweight_UK")
    MegaV = URIRef("http://qudt.org/vocab/unit/MegaV")
    BTU_IT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MIN")
    LB_F_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN")
    CAL_TH_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM2-K")
    BAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/BAR-PER-BAR")
    GigaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-SEC")
    DEG_R = URIRef("http://qudt.org/vocab/unit/DEG_R")
    MOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM")
    G = URIRef("http://qudt.org/vocab/unit/G")
    HectoPA_PER_HR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-HR")
    DYN_SEC_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM")
    NanoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/NanoKAT-PER-L")
    KiloR = URIRef("http://qudt.org/vocab/unit/KiloR")
    FemtoGM_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-L")
    KiloGM_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-MilliM2")
    MicroM2 = URIRef("http://qudt.org/vocab/unit/MicroM2")
    W = URIRef("http://qudt.org/vocab/unit/W")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    DEGREE_BRIX = URIRef("http://qudt.org/vocab/unit/DEGREE_BRIX")
    PERCENT_FT_HR_PER_LB = URIRef("http://qudt.org/vocab/unit/PERCENT-FT-HR-PER-LB")
    DRAM_US = URIRef("http://qudt.org/vocab/unit/DRAM_US")
    V2_PER_K2 = URIRef("http://qudt.org/vocab/unit/V2-PER-K2")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    PicoC = URIRef("http://qudt.org/vocab/unit/PicoC")
    KiloEV_PER_MicroM = URIRef("http://qudt.org/vocab/unit/KiloEV-PER-MicroM")
    DEG_F_PER_BAR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-BAR")
    MilliL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC")
    K_PER_M = URIRef("http://qudt.org/vocab/unit/K-PER-M")
    CD_PER_FT2 = URIRef("http://qudt.org/vocab/unit/CD-PER-FT2")
    NanoBQ_PER_L = URIRef("http://qudt.org/vocab/unit/NanoBQ-PER-L")
    BTU_TH_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_R")
    M2_PER_SR_J = URIRef("http://qudt.org/vocab/unit/M2-PER-SR-J")
    CAL_IT_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM2-K")
    DeciTON_Metric = URIRef("http://qudt.org/vocab/unit/DeciTON_Metric")
    ExaBYTE = URIRef("http://qudt.org/vocab/unit/ExaBYTE")
    MegaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-SEC")
    W_PER_SR_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-SR-M2")
    KiloJ_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-DAY")
    A_PER_CentiM = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM")
    W_PER_M_K = URIRef("http://qudt.org/vocab/unit/W-PER-M-K")
    L_PER_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-SEC")
    MilliL_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-K")
    PER_MO = URIRef("http://qudt.org/vocab/unit/PER-MO")
    ExaJ = URIRef("http://qudt.org/vocab/unit/ExaJ")
    B_PER_M = URIRef("http://qudt.org/vocab/unit/B-PER-M")
    HectoPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-M3-PER-SEC")
    KibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M2")
    MebiBYTE = URIRef("http://qudt.org/vocab/unit/MebiBYTE")
    LB_SEC_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-YD3")
    A_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-M2")
    M4 = URIRef("http://qudt.org/vocab/unit/M4")
    M_PER_HR = URIRef("http://qudt.org/vocab/unit/M-PER-HR")
    KiloWB_PER_M = URIRef("http://qudt.org/vocab/unit/KiloWB-PER-M")
    KiloBTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-FT2")
    CAL_TH = URIRef("http://qudt.org/vocab/unit/CAL_TH")
    W_PER_M2_M_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M-SR")
    RHE = URIRef("http://qudt.org/vocab/unit/RHE")
    GM_PER_CentiM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM-BAR")
    NanoM_PER_CentiM_PSI = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-PSI")
    PER_BAR = URIRef("http://qudt.org/vocab/unit/PER-BAR")
    BTU_IT_PER_SEC_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_R")
    FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/FT2-PER-BTU_IT-IN")
    N_M_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-RAD")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    MilliM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-M3")
    KiloJ_PER_KiloV = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloV")
    TON_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-DAY")
    LB_HR_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-YD3")
    ROD = URIRef("http://qudt.org/vocab/unit/ROD")
    MilliGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-MIN")
    LB_HR_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN6")
    LB_F_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN")
    J = URIRef("http://qudt.org/vocab/unit/J")
    BTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    QT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_US-PER-DAY")
    BBL = URIRef("http://qudt.org/vocab/unit/BBL")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    A_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-M2")
    M3_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-BAR")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    MicroC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M3")
    L_PER_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-SEC")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    M_PER_YR = URIRef("http://qudt.org/vocab/unit/M-PER-YR")
    N_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM2")
    MilliOHM_M = URIRef("http://qudt.org/vocab/unit/MilliOHM-M")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    W = URIRef("http://qudt.org/vocab/unit/W")
    GM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM")
    GM_PER_MilliL_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL-BAR")
    BARYE = URIRef("http://qudt.org/vocab/unit/BARYE")
    KibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    MilliW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2")
    MicroW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroW-PER-M2")
    MilliOHM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-K")
    OHM_Stat = URIRef("http://qudt.org/vocab/unit/OHM_Stat")
    AttoFARAD = URIRef("http://qudt.org/vocab/unit/AttoFARAD")
    ERG_CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-CentiM2-PER-GM")
    TON_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-DAY")
    GM_MilliM = URIRef("http://qudt.org/vocab/unit/GM-MilliM")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    M_PER_PA = URIRef("http://qudt.org/vocab/unit/M-PER-PA")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    PPTR = URIRef("http://qudt.org/vocab/unit/PPTR")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    TON_SHORT_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR")
    A_Stat = URIRef("http://qudt.org/vocab/unit/A_Stat")
    BU_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-DAY")
    ENZ = URIRef("http://qudt.org/vocab/unit/ENZ")
    DecaM3 = URIRef("http://qudt.org/vocab/unit/DecaM3")
    MilliM_HGA = URIRef("http://qudt.org/vocab/unit/MilliM_HGA")
    MicroMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-SEC")
    MicroSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-MIN")
    KiloCAL_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2")
    GM_PER_M2 = URIRef("http://qudt.org/vocab/unit/GM-PER-M2")
    LUX_HR = URIRef("http://qudt.org/vocab/unit/LUX-HR")
    CAL_IT = URIRef("http://qudt.org/vocab/unit/CAL_IT")
    PPTM = URIRef("http://qudt.org/vocab/unit/PPTM")
    YD3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD3-PER-DEG_F")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    OCTET = URIRef("http://qudt.org/vocab/unit/OCTET")
    ERG_PER_G = URIRef("http://qudt.org/vocab/unit/ERG-PER-G")
    HectoPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-BAR")
    OZ_VOL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-MIN")
    RT = URIRef("http://qudt.org/vocab/unit/RT")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    N_PER_A = URIRef("http://qudt.org/vocab/unit/N-PER-A")
    BTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2")
    KibiBYTE = URIRef("http://qudt.org/vocab/unit/KibiBYTE")
    LB_PER_MIN_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN-DEG_F")
    MilliIN = URIRef("http://qudt.org/vocab/unit/MilliIN")
    N_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM2")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    PERCENT_PER_V = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-V")
    TORR = URIRef("http://qudt.org/vocab/unit/TORR")
    LB_PER_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-PSI")
    KiloJ_PER_KiloV = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloV")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    CentiM3_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR")
    GM_SEC_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L-CentiM3")
    HP = URIRef("http://qudt.org/vocab/unit/HP")
    MicroW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroW-PER-M2")
    K_SEC = URIRef("http://qudt.org/vocab/unit/K-SEC")
    GM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL")
    OZ_MIN_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-GAL_UK")
    DeciN_M = URIRef("http://qudt.org/vocab/unit/DeciN-M")
    TONNE_PER_HR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR")
    TON_Metric_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY-K")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    MicroFARAD = URIRef("http://qudt.org/vocab/unit/MicroFARAD")
    M_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-PA")
    MicroH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-KiloOHM")
    IN4 = URIRef("http://qudt.org/vocab/unit/IN4")
    PER_DEG_C = URIRef("http://qudt.org/vocab/unit/PER-DEG_C")
    L_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-K")
    BIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/BIT-PER-M3")
    SON = URIRef("http://qudt.org/vocab/unit/SON")
    TON_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_US-PER-DAY")
    BTU_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-MIN")
    MebiBYTE = URIRef("http://qudt.org/vocab/unit/MebiBYTE")
    PER_HR = URIRef("http://qudt.org/vocab/unit/PER-HR")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    GigaOHM = URIRef("http://qudt.org/vocab/unit/GigaOHM")
    GRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/GRAY-PER-SEC")
    M2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2")
    KiloS_PER_M = URIRef("http://qudt.org/vocab/unit/KiloS-PER-M")
    BTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR")
    MicroG = URIRef("http://qudt.org/vocab/unit/MicroG")
    KiloM = URIRef("http://qudt.org/vocab/unit/KiloM")
    LB_PER_FT_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-MIN")
    PPM_PER_K = URIRef("http://qudt.org/vocab/unit/PPM-PER-K")
    ATM_M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/ATM-M3-PER-MOL")
    MOL_PER_KiloGM_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-PA")
    SLUG_PER_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-SEC")
    GM_SEC_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L-M3")
    GRAIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL_US")
    MegaHZ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-K")
    V_PER_K = URIRef("http://qudt.org/vocab/unit/V-PER-K")
    MilliM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-M3")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT")
    A_PER_CentiM = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    N_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M")
    LB_PER_FT_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-HR")
    PERCENT_PER_DEG = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEG")
    C_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM")
    TONNE_PER_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-K")
    GigaPA_CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/GigaPA-CentiM3-PER-GM")
    W_M2_PER_SR = URIRef("http://qudt.org/vocab/unit/W-M2-PER-SR")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    CentiM_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-BAR")
    KiloGM_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-BAR")
    MilliBAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-BAR")
    LB_F_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN")
    MI = URIRef("http://qudt.org/vocab/unit/MI")
    M_PER_MIN = URIRef("http://qudt.org/vocab/unit/M-PER-MIN")
    MicroGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M2-DAY")
    KiloGM_PER_M_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC2")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    OZ_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ-PER-HR")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    KiloGM_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-BAR")
    TeraV_A = URIRef("http://qudt.org/vocab/unit/TeraV-A")
    LB_SEC_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-GAL_UK")
    CH = URIRef("http://qudt.org/vocab/unit/CH")
    GigaOHM = URIRef("http://qudt.org/vocab/unit/GigaOHM")
    PicoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-KiloGM")
    MilliGM_SEC_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L2")
    BTU_IT_PER_HR_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_R")
    MilliW_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM")
    MicroM_PER_M = URIRef("http://qudt.org/vocab/unit/MicroM-PER-M")
    MilliTORR = URIRef("http://qudt.org/vocab/unit/MilliTORR")
    MicroW = URIRef("http://qudt.org/vocab/unit/MicroW")
    LB_F_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-SEC")
    TON_Metric_PER_M3 = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3")
    GigaW = URIRef("http://qudt.org/vocab/unit/GigaW")
    KiloLB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-IN2")
    MilliN = URIRef("http://qudt.org/vocab/unit/MilliN")
    DeciM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MOL")
    PK_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-HR")
    M2_PER_J = URIRef("http://qudt.org/vocab/unit/M2-PER-J")
    AC = URIRef("http://qudt.org/vocab/unit/AC")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    OZ_SEC_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-FT3")
    MOL_PER_KiloGM_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-PA")
    MilliL_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-K")
    CentiM2_PER_ERG = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-ERG")
    LB_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT2")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PER-M3-SEC")
    CAL_IT = URIRef("http://qudt.org/vocab/unit/CAL_IT")
    CentiM_HG = URIRef("http://qudt.org/vocab/unit/CentiM_HG")
    PERCENT_SEC_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-GAL_UK")
    NanoBQ_PER_L = URIRef("http://qudt.org/vocab/unit/NanoBQ-PER-L")
    PER_SR = URIRef("http://qudt.org/vocab/unit/PER-SR")
    PER_GM = URIRef("http://qudt.org/vocab/unit/PER-GM")
    NanoN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/NanoN-M-PER-M2")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    FT_PER_PSI = URIRef("http://qudt.org/vocab/unit/FT-PER-PSI")
    GM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloM")
    MicroKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MicroKAT-PER-L")
    BAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-M3-PER-SEC")
    BARN_PER_EV = URIRef("http://qudt.org/vocab/unit/BARN-PER-EV")
    NanoMOL_PER_MicroGM_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroGM-HR")
    KiloGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-K")
    MilliW_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM-SR")
    LB_PER_YD = URIRef("http://qudt.org/vocab/unit/LB-PER-YD")
    W_PER_M2_M = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    KiloBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-HR")
    BTU_TH_FT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-HR-FT2-DEG_F")
    C_Stat_PER_MOL = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-MOL")
    MilliDARCY = URIRef("http://qudt.org/vocab/unit/MilliDARCY")
    BBL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-MIN")
    MicroH = URIRef("http://qudt.org/vocab/unit/MicroH")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    MilliS_PER_M = URIRef("http://qudt.org/vocab/unit/MilliS-PER-M")
    KiloGM_PER_M_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-DAY")
    YR_Common = URIRef("http://qudt.org/vocab/unit/YR_Common")
    BBL_US = URIRef("http://qudt.org/vocab/unit/BBL_US")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    REV_PER_SEC = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC")
    CentiM_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-HR")
    CAL_TH_PER_G = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-G")
    CentiM3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL-SEC")
    REM = URIRef("http://qudt.org/vocab/unit/REM")
    PHOT = URIRef("http://qudt.org/vocab/unit/PHOT")
    MegaJ_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M3")
    BIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BIT-PER-SEC")
    V_PER_M2 = URIRef("http://qudt.org/vocab/unit/V-PER-M2")
    HectoC = URIRef("http://qudt.org/vocab/unit/HectoC")
    M4 = URIRef("http://qudt.org/vocab/unit/M4")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    SLUG_PER_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-SEC")
    A_PER_CentiM = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM")
    CentiM3_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN-BAR")
    MegaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBIT-PER-SEC")
    A_PER_GM = URIRef("http://qudt.org/vocab/unit/A-PER-GM")
    KiloLB_F_FT_PER_A = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-A")
    PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-PER-SEC")
    PERCENT_PER_PA_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-PA-SEC")
    BTU_IT_IN_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-HR-FT2-DEG_F")
    W_HR = URIRef("http://qudt.org/vocab/unit/W-HR")
    SLUG_PER_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-SEC")
    CAL_TH_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2-MIN")
    GM_PER_L = URIRef("http://qudt.org/vocab/unit/GM-PER-L")
    BTU_IT_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB")
    KiloWB_PER_M = URIRef("http://qudt.org/vocab/unit/KiloWB-PER-M")
    KiloEV = URIRef("http://qudt.org/vocab/unit/KiloEV")
    PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PER-M3-SEC")
    MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC")
    MilliM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-KiloGM")
    PER_MIN = URIRef("http://qudt.org/vocab/unit/PER-MIN")
    M2_PER_SR_J = URIRef("http://qudt.org/vocab/unit/M2-PER-SR-J")
    N_PER_C = URIRef("http://qudt.org/vocab/unit/N-PER-C")
    KiloCAL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-SEC")
    TON_LONG = URIRef("http://qudt.org/vocab/unit/TON_LONG")
    CentiM_H2O_4DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_H2O_4DEG_C")
    GM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/GM-PER-HR-K")
    TON_US_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_US-PER-YD3")
    GM_F = URIRef("http://qudt.org/vocab/unit/GM_F")
    KiloJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM")
    BTU_IT_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB")
    TON_Metric_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN-K")
    KiloMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-KiloGM")
    A_PER_MilliM = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM")
    PERCENT_FT_HR_PER_LB = URIRef("http://qudt.org/vocab/unit/PERCENT-FT-HR-PER-LB")
    HectoC = URIRef("http://qudt.org/vocab/unit/HectoC")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    MicroMOL_PER_MicroMOL_DAY = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MicroMOL-DAY")
    SLUG_PER_FT3 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT3")
    CentiM_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-HR")
    KiloGM_F = URIRef("http://qudt.org/vocab/unit/KiloGM_F")
    MilliL_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-BAR")
    GigaHZ = URIRef("http://qudt.org/vocab/unit/GigaHZ")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    L_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-BAR")
    PicoPA_PER_KiloM = URIRef("http://qudt.org/vocab/unit/PicoPA-PER-KiloM")
    PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PER-M3-SEC")
    BTU_IT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_F")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    PDL_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-FT2")
    RAD_PER_MIN = URIRef("http://qudt.org/vocab/unit/RAD-PER-MIN")
    TeraC = URIRef("http://qudt.org/vocab/unit/TeraC")
    KiloV_PER_M = URIRef("http://qudt.org/vocab/unit/KiloV-PER-M")
    MilliGM_HR_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L2")
    FT_LB_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-SEC")
    KiloGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM2")
    BTU_IT_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC-DEG_F")
    KiloN_M_PER_DEG_M = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-DEG-M")
    PER_IN2 = URIRef("http://qudt.org/vocab/unit/PER-IN2")
    W_PER_M = URIRef("http://qudt.org/vocab/unit/W-PER-M")
    BTU_IT_PER_LB_F_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_R")
    MI_PER_SEC = URIRef("http://qudt.org/vocab/unit/MI-PER-SEC")
    MicroV_A = URIRef("http://qudt.org/vocab/unit/MicroV-A")
    KiloA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M")
    GM_HR_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L-CentiM3")
    FemtoC = URIRef("http://qudt.org/vocab/unit/FemtoC")
    DeciS_PER_M = URIRef("http://qudt.org/vocab/unit/DeciS-PER-M")
    KiloJ = URIRef("http://qudt.org/vocab/unit/KiloJ")
    EUR_PER_KiloW_HR = URIRef("http://qudt.org/vocab/unit/EUR-PER-KiloW-HR")
    M3_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-PA")
    MilliK_PER_K = URIRef("http://qudt.org/vocab/unit/MilliK-PER-K")
    LB_PER_M3 = URIRef("http://qudt.org/vocab/unit/LB-PER-M3")
    MilliM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-KiloGM")
    GM_PER_L_K = URIRef("http://qudt.org/vocab/unit/GM-PER-L-K")
    MegaPA_M0pt5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0pt5")
    KN = URIRef("http://qudt.org/vocab/unit/KN")
    KiloGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-BAR")
    MilliL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN")
    PDL = URIRef("http://qudt.org/vocab/unit/PDL")
    PlanckCurrent = URIRef("http://qudt.org/vocab/unit/PlanckCurrent")
    WK = URIRef("http://qudt.org/vocab/unit/WK")
    N_M_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-RAD")
    QT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-SEC")
    CentiM3_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY-K")
    V_Ab_SEC = URIRef("http://qudt.org/vocab/unit/V_Ab-SEC")
    GM_MilliM = URIRef("http://qudt.org/vocab/unit/GM-MilliM")
    FT3_PER_HR = URIRef("http://qudt.org/vocab/unit/FT3-PER-HR")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    PPQ = URIRef("http://qudt.org/vocab/unit/PPQ")
    DEG_F_HR_FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT-IN")
    PicoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-KiloGM")
    DEATHS_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000I-YR")
    AttoC = URIRef("http://qudt.org/vocab/unit/AttoC")
    FT_HR_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-GAL_US")
    RAD_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-KiloGM")
    TeraV_A_Reactive = URIRef("http://qudt.org/vocab/unit/TeraV-A_Reactive")
    PicoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L")
    RAD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC2")
    KiloW_PER_M2_K = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M2-K")
    FemtoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-KiloGM")
    FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/FT2-PER-BTU_IT-IN")
    DeciL_PER_GM = URIRef("http://qudt.org/vocab/unit/DeciL-PER-GM")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    MilliM3 = URIRef("http://qudt.org/vocab/unit/MilliM3")
    KiloHZ_M = URIRef("http://qudt.org/vocab/unit/KiloHZ-M")
    UnitPole = URIRef("http://qudt.org/vocab/unit/UnitPole")
    V_PER_MicroSEC = URIRef("http://qudt.org/vocab/unit/V-PER-MicroSEC")
    MicroSEC = URIRef("http://qudt.org/vocab/unit/MicroSEC")
    PicoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/PicoKAT-PER-L")
    KiloBIT = URIRef("http://qudt.org/vocab/unit/KiloBIT")
    PER_DAY = URIRef("http://qudt.org/vocab/unit/PER-DAY")
    GAL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-SEC")
    PER_M_K = URIRef("http://qudt.org/vocab/unit/PER-M-K")
    PPTM = URIRef("http://qudt.org/vocab/unit/PPTM")
    CFU = URIRef("http://qudt.org/vocab/unit/CFU")
    N = URIRef("http://qudt.org/vocab/unit/N")
    HectoPA_PER_K = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-K")
    L_PER_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-SEC")
    TON_SHORT_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR")
    H_Ab = URIRef("http://qudt.org/vocab/unit/H_Ab")
    GM_PER_CentiM2_YR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2-YR")
    MI_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI-PER-MIN")
    MilliJ = URIRef("http://qudt.org/vocab/unit/MilliJ")
    PER_YR = URIRef("http://qudt.org/vocab/unit/PER-YR")
    CentiM_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-HR")
    TONNE_PER_DAY = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY")
    CentiM3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-K")
    DEG_F_SEC_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-SEC-PER-BTU_TH")
    W_PER_M2_PA = URIRef("http://qudt.org/vocab/unit/W-PER-M2-PA")
    KIP_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KIP_F-PER-IN2")
    PicoC = URIRef("http://qudt.org/vocab/unit/PicoC")
    MilliGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-BAR")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    MegaOHM = URIRef("http://qudt.org/vocab/unit/MegaOHM")
    A_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-PER-CentiM2")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    PlanckVolume = URIRef("http://qudt.org/vocab/unit/PlanckVolume")
    MilliT = URIRef("http://qudt.org/vocab/unit/MilliT")
    C_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-CentiM2")
    MicroN_M = URIRef("http://qudt.org/vocab/unit/MicroN-M")
    MicroC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M3")
    TONNE_PER_MO = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MO")
    FT_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT-PER-DAY")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    GM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-CentiM-PER-SEC")
    TeraW_HR = URIRef("http://qudt.org/vocab/unit/TeraW-HR")
    PK_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-MIN")
    FT3_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT3-PER-SEC")
    PER_H = URIRef("http://qudt.org/vocab/unit/PER-H")
    PSI_IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-IN3-PER-SEC")
    OZ_HR_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-YD3")
    PicoFARAD = URIRef("http://qudt.org/vocab/unit/PicoFARAD")
    BARYE = URIRef("http://qudt.org/vocab/unit/BARYE")
    Gs = URIRef("http://qudt.org/vocab/unit/Gs")
    PER_M_SR = URIRef("http://qudt.org/vocab/unit/PER-M-SR")
    CentiM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY")
    GM = URIRef("http://qudt.org/vocab/unit/GM")
    ExaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/ExaBIT-PER-SEC")
    GI_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-DAY")
    BBL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-MIN")
    BTU_IT_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-HR-DEG_F")
    LB_SEC_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK2")
    M3_PER_HR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR")
    V_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/V-A_Reactive-HR")
    M2_PER_M2 = URIRef("http://qudt.org/vocab/unit/M2-PER-M2")
    MilliMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3")
    PicoL = URIRef("http://qudt.org/vocab/unit/PicoL")
    MilliM_PER_YR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-YR")
    M_PER_BAR = URIRef("http://qudt.org/vocab/unit/M-PER-BAR")
    KiloGM_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-M2")
    PER_L = URIRef("http://qudt.org/vocab/unit/PER-L")
    M3_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-K")
    TON_UK = URIRef("http://qudt.org/vocab/unit/TON_UK")
    CentiM_H2O = URIRef("http://qudt.org/vocab/unit/CentiM_H2O")
    KiloJ_PER_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-K")
    MegaHZ_PER_T = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-T")
    PERCENT_PER_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MilliPA-SEC")
    MicroGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-MilliL")
    OZ_IN2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/OZ-IN2-PER-IN3-LB_F-SEC")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN")
    LB_PER_M3 = URIRef("http://qudt.org/vocab/unit/LB-PER-M3")
    BTU_IT_PER_SEC_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2")
    CAL_TH_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM")
    MilliGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HA")
    DEG_R = URIRef("http://qudt.org/vocab/unit/DEG_R")
    KiloCAL_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM")
    DEATHS_PER_MegaINDIV_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-MegaINDIV-YR")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    CentiM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY")
    CAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-K")
    NanoV_A_Reactive = URIRef("http://qudt.org/vocab/unit/NanoV-A_Reactive")
    MOMME_Pearl = URIRef("http://qudt.org/vocab/unit/MOMME_Pearl")
    M3_PER_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-BAR")
    MilliGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2")
    BU_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-MIN")
    J_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-GM-DEG_C")
    KiloM = URIRef("http://qudt.org/vocab/unit/KiloM")
    QUAD = URIRef("http://qudt.org/vocab/unit/QUAD")
    KiloPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-BAR")
    MilliGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-SEC")
    MilliW_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-MilliGM")
    TON_SHORT = URIRef("http://qudt.org/vocab/unit/TON_SHORT")
    FemtoMOL = URIRef("http://qudt.org/vocab/unit/FemtoMOL")
    DEGREE_API = URIRef("http://qudt.org/vocab/unit/DEGREE_API")
    LB_M = URIRef("http://qudt.org/vocab/unit/LB_M")
    L_PER_K = URIRef("http://qudt.org/vocab/unit/L-PER-K")
    GAUSS = URIRef("http://qudt.org/vocab/unit/GAUSS")
    MegaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBIT-PER-SEC")
    MilliV_A_PER_K = URIRef("http://qudt.org/vocab/unit/MilliV-A-PER-K")
    PERCENT_FT_SEC_PER_LB = URIRef("http://qudt.org/vocab/unit/PERCENT-FT-SEC-PER-LB")
    TeraV_A = URIRef("http://qudt.org/vocab/unit/TeraV-A")
    ERG_PER_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-SEC")
    MilliGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    DEG_F_HR_FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT-IN")
    MilliGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-K")
    PER_MicroMOL_L = URIRef("http://qudt.org/vocab/unit/PER-MicroMOL-L")
    MilliT = URIRef("http://qudt.org/vocab/unit/MilliT")
    RPK = URIRef("http://qudt.org/vocab/unit/RPK")
    BTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    CAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    N_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-PER-KiloGM")
    J = URIRef("http://qudt.org/vocab/unit/J")
    KiloC_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M2")
    SLUG_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT-SEC")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    KiloGM_PER_J = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-J")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    PERCENT_HR_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-IN3")
    MilliA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/MilliA-PER-MilliM")
    PPQ = URIRef("http://qudt.org/vocab/unit/PPQ")
    DeciM3 = URIRef("http://qudt.org/vocab/unit/DeciM3")
    FT3_PER_LB = URIRef("http://qudt.org/vocab/unit/FT3-PER-LB")
    KiloTONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloTONNE-PER-YR")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    SLUG_PER_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-SEC")
    MegaBQ = URIRef("http://qudt.org/vocab/unit/MegaBQ")
    MicroGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-K")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    ElementaryCharge = URIRef("http://qudt.org/vocab/unit/ElementaryCharge")
    PER_YD3 = URIRef("http://qudt.org/vocab/unit/PER-YD3")
    MilliK_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliK-PER-BAR")
    L_PER_MIN = URIRef("http://qudt.org/vocab/unit/L-PER-MIN")
    PicoGM_PER_GM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-GM")
    MilliL_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY")
    QT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-SEC")
    CH = URIRef("http://qudt.org/vocab/unit/CH")
    MilliGRAY = URIRef("http://qudt.org/vocab/unit/MilliGRAY")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    MegaV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive-HR")
    MicroT = URIRef("http://qudt.org/vocab/unit/MicroT")
    GigaC = URIRef("http://qudt.org/vocab/unit/GigaC")
    GigaA = URIRef("http://qudt.org/vocab/unit/GigaA")
    G = URIRef("http://qudt.org/vocab/unit/G")
    BTU_TH_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB")
    AttoSEC = URIRef("http://qudt.org/vocab/unit/AttoSEC")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    KiloCAL_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-HR")
    MilliS = URIRef("http://qudt.org/vocab/unit/MilliS")
    OZ_MIN_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN6")
    MicroRAD = URIRef("http://qudt.org/vocab/unit/MicroRAD")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    MicroM2 = URIRef("http://qudt.org/vocab/unit/MicroM2")
    AMU = URIRef("http://qudt.org/vocab/unit/AMU")
    DEGREE_API = URIRef("http://qudt.org/vocab/unit/DEGREE_API")
    KiloM3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM3-PER-SEC2")
    LM_SEC = URIRef("http://qudt.org/vocab/unit/LM-SEC")
    NUM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NUM-PER-MicroL")
    BARYE = URIRef("http://qudt.org/vocab/unit/BARYE")
    NUM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NUM-PER-M3")
    MilliL = URIRef("http://qudt.org/vocab/unit/MilliL")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    BU_US = URIRef("http://qudt.org/vocab/unit/BU_US")
    CAL_IT_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM")
    SAMPLE_PER_SEC = URIRef("http://qudt.org/vocab/unit/SAMPLE-PER-SEC")
    BTU_TH_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_F")
    CAL_TH_PER_G = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-G")
    IN_PER_YR = URIRef("http://qudt.org/vocab/unit/IN-PER-YR")
    MicroGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-HR")
    LM_PER_W = URIRef("http://qudt.org/vocab/unit/LM-PER-W")
    SLUG_PER_FT2 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT2")
    DeciSEC = URIRef("http://qudt.org/vocab/unit/DeciSEC")
    A_PER_RAD = URIRef("http://qudt.org/vocab/unit/A-PER-RAD")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    CentiC = URIRef("http://qudt.org/vocab/unit/CentiC")
    PINT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-SEC")
    MI_N_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI_N-PER-MIN")
    BBL_US_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-SEC")
    MilliL_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-BAR")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    H = URIRef("http://qudt.org/vocab/unit/H")
    PERCENT_HR_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-GAL_US")
    CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3")
    MegaPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-L-PER-SEC")
    KiloGM_PER_CentiM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-BAR")
    PER_GigaEV2 = URIRef("http://qudt.org/vocab/unit/PER-GigaEV2")
    CentiM_HG = URIRef("http://qudt.org/vocab/unit/CentiM_HG")
    M2_HZ3 = URIRef("http://qudt.org/vocab/unit/M2-HZ3")
    KiloCAL_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL")
    PER_MOL = URIRef("http://qudt.org/vocab/unit/PER-MOL")
    KiloN_M = URIRef("http://qudt.org/vocab/unit/KiloN-M")
    ERG_PER_CentiM = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM")
    DecaC = URIRef("http://qudt.org/vocab/unit/DecaC")
    GM_PER_GM = URIRef("http://qudt.org/vocab/unit/GM-PER-GM")
    KiloBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloBQ-PER-KiloGM")
    CentiM3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-BAR")
    MegaV_PER_M = URIRef("http://qudt.org/vocab/unit/MegaV-PER-M")
    PINT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-HR")
    R = URIRef("http://qudt.org/vocab/unit/R")
    AttoFARAD = URIRef("http://qudt.org/vocab/unit/AttoFARAD")
    PERCENT_HR_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-IN3")
    QT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-MIN")
    PH = URIRef("http://qudt.org/vocab/unit/PH")
    J_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-M2-PER-KiloGM")
    GigaC = URIRef("http://qudt.org/vocab/unit/GigaC")
    BU_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-SEC")
    DEG_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC")
    MegaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-SEC")
    DYN_M = URIRef("http://qudt.org/vocab/unit/DYN-M")
    M3_PER_C = URIRef("http://qudt.org/vocab/unit/M3-PER-C")
    PER_M_K = URIRef("http://qudt.org/vocab/unit/PER-M-K")
    KiloC = URIRef("http://qudt.org/vocab/unit/KiloC")
    FA = URIRef("http://qudt.org/vocab/unit/FA")
    MIL = URIRef("http://qudt.org/vocab/unit/MIL")
    GM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloM")
    GM_PER_GM = URIRef("http://qudt.org/vocab/unit/GM-PER-GM")
    FT3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT3-PER-DEG_F")
    GI_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_US-PER-HR")
    LB_SEC_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-GAL_UK")
    GM_PER_M3 = URIRef("http://qudt.org/vocab/unit/GM-PER-M3")
    MilliA = URIRef("http://qudt.org/vocab/unit/MilliA")
    KiloOHM_PER_K = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-K")
    YR_TROPICAL = URIRef("http://qudt.org/vocab/unit/YR_TROPICAL")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    MegaBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaBQ-PER-KiloGM")
    FT3_PER_MIN_FT2 = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN-FT2")
    KiloLB_F_FT_PER_LB = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-LB")
    CentiM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL")
    MilliV_PER_V = URIRef("http://qudt.org/vocab/unit/MilliV-PER-V")
    J_PER_KiloGM_K_PA = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-PA")
    KiloGM_F = URIRef("http://qudt.org/vocab/unit/KiloGM_F")
    MicroMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-SEC")
    POISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/POISE-PER-BAR")
    PERCENT_PER_WK = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-WK")
    MilliOHM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-K")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    PERCENT_PER_10KiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-10KiloCount")
    DEGREE_BRIX = URIRef("http://qudt.org/vocab/unit/DEGREE_BRIX")
    BTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR")
    KiloJ = URIRef("http://qudt.org/vocab/unit/KiloJ")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    PER_SEC_M3 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M3")
    REV_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC2")
    CAL_TH_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM-SEC-DEG_C")
    NanoGM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MicroL")
    TON_LONG = URIRef("http://qudt.org/vocab/unit/TON_LONG")
    PicoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/PicoW-PER-M2")
    TONNE_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY-K")
    DEG_F_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC2")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    ATM = URIRef("http://qudt.org/vocab/unit/ATM")
    LB_PER_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-HR-DEG_F")
    MilliMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2")
    MegaGM = URIRef("http://qudt.org/vocab/unit/MegaGM")
    ERG_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM2-SEC")
    ERLANG = URIRef("http://qudt.org/vocab/unit/ERLANG")
    KiloCAL_Mean = URIRef("http://qudt.org/vocab/unit/KiloCAL_Mean")
    KiloTON_Metric = URIRef("http://qudt.org/vocab/unit/KiloTON_Metric")
    BTU_TH_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-HR-DEG_F")
    MicroBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-KiloGM")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    A = URIRef("http://qudt.org/vocab/unit/A")
    M3_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-PA")
    T = URIRef("http://qudt.org/vocab/unit/T")
    PERCENT_SEC_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-FT3")
    BBL_UK_PET = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET")
    MilliM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliM-PER-M")
    CAL_IT_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM-K")
    Flight = URIRef("http://qudt.org/vocab/unit/Flight")
    M_SEC = URIRef("http://qudt.org/vocab/unit/M-SEC")
    MilliM4 = URIRef("http://qudt.org/vocab/unit/MilliM4")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    TON_FG_HR = URIRef("http://qudt.org/vocab/unit/TON_FG-HR")
    A = URIRef("http://qudt.org/vocab/unit/A")
    TON_Metric_PER_MIN = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN")
    FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-SEC")
    MegaPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-L-PER-SEC")
    MicroV_PER_M = URIRef("http://qudt.org/vocab/unit/MicroV-PER-M")
    MicroG_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroG-PER-CentiM2")
    PicoMOL = URIRef("http://qudt.org/vocab/unit/PicoMOL")
    OZ_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ-PER-MIN")
    CentiM3_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY-K")
    N_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-PER-M3")
    PicoS = URIRef("http://qudt.org/vocab/unit/PicoS")
    W_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M2")
    MilliS = URIRef("http://qudt.org/vocab/unit/MilliS")
    YD_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD-PER-DEG_F")
    KiloBTU_TH = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH")
    MilliV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MilliV-A_Reactive")
    M2_PER_HZ = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ")
    PA_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M")
    BAR = URIRef("http://qudt.org/vocab/unit/BAR")
    MicroFARAD = URIRef("http://qudt.org/vocab/unit/MicroFARAD")
    K_PER_T = URIRef("http://qudt.org/vocab/unit/K-PER-T")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    NanoH = URIRef("http://qudt.org/vocab/unit/NanoH")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    HP_Brake = URIRef("http://qudt.org/vocab/unit/HP_Brake")
    MilliGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-K")
    MegaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBYTE-PER-SEC")
    BTU_TH_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_F")
    TON_FG = URIRef("http://qudt.org/vocab/unit/TON_FG")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    DeciM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MIN")
    PER_M2 = URIRef("http://qudt.org/vocab/unit/PER-M2")
    C_M2 = URIRef("http://qudt.org/vocab/unit/C-M2")
    PPTM_PER_K = URIRef("http://qudt.org/vocab/unit/PPTM-PER-K")
    FC = URIRef("http://qudt.org/vocab/unit/FC")
    PA_PER_MIN = URIRef("http://qudt.org/vocab/unit/PA-PER-MIN")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    OHM_Stat = URIRef("http://qudt.org/vocab/unit/OHM_Stat")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    Da = URIRef("http://qudt.org/vocab/unit/Da")
    PicoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/PicoKAT-PER-L")
    A_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-PER-DEG_C")
    KiloCAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-SEC")
    V = URIRef("http://qudt.org/vocab/unit/V")
    CD_PER_M2 = URIRef("http://qudt.org/vocab/unit/CD-PER-M2")
    KN_PER_SEC = URIRef("http://qudt.org/vocab/unit/KN-PER-SEC")
    NanoGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2")
    CH = URIRef("http://qudt.org/vocab/unit/CH")
    MicroGM = URIRef("http://qudt.org/vocab/unit/MicroGM")
    PlanckForce = URIRef("http://qudt.org/vocab/unit/PlanckForce")
    KIP_F = URIRef("http://qudt.org/vocab/unit/KIP_F")
    J = URIRef("http://qudt.org/vocab/unit/J")
    MicroSV = URIRef("http://qudt.org/vocab/unit/MicroSV")
    H_Ab = URIRef("http://qudt.org/vocab/unit/H_Ab")
    SLUG_PER_FT2 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT2")
    GM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM_F-PER-CentiM2")
    J_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K")
    DIOPTER = URIRef("http://qudt.org/vocab/unit/DIOPTER")
    BTU_IT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR-DEG_F")
    MilliJ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-GM")
    DEGREE_TWADDELL = URIRef("http://qudt.org/vocab/unit/DEGREE_TWADDELL")
    HP_H2O = URIRef("http://qudt.org/vocab/unit/HP_H2O")
    M2_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-PA")
    MicroMOL_PER_GM_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM-HR")
    HectoGM = URIRef("http://qudt.org/vocab/unit/HectoGM")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    PER_M_NanoM = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM")
    GM_HR_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L-M3")
    YR = URIRef("http://qudt.org/vocab/unit/YR")
    MilliMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-KiloGM")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    MicroC = URIRef("http://qudt.org/vocab/unit/MicroC")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    MilloMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilloMOL-PER-L")
    MicroMHO = URIRef("http://qudt.org/vocab/unit/MicroMHO")
    TON_US = URIRef("http://qudt.org/vocab/unit/TON_US")
    A_PER_PA = URIRef("http://qudt.org/vocab/unit/A-PER-PA")
    FT_US = URIRef("http://qudt.org/vocab/unit/FT_US")
    MilliW_PER_CentiM2_MicroM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-CentiM2-MicroM-SR")
    S = URIRef("http://qudt.org/vocab/unit/S")
    LB_PER_MIN_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN-PSI")
    GM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciL")
    PlanckTemperature = URIRef("http://qudt.org/vocab/unit/PlanckTemperature")
    V_PER_BAR = URIRef("http://qudt.org/vocab/unit/V-PER-BAR")
    MilliL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M3")
    MilliGM_SEC_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L-M3")
    M2_PER_SR = URIRef("http://qudt.org/vocab/unit/M2-PER-SR")
    AttoFARAD = URIRef("http://qudt.org/vocab/unit/AttoFARAD")
    DEG_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC2")
    PPM = URIRef("http://qudt.org/vocab/unit/PPM")
    MicroGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-MilliL")
    GRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/GRAY-PER-HR")
    W_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M2")
    DecaGM = URIRef("http://qudt.org/vocab/unit/DecaGM")
    KiloCAL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-SEC")
    IN2_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN2-PER-SEC")
    KiloMIL_Circ = URIRef("http://qudt.org/vocab/unit/KiloMIL_Circ")
    MegaN = URIRef("http://qudt.org/vocab/unit/MegaN")
    NanoM = URIRef("http://qudt.org/vocab/unit/NanoM")
    PicoSEC = URIRef("http://qudt.org/vocab/unit/PicoSEC")
    KiloCAL_Mean = URIRef("http://qudt.org/vocab/unit/KiloCAL_Mean")
    BTU_IT_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-HR-DEG_F")
    GM = URIRef("http://qudt.org/vocab/unit/GM")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    IU = URIRef("http://qudt.org/vocab/unit/IU")
    TON_Assay = URIRef("http://qudt.org/vocab/unit/TON_Assay")
    KiloLB_F_FT_PER_LB = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-LB")
    NUM_PER_NanoL = URIRef("http://qudt.org/vocab/unit/NUM-PER-NanoL")
    PDL_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-FT2")
    NanoC = URIRef("http://qudt.org/vocab/unit/NanoC")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    M2_PER_J = URIRef("http://qudt.org/vocab/unit/M2-PER-J")
    OZ_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ-PER-DAY")
    PPB = URIRef("http://qudt.org/vocab/unit/PPB")
    GM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2")
    PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/PER-M2-SEC")
    M3_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-K")
    CentiM = URIRef("http://qudt.org/vocab/unit/CentiM")
    A_Ab = URIRef("http://qudt.org/vocab/unit/A_Ab")
    L = URIRef("http://qudt.org/vocab/unit/L")
    KiloHZ = URIRef("http://qudt.org/vocab/unit/KiloHZ")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    MicroGM_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L-HR")
    LB = URIRef("http://qudt.org/vocab/unit/LB")
    IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN3-PER-SEC")
    TeraA = URIRef("http://qudt.org/vocab/unit/TeraA")
    CentiMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-KiloGM")
    DecaM = URIRef("http://qudt.org/vocab/unit/DecaM")
    FT_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-PER-HR")
    BAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/BAR-PER-BAR")
    L_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-K")
    LB_HR_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-GAL_US")
    DYN_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM3")
    PINT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-SEC")
    GM_PER_MOL = URIRef("http://qudt.org/vocab/unit/GM-PER-MOL")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    MicroGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-DeciL")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    MicroGRAY = URIRef("http://qudt.org/vocab/unit/MicroGRAY")
    NanoMOL_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-GM-SEC")
    CHAIN_US = URIRef("http://qudt.org/vocab/unit/CHAIN_US")
    MilliS = URIRef("http://qudt.org/vocab/unit/MilliS")
    N_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM2")
    MilliM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM2-PER-SEC")
    BTU_IT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    L_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-K")
    MicroGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3")
    G = URIRef("http://qudt.org/vocab/unit/G")
    MI3 = URIRef("http://qudt.org/vocab/unit/MI3")
    MilliG = URIRef("http://qudt.org/vocab/unit/MilliG")
    REM = URIRef("http://qudt.org/vocab/unit/REM")
    ARCSEC = URIRef("http://qudt.org/vocab/unit/ARCSEC")
    MOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2")
    CentiM_H2O = URIRef("http://qudt.org/vocab/unit/CentiM_H2O")
    MI_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI-PER-MIN")
    MilliC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M2")
    PDL_FT = URIRef("http://qudt.org/vocab/unit/PDL-FT")
    M2_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-V-SEC")
    LB_SEC_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-FT3")
    M2_PER_N = URIRef("http://qudt.org/vocab/unit/M2-PER-N")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    HR_PER_FT2 = URIRef("http://qudt.org/vocab/unit/HR-PER-FT2")
    TON_Metric_PER_M3 = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3")
    KiloA = URIRef("http://qudt.org/vocab/unit/KiloA")
    ERG_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM2-SEC")
    IN4 = URIRef("http://qudt.org/vocab/unit/IN4")
    TONNE_PER_DAY = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY")
    MilliBAR_PER_K = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-K")
    FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-SEC")
    KiloGM_F_M = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M")
    PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PER-KiloGM")
    A_SEC = URIRef("http://qudt.org/vocab/unit/A-SEC")
    PicoS_PER_M = URIRef("http://qudt.org/vocab/unit/PicoS-PER-M")
    N_PER_CentiM = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM")
    KiloGM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MilliM")
    PlanckCurrentDensity = URIRef("http://qudt.org/vocab/unit/PlanckCurrentDensity")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    GigaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/GigaC-PER-M3")
    PH = URIRef("http://qudt.org/vocab/unit/PH")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    THERM_EC = URIRef("http://qudt.org/vocab/unit/THERM_EC")
    M3_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-BAR")
    CAL_TH_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM-SEC-DEG_C")
    DeciGM = URIRef("http://qudt.org/vocab/unit/DeciGM")
    K = URIRef("http://qudt.org/vocab/unit/K")
    A_M2 = URIRef("http://qudt.org/vocab/unit/A-M2")
    NanoGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M3")
    MicroFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-M")
    PicoA_PER_MicroMOL_L = URIRef("http://qudt.org/vocab/unit/PicoA-PER-MicroMOL-L")
    MilliH = URIRef("http://qudt.org/vocab/unit/MilliH")
    BBL_UK_PET = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET")
    PA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-BAR")
    OZ_MIN_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-GAL_UK")
    DEG_F_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-K")
    C_Ab = URIRef("http://qudt.org/vocab/unit/C_Ab")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    N_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG")
    PDL = URIRef("http://qudt.org/vocab/unit/PDL")
    J_PER_M4 = URIRef("http://qudt.org/vocab/unit/J-PER-M4")
    KiloCAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-MIN")
    TON_LONG_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_LONG-PER-YD3")
    FT_LB_F = URIRef("http://qudt.org/vocab/unit/FT-LB_F")
    N_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-PER-RAD")
    TON_Metric_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC-BAR")
    J = URIRef("http://qudt.org/vocab/unit/J")
    L_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/L-PER-MicroMOL")
    NAT_PER_SEC = URIRef("http://qudt.org/vocab/unit/NAT-PER-SEC")
    MilliBQ = URIRef("http://qudt.org/vocab/unit/MilliBQ")
    PDL_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-FT2")
    HectoPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-L-PER-SEC")
    GM_HR_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L-M3")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    MegaHZ_M = URIRef("http://qudt.org/vocab/unit/MegaHZ-M")
    MilliA_PER_IN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-IN")
    V_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Ab-PER-CentiM")
    MilliMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3")
    PPM = URIRef("http://qudt.org/vocab/unit/PPM")
    TONNE_PER_MO = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MO")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    FT_SEC_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-GAL_US")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    MegaC = URIRef("http://qudt.org/vocab/unit/MegaC")
    KiloJ_PER_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-K")
    MegaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-HR")
    IN_H2O_60DEG_F = URIRef("http://qudt.org/vocab/unit/IN_H2O_60DEG_F")
    LB_SEC_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-IN3")
    MegaDOLLAR_US_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MegaDOLLAR_US-PER-FLIGHT")
    BTU_IT = URIRef("http://qudt.org/vocab/unit/BTU_IT")
    MegaHZ_M = URIRef("http://qudt.org/vocab/unit/MegaHZ-M")
    KiloCAL_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2")
    MilliL_PER_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-K")
    MilliJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-M2")
    TONNE_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN-BAR")
    N_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-PER-RAD")
    MegaN_M = URIRef("http://qudt.org/vocab/unit/MegaN-M")
    KIP_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KIP_F-PER-IN2")
    MOL_PER_M2_SEC_M_SR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-M-SR")
    GI_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-MIN")
    MilliC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M2")
    OZ_VOL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-DAY")
    MOMME_Textile = URIRef("http://qudt.org/vocab/unit/MOMME_Textile")
    TON = URIRef("http://qudt.org/vocab/unit/TON")
    MilliDEG_C = URIRef("http://qudt.org/vocab/unit/MilliDEG_C")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    DeciB_M = URIRef("http://qudt.org/vocab/unit/DeciB_M")
    N_M_PER_MIN_Angle = URIRef("http://qudt.org/vocab/unit/N-M-PER-MIN_Angle")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    DYN_M = URIRef("http://qudt.org/vocab/unit/DYN-M")
    MicroC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M3")
    PA_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-PER-BAR")
    PK_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-DAY")
    DeciBAR = URIRef("http://qudt.org/vocab/unit/DeciBAR")
    MilliA = URIRef("http://qudt.org/vocab/unit/MilliA")
    DeciS_PER_M = URIRef("http://qudt.org/vocab/unit/DeciS-PER-M")
    PER_J_M3 = URIRef("http://qudt.org/vocab/unit/PER-J-M3")
    MI_N = URIRef("http://qudt.org/vocab/unit/MI_N")
    GigaEV = URIRef("http://qudt.org/vocab/unit/GigaEV")
    MilliA_PER_IN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-IN")
    HART_PER_SEC = URIRef("http://qudt.org/vocab/unit/HART-PER-SEC")
    M2_PER_M2 = URIRef("http://qudt.org/vocab/unit/M2-PER-M2")
    KiloL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloL-PER-HR")
    PER_SEC_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR")
    GM_SEC_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L-CentiM3")
    MicroFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-M")
    CAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-K")
    FT_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC-DEG_F")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    MilliH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-OHM")
    N_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG")
    HectoC = URIRef("http://qudt.org/vocab/unit/HectoC")
    GM_PER_MOL = URIRef("http://qudt.org/vocab/unit/GM-PER-MOL")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    M5 = URIRef("http://qudt.org/vocab/unit/M5")
    SEC_PER_RAD_M3 = URIRef("http://qudt.org/vocab/unit/SEC-PER-RAD-M3")
    MicroM_PER_K = URIRef("http://qudt.org/vocab/unit/MicroM-PER-K")
    N_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG")
    KiloN_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-DEG")
    NanoSEC = URIRef("http://qudt.org/vocab/unit/NanoSEC")
    MilliSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-MIN")
    W_PER_M2_K4 = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K4")
    GM_MIN_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M6")
    ATM_M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/ATM-M3-PER-MOL")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    CAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-K")
    PicoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/PicoFARAD-PER-M")
    MilliM3 = URIRef("http://qudt.org/vocab/unit/MilliM3")
    LB_PER_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-HR-DEG_F")
    KiloA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M")
    TebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M")
    MilliGM_PER_L_PA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-PA-SEC")
    ERG_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM-SEC")
    KiloSEC = URIRef("http://qudt.org/vocab/unit/KiloSEC")
    KiloL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloL-PER-HR")
    PA_PER_MIN = URIRef("http://qudt.org/vocab/unit/PA-PER-MIN")
    PERM_0DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_0DEG_C")
    MilliL_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR")
    GM_MIN_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M6")
    H_Ab = URIRef("http://qudt.org/vocab/unit/H_Ab")
    M3_PER_HR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR")
    MilliG = URIRef("http://qudt.org/vocab/unit/MilliG")
    NanoM_PER_CentiM_PSI = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-PSI")
    GAL_US = URIRef("http://qudt.org/vocab/unit/GAL_US")
    T_Ab = URIRef("http://qudt.org/vocab/unit/T_Ab")
    MegaN_M = URIRef("http://qudt.org/vocab/unit/MegaN-M")
    CentiBAR = URIRef("http://qudt.org/vocab/unit/CentiBAR")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    LB_PER_FT3_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3-PSI")
    A_SEC2 = URIRef("http://qudt.org/vocab/unit/A-SEC2")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    NanoV = URIRef("http://qudt.org/vocab/unit/NanoV")
    MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/MOL-DEG_C")
    LM_PER_W = URIRef("http://qudt.org/vocab/unit/LM-PER-W")
    TON_Metric_PER_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-K")
    MilliGAL = URIRef("http://qudt.org/vocab/unit/MilliGAL")
    SPF = URIRef("http://qudt.org/vocab/unit/SPF")
    BAR_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/BAR-PER-DEG_C")
    TON_Metric_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY-K")
    SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-PER-FT2")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    EarthMass = URIRef("http://qudt.org/vocab/unit/EarthMass")
    KiloGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-BAR")
    MilliC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M2")
    W_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-PER-M3")
    IN = URIRef("http://qudt.org/vocab/unit/IN")
    MilliW_PER_CentiM2_MicroM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-CentiM2-MicroM-SR")
    NanoMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-M2-DAY")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    YD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/YD-PER-SEC2")
    R_man = URIRef("http://qudt.org/vocab/unit/R_man")
    A_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/A-PER-KiloGM")
    PER_SEC_M2_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2-SR")
    KiloGM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM")
    BTU_IT_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-SEC-DEG_F")
    MegaV = URIRef("http://qudt.org/vocab/unit/MegaV")
    L = URIRef("http://qudt.org/vocab/unit/L")
    PicoS_PER_M = URIRef("http://qudt.org/vocab/unit/PicoS-PER-M")
    M4_PER_SEC = URIRef("http://qudt.org/vocab/unit/M4-PER-SEC")
    GI_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_US-PER-SEC")
    MilliGM_MIN_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M3-CentiM3")
    MilliBAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-L-PER-SEC")
    MicroMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L")
    GM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3-K")
    IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC")
    KiloJ_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM-K")
    PERCENT_HR_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-FT3")
    KiloBTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-FT2")
    N_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM2")
    CentiN_M = URIRef("http://qudt.org/vocab/unit/CentiN-M")
    LB_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_UK")
    GM_PER_MIN = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN")
    NanoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/NanoFARAD-PER-M")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    LB_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-DEG_F")
    MilliRAD = URIRef("http://qudt.org/vocab/unit/MilliRAD")
    OZ_VOL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-DAY")
    C_Ab = URIRef("http://qudt.org/vocab/unit/C_Ab")
    M2_PER_M2 = URIRef("http://qudt.org/vocab/unit/M2-PER-M2")
    N_M_PER_M_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-M-RAD")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    MOL_PER_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-HR")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    DPI = URIRef("http://qudt.org/vocab/unit/DPI")
    M2_PER_HZ = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ")
    KiloL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloL-PER-HR")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    MilliBQ_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-M2-DAY")
    KiloGM_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-M2")
    MOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-DAY")
    KiloN_M_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-M")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    J = URIRef("http://qudt.org/vocab/unit/J")
    MilliGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC")
    PER_CentiM = URIRef("http://qudt.org/vocab/unit/PER-CentiM")
    HectoPA = URIRef("http://qudt.org/vocab/unit/HectoPA")
    PER_MILLE_PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PER-PSI")
    SUSCEPTIBILITY_ELEC = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_ELEC")
    J_PER_MOL_K = URIRef("http://qudt.org/vocab/unit/J-PER-MOL-K")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    Z = URIRef("http://qudt.org/vocab/unit/Z")
    DAY_Sidereal = URIRef("http://qudt.org/vocab/unit/DAY_Sidereal")
    AttoA = URIRef("http://qudt.org/vocab/unit/AttoA")
    CASES_PER_KiloINDIV_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-KiloINDIV-YR")
    PA2_SEC = URIRef("http://qudt.org/vocab/unit/PA2-SEC")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    ARE = URIRef("http://qudt.org/vocab/unit/ARE")
    MIN_Sidereal = URIRef("http://qudt.org/vocab/unit/MIN_Sidereal")
    C3_M_PER_J2 = URIRef("http://qudt.org/vocab/unit/C3-M-PER-J2")
    DeciB_M = URIRef("http://qudt.org/vocab/unit/DeciB_M")
    LANGLEY = URIRef("http://qudt.org/vocab/unit/LANGLEY")
    DEGREE_BALLING = URIRef("http://qudt.org/vocab/unit/DEGREE_BALLING")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    SEC_PER_RAD_M3 = URIRef("http://qudt.org/vocab/unit/SEC-PER-RAD-M3")
    EUR_PER_W_SEC = URIRef("http://qudt.org/vocab/unit/EUR-PER-W-SEC")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    BTU_IT_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC-DEG_F")
    BTU_IT_PER_LB_F_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_R")
    LB_HR_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-GAL_US")
    HectoL = URIRef("http://qudt.org/vocab/unit/HectoL")
    SolarMass = URIRef("http://qudt.org/vocab/unit/SolarMass")
    MOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3")
    A2_SEC = URIRef("http://qudt.org/vocab/unit/A2-SEC")
    BAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-L-PER-SEC")
    LB_MOL = URIRef("http://qudt.org/vocab/unit/LB-MOL")
    YD_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD-PER-MIN")
    MOL_PER_KiloGM_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-BAR")
    MicroKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MicroKAT-PER-L")
    OZ_TROY = URIRef("http://qudt.org/vocab/unit/OZ_TROY")
    CentiM3_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-K")
    PK_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-HR")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    N_CentiM = URIRef("http://qudt.org/vocab/unit/N-CentiM")
    PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/PER-ANGSTROM")
    OHM_CIRC_MIL_PER_FT = URIRef("http://qudt.org/vocab/unit/OHM_CIRC-MIL-PER-FT")
    ExbiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M")
    NanoGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DeciL")
    MegaOHM = URIRef("http://qudt.org/vocab/unit/MegaOHM")
    PER_RAD = URIRef("http://qudt.org/vocab/unit/PER-RAD")
    J_PER_T2 = URIRef("http://qudt.org/vocab/unit/J-PER-T2")
    NAT = URIRef("http://qudt.org/vocab/unit/NAT")
    PER_DAY = URIRef("http://qudt.org/vocab/unit/PER-DAY")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    KiloJ_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MOL")
    PSI = URIRef("http://qudt.org/vocab/unit/PSI")
    PER_TON = URIRef("http://qudt.org/vocab/unit/PER-TON")
    J_PER_GM = URIRef("http://qudt.org/vocab/unit/J-PER-GM")
    BAR = URIRef("http://qudt.org/vocab/unit/BAR")
    LB_HR_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN6")
    DeciTON_Metric = URIRef("http://qudt.org/vocab/unit/DeciTON_Metric")
    MI3 = URIRef("http://qudt.org/vocab/unit/MI3")
    NanoV = URIRef("http://qudt.org/vocab/unit/NanoV")
    MilliC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliC-PER-KiloGM")
    M2_PER_N = URIRef("http://qudt.org/vocab/unit/M2-PER-N")
    TONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-YR")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    DeciSEC = URIRef("http://qudt.org/vocab/unit/DeciSEC")
    TON_SHIPPING_UK = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_UK")
    M_KiloGM = URIRef("http://qudt.org/vocab/unit/M-KiloGM")
    MilliL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-SEC")
    PicoL = URIRef("http://qudt.org/vocab/unit/PicoL")
    PERCENT_PER_OHM = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-OHM")
    V_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-PER-CentiM")
    M_KiloGM = URIRef("http://qudt.org/vocab/unit/M-KiloGM")
    W_PER_GM = URIRef("http://qudt.org/vocab/unit/W-PER-GM")
    BARN_PER_SR = URIRef("http://qudt.org/vocab/unit/BARN-PER-SR")
    FT_SEC_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-GAL_UK")
    PERCENT_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-CentiM3")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    failures_in_time = URIRef("http://qudt.org/vocab/unit/failures-in-time")
    FT2_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT2-PER-SEC")
    KiloR = URIRef("http://qudt.org/vocab/unit/KiloR")
    M_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-BAR")
    DeciB_C = URIRef("http://qudt.org/vocab/unit/DeciB_C")
    KiloPA_M2_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloPA-M2-PER-GM")
    PER_MIN = URIRef("http://qudt.org/vocab/unit/PER-MIN")
    MilliV_A = URIRef("http://qudt.org/vocab/unit/MilliV-A")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    MI_PER_HR = URIRef("http://qudt.org/vocab/unit/MI-PER-HR")
    MegaPSI = URIRef("http://qudt.org/vocab/unit/MegaPSI")
    DeciS_PER_M = URIRef("http://qudt.org/vocab/unit/DeciS-PER-M")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    CentiM3_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-K")
    PERCENT_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-M3")
    C_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM2")
    CentiM3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-BAR")
    KiloCAL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-SEC")
    BTU_IT_PER_HR_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_R")
    PER_MILLE_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PSI")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    IN_H2O = URIRef("http://qudt.org/vocab/unit/IN_H2O")
    DWT = URIRef("http://qudt.org/vocab/unit/DWT")
    OHM_PER_K = URIRef("http://qudt.org/vocab/unit/OHM-PER-K")
    DecaGM = URIRef("http://qudt.org/vocab/unit/DecaGM")
    IN3_PER_LB = URIRef("http://qudt.org/vocab/unit/IN3-PER-LB")
    MilliSV = URIRef("http://qudt.org/vocab/unit/MilliSV")
    NUM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NUM-PER-MicroL")
    CentiM_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-BAR")
    MilliL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN")
    OZ_PER_YD2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD2")
    MilliKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MilliKAT-PER-L")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    W_PER_M2_K = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K")
    LB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT")
    YD3_PER_PSI = URIRef("http://qudt.org/vocab/unit/YD3-PER-PSI")
    J_M_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-M-PER-MOL")
    MicroGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-HR")
    V2_PER_K2 = URIRef("http://qudt.org/vocab/unit/V2-PER-K2")
    DeciB_C = URIRef("http://qudt.org/vocab/unit/DeciB_C")
    FT_LB_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-SEC")
    DIOPTER = URIRef("http://qudt.org/vocab/unit/DIOPTER")
    THM_US = URIRef("http://qudt.org/vocab/unit/THM_US")
    BTU_IT_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC")
    DeciB_MilliW_PER_MegaHZ = URIRef("http://qudt.org/vocab/unit/DeciB-MilliW-PER-MegaHZ")
    KiloOHM_M = URIRef("http://qudt.org/vocab/unit/KiloOHM-M")
    W_PER_M2_M = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    LB_PER_HR_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-HR-PSI")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    GigaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-PER-M")
    BTU_IT_FT = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT")
    EV_SEC = URIRef("http://qudt.org/vocab/unit/EV-SEC")
    L_PER_HR_K = URIRef("http://qudt.org/vocab/unit/L-PER-HR-K")
    GM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2")
    unit = URIRef("http://qudt.org/vocab/unit")
    PER_MOL = URIRef("http://qudt.org/vocab/unit/PER-MOL")
    LB_PER_HR_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-HR-PSI")
    KibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M3")
    BTU_IT_FT = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT")
    NanoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L")
    H_PER_OHM = URIRef("http://qudt.org/vocab/unit/H-PER-OHM")
    ERG_PER_CentiM = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM")
    MicroW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroW-PER-M2")
    DEG_R_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-SEC")
    KiloWB = URIRef("http://qudt.org/vocab/unit/KiloWB")
    NUM_PER_HR = URIRef("http://qudt.org/vocab/unit/NUM-PER-HR")
    PicoMOL_PER_M_W_SEC = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M-W-SEC")
    BTU_TH_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-HR-DEG_F")
    YR_Common = URIRef("http://qudt.org/vocab/unit/YR_Common")
    LB_PER_FT = URIRef("http://qudt.org/vocab/unit/LB-PER-FT")
    CentiMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-KiloGM")
    CAL_TH_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2-SEC")
    PER_KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/PER-KiloV-A-HR")
    PERCENT_HR_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-GAL_UK")
    PK_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-MIN")
    Kilo_FT3 = URIRef("http://qudt.org/vocab/unit/Kilo-FT3")
    MIN_Angle = URIRef("http://qudt.org/vocab/unit/MIN_Angle")
    M_KiloGM = URIRef("http://qudt.org/vocab/unit/M-KiloGM")
    MicroM_PER_N = URIRef("http://qudt.org/vocab/unit/MicroM-PER-N")
    PSI_YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-YD3-PER-SEC")
    KiloM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloM-PER-DAY")
    A_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-M3")
    UNKNOWN = URIRef("http://qudt.org/vocab/unit/UNKNOWN")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    OZ_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ-PER-DAY")
    MilliGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-HR")
    KiloS_PER_M = URIRef("http://qudt.org/vocab/unit/KiloS-PER-M")
    PER_MegaK = URIRef("http://qudt.org/vocab/unit/PER-MegaK")
    QT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-HR")
    OZ_FT = URIRef("http://qudt.org/vocab/unit/OZ-FT")
    M2_PER_SR = URIRef("http://qudt.org/vocab/unit/M2-PER-SR")
    A_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM2")
    FemtoM = URIRef("http://qudt.org/vocab/unit/FemtoM")
    MicroCi = URIRef("http://qudt.org/vocab/unit/MicroCi")
    GRAIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-M3")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PER-M3-SEC")
    BAUD = URIRef("http://qudt.org/vocab/unit/BAUD")
    PlanckDensity = URIRef("http://qudt.org/vocab/unit/PlanckDensity")
    MegaBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaBTU_IT-PER-HR")
    BTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    LB_MIN_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-GAL_US")
    FT = URIRef("http://qudt.org/vocab/unit/FT")
    FemtoA = URIRef("http://qudt.org/vocab/unit/FemtoA")
    KiloJ_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-HR")
    PK_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-SEC")
    CD_PER_IN2 = URIRef("http://qudt.org/vocab/unit/CD-PER-IN2")
    MicroMHO = URIRef("http://qudt.org/vocab/unit/MicroMHO")
    OZ_IN = URIRef("http://qudt.org/vocab/unit/OZ-IN")
    NanoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L")
    KiloJ_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MOL")
    MilliDEG_C = URIRef("http://qudt.org/vocab/unit/MilliDEG_C")
    WK = URIRef("http://qudt.org/vocab/unit/WK")
    PINT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-MIN")
    MilliMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-L")
    ST_PER_K = URIRef("http://qudt.org/vocab/unit/ST-PER-K")
    CentiM3_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-K")
    MOHM = URIRef("http://qudt.org/vocab/unit/MOHM")
    M_H2O = URIRef("http://qudt.org/vocab/unit/M_H2O")
    N_M_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-M")
    NanoJ = URIRef("http://qudt.org/vocab/unit/NanoJ")
    KiloA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M")
    MegaBAR = URIRef("http://qudt.org/vocab/unit/MegaBAR")
    TONNE_PER_HA = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA")
    MX = URIRef("http://qudt.org/vocab/unit/MX")
    MegaEV_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-CentiM")
    MicroBQ = URIRef("http://qudt.org/vocab/unit/MicroBQ")
    GI_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-SEC")
    GM_PER_K = URIRef("http://qudt.org/vocab/unit/GM-PER-K")
    MilliL_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-K")
    IN3 = URIRef("http://qudt.org/vocab/unit/IN3")
    KiloEV = URIRef("http://qudt.org/vocab/unit/KiloEV")
    LB_PER_FT3 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3")
    MilliGM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR")
    MegaPA = URIRef("http://qudt.org/vocab/unit/MegaPA")
    M2_PER_J = URIRef("http://qudt.org/vocab/unit/M2-PER-J")
    DEGREE_API = URIRef("http://qudt.org/vocab/unit/DEGREE_API")
    CD_PER_IN2 = URIRef("http://qudt.org/vocab/unit/CD-PER-IN2")
    GigaFLOPS = URIRef("http://qudt.org/vocab/unit/GigaFLOPS")
    A_Stat = URIRef("http://qudt.org/vocab/unit/A_Stat")
    OZ_PER_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD3")
    PPTR_VOL = URIRef("http://qudt.org/vocab/unit/PPTR_VOL")
    MilliGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-CentiM2")
    KiloCAL_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2")
    ERG_CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-CentiM2-PER-GM")
    GM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciL")
    FATH = URIRef("http://qudt.org/vocab/unit/FATH")
    MicroGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-DeciL")
    PH = URIRef("http://qudt.org/vocab/unit/PH")
    MicroSEC = URIRef("http://qudt.org/vocab/unit/MicroSEC")
    OZ_VOL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-SEC")
    KiloA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M")
    MebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M2")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    CentiM_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-K")
    MegaTOE = URIRef("http://qudt.org/vocab/unit/MegaTOE")
    PA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-L-PER-SEC")
    N_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM2")
    M_PER_HR = URIRef("http://qudt.org/vocab/unit/M-PER-HR")
    DeciL_PER_GM = URIRef("http://qudt.org/vocab/unit/DeciL-PER-GM")
    C_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM3")
    OZ_F_IN = URIRef("http://qudt.org/vocab/unit/OZ_F-IN")
    TON_Metric_PER_HA = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HA")
    CAL_MEAN = URIRef("http://qudt.org/vocab/unit/CAL_MEAN")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    BU_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-DAY")
    PicoPA = URIRef("http://qudt.org/vocab/unit/PicoPA")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    GM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloGM")
    MDOLLAR_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MDOLLAR-PER-FLIGHT")
    PicoMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L-HR")
    MilliOHM = URIRef("http://qudt.org/vocab/unit/MilliOHM")
    OZ_HR_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-FT3")
    PicoGM_PER_GM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-GM")
    GI_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_US-PER-SEC")
    BTU_IT_PER_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL-DEG_F")
    MilliGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY")
    ExbiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M2")
    KiloV_A_PER_K = URIRef("http://qudt.org/vocab/unit/KiloV-A-PER-K")
    FT3_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT3-PER-SEC")
    GigaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-SEC")
    PER_GM = URIRef("http://qudt.org/vocab/unit/PER-GM")
    A = URIRef("http://qudt.org/vocab/unit/A")
    DIOPTER = URIRef("http://qudt.org/vocab/unit/DIOPTER")
    MilliBQ_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-M2-DAY")
    YD_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD-PER-MIN")
    KiloM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-HR")
    MilliV = URIRef("http://qudt.org/vocab/unit/MilliV")
    T = URIRef("http://qudt.org/vocab/unit/T")
    W_PER_M_K = URIRef("http://qudt.org/vocab/unit/W-PER-M-K")
    BTU_IT_PER_LB_MOL = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-MOL")
    ExaBYTE = URIRef("http://qudt.org/vocab/unit/ExaBYTE")
    MilliL_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR")
    CentiMOL = URIRef("http://qudt.org/vocab/unit/CentiMOL")
    HectoBAR = URIRef("http://qudt.org/vocab/unit/HectoBAR")
    KiloM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloM-PER-DAY")
    CAL_TH_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-DEG_C")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    KiloW_PER_M_K = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M-K")
    MicroGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-HR")
    BTU_MEAN = URIRef("http://qudt.org/vocab/unit/BTU_MEAN")
    M_PER_DEG_C_M = URIRef("http://qudt.org/vocab/unit/M-PER-DEG_C-M")
    PicoJ = URIRef("http://qudt.org/vocab/unit/PicoJ")
    MicroM_PER_N = URIRef("http://qudt.org/vocab/unit/MicroM-PER-N")
    MilliL_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-K")
    YD3 = URIRef("http://qudt.org/vocab/unit/YD3")
    N = URIRef("http://qudt.org/vocab/unit/N")
    PSI_PER_IN = URIRef("http://qudt.org/vocab/unit/PSI-PER-IN")
    STILB = URIRef("http://qudt.org/vocab/unit/STILB")
    PERCENT_PER_CentiPOISE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-CentiPOISE")
    A_M2_PER_J_SEC = URIRef("http://qudt.org/vocab/unit/A-M2-PER-J-SEC")
    GI_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-HR")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    LB_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT2")
    MilliW_PER_CentiM2_MicroM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-CentiM2-MicroM-SR")
    ZOLL = URIRef("http://qudt.org/vocab/unit/ZOLL")
    ATM = URIRef("http://qudt.org/vocab/unit/ATM")
    MicroMOL_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-HR")
    PicoV_A = URIRef("http://qudt.org/vocab/unit/PicoV-A")
    M_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-V-SEC")
    DYN_M = URIRef("http://qudt.org/vocab/unit/DYN-M")
    M2_PER_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ2")
    KiloGM_PER_MegaBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MegaBTU_IT")
    MegaN = URIRef("http://qudt.org/vocab/unit/MegaN")
    BTU_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-MIN")
    A_HR = URIRef("http://qudt.org/vocab/unit/A-HR")
    CentiM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SEC")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    MicroGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-MIN")
    MilliRAD_R_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliRAD_R-PER-HR")
    OZ_HR_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN6")
    TeraOHM = URIRef("http://qudt.org/vocab/unit/TeraOHM")
    MegaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-M")
    HP = URIRef("http://qudt.org/vocab/unit/HP")
    IN_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN-PER-MIN")
    OHM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/OHM-PER-KiloM")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    DEG_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG-PER-HR")
    LB_SEC_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK2")
    DecaPA = URIRef("http://qudt.org/vocab/unit/DecaPA")
    ZeptoC = URIRef("http://qudt.org/vocab/unit/ZeptoC")
    MilliGM_MIN_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M3-L")
    GM_PER_M3 = URIRef("http://qudt.org/vocab/unit/GM-PER-M3")
    L_PER_MOL = URIRef("http://qudt.org/vocab/unit/L-PER-MOL")
    MilliC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliC-PER-KiloGM")
    N = URIRef("http://qudt.org/vocab/unit/N")
    TONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-YR")
    C_M2 = URIRef("http://qudt.org/vocab/unit/C-M2")
    CentiM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN")
    REV_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC2")
    LM_HR = URIRef("http://qudt.org/vocab/unit/LM-HR")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    PER_PA_SEC = URIRef("http://qudt.org/vocab/unit/PER-PA-SEC")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    TON_F_US = URIRef("http://qudt.org/vocab/unit/TON_F_US")
    K_PER_HR = URIRef("http://qudt.org/vocab/unit/K-PER-HR")
    OZ_IN2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/OZ-IN2-PER-IN3-LB_F-SEC")
    OHM_CIRC_MIL_PER_FT = URIRef("http://qudt.org/vocab/unit/OHM_CIRC-MIL-PER-FT")
    PER_MILLE_PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PER-PSI")
    KiloN_M = URIRef("http://qudt.org/vocab/unit/KiloN-M")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    MicroC = URIRef("http://qudt.org/vocab/unit/MicroC")
    ANGSTROM3 = URIRef("http://qudt.org/vocab/unit/ANGSTROM3")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    J_PER_T2 = URIRef("http://qudt.org/vocab/unit/J-PER-T2")
    KiloCAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-SEC")
    MilliL_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-K")
    OZ = URIRef("http://qudt.org/vocab/unit/OZ")
    M_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-K")
    KiloV_A_Reactive = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive")
    SON = URIRef("http://qudt.org/vocab/unit/SON")
    KiloGM_PER_M_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-HR")
    TON_FG = URIRef("http://qudt.org/vocab/unit/TON_FG")
    B = URIRef("http://qudt.org/vocab/unit/B")
    ERG_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM")
    FBM = URIRef("http://qudt.org/vocab/unit/FBM")
    BAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-M3-PER-SEC")
    Denier = URIRef("http://qudt.org/vocab/unit/Denier")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    THM_US_PER_HR = URIRef("http://qudt.org/vocab/unit/THM_US-PER-HR")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    KiloM = URIRef("http://qudt.org/vocab/unit/KiloM")
    MI = URIRef("http://qudt.org/vocab/unit/MI")
    PicoMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M3")
    MOMME_Textile = URIRef("http://qudt.org/vocab/unit/MOMME_Textile")
    KiloBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT")
    QUAD = URIRef("http://qudt.org/vocab/unit/QUAD")
    RAD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC2")
    BARYE = URIRef("http://qudt.org/vocab/unit/BARYE")
    MilliV = URIRef("http://qudt.org/vocab/unit/MilliV")
    MilliKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MilliKAT-PER-L")
    GM_MIN_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M3-CentiM3")
    PA_M = URIRef("http://qudt.org/vocab/unit/PA-M")
    L_PER_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-SEC")
    CentiPOISE = URIRef("http://qudt.org/vocab/unit/CentiPOISE")
    AT = URIRef("http://qudt.org/vocab/unit/AT")
    KiloCAL = URIRef("http://qudt.org/vocab/unit/KiloCAL")
    MilliGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN")
    NanoBQ = URIRef("http://qudt.org/vocab/unit/NanoBQ")
    MilliMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2")
    PK_US_DRY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY")
    V_PER_MilliM = URIRef("http://qudt.org/vocab/unit/V-PER-MilliM")
    KiloCAL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-SEC")
    M_PER_RAD = URIRef("http://qudt.org/vocab/unit/M-PER-RAD")
    PERCENT_PER_MilliM = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MilliM")
    MicroSV = URIRef("http://qudt.org/vocab/unit/MicroSV")
    KiloA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    SPF = URIRef("http://qudt.org/vocab/unit/SPF")
    MicroW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroW-PER-M2")
    TonEnergy = URIRef("http://qudt.org/vocab/unit/TonEnergy")
    DYN = URIRef("http://qudt.org/vocab/unit/DYN")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    MilliW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2")
    NAT = URIRef("http://qudt.org/vocab/unit/NAT")
    MicroGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-GM")
    PERMEABILITY_EM_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_EM_REL")
    TORR_PER_M = URIRef("http://qudt.org/vocab/unit/TORR-PER-M")
    IU = URIRef("http://qudt.org/vocab/unit/IU")
    SEC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/SEC-PER-KiloGM")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    MilliGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-MIN")
    PebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M3")
    MilliGAL = URIRef("http://qudt.org/vocab/unit/MilliGAL")
    TON_SHORT_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-YD3")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    MicroJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroJ-PER-SEC")
    MilliGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MilliL")
    SUSCEPTIBILITY_MAG = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_MAG")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    MicroFARAD = URIRef("http://qudt.org/vocab/unit/MicroFARAD")
    KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A-HR")
    A_M2_PER_J_SEC = URIRef("http://qudt.org/vocab/unit/A-M2-PER-J-SEC")
    N_M_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-M")
    MilliBAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-BAR")
    KiloCAL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-SEC")
    BTU_TH_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-FT2-HR-DEG_F")
    PERCENT_PER_PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-PERCENT")
    FT_LB_F_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-HR")
    GM_PER_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    M_KiloGM = URIRef("http://qudt.org/vocab/unit/M-KiloGM")
    PER_M_K = URIRef("http://qudt.org/vocab/unit/PER-M-K")
    RAYL = URIRef("http://qudt.org/vocab/unit/RAYL")
    L_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-HR-BAR")
    PER_FT3 = URIRef("http://qudt.org/vocab/unit/PER-FT3")
    BTU_IT_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    EUR_PER_W_SEC = URIRef("http://qudt.org/vocab/unit/EUR-PER-W-SEC")
    KiloBIT = URIRef("http://qudt.org/vocab/unit/KiloBIT")
    MilliGM_MIN_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L-CentiM3")
    ExaJ = URIRef("http://qudt.org/vocab/unit/ExaJ")
    MegaW = URIRef("http://qudt.org/vocab/unit/MegaW")
    NanoMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    NanoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/NanoFARAD-PER-M")
    KiloGM_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-M2")
    PPM = URIRef("http://qudt.org/vocab/unit/PPM")
    MI_N_PER_HR = URIRef("http://qudt.org/vocab/unit/MI_N-PER-HR")
    GM_PER_CentiM2_YR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2-YR")
    MilliS = URIRef("http://qudt.org/vocab/unit/MilliS")
    W = URIRef("http://qudt.org/vocab/unit/W")
    J_PER_KiloGM_K_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-M3")
    DEG_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC2")
    QT_US = URIRef("http://qudt.org/vocab/unit/QT_US")
    MegaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M2")
    NanoSEC = URIRef("http://qudt.org/vocab/unit/NanoSEC")
    BQ_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-SEC-PER-M3")
    PicoJ = URIRef("http://qudt.org/vocab/unit/PicoJ")
    M2_PER_M2 = URIRef("http://qudt.org/vocab/unit/M2-PER-M2")
    DeciM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-M3")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    MIN = URIRef("http://qudt.org/vocab/unit/MIN")
    K_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/K-PER-SEC2")
    QT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_US-PER-SEC")
    PERCENT_MIN_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-CentiM3")
    FT = URIRef("http://qudt.org/vocab/unit/FT")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    PER_SEC_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR")
    STILB = URIRef("http://qudt.org/vocab/unit/STILB")
    LB_MOL = URIRef("http://qudt.org/vocab/unit/LB-MOL")
    M2_PER_HZ = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ")
    PicoGM_PER_L = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-L")
    TON_Assay = URIRef("http://qudt.org/vocab/unit/TON_Assay")
    KiloGM_PER_L = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L")
    BU_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-MIN")
    MilliM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC2")
    PERCENT_PER_MilliM = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MilliM")
    PPTM = URIRef("http://qudt.org/vocab/unit/PPTM")
    MilliGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN")
    MI_PER_SEC = URIRef("http://qudt.org/vocab/unit/MI-PER-SEC")
    IN_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC2")
    ERG_PER_CentiM = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM")
    QT_US = URIRef("http://qudt.org/vocab/unit/QT_US")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    GM_PER_CentiM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM-BAR")
    MicroC = URIRef("http://qudt.org/vocab/unit/MicroC")
    MilliL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-MIN")
    BBL_UK_PET_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-MIN")
    GM_PER_CentiM_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM-SEC")
    M_PER_MIN = URIRef("http://qudt.org/vocab/unit/M-PER-MIN")
    OZ_VOL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-HR")
    DEGREE_BRIX = URIRef("http://qudt.org/vocab/unit/DEGREE_BRIX")
    MilliGM_MIN_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L-M3")
    TON_Metric = URIRef("http://qudt.org/vocab/unit/TON_Metric")
    CentiM3_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR")
    NanoM2 = URIRef("http://qudt.org/vocab/unit/NanoM2")
    GigaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-SEC")
    KiloA_HR = URIRef("http://qudt.org/vocab/unit/KiloA-HR")
    N_PER_A = URIRef("http://qudt.org/vocab/unit/N-PER-A")
    NanoSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-MIN")
    MicroSEC = URIRef("http://qudt.org/vocab/unit/MicroSEC")
    LB_SEC_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-IN3")
    MicroRAD = URIRef("http://qudt.org/vocab/unit/MicroRAD")
    AttoJ = URIRef("http://qudt.org/vocab/unit/AttoJ")
    MicroL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroL-PER-L")
    DEG_C_KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/DEG_C-KiloGM-PER-M2")
    PA2_SEC = URIRef("http://qudt.org/vocab/unit/PA2-SEC")
    LB_PER_GAL = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL")
    MilliGM_SEC_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M3-L")
    MegaFLOPS = URIRef("http://qudt.org/vocab/unit/MegaFLOPS")
    N_M_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-M-PER-KiloGM")
    CASES_PER_KiloINDIV_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-KiloINDIV-YR")
    MicroMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-DAY")
    PDL_IN = URIRef("http://qudt.org/vocab/unit/PDL-IN")
    KiloCAL_Mean = URIRef("http://qudt.org/vocab/unit/KiloCAL_Mean")
    GM_HR_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M3-L")
    ExaC = URIRef("http://qudt.org/vocab/unit/ExaC")
    DeciM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MIN")
    IN_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN-PER-MIN")
    M3_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-K")
    GI_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_US-PER-SEC")
    LB_F_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN")
    HectoPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-L-PER-SEC")
    PicoGM_PER_L = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-L")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    LB_MIN_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-GAL_US")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    FARAD_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/FARAD_Ab-PER-CentiM")
    MicroM_PER_N = URIRef("http://qudt.org/vocab/unit/MicroM-PER-N")
    IN4 = URIRef("http://qudt.org/vocab/unit/IN4")
    IU = URIRef("http://qudt.org/vocab/unit/IU")
    ONE = URIRef("http://qudt.org/vocab/unit/ONE")
    A_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Stat-PER-CentiM2")
    GM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3-K")
    LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT2")
    KiloL = URIRef("http://qudt.org/vocab/unit/KiloL")
    MilliC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M2")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    PERCENT_HR_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-YD3")
    MOL_LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-MIN")
    KiloBIT = URIRef("http://qudt.org/vocab/unit/KiloBIT")
    DEG_R = URIRef("http://qudt.org/vocab/unit/DEG_R")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    NanoGM_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2-DAY")
    MilliGM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M")
    BIT_PER_M = URIRef("http://qudt.org/vocab/unit/BIT-PER-M")
    KibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M3")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    GigaW = URIRef("http://qudt.org/vocab/unit/GigaW")
    DeciM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-KiloGM")
    S_Stat = URIRef("http://qudt.org/vocab/unit/S_Stat")
    MegaA_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaA-PER-M2")
    GM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-M2-DAY")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    NanoH = URIRef("http://qudt.org/vocab/unit/NanoH")
    CentiM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY")
    NanoGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M3")
    MicroN = URIRef("http://qudt.org/vocab/unit/MicroN")
    PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PER-M3-SEC")
    WB_PER_MilliM = URIRef("http://qudt.org/vocab/unit/WB-PER-MilliM")
    GigaEV = URIRef("http://qudt.org/vocab/unit/GigaEV")
    HP_Boiler = URIRef("http://qudt.org/vocab/unit/HP_Boiler")
    MicroS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MicroS-PER-CentiM")
    W_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/W-PER-CentiM2")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    MilliGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-BAR")
    PicoGM = URIRef("http://qudt.org/vocab/unit/PicoGM")
    DEG_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC")
    BTU_IT_PER_MOL_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB")
    DecaGM = URIRef("http://qudt.org/vocab/unit/DecaGM")
    PA_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC2")
    KiloW_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloW-HR-PER-M2")
    MilliMOL = URIRef("http://qudt.org/vocab/unit/MilliMOL")
    BARN = URIRef("http://qudt.org/vocab/unit/BARN")
    CD_IN = URIRef("http://qudt.org/vocab/unit/CD_IN")
    MilliRAD_R_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliRAD_R-PER-HR")
    YR_Sidereal = URIRef("http://qudt.org/vocab/unit/YR_Sidereal")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    TON_SHORT_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-YD3")
    L_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/L-PER-MicroMOL")
    MilliSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-HR")
    KiloPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-BAR")
    FT_H2O_39dot2DEG_F = URIRef("http://qudt.org/vocab/unit/FT_H2O_39dot2DEG_F")
    K_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/K-PER-SEC2")
    OZ = URIRef("http://qudt.org/vocab/unit/OZ")
    NanoGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-SEC")
    OZ_HR_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-GAL_UK")
    ATM_T = URIRef("http://qudt.org/vocab/unit/ATM_T")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    MicroH_PER_M = URIRef("http://qudt.org/vocab/unit/MicroH-PER-M")
    MicroGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-DeciL")
    PetaA = URIRef("http://qudt.org/vocab/unit/PetaA")
    W = URIRef("http://qudt.org/vocab/unit/W")
    PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-PER-SEC")
    KiloV = URIRef("http://qudt.org/vocab/unit/KiloV")
    MilliN = URIRef("http://qudt.org/vocab/unit/MilliN")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    C_M2_PER_V = URIRef("http://qudt.org/vocab/unit/C-M2-PER-V")
    HectoPA = URIRef("http://qudt.org/vocab/unit/HectoPA")
    MebiBYTE = URIRef("http://qudt.org/vocab/unit/MebiBYTE")
    GigaJ = URIRef("http://qudt.org/vocab/unit/GigaJ")
    BIOT = URIRef("http://qudt.org/vocab/unit/BIOT")
    DeciS_PER_M = URIRef("http://qudt.org/vocab/unit/DeciS-PER-M")
    BTU_IT_PER_SEC_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2")
    KiloGM_PER_MegaBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MegaBTU_IT")
    MicroA = URIRef("http://qudt.org/vocab/unit/MicroA")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    PERMEABILITY_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_REL")
    IN3_PER_HR = URIRef("http://qudt.org/vocab/unit/IN3-PER-HR")
    DEG2 = URIRef("http://qudt.org/vocab/unit/DEG2")
    MilliM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC2")
    W_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM")
    EUR_PER_KiloW = URIRef("http://qudt.org/vocab/unit/EUR-PER-KiloW")
    MegaV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive-HR")
    CAL_TH_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2-MIN")
    SEC_PER_M = URIRef("http://qudt.org/vocab/unit/SEC-PER-M")
    ExaBYTE = URIRef("http://qudt.org/vocab/unit/ExaBYTE")
    NanoMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L-HR")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    PERMEABILITY_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_REL")
    K_PER_PA = URIRef("http://qudt.org/vocab/unit/K-PER-PA")
    LB_PER_MIN_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN-DEG_F")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    MOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3")
    LB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT")
    BTU_IT_PER_LB_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    N_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-RAD")
    MilliL_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-K")
    GM_MIN_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L-CentiM3")
    MilliC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M3")
    C_M2 = URIRef("http://qudt.org/vocab/unit/C-M2")
    FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-DEG_F")
    HectoPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-BAR")
    MicroN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroN-M-PER-M2")
    MilliA_HR = URIRef("http://qudt.org/vocab/unit/MilliA-HR")
    MicroMHO = URIRef("http://qudt.org/vocab/unit/MicroMHO")
    PER_CentiM = URIRef("http://qudt.org/vocab/unit/PER-CentiM")
    TON_SHORT_PER_HR_PSI = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR-PSI")
    LB_MIN_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN6")
    M2_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-HZ2")
    KiloBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-HR")
    PetaC = URIRef("http://qudt.org/vocab/unit/PetaC")
    DYN_SEC_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM")
    LB_IN2_PER_GAL_UK_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-GAL_UK-LB_F-SEC")
    AWG = URIRef("http://qudt.org/vocab/unit/AWG")
    ZettaC = URIRef("http://qudt.org/vocab/unit/ZettaC")
    OCTET_PER_SEC = URIRef("http://qudt.org/vocab/unit/OCTET-PER-SEC")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    PA2_SEC = URIRef("http://qudt.org/vocab/unit/PA2-SEC")
    KiloGM_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM2")
    LB_M = URIRef("http://qudt.org/vocab/unit/LB_M")
    MegaBQ = URIRef("http://qudt.org/vocab/unit/MegaBQ")
    CUP_US = URIRef("http://qudt.org/vocab/unit/CUP_US")
    BBL_US = URIRef("http://qudt.org/vocab/unit/BBL_US")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    KiloGM_PER_M2_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC2")
    KiloGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN")
    FT_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-PER-MIN")
    MegaJ = URIRef("http://qudt.org/vocab/unit/MegaJ")
    A_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-PER-DEG_C")
    KiloM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM2-PER-SEC2")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    KiloGM_PER_KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloMOL")
    MilliGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-BAR")
    BTU_TH_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-HR-DEG_F")
    MilliGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-KiloGM")
    PERMEABILITY_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_REL")
    ExaC = URIRef("http://qudt.org/vocab/unit/ExaC")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    TON_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-DAY")
    IN_HG_60DEG_F = URIRef("http://qudt.org/vocab/unit/IN_HG_60DEG_F")
    DeciM2 = URIRef("http://qudt.org/vocab/unit/DeciM2")
    GM_SEC_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L2")
    M2_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-PA")
    M_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-BAR")
    IN_H2O_60DEG_F = URIRef("http://qudt.org/vocab/unit/IN_H2O_60DEG_F")
    PicoW = URIRef("http://qudt.org/vocab/unit/PicoW")
    MilliGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-BAR")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    OZ_PER_GAL = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL")
    M3_PER_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-BAR")
    MicroS_PER_M = URIRef("http://qudt.org/vocab/unit/MicroS-PER-M")
    DEG_F_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC2")
    CentiPOISE = URIRef("http://qudt.org/vocab/unit/CentiPOISE")
    MegaEV_PER_SpeedOfLight = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-SpeedOfLight")
    PK_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-DAY")
    MI_N = URIRef("http://qudt.org/vocab/unit/MI_N")
    YR_Common = URIRef("http://qudt.org/vocab/unit/YR_Common")
    IU_PER_L = URIRef("http://qudt.org/vocab/unit/IU-PER-L")
    KiloGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM2")
    MilliL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M3")
    KiloA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloA-PER-K")
    M2_PER_SR = URIRef("http://qudt.org/vocab/unit/M2-PER-SR")
    DEGREE_BAUME_US_HEAVY = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_HEAVY")
    GRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/GRAY-PER-SEC")
    PHOT = URIRef("http://qudt.org/vocab/unit/PHOT")
    HR_Sidereal = URIRef("http://qudt.org/vocab/unit/HR_Sidereal")
    THM_US = URIRef("http://qudt.org/vocab/unit/THM_US")
    DeciM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-M3")
    FT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-DEG_F")
    DeciTONNE = URIRef("http://qudt.org/vocab/unit/DeciTONNE")
    BBL_US_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-SEC")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    CAL_TH_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM2-K")
    MicroH = URIRef("http://qudt.org/vocab/unit/MicroH")
    AT = URIRef("http://qudt.org/vocab/unit/AT")
    HectoGM = URIRef("http://qudt.org/vocab/unit/HectoGM")
    MicroA_PER_K = URIRef("http://qudt.org/vocab/unit/MicroA-PER-K")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    MegaPA = URIRef("http://qudt.org/vocab/unit/MegaPA")
    KibiBYTE = URIRef("http://qudt.org/vocab/unit/KibiBYTE")
    MilliW = URIRef("http://qudt.org/vocab/unit/MilliW")
    PicoS_PER_M = URIRef("http://qudt.org/vocab/unit/PicoS-PER-M")
    KiloN_M_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-M")
    TON_SHORT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-DEG_F")
    MilliS = URIRef("http://qudt.org/vocab/unit/MilliS")
    A_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Stat-PER-CentiM2")
    MicroGM = URIRef("http://qudt.org/vocab/unit/MicroGM")
    A_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-M2")
    KiloTONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloTONNE-PER-YR")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    TONNE_PER_DAY = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY")
    KiloGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-BAR")
    MilliN_PER_M = URIRef("http://qudt.org/vocab/unit/MilliN-PER-M")
    LB_IN2 = URIRef("http://qudt.org/vocab/unit/LB-IN2")
    MilliKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MilliKAT-PER-L")
    TOE = URIRef("http://qudt.org/vocab/unit/TOE")
    KiloA_HR = URIRef("http://qudt.org/vocab/unit/KiloA-HR")
    KiloL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloL-PER-HR")
    HectoPA_PER_K = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-K")
    CAL_IT_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM")
    GigaBIT_PER_M = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-M")
    MilliGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-BAR")
    PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PER-M3-SEC")
    N_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-M-PER-M2")
    KiloL = URIRef("http://qudt.org/vocab/unit/KiloL")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    PA_M = URIRef("http://qudt.org/vocab/unit/PA-M")
    MicroV = URIRef("http://qudt.org/vocab/unit/MicroV")
    MicroGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-DeciL")
    MegaEV_PER_SpeedOfLight = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-SpeedOfLight")
    MicroGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-HR")
    M_SEC2 = URIRef("http://qudt.org/vocab/unit/M-SEC2")
    LB_F_PER_LB = URIRef("http://qudt.org/vocab/unit/LB_F-PER-LB")
    LB_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-DEG_F")
    YD_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD-PER-MIN")
    MilliGM = URIRef("http://qudt.org/vocab/unit/MilliGM")
    EarthMass = URIRef("http://qudt.org/vocab/unit/EarthMass")
    KiloGM_PER_J = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-J")
    IU = URIRef("http://qudt.org/vocab/unit/IU")
    DeciB_A = URIRef("http://qudt.org/vocab/unit/DeciB_A")
    CentiM_PER_YR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-YR")
    PK_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-SEC")
    GI = URIRef("http://qudt.org/vocab/unit/GI")
    GigaOHM_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-M")
    NanoMOL_PER_MicroGM_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroGM-HR")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    NUM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/NUM-PER-KiloM2")
    MilliC = URIRef("http://qudt.org/vocab/unit/MilliC")
    PERCENT_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-M3")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    EV_PER_K = URIRef("http://qudt.org/vocab/unit/EV-PER-K")
    M3_PER_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-M2")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    GAL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-SEC")
    PicoMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L-HR")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    PER_IN = URIRef("http://qudt.org/vocab/unit/PER-IN")
    DEG_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    SEC_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-FT2")
    M2_K_PER_W = URIRef("http://qudt.org/vocab/unit/M2-K-PER-W")
    MicroV_PER_M = URIRef("http://qudt.org/vocab/unit/MicroV-PER-M")
    GM_PER_L = URIRef("http://qudt.org/vocab/unit/GM-PER-L")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    FT_LB_F_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2-SEC")
    DeciM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-M3")
    PER_YR = URIRef("http://qudt.org/vocab/unit/PER-YR")
    BTU_60DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_60DEG_F")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    GM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY-BAR")
    MilliL = URIRef("http://qudt.org/vocab/unit/MilliL")
    W = URIRef("http://qudt.org/vocab/unit/W")
    CAL_TH_PER_G = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-G")
    MOL_PER_L = URIRef("http://qudt.org/vocab/unit/MOL-PER-L")
    DYN_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-CentiM")
    YottaC = URIRef("http://qudt.org/vocab/unit/YottaC")
    PA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M3-PER-SEC")
    T_Ab = URIRef("http://qudt.org/vocab/unit/T_Ab")
    CWT_LONG = URIRef("http://qudt.org/vocab/unit/CWT_LONG")
    KiloFARAD = URIRef("http://qudt.org/vocab/unit/KiloFARAD")
    PHOT = URIRef("http://qudt.org/vocab/unit/PHOT")
    QUAD = URIRef("http://qudt.org/vocab/unit/QUAD")
    MegaV_A = URIRef("http://qudt.org/vocab/unit/MegaV-A")
    PER_DAY = URIRef("http://qudt.org/vocab/unit/PER-DAY")
    MegaEV_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-CentiM")
    PERMEABILITY_EM_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_EM_REL")
    DEG_F_HR_FT2_PER_BTU_TH_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH-IN")
    PSI = URIRef("http://qudt.org/vocab/unit/PSI")
    M2_PER_HA = URIRef("http://qudt.org/vocab/unit/M2-PER-HA")
    PicoJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/PicoJ-PER-SEC")
    MilliFARAD = URIRef("http://qudt.org/vocab/unit/MilliFARAD")
    GM_PER_M3_POISE = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-POISE")
    DeciB_ISO = URIRef("http://qudt.org/vocab/unit/DeciB_ISO")
    MilliGM_MIN_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L-M3")
    PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/PER-ANGSTROM")
    KiloPA_M2_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloPA-M2-PER-GM")
    PINT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-HR")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    PER_SEC_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR")
    BARYE = URIRef("http://qudt.org/vocab/unit/BARYE")
    ERG_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM3")
    C = URIRef("http://qudt.org/vocab/unit/C")
    CAL_TH_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2-SEC")
    OHM_Stat = URIRef("http://qudt.org/vocab/unit/OHM_Stat")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    MebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M")
    MilliGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-SEC")
    LM_SEC = URIRef("http://qudt.org/vocab/unit/LM-SEC")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    OHM_Ab = URIRef("http://qudt.org/vocab/unit/OHM_Ab")
    FemtoMOL = URIRef("http://qudt.org/vocab/unit/FemtoMOL")
    NUM_PER_YR = URIRef("http://qudt.org/vocab/unit/NUM-PER-YR")
    FC = URIRef("http://qudt.org/vocab/unit/FC")
    FT3_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN")
    N_PER_C = URIRef("http://qudt.org/vocab/unit/N-PER-C")
    LUX_HR = URIRef("http://qudt.org/vocab/unit/LUX-HR")
    GigaFLOPS = URIRef("http://qudt.org/vocab/unit/GigaFLOPS")
    KiloCAL_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM-SEC-DEG_C")
    MicroPOISE = URIRef("http://qudt.org/vocab/unit/MicroPOISE")
    N_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-M-PER-M2")
    KiloGM_PER_L_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-K")
    KiloGM_PER_CentiM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-BAR")
    SV_PER_MIN = URIRef("http://qudt.org/vocab/unit/SV-PER-MIN")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    MilliL_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-BAR")
    CentiM2_PER_SR_ERG = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SR-ERG")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    TeraFLOPS = URIRef("http://qudt.org/vocab/unit/TeraFLOPS")
    NUM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/NUM-PER-M2-DAY")
    NUM_PER_M = URIRef("http://qudt.org/vocab/unit/NUM-PER-M")
    KibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M3")
    GAL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-DAY")
    MilliGM_HR_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M3-CentiM3")
    M_PER_YR = URIRef("http://qudt.org/vocab/unit/M-PER-YR")
    K_SEC = URIRef("http://qudt.org/vocab/unit/K-SEC")
    ONE = URIRef("http://qudt.org/vocab/unit/ONE")
    MilliV = URIRef("http://qudt.org/vocab/unit/MilliV")
    L_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-HR-BAR")
    FT2_HR_DEG_F_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F-PER-BTU_IT")
    B = URIRef("http://qudt.org/vocab/unit/B")
    PER_SEC_SR_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR-M2")
    LB_F_FT_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-FT-PER-IN")
    LB_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT2")
    GM_PER_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-BAR")
    PicoMOL = URIRef("http://qudt.org/vocab/unit/PicoMOL")
    PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PER-KiloGM")
    KiloGM_PER_M_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-MIN")
    J_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-M2-PER-KiloGM")
    K_PER_HR = URIRef("http://qudt.org/vocab/unit/K-PER-HR")
    MilliRAD = URIRef("http://qudt.org/vocab/unit/MilliRAD")
    OZ_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_US")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    FT_H2O_39dot2DEG_F = URIRef("http://qudt.org/vocab/unit/FT_H2O_39dot2DEG_F")
    CUP = URIRef("http://qudt.org/vocab/unit/CUP")
    LB_F_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN")
    GAUGE_FR = URIRef("http://qudt.org/vocab/unit/GAUGE_FR")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    MI = URIRef("http://qudt.org/vocab/unit/MI")
    PER_IN3 = URIRef("http://qudt.org/vocab/unit/PER-IN3")
    DEG_C_KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/DEG_C-KiloGM-PER-M2")
    EV_PER_T = URIRef("http://qudt.org/vocab/unit/EV-PER-T")
    GM_SEC_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M6")
    KiloV_A_Reactive = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    FUR = URIRef("http://qudt.org/vocab/unit/FUR")
    ZettaC = URIRef("http://qudt.org/vocab/unit/ZettaC")
    BTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR")
    CentiM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-M3")
    MegaGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-HA")
    MOL_K = URIRef("http://qudt.org/vocab/unit/MOL-K")
    A_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-PER-CentiM2")
    LB_PER_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-DAY")
    MilliL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN")
    N_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM2")
    NanoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-KiloGM")
    MicroPA = URIRef("http://qudt.org/vocab/unit/MicroPA")
    N_M2 = URIRef("http://qudt.org/vocab/unit/N-M2")
    OHM_M2_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-M2-PER-M")
    BTU_IT_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_F")
    LB_HR_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-FT3")
    KiloA_HR = URIRef("http://qudt.org/vocab/unit/KiloA-HR")
    RAD_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-MOL")
    PetaA = URIRef("http://qudt.org/vocab/unit/PetaA")
    BTU_TH_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-HR-DEG_F")
    GI_UK = URIRef("http://qudt.org/vocab/unit/GI_UK")
    KiloGM_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM2")
    FT3 = URIRef("http://qudt.org/vocab/unit/FT3")
    MilliA_PER_L_MIN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-L-MIN")
    DeciM3_PER_HR = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-HR")
    KiloGM_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM2")
    IN2 = URIRef("http://qudt.org/vocab/unit/IN2")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    M3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL-SEC")
    DEG_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC")
    POISE_PER_PA = URIRef("http://qudt.org/vocab/unit/POISE-PER-PA")
    TON_Metric_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY-BAR")
    MicroKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MicroKAT-PER-L")
    FemtoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-KiloGM")
    PlanckMass = URIRef("http://qudt.org/vocab/unit/PlanckMass")
    MilliCD = URIRef("http://qudt.org/vocab/unit/MilliCD")
    MegaPA_M0pt5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0pt5")
    MebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M3")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    GI_UK = URIRef("http://qudt.org/vocab/unit/GI_UK")
    KiloCAL_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-HR")
    LB_PER_FT3 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3")
    KiloGM_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC2")
    MilliGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-MIN")
    GAL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-MIN")
    KiloJ_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MIN")
    J = URIRef("http://qudt.org/vocab/unit/J")
    M2_PER_HA = URIRef("http://qudt.org/vocab/unit/M2-PER-HA")
    PetaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/PetaBIT-PER-SEC")
    CentiM_PER_YR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-YR")
    MilliGM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-K")
    J_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2")
    A_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM2")
    W_PER_M2_M_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M-SR")
    GM_PER_M3_POISE = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-POISE")
    DEGREE_PLATO = URIRef("http://qudt.org/vocab/unit/DEGREE_PLATO")
    KiloGM_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM2")
    MicroMOL_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-HR")
    TONNE_PER_SEC = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC")
    GM_F = URIRef("http://qudt.org/vocab/unit/GM_F")
    MebiBYTE = URIRef("http://qudt.org/vocab/unit/MebiBYTE")
    GM_PER_DeciM3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3-K")
    KiloGM_PER_GigaJ = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-GigaJ")
    MilliN_PER_M = URIRef("http://qudt.org/vocab/unit/MilliN-PER-M")
    GM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-K")
    EUR_PER_M2 = URIRef("http://qudt.org/vocab/unit/EUR-PER-M2")
    KiloMOL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-HR")
    MicroM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroM-PER-SEC")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    AttoSEC = URIRef("http://qudt.org/vocab/unit/AttoSEC")
    FATH = URIRef("http://qudt.org/vocab/unit/FATH")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    TON_SHIPPING_US = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_US")
    YD3_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD3-PER-MIN")
    FT_LA = URIRef("http://qudt.org/vocab/unit/FT-LA")
    KiloGM_PER_KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloMOL")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    OZ_SEC_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-GAL_US")
    OERSTED = URIRef("http://qudt.org/vocab/unit/OERSTED")
    BTU_IT_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-SEC-DEG_F")
    LB_FT2_PER_GAL_US_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-GAL_US-LB_F-SEC")
    LB_F_FT = URIRef("http://qudt.org/vocab/unit/LB_F-FT")
    MegaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-SEC")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    H_PER_OHM = URIRef("http://qudt.org/vocab/unit/H-PER-OHM")
    MilliBQ = URIRef("http://qudt.org/vocab/unit/MilliBQ")
    LB_DEG_R = URIRef("http://qudt.org/vocab/unit/LB-DEG_R")
    MegaBAR = URIRef("http://qudt.org/vocab/unit/MegaBAR")
    MicroBQ = URIRef("http://qudt.org/vocab/unit/MicroBQ")
    PER_M_NanoM_SR = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM-SR")
    GAL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-DAY")
    ERG_SEC = URIRef("http://qudt.org/vocab/unit/ERG-SEC")
    HectoPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-L-PER-SEC")
    KiloSEC = URIRef("http://qudt.org/vocab/unit/KiloSEC")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    RAD_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-MOL")
    OZ_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_UK")
    M2_PER_GM_DRY = URIRef("http://qudt.org/vocab/unit/M2-PER-GM_DRY")
    NanoMOL_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-GM-SEC")
    LB = URIRef("http://qudt.org/vocab/unit/LB")
    TeraV_A = URIRef("http://qudt.org/vocab/unit/TeraV-A")
    W_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM-SR")
    KiloGM_F_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-SEC")
    MegaHZ_PER_T = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-T")
    A_MIN = URIRef("http://qudt.org/vocab/unit/A-MIN")
    OZ_VOL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-DAY")
    K_PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PA-PER-SEC")
    L_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-K")
    NanoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-KiloGM")
    QT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_US-PER-SEC")
    DYN = URIRef("http://qudt.org/vocab/unit/DYN")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    BBL_UK_PET_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-DAY")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    FBM = URIRef("http://qudt.org/vocab/unit/FBM")
    DYN = URIRef("http://qudt.org/vocab/unit/DYN")
    NUM_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/NUM-PER-MilliM3")
    DEG_C_PER_BAR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-BAR")
    OZ_F_IN = URIRef("http://qudt.org/vocab/unit/OZ_F-IN")
    LB_HR_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-YD3")
    ElementaryCharge = URIRef("http://qudt.org/vocab/unit/ElementaryCharge")
    PINT_UK = URIRef("http://qudt.org/vocab/unit/PINT_UK")
    QT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-SEC")
    MegaJ = URIRef("http://qudt.org/vocab/unit/MegaJ")
    MicroGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3")
    BBL = URIRef("http://qudt.org/vocab/unit/BBL")
    BU_US = URIRef("http://qudt.org/vocab/unit/BU_US")
    ROD = URIRef("http://qudt.org/vocab/unit/ROD")
    BTU_TH_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-SEC-DEG_F")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    N_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-M-PER-M2")
    YoctoC = URIRef("http://qudt.org/vocab/unit/YoctoC")
    GigaEV = URIRef("http://qudt.org/vocab/unit/GigaEV")
    TONNE_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3-BAR")
    GM_PER_L_K = URIRef("http://qudt.org/vocab/unit/GM-PER-L-K")
    KiloGM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-FT2")
    PebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M2")
    unit = URIRef("http://qudt.org/vocab/unit")
    PPM = URIRef("http://qudt.org/vocab/unit/PPM")
    T_Ab = URIRef("http://qudt.org/vocab/unit/T_Ab")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    A_HR_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-HR-PER-DEG_C")
    LB_FT2_PER_GAL_US_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-GAL_US-LB_F-SEC")
    GigaJ = URIRef("http://qudt.org/vocab/unit/GigaJ")
    DYN_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM2")
    NanoSEC = URIRef("http://qudt.org/vocab/unit/NanoSEC")
    KiloGM_PER_KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloMOL")
    FemtoGM = URIRef("http://qudt.org/vocab/unit/FemtoGM")
    BTU_IT_PER_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL-DEG_F")
    MicroCi = URIRef("http://qudt.org/vocab/unit/MicroCi")
    QT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_US-PER-SEC")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    MilliMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-L")
    GigaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/GigaC-PER-M3")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    CAL_TH_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM-K")
    CH = URIRef("http://qudt.org/vocab/unit/CH")
    YD = URIRef("http://qudt.org/vocab/unit/YD")
    BTU_TH_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-SEC")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    PlanckLength = URIRef("http://qudt.org/vocab/unit/PlanckLength")
    GigaA = URIRef("http://qudt.org/vocab/unit/GigaA")
    MicroW = URIRef("http://qudt.org/vocab/unit/MicroW")
    FR = URIRef("http://qudt.org/vocab/unit/FR")
    KiloM = URIRef("http://qudt.org/vocab/unit/KiloM")
    IN3_PER_LB = URIRef("http://qudt.org/vocab/unit/IN3-PER-LB")
    TON_UK = URIRef("http://qudt.org/vocab/unit/TON_UK")
    KiloGM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MilliM")
    PDL_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-SEC-PER-FT2")
    PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/PER-M2-SEC")
    BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN")
    NanoV_A = URIRef("http://qudt.org/vocab/unit/NanoV-A")
    M2_PER_GM = URIRef("http://qudt.org/vocab/unit/M2-PER-GM")
    GM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciL")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    MicroV_PER_M = URIRef("http://qudt.org/vocab/unit/MicroV-PER-M")
    EV_PER_M = URIRef("http://qudt.org/vocab/unit/EV-PER-M")
    MOL_PER_M2_SEC_SR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-SR")
    KiloMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3")
    ExaC = URIRef("http://qudt.org/vocab/unit/ExaC")
    W_PER_M2_K4 = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K4")
    KiloLB_F_FT_PER_LB = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-LB")
    CAL_TH_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-K")
    CentiM3_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-BAR")
    PINT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-DAY")
    OZ_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN3")
    CD_PER_M2 = URIRef("http://qudt.org/vocab/unit/CD-PER-M2")
    PA_M = URIRef("http://qudt.org/vocab/unit/PA-M")
    KiloLB_F_FT_PER_LB = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-LB")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    KiloC = URIRef("http://qudt.org/vocab/unit/KiloC")
    CAL_IT = URIRef("http://qudt.org/vocab/unit/CAL_IT")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    LY = URIRef("http://qudt.org/vocab/unit/LY")
    PERM_Metric_0DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_Metric_0DEG_C")
    KiloGM_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-M2")
    MilliOHM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-K")
    BTU_IT_PER_FT2_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR")
    SEC_PER_RAD_M3 = URIRef("http://qudt.org/vocab/unit/SEC-PER-RAD-M3")
    DeciB_C = URIRef("http://qudt.org/vocab/unit/DeciB_C")
    MilliGRAY = URIRef("http://qudt.org/vocab/unit/MilliGRAY")
    GM_PER_CentiM_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM-SEC")
    OHM_Ab = URIRef("http://qudt.org/vocab/unit/OHM_Ab")
    CentiM3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-BAR")
    ElementaryCharge = URIRef("http://qudt.org/vocab/unit/ElementaryCharge")
    J_PER_HR = URIRef("http://qudt.org/vocab/unit/J-PER-HR")
    DEG_F_SEC_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-SEC-PER-BTU_TH")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    MegaOHM_KiloM = URIRef("http://qudt.org/vocab/unit/MegaOHM-KiloM")
    TON_Assay = URIRef("http://qudt.org/vocab/unit/TON_Assay")
    L_PER_DAY = URIRef("http://qudt.org/vocab/unit/L-PER-DAY")
    OZ_SEC_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN6")
    IN_HG = URIRef("http://qudt.org/vocab/unit/IN_HG")
    BTU_IT_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT3")
    T = URIRef("http://qudt.org/vocab/unit/T")
    PSI_PER_PSI = URIRef("http://qudt.org/vocab/unit/PSI-PER-PSI")
    W_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM")
    PDL_PER_IN2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-IN2")
    KiloWB_PER_M = URIRef("http://qudt.org/vocab/unit/KiloWB-PER-M")
    MI_PER_SEC = URIRef("http://qudt.org/vocab/unit/MI-PER-SEC")
    EUR_PER_W_HR = URIRef("http://qudt.org/vocab/unit/EUR-PER-W-HR")
    BTU_IT_PER_SEC_FT_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT-DEG_R")
    PERCENT_IN2_PER_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-IN2-PER-LB_F-SEC")
    GM_MIN_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L-M3")
    L_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-K")
    NanoMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L-HR")
    KiloPA_M2_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloPA-M2-PER-GM")
    BIT_PER_M = URIRef("http://qudt.org/vocab/unit/BIT-PER-M")
    MegaV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive-HR")
    L_PER_MOL = URIRef("http://qudt.org/vocab/unit/L-PER-MOL")
    GigaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/GigaC-PER-M3")
    GM_Carbon_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Carbon-PER-M2-DAY")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    IU_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliGM")
    MilliA_PER_LB_F_IN2 = URIRef("http://qudt.org/vocab/unit/MilliA-PER-LB_F-IN2")
    PK_US_DRY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY")
    MOL_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    MegaPA_M0dot5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0dot5")
    BTU_IT_IN_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-SEC-FT2-DEG_F")
    KiloWB = URIRef("http://qudt.org/vocab/unit/KiloWB")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    MOL_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-K")
    S_Ab = URIRef("http://qudt.org/vocab/unit/S_Ab")
    GAL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-MIN")
    NP_PER_SEC = URIRef("http://qudt.org/vocab/unit/NP-PER-SEC")
    MegaL = URIRef("http://qudt.org/vocab/unit/MegaL")
    FT_LB_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-M2")
    GM_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM2")
    MegaW_HR = URIRef("http://qudt.org/vocab/unit/MegaW-HR")
    GI = URIRef("http://qudt.org/vocab/unit/GI")
    PER_YD3 = URIRef("http://qudt.org/vocab/unit/PER-YD3")
    V_Ab = URIRef("http://qudt.org/vocab/unit/V_Ab")
    W_HR = URIRef("http://qudt.org/vocab/unit/W-HR")
    MegaGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-HA")
    GM_PER_L = URIRef("http://qudt.org/vocab/unit/GM-PER-L")
    M2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2")
    TONNE_PER_HR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    KiloGM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-BAR")
    TON_US_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_US-PER-YD3")
    NUM_PER_M = URIRef("http://qudt.org/vocab/unit/NUM-PER-M")
    GM_PER_M = URIRef("http://qudt.org/vocab/unit/GM-PER-M")
    C_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Ab-PER-CentiM2")
    FemtoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-KiloGM")
    IN_H2O = URIRef("http://qudt.org/vocab/unit/IN_H2O")
    M2_PER_SR = URIRef("http://qudt.org/vocab/unit/M2-PER-SR")
    ATM = URIRef("http://qudt.org/vocab/unit/ATM")
    MilliMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-L")
    BTU_60DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_60DEG_F")
    LB_T = URIRef("http://qudt.org/vocab/unit/LB_T")
    FT_SEC_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-GAL_US")
    BTU_IT_PER_LB_F_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_F")
    GI_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-DAY")
    J_PER_HR = URIRef("http://qudt.org/vocab/unit/J-PER-HR")
    FT3_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT3-PER-SEC")
    PicoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-KiloGM")
    MI_N = URIRef("http://qudt.org/vocab/unit/MI_N")
    K_M_PER_W = URIRef("http://qudt.org/vocab/unit/K-M-PER-W")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    REV_PER_SEC = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC")
    K_PER_M = URIRef("http://qudt.org/vocab/unit/K-PER-M")
    NanoS_PER_M = URIRef("http://qudt.org/vocab/unit/NanoS-PER-M")
    MicroTORR = URIRef("http://qudt.org/vocab/unit/MicroTORR")
    C_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM2")
    NUM_PER_YR = URIRef("http://qudt.org/vocab/unit/NUM-PER-YR")
    BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    BTU_IT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MIN")
    FBM = URIRef("http://qudt.org/vocab/unit/FBM")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    W_PER_M2_M_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M-SR")
    LB_SEC_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-GAL_US")
    PicoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-KiloGM")
    C_PER_MOL = URIRef("http://qudt.org/vocab/unit/C-PER-MOL")
    TONNE_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC-BAR")
    MicroBQ = URIRef("http://qudt.org/vocab/unit/MicroBQ")
    B = URIRef("http://qudt.org/vocab/unit/B")
    SV_PER_SEC = URIRef("http://qudt.org/vocab/unit/SV-PER-SEC")
    A_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM2")
    GM_SEC_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L-CentiM3")
    PicoL = URIRef("http://qudt.org/vocab/unit/PicoL")
    DeciM2 = URIRef("http://qudt.org/vocab/unit/DeciM2")
    MicroM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM-PER-MilliL")
    CentiM3_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR")
    PK_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-HR")
    KiloCAL_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL")
    BTU_TH_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_F")
    RAD_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-MOL")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    A_PER_M2_K2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2-K2")
    KiloT = URIRef("http://qudt.org/vocab/unit/KiloT")
    FT3_PER_LB = URIRef("http://qudt.org/vocab/unit/FT3-PER-LB")
    MicroH_PER_M = URIRef("http://qudt.org/vocab/unit/MicroH-PER-M")
    FT2_PER_HR = URIRef("http://qudt.org/vocab/unit/FT2-PER-HR")
    LB_F_IN_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN-PER-IN")
    PARSEC = URIRef("http://qudt.org/vocab/unit/PARSEC")
    V_PER_IN = URIRef("http://qudt.org/vocab/unit/V-PER-IN")
    NAT_PER_SEC = URIRef("http://qudt.org/vocab/unit/NAT-PER-SEC")
    PlanckTemperature = URIRef("http://qudt.org/vocab/unit/PlanckTemperature")
    LB_PER_FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-LB_F-SEC")
    MilliM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DAY")
    PK_US_DRY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY")
    KiloGM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-BAR")
    KiloGM_PER_HA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HA")
    ERG_PER_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-SEC")
    M2_PER_SR_J = URIRef("http://qudt.org/vocab/unit/M2-PER-SR-J")
    MegaGRAY = URIRef("http://qudt.org/vocab/unit/MegaGRAY")
    PINT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-HR")
    TeraW = URIRef("http://qudt.org/vocab/unit/TeraW")
    MilliV = URIRef("http://qudt.org/vocab/unit/MilliV")
    MegaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M3")
    M = URIRef("http://qudt.org/vocab/unit/M")
    KiloGM_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC2")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    OZ_VOL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-MIN")
    LB_HR_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US2")
    MilliRAD = URIRef("http://qudt.org/vocab/unit/MilliRAD")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    NanoSEC = URIRef("http://qudt.org/vocab/unit/NanoSEC")
    GM_PER_MilliL_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL-BAR")
    AttoSEC = URIRef("http://qudt.org/vocab/unit/AttoSEC")
    PA_PER_MIN = URIRef("http://qudt.org/vocab/unit/PA-PER-MIN")
    V_PER_SEC = URIRef("http://qudt.org/vocab/unit/V-PER-SEC")
    OZ_VOL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-DAY")
    PERCENT_PER_K = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-K")
    BBL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-DAY")
    PER_M_SR = URIRef("http://qudt.org/vocab/unit/PER-M-SR")
    MegaPA_PER_K = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-K")
    CentiM3_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN-K")
    LB_PER_IN = URIRef("http://qudt.org/vocab/unit/LB-PER-IN")
    MilliGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-KiloGM")
    KiloC_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M3")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    MilliKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MilliKAT-PER-L")
    KiloCAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-GM-K")
    M2_PER_GM = URIRef("http://qudt.org/vocab/unit/M2-PER-GM")
    PDL_PER_IN = URIRef("http://qudt.org/vocab/unit/PDL-PER-IN")
    J_PER_GM = URIRef("http://qudt.org/vocab/unit/J-PER-GM")
    TON_SHORT_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-YD3")
    MI3 = URIRef("http://qudt.org/vocab/unit/MI3")
    DEGREE_OECHSLE = URIRef("http://qudt.org/vocab/unit/DEGREE_OECHSLE")
    PER_M_K = URIRef("http://qudt.org/vocab/unit/PER-M-K")
    PicoM = URIRef("http://qudt.org/vocab/unit/PicoM")
    KiloCAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-GM-K")
    PicoFARAD = URIRef("http://qudt.org/vocab/unit/PicoFARAD")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    OZ_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_US")
    OZ_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN3")
    MilliBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-L")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    W_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-SEC-PER-M2")
    PicoM = URIRef("http://qudt.org/vocab/unit/PicoM")
    CWT_LONG = URIRef("http://qudt.org/vocab/unit/CWT_LONG")
    TeraV = URIRef("http://qudt.org/vocab/unit/TeraV")
    ONE_PER_ONE = URIRef("http://qudt.org/vocab/unit/ONE-PER-ONE")
    MilliMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-MOL")
    MicroA = URIRef("http://qudt.org/vocab/unit/MicroA")
    MilliC = URIRef("http://qudt.org/vocab/unit/MilliC")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    MegaBIT = URIRef("http://qudt.org/vocab/unit/MegaBIT")
    LB_F_FT_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-FT-PER-IN")
    PK_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-SEC")
    KiloGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-PA-SEC")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    TON_Metric_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR")
    LB_IN = URIRef("http://qudt.org/vocab/unit/LB-IN")
    GigaN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaN-M-PER-M2")
    MicroOHM = URIRef("http://qudt.org/vocab/unit/MicroOHM")
    MilliBAR_PER_K = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-K")
    MicroH_PER_M = URIRef("http://qudt.org/vocab/unit/MicroH-PER-M")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    TebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M3")
    A_PER_J = URIRef("http://qudt.org/vocab/unit/A-PER-J")
    ERG_SEC = URIRef("http://qudt.org/vocab/unit/ERG-SEC")
    MicroBAR = URIRef("http://qudt.org/vocab/unit/MicroBAR")
    PicoGM_PER_L = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-L")
    TONNE_PER_MIN = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN")
    LB_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_UK")
    MI_N = URIRef("http://qudt.org/vocab/unit/MI_N")
    V_A_HR = URIRef("http://qudt.org/vocab/unit/V-A-HR")
    M_PER_K = URIRef("http://qudt.org/vocab/unit/M-PER-K")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    MilliGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC")
    KAT_PER_MicroL = URIRef("http://qudt.org/vocab/unit/KAT-PER-MicroL")
    DeciGM = URIRef("http://qudt.org/vocab/unit/DeciGM")
    GigaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBYTE-PER-SEC")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    KiloV = URIRef("http://qudt.org/vocab/unit/KiloV")
    PERCENT_RH = URIRef("http://qudt.org/vocab/unit/PERCENT_RH")
    DEGREE_BAUME_US_LIGHT = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_LIGHT")
    GM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY-BAR")
    MegaEV_PER_SpeedOfLight = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-SpeedOfLight")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    MegaHZ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-K")
    ZettaC = URIRef("http://qudt.org/vocab/unit/ZettaC")
    OZ_PER_FT2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-FT2")
    BBL_US = URIRef("http://qudt.org/vocab/unit/BBL_US")
    MicroRAD = URIRef("http://qudt.org/vocab/unit/MicroRAD")
    DeciTONNE = URIRef("http://qudt.org/vocab/unit/DeciTONNE")
    MilliDEG_C = URIRef("http://qudt.org/vocab/unit/MilliDEG_C")
    BTU_IT_PER_LB_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F")
    HectoGM = URIRef("http://qudt.org/vocab/unit/HectoGM")
    M3_PER_HR_K = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-K")
    L_PER_MOL = URIRef("http://qudt.org/vocab/unit/L-PER-MOL")
    PicoC = URIRef("http://qudt.org/vocab/unit/PicoC")
    EU_PER_L = URIRef("http://qudt.org/vocab/unit/EU-PER-L")
    NanoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/NanoFARAD-PER-M")
    SEC_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-FT2")
    FT_PDL = URIRef("http://qudt.org/vocab/unit/FT-PDL")
    DecaARE = URIRef("http://qudt.org/vocab/unit/DecaARE")
    M2_HZ3 = URIRef("http://qudt.org/vocab/unit/M2-HZ3")
    PA_M = URIRef("http://qudt.org/vocab/unit/PA-M")
    J_PER_SEC = URIRef("http://qudt.org/vocab/unit/J-PER-SEC")
    KiloGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC")
    KiloSEC = URIRef("http://qudt.org/vocab/unit/KiloSEC")
    A_SEC = URIRef("http://qudt.org/vocab/unit/A-SEC")
    NUM_PER_HR = URIRef("http://qudt.org/vocab/unit/NUM-PER-HR")
    MilliT = URIRef("http://qudt.org/vocab/unit/MilliT")
    PSI_PER_IN = URIRef("http://qudt.org/vocab/unit/PSI-PER-IN")
    STR = URIRef("http://qudt.org/vocab/unit/STR")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    GRAIN = URIRef("http://qudt.org/vocab/unit/GRAIN")
    HART = URIRef("http://qudt.org/vocab/unit/HART")
    PlanckLength = URIRef("http://qudt.org/vocab/unit/PlanckLength")
    H = URIRef("http://qudt.org/vocab/unit/H")
    PSI_YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-YD3-PER-SEC")
    CentiM_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-K")
    NanoMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL")
    PER_T_SEC = URIRef("http://qudt.org/vocab/unit/PER-T-SEC")
    M2_PER_SR_J = URIRef("http://qudt.org/vocab/unit/M2-PER-SR-J")
    C_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM2")
    A_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM2")
    BYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/BYTE-PER-SEC")
    MilliL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliL-PER-L")
    KAT_PER_MicroL = URIRef("http://qudt.org/vocab/unit/KAT-PER-MicroL")
    MilliGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-HR")
    GM_MIN_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M3-CentiM3")
    FT3_PER_HR = URIRef("http://qudt.org/vocab/unit/FT3-PER-HR")
    W_HR_PER_L = URIRef("http://qudt.org/vocab/unit/W-HR-PER-L")
    A_PER_RAD = URIRef("http://qudt.org/vocab/unit/A-PER-RAD")
    PicoC = URIRef("http://qudt.org/vocab/unit/PicoC")
    MilliL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC")
    CAL_TH = URIRef("http://qudt.org/vocab/unit/CAL_TH")
    LB_PER_IN = URIRef("http://qudt.org/vocab/unit/LB-PER-IN")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    AttoC = URIRef("http://qudt.org/vocab/unit/AttoC")
    FemtoJ = URIRef("http://qudt.org/vocab/unit/FemtoJ")
    IN_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN-PER-MIN")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    GM_PER_MIN = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN")
    PH = URIRef("http://qudt.org/vocab/unit/PH")
    ERG = URIRef("http://qudt.org/vocab/unit/ERG")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    DeciB_MilliW_PER_MegaHZ = URIRef("http://qudt.org/vocab/unit/DeciB-MilliW-PER-MegaHZ")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    MilliA_HR = URIRef("http://qudt.org/vocab/unit/MilliA-HR")
    M6 = URIRef("http://qudt.org/vocab/unit/M6")
    KiloSEC = URIRef("http://qudt.org/vocab/unit/KiloSEC")
    PERCENT_HR_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-GAL_UK")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    L_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-BAR")
    M2_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-BAR")
    GM_PER_HR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    CentiMOL_PER_L = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-L")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    S_Ab = URIRef("http://qudt.org/vocab/unit/S_Ab")
    DEG_F_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC2")
    KiloBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloBQ-PER-KiloGM")
    MIN = URIRef("http://qudt.org/vocab/unit/MIN")
    HZ_M = URIRef("http://qudt.org/vocab/unit/HZ-M")
    GigaW = URIRef("http://qudt.org/vocab/unit/GigaW")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    PPQ = URIRef("http://qudt.org/vocab/unit/PPQ")
    M3_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-BAR")
    MOL_LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-SEC")
    Gamma = URIRef("http://qudt.org/vocab/unit/Gamma")
    A_M2_PER_J_SEC = URIRef("http://qudt.org/vocab/unit/A-M2-PER-J-SEC")
    PicoFARAD = URIRef("http://qudt.org/vocab/unit/PicoFARAD")
    PER_J = URIRef("http://qudt.org/vocab/unit/PER-J")
    PERCENT_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-M3")
    V_Ab = URIRef("http://qudt.org/vocab/unit/V_Ab")
    DECADE = URIRef("http://qudt.org/vocab/unit/DECADE")
    MicroM3_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-MilliL")
    TON_Metric_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY-BAR")
    BTU_IT_PER_HR_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2")
    FT3_PER_HR = URIRef("http://qudt.org/vocab/unit/FT3-PER-HR")
    KiloMOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-MIN")
    TON_Register = URIRef("http://qudt.org/vocab/unit/TON_Register")
    DEG_F_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-HR")
    NUM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/NUM-PER-M2-DAY")
    KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT")
    FemtoM = URIRef("http://qudt.org/vocab/unit/FemtoM")
    TONNE_PER_HA_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA-YR")
    CentiM_H2O = URIRef("http://qudt.org/vocab/unit/CentiM_H2O")
    MicroN_M = URIRef("http://qudt.org/vocab/unit/MicroN-M")
    MicroA = URIRef("http://qudt.org/vocab/unit/MicroA")
    MicroGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-BAR")
    MicroMOL_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-HR")
    GM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloGM")
    MilliM2 = URIRef("http://qudt.org/vocab/unit/MilliM2")
    GAL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-MIN")
    GM_PER_CentiM_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM-SEC")
    MilliL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN")
    LB_SEC_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US2")
    GRAIN_PER_GAL = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL")
    MACH = URIRef("http://qudt.org/vocab/unit/MACH")
    N_PER_C = URIRef("http://qudt.org/vocab/unit/N-PER-C")
    CD_PER_FT2 = URIRef("http://qudt.org/vocab/unit/CD-PER-FT2")
    IN_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC-DEG_F")
    M2_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-V-SEC")
    BAN = URIRef("http://qudt.org/vocab/unit/BAN")
    BTU_TH_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-SEC")
    C2_M2_PER_J = URIRef("http://qudt.org/vocab/unit/C2-M2-PER-J")
    ExbiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M3")
    LB_F_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-IN2")
    KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloM2")
    MilliGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-GM")
    F = URIRef("http://qudt.org/vocab/unit/F")
    KibiBYTE = URIRef("http://qudt.org/vocab/unit/KibiBYTE")
    REV_PER_MIN = URIRef("http://qudt.org/vocab/unit/REV-PER-MIN")
    A_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-PER-DEG_C")
    N_M2_PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/N-M2-PER-KiloGM2")
    CentiBAR = URIRef("http://qudt.org/vocab/unit/CentiBAR")
    F = URIRef("http://qudt.org/vocab/unit/F")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    GigaHZ = URIRef("http://qudt.org/vocab/unit/GigaHZ")
    LB_IN = URIRef("http://qudt.org/vocab/unit/LB-IN")
    LB_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-SEC")
    GigaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBYTE-PER-SEC")
    STILB = URIRef("http://qudt.org/vocab/unit/STILB")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    IN_H2O = URIRef("http://qudt.org/vocab/unit/IN_H2O")
    DEG_C_PER_YR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-YR")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    GigaBQ = URIRef("http://qudt.org/vocab/unit/GigaBQ")
    GM_MIN_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L-CentiM3")
    M_KiloGM = URIRef("http://qudt.org/vocab/unit/M-KiloGM")
    PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PER-SEC2")
    MicroH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-KiloOHM")
    DeciB_MilliW = URIRef("http://qudt.org/vocab/unit/DeciB-MilliW")
    MilliOHM = URIRef("http://qudt.org/vocab/unit/MilliOHM")
    KiloP = URIRef("http://qudt.org/vocab/unit/KiloP")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    PicoS_PER_M = URIRef("http://qudt.org/vocab/unit/PicoS-PER-M")
    CAL_TH_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM2-K")
    CentiM3_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-CentiM3")
    M_K = URIRef("http://qudt.org/vocab/unit/M-K")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    TONNE_PER_M3 = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3")
    M3_PER_K = URIRef("http://qudt.org/vocab/unit/M3-PER-K")
    C = URIRef("http://qudt.org/vocab/unit/C")
    TONNE_PER_HA_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA-YR")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    S_PER_CentiM = URIRef("http://qudt.org/vocab/unit/S-PER-CentiM")
    C_M2 = URIRef("http://qudt.org/vocab/unit/C-M2")
    LB_IN2_PER_GAL_US_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-GAL_US-LB_F-SEC")
    MilliN_M = URIRef("http://qudt.org/vocab/unit/MilliN-M")
    MicroFARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-KiloM")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    CD_PER_M2 = URIRef("http://qudt.org/vocab/unit/CD-PER-M2")
    TONNE_PER_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-K")
    MegaGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-HA")
    DWT = URIRef("http://qudt.org/vocab/unit/DWT")
    KiloPA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-MilliM")
    ERG_CentiM2 = URIRef("http://qudt.org/vocab/unit/ERG-CentiM2")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    KiloCAL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-SEC")
    PERCENT_PER_IN = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-IN")
    MegaL = URIRef("http://qudt.org/vocab/unit/MegaL")
    TeraBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/TeraBIT-PER-SEC")
    MegaA = URIRef("http://qudt.org/vocab/unit/MegaA")
    FT_LB_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-MIN")
    V_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/V-SEC-PER-M")
    SLUG_PER_FT3 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT3")
    L_PER_MIN = URIRef("http://qudt.org/vocab/unit/L-PER-MIN")
    MI_PER_HR = URIRef("http://qudt.org/vocab/unit/MI-PER-HR")
    KiloJ_PER_KiloV = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloV")
    HectoPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-BAR")
    MilliC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M3")
    YD = URIRef("http://qudt.org/vocab/unit/YD")
    BTU_IT_PER_MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB-DEG_F")
    LB_HR_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-IN3")
    TON_Metric_PER_HA = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HA")
    LB_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_UK")
    CentiM_H20_4DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_H20_4DEG_C")
    PER_GM = URIRef("http://qudt.org/vocab/unit/PER-GM")
    J_PER_M = URIRef("http://qudt.org/vocab/unit/J-PER-M")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    LB_MIN_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-IN3")
    BTU_IT_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT-PER-FT2-HR-DEG_F")
    MicroMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-SEC")
    MicroMOL_PER_GM_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM-HR")
    V_Ab_SEC = URIRef("http://qudt.org/vocab/unit/V_Ab-SEC")
    BIOT = URIRef("http://qudt.org/vocab/unit/BIOT")
    DeciS_PER_M = URIRef("http://qudt.org/vocab/unit/DeciS-PER-M")
    LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN")
    GibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M3")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    BTU_IT_PER_HR_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2")
    KiloM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-HR")
    MicroGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-GM")
    PERCENT_PER_OHM = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-OHM")
    L_PER_HR = URIRef("http://qudt.org/vocab/unit/L-PER-HR")
    GA_Charriere = URIRef("http://qudt.org/vocab/unit/GA_Charriere")
    DEG_F_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-K")
    OZ_F_IN = URIRef("http://qudt.org/vocab/unit/OZ_F-IN")
    YR = URIRef("http://qudt.org/vocab/unit/YR")
    NanoT = URIRef("http://qudt.org/vocab/unit/NanoT")
    RAD_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-MOL")
    M_K = URIRef("http://qudt.org/vocab/unit/M-K")
    IN_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC2")
    ST_PER_PA = URIRef("http://qudt.org/vocab/unit/ST-PER-PA")
    SEC_PER_RAD_M3 = URIRef("http://qudt.org/vocab/unit/SEC-PER-RAD-M3")
    MilliMOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2-SEC")
    BTU_TH_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC-FT2-DEG_F")
    TON_Metric_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR")
    STILB = URIRef("http://qudt.org/vocab/unit/STILB")
    KiloN_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M2")
    KiloGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-K")
    PARSEC = URIRef("http://qudt.org/vocab/unit/PARSEC")
    DEG_R = URIRef("http://qudt.org/vocab/unit/DEG_R")
    YD_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD-PER-DEG_F")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    LB_HR_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-GAL_UK")
    LUX_HR = URIRef("http://qudt.org/vocab/unit/LUX-HR")
    EarthMass = URIRef("http://qudt.org/vocab/unit/EarthMass")
    PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/PER-KiloGM2")
    DEG_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC2")
    MicroGM_PER_IN2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-IN2")
    GM_PER_HZ = URIRef("http://qudt.org/vocab/unit/GM-PER-HZ")
    MilliL_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-BAR")
    BREATH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BREATH-PER-MIN")
    OZ_VOL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-HR")
    BTU_TH_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC-FT2-DEG_F")
    KiloBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloBQ-PER-KiloGM")
    LB_F = URIRef("http://qudt.org/vocab/unit/LB_F")
    GM_MIN_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L2")
    Da = URIRef("http://qudt.org/vocab/unit/Da")
    PetaC = URIRef("http://qudt.org/vocab/unit/PetaC")
    YR = URIRef("http://qudt.org/vocab/unit/YR")
    M2_PER_HZ_DEG = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ-DEG")
    CentiM3_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-K")
    KiloGM_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-PA")
    KiloGM_F_M_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-CentiM2")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    CentiN_M = URIRef("http://qudt.org/vocab/unit/CentiN-M")
    FT2_HR_DEG_F_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F-PER-BTU_IT")
    KiloCAL_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2")
    KIP_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KIP_F-PER-IN2")
    MicroGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-GM")
    OZ_M = URIRef("http://qudt.org/vocab/unit/OZ_M")
    NanoGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DeciL")
    A_PER_PA = URIRef("http://qudt.org/vocab/unit/A-PER-PA")
    M3_PER_C = URIRef("http://qudt.org/vocab/unit/M3-PER-C")
    FT_LB_F_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2-SEC")
    K_PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PA-PER-SEC")
    PER_CentiM = URIRef("http://qudt.org/vocab/unit/PER-CentiM")
    LB_PER_IN = URIRef("http://qudt.org/vocab/unit/LB-PER-IN")
    QT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_US-PER-MIN")
    MicroGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-MIN")
    DEG_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-MIN")
    PER_PlanckMass2 = URIRef("http://qudt.org/vocab/unit/PER-PlanckMass2")
    N_M_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-M")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    KY = URIRef("http://qudt.org/vocab/unit/KY")
    PicoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/PicoFARAD-PER-M")
    AttoC = URIRef("http://qudt.org/vocab/unit/AttoC")
    PERCENT_MIN_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-FT3")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    YD3_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD3-PER-MIN")
    GAL_IMP = URIRef("http://qudt.org/vocab/unit/GAL_IMP")
    MilliS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MilliS-PER-CentiM")
    PK_UK = URIRef("http://qudt.org/vocab/unit/PK_UK")
    MicroM3_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-MilliL")
    MOL_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-BAR")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    PINT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-DAY")
    CentiM4 = URIRef("http://qudt.org/vocab/unit/CentiM4")
    A_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Stat-PER-CentiM2")
    KiloOHM_PER_K = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-K")
    BTU_IT_PER_SEC_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_R")
    SLUG_PER_DAY = URIRef("http://qudt.org/vocab/unit/SLUG-PER-DAY")
    V_PER_IN = URIRef("http://qudt.org/vocab/unit/V-PER-IN")
    HectoBAR = URIRef("http://qudt.org/vocab/unit/HectoBAR")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    KiloC_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M3")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    HART = URIRef("http://qudt.org/vocab/unit/HART")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    WB_PER_MilliM = URIRef("http://qudt.org/vocab/unit/WB-PER-MilliM")
    TONNE_PER_MIN = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN")
    CentiM3_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR")
    MilliGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-KiloGM")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    KIP_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KIP_F-PER-IN2")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    MegaHZ = URIRef("http://qudt.org/vocab/unit/MegaHZ")
    CFU = URIRef("http://qudt.org/vocab/unit/CFU")
    PK_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-SEC")
    LB_SEC_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-IN3")
    HectoL = URIRef("http://qudt.org/vocab/unit/HectoL")
    MegaBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaBTU_IT-PER-HR")
    Standard = URIRef("http://qudt.org/vocab/unit/Standard")
    M_SEC = URIRef("http://qudt.org/vocab/unit/M-SEC")
    BTU_IT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC")
    MilliTORR = URIRef("http://qudt.org/vocab/unit/MilliTORR")
    MilliT = URIRef("http://qudt.org/vocab/unit/MilliT")
    CentiM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-M3")
    MilliN_PER_M = URIRef("http://qudt.org/vocab/unit/MilliN-PER-M")
    GibiBIT = URIRef("http://qudt.org/vocab/unit/GibiBIT")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    GigaPA_CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/GigaPA-CentiM3-PER-GM")
    CentiM3_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-CentiM3")
    TeraHZ = URIRef("http://qudt.org/vocab/unit/TeraHZ")
    J = URIRef("http://qudt.org/vocab/unit/J")
    LunarMass = URIRef("http://qudt.org/vocab/unit/LunarMass")
    Gs = URIRef("http://qudt.org/vocab/unit/Gs")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    GM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    MilliOHM = URIRef("http://qudt.org/vocab/unit/MilliOHM")
    BARN = URIRef("http://qudt.org/vocab/unit/BARN")
    M2_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-HZ2")
    FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F")
    KiloGM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-K")
    MicroGM_PER_L = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L")
    PER_MilliL = URIRef("http://qudt.org/vocab/unit/PER-MilliL")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    C_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM")
    GRAIN = URIRef("http://qudt.org/vocab/unit/GRAIN")
    MegaEV_FemtoM = URIRef("http://qudt.org/vocab/unit/MegaEV-FemtoM")
    NanoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/NanoW-PER-M2")
    PERCENT_PER_10KiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-10KiloCount")
    PPM = URIRef("http://qudt.org/vocab/unit/PPM")
    KiloGM_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-YR")
    HectoPA_PER_K = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-K")
    MI_PER_HR = URIRef("http://qudt.org/vocab/unit/MI-PER-HR")
    SPF = URIRef("http://qudt.org/vocab/unit/SPF")
    CentiC = URIRef("http://qudt.org/vocab/unit/CentiC")
    PERCENT_PER_DecaKiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaKiloCount")
    OZ_MIN_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-GAL_US")
    CUP = URIRef("http://qudt.org/vocab/unit/CUP")
    NanoMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L-HR")
    MicroJ = URIRef("http://qudt.org/vocab/unit/MicroJ")
    NanoM_PER_CentiM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-MegaPA")
    KiloCAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-MIN")
    LB_MIN_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-YD3")
    N_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-PER-RAD")
    OERSTED = URIRef("http://qudt.org/vocab/unit/OERSTED")
    BTU_IT_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_R")
    MOL_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-SEC")
    KiloBAR = URIRef("http://qudt.org/vocab/unit/KiloBAR")
    MegaV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive-HR")
    PH = URIRef("http://qudt.org/vocab/unit/PH")
    MilliBQ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-GM")
    A_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-PER-DEG_C")
    KiloN_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M2")
    MilliGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-KiloGM")
    GM = URIRef("http://qudt.org/vocab/unit/GM")
    LB_MIN_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN6")
    SEC2 = URIRef("http://qudt.org/vocab/unit/SEC2")
    PicoV_A_Reactive = URIRef("http://qudt.org/vocab/unit/PicoV-A_Reactive")
    B = URIRef("http://qudt.org/vocab/unit/B")
    MicroFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-M")
    KiloV_A_Reactive = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive")
    GM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/GM-PER-HR-K")
    MilliPA_PER_M = URIRef("http://qudt.org/vocab/unit/MilliPA-PER-M")
    CentiMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-KiloGM")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    MOL_PER_KiloGM_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-PA")
    OZ_VOL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-SEC")
    KiloCAL_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM-SEC-DEG_C")
    TON_Metric_PER_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-K")
    ERG_CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-CentiM2-PER-GM")
    KiloGM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-K")
    A_Ab_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-CentiM2")
    DecaPA = URIRef("http://qudt.org/vocab/unit/DecaPA")
    PARSEC = URIRef("http://qudt.org/vocab/unit/PARSEC")
    TON_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-DAY")
    PicoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/PicoFARAD-PER-M")
    DEG2 = URIRef("http://qudt.org/vocab/unit/DEG2")
    C4_M4_PER_J3 = URIRef("http://qudt.org/vocab/unit/C4-M4-PER-J3")
    MilliGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-BAR")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    MicroIN = URIRef("http://qudt.org/vocab/unit/MicroIN")
    MegaN = URIRef("http://qudt.org/vocab/unit/MegaN")
    MicroOHM = URIRef("http://qudt.org/vocab/unit/MicroOHM")
    M3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-BAR")
    MicroMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-KiloGM")
    MilliIN = URIRef("http://qudt.org/vocab/unit/MilliIN")
    M2_PER_SR_J = URIRef("http://qudt.org/vocab/unit/M2-PER-SR-J")
    MilliGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-K")
    ANGSTROM3 = URIRef("http://qudt.org/vocab/unit/ANGSTROM3")
    PSI_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-M3-PER-SEC")
    KiloPOND = URIRef("http://qudt.org/vocab/unit/KiloPOND")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    KiloM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM2-PER-SEC2")
    BTU_IT_IN_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-HR-FT2-DEG_F")
    TONNE_PER_HR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    KiloCAL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-SEC")
    KiloGM_PER_M3_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-PA")
    DEATHS_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000I-YR")
    KiloN_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M3")
    LB_F_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN")
    LB_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-MOL-DEG_F")
    MicroGM_PER_L = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L")
    MilliL_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY")
    OHM_KiloM = URIRef("http://qudt.org/vocab/unit/OHM-KiloM")
    PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PER-SEC2")
    FT_LB_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-M2")
    PicoS_PER_M = URIRef("http://qudt.org/vocab/unit/PicoS-PER-M")
    TORR = URIRef("http://qudt.org/vocab/unit/TORR")
    NanoGM = URIRef("http://qudt.org/vocab/unit/NanoGM")
    FT3 = URIRef("http://qudt.org/vocab/unit/FT3")
    HP_Metric = URIRef("http://qudt.org/vocab/unit/HP_Metric")
    CentiM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    MilliM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliM-PER-MIN")
    IN_HG_60DEG_F = URIRef("http://qudt.org/vocab/unit/IN_HG_60DEG_F")
    DEGREE_BAUME_US_LIGHT = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_LIGHT")
    PER_SR = URIRef("http://qudt.org/vocab/unit/PER-SR")
    MilliGM_PER_M3_CentiPOISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-CentiPOISE")
    NanoMOL_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-GM-SEC")
    M4 = URIRef("http://qudt.org/vocab/unit/M4")
    PER_K = URIRef("http://qudt.org/vocab/unit/PER-K")
    GM_PER_L_CentiPOISE = URIRef("http://qudt.org/vocab/unit/GM-PER-L-CentiPOISE")
    MicroM3 = URIRef("http://qudt.org/vocab/unit/MicroM3")
    MilliGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DeciL")
    ExaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/ExaJ-PER-SEC")
    LB_F_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-IN2")
    A_M2_PER_J_SEC = URIRef("http://qudt.org/vocab/unit/A-M2-PER-J-SEC")
    J_SEC_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-SEC-PER-MOL")
    M2_PER_SR = URIRef("http://qudt.org/vocab/unit/M2-PER-SR")
    Da = URIRef("http://qudt.org/vocab/unit/Da")
    J = URIRef("http://qudt.org/vocab/unit/J")
    FT_LB_F_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-HR")
    GAUGE_FR = URIRef("http://qudt.org/vocab/unit/GAUGE_FR")
    H_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/H-PER-KiloOHM")
    MicroOHM_M = URIRef("http://qudt.org/vocab/unit/MicroOHM-M")
    CentiM4 = URIRef("http://qudt.org/vocab/unit/CentiM4")
    KiloGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC")
    KiloM3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM3-PER-SEC2")
    KAT_PER_M3 = URIRef("http://qudt.org/vocab/unit/KAT-PER-M3")
    MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC")
    N_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-M-PER-M2")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    GAL_US = URIRef("http://qudt.org/vocab/unit/GAL_US")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    W_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-PER-KiloGM")
    KiloGM_PER_M_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-HR")
    MilliGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-K")
    DeciM = URIRef("http://qudt.org/vocab/unit/DeciM")
    PER_L = URIRef("http://qudt.org/vocab/unit/PER-L")
    HectoM = URIRef("http://qudt.org/vocab/unit/HectoM")
    NanoJ = URIRef("http://qudt.org/vocab/unit/NanoJ")
    FT_SEC_PER_IN3 = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-IN3")
    CentiM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SEC")
    MicroBQ = URIRef("http://qudt.org/vocab/unit/MicroBQ")
    REV_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC2")
    PA_M0pt5 = URIRef("http://qudt.org/vocab/unit/PA-M0pt5")
    MilliMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2-DAY")
    KiloGM_F_M = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M")
    PER_M_SR = URIRef("http://qudt.org/vocab/unit/PER-M-SR")
    CentiM3_PER_HR_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR-K")
    C_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM2")
    N_M_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-M")
    DEG_F_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-K")
    ST = URIRef("http://qudt.org/vocab/unit/ST")
    KiloCAL_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM")
    LB_PER_YD = URIRef("http://qudt.org/vocab/unit/LB-PER-YD")
    DeciM2 = URIRef("http://qudt.org/vocab/unit/DeciM2")
    MilliGM_SEC_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L-M3")
    PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PER-CentiM3")
    KiloGM_M = URIRef("http://qudt.org/vocab/unit/KiloGM-M")
    FemtoSEC = URIRef("http://qudt.org/vocab/unit/FemtoSEC")
    TebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M2")
    GM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN-K")
    LB_MIN_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-FT3")
    IN3_PER_HR = URIRef("http://qudt.org/vocab/unit/IN3-PER-HR")
    MicroMHO = URIRef("http://qudt.org/vocab/unit/MicroMHO")
    DEG_F_HR_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_IT")
    PERCENT_PER_DecaK = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaK")
    N_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M3")
    MilliWB = URIRef("http://qudt.org/vocab/unit/MilliWB")
    MilliL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC")
    GM = URIRef("http://qudt.org/vocab/unit/GM")
    NanoM = URIRef("http://qudt.org/vocab/unit/NanoM")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    PINT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-MIN")
    OZ_M = URIRef("http://qudt.org/vocab/unit/OZ_M")
    DYN = URIRef("http://qudt.org/vocab/unit/DYN")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    LM_PER_W = URIRef("http://qudt.org/vocab/unit/LM-PER-W")
    M = URIRef("http://qudt.org/vocab/unit/M")
    CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CentiM2-MIN")
    J_PER_M = URIRef("http://qudt.org/vocab/unit/J-PER-M")
    PSI_IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-IN3-PER-SEC")
    J_PER_SEC = URIRef("http://qudt.org/vocab/unit/J-PER-SEC")
    J_PER_GM = URIRef("http://qudt.org/vocab/unit/J-PER-GM")
    LB_F_FT_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-FT-PER-IN")
    PERCENT_SEC_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-FT3")
    SLUG_PER_FT2 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT2")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    N_M2_PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/N-M2-PER-KiloGM2")
    N_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M")
    C = URIRef("http://qudt.org/vocab/unit/C")
    MilliW_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM")
    DEG_F_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC2")
    BTU_IT_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_R")
    A_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-M2")
    K_PER_W = URIRef("http://qudt.org/vocab/unit/K-PER-W")
    A_PER_GM = URIRef("http://qudt.org/vocab/unit/A-PER-GM")
    TONNE_PER_HA_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA-YR")
    M2_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/M2-SEC-PER-RAD")
    GigaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-SEC")
    BBL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-DAY")
    M3_PER_KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM-SEC2")
    M3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-K")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    M3_PER_PA = URIRef("http://qudt.org/vocab/unit/M3-PER-PA")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    PER_K = URIRef("http://qudt.org/vocab/unit/PER-K")
    Hundredweight_US = URIRef("http://qudt.org/vocab/unit/Hundredweight_US")
    MHO = URIRef("http://qudt.org/vocab/unit/MHO")
    BQ_PER_M2 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M2")
    MicroOHM = URIRef("http://qudt.org/vocab/unit/MicroOHM")
    MegaPSI = URIRef("http://qudt.org/vocab/unit/MegaPSI")
    HZ_M = URIRef("http://qudt.org/vocab/unit/HZ-M")
    MilliGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-BAR")
    W_SEC = URIRef("http://qudt.org/vocab/unit/W-SEC")
    MicroGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-HR")
    GM_HR_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L2")
    MicroFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-M")
    C_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Ab-PER-CentiM2")
    DEG_F_HR_FT2_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH")
    LB_PER_FT3_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3-PSI")
    PERCENT_PER_HectoBAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-HectoBAR")
    ERG_CentiM2 = URIRef("http://qudt.org/vocab/unit/ERG-CentiM2")
    MicroV_PER_M = URIRef("http://qudt.org/vocab/unit/MicroV-PER-M")
    MilliGM_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-HR")
    V_A_HR = URIRef("http://qudt.org/vocab/unit/V-A-HR")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    OZ_IN = URIRef("http://qudt.org/vocab/unit/OZ-IN")
    DeciS = URIRef("http://qudt.org/vocab/unit/DeciS")
    BTU_IT_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC")
    PERCENT_PER_HectoBAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-HectoBAR")
    ENZ = URIRef("http://qudt.org/vocab/unit/ENZ")
    CAL_IT_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-DEG_C")
    KiloSEC = URIRef("http://qudt.org/vocab/unit/KiloSEC")
    M3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    HART = URIRef("http://qudt.org/vocab/unit/HART")
    BU_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-MIN")
    DeciB_Z = URIRef("http://qudt.org/vocab/unit/DeciB_Z")
    PicoMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L-HR")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    TONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-YR")
    KiloW_PER_M2_K = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M2-K")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    C4_M4_PER_J3 = URIRef("http://qudt.org/vocab/unit/C4-M4-PER-J3")
    KiloJ_PER_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-K")
    MilliV_PER_M = URIRef("http://qudt.org/vocab/unit/MilliV-PER-M")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    M2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2")
    DEG_F_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-HR")
    MilliL_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-K")
    M3_PER_KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM-SEC2")
    C = URIRef("http://qudt.org/vocab/unit/C")
    MilliSV = URIRef("http://qudt.org/vocab/unit/MilliSV")
    M2_PER_SEC2_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2-K")
    NUM_PER_L = URIRef("http://qudt.org/vocab/unit/NUM-PER-L")
    YD = URIRef("http://qudt.org/vocab/unit/YD")
    W_PER_M2_K4 = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K4")
    PER_PA_SEC = URIRef("http://qudt.org/vocab/unit/PER-PA-SEC")
    OHM_PER_K = URIRef("http://qudt.org/vocab/unit/OHM-PER-K")
    DEGREE_BAUME_US_LIGHT = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_LIGHT")
    MilliL_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-BAR")
    M_PER_MIN = URIRef("http://qudt.org/vocab/unit/M-PER-MIN")
    M2_K_PER_W = URIRef("http://qudt.org/vocab/unit/M2-K-PER-W")
    BTU_IT_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-HR-DEG_F")
    MicroS_PER_M = URIRef("http://qudt.org/vocab/unit/MicroS-PER-M")
    NanoMOL_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL")
    BTU_MEAN = URIRef("http://qudt.org/vocab/unit/BTU_MEAN")
    LM_SEC = URIRef("http://qudt.org/vocab/unit/LM-SEC")
    PetaW = URIRef("http://qudt.org/vocab/unit/PetaW")
    LB_PER_LB = URIRef("http://qudt.org/vocab/unit/LB-PER-LB")
    PER_M_NanoM_SR = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM-SR")
    N_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-PER-KiloGM")
    J_PER_MOL_K = URIRef("http://qudt.org/vocab/unit/J-PER-MOL-K")
    KiloGM_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-PA")
    HZ_PER_T = URIRef("http://qudt.org/vocab/unit/HZ-PER-T")
    IN_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN-PER-MIN")
    ExaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/ExaBIT-PER-SEC")
    V_M = URIRef("http://qudt.org/vocab/unit/V-M")
    MilliV = URIRef("http://qudt.org/vocab/unit/MilliV")
    CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-SEC")
    M_PER_FARAD = URIRef("http://qudt.org/vocab/unit/M-PER-FARAD")
    BTU_IT_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-SEC-DEG_F")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    CWT_SHORT = URIRef("http://qudt.org/vocab/unit/CWT_SHORT")
    HectoC = URIRef("http://qudt.org/vocab/unit/HectoC")
    MicroW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroW-PER-M2")
    GigaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/GigaC-PER-M3")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    OZ_VOL_UK = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK")
    PlanckFrequency_Ang = URIRef("http://qudt.org/vocab/unit/PlanckFrequency_Ang")
    AttoC = URIRef("http://qudt.org/vocab/unit/AttoC")
    LB_SEC_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-YD3")
    FT_LA = URIRef("http://qudt.org/vocab/unit/FT-LA")
    K_DAY = URIRef("http://qudt.org/vocab/unit/K-DAY")
    PER_M2 = URIRef("http://qudt.org/vocab/unit/PER-M2")
    MicroL = URIRef("http://qudt.org/vocab/unit/MicroL")
    GibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M2")
    IN_HG = URIRef("http://qudt.org/vocab/unit/IN_HG")
    PetaBIT = URIRef("http://qudt.org/vocab/unit/PetaBIT")
    GM_PER_L = URIRef("http://qudt.org/vocab/unit/GM-PER-L")
    TeraBIT = URIRef("http://qudt.org/vocab/unit/TeraBIT")
    PHON = URIRef("http://qudt.org/vocab/unit/PHON")
    LB_PER_IN3 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3")
    KiloN_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M2")
    M3_PER_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-M2")
    CAL_IT_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT2")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    MegaN_M = URIRef("http://qudt.org/vocab/unit/MegaN-M")
    M3_PER_HA = URIRef("http://qudt.org/vocab/unit/M3-PER-HA")
    N_M_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-M")
    PPTH_PER_HR = URIRef("http://qudt.org/vocab/unit/PPTH-PER-HR")
    Hundredweight_US = URIRef("http://qudt.org/vocab/unit/Hundredweight_US")
    LB_F_FT_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-FT-PER-IN")
    PERCENT_PER_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MilliPA-SEC")
    CAL_TH_PER_G = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-G")
    PERCENT_IN2_PER_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-IN2-PER-LB_F-SEC")
    MegaA = URIRef("http://qudt.org/vocab/unit/MegaA")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    BTU_IT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC")
    DEG_R_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-HR")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    MicroT = URIRef("http://qudt.org/vocab/unit/MicroT")
    DYN_SEC_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM")
    W_M2 = URIRef("http://qudt.org/vocab/unit/W-M2")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    HectoGM = URIRef("http://qudt.org/vocab/unit/HectoGM")
    PERM_Metric_0DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_Metric_0DEG_C")
    PER_EV_M3 = URIRef("http://qudt.org/vocab/unit/PER-EV-M3")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    KiloGM_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-YR")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    ROD = URIRef("http://qudt.org/vocab/unit/ROD")
    KiloV_PER_M = URIRef("http://qudt.org/vocab/unit/KiloV-PER-M")
    MilliL_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY")
    HZ_PER_T = URIRef("http://qudt.org/vocab/unit/HZ-PER-T")
    ExaJ = URIRef("http://qudt.org/vocab/unit/ExaJ")
    MicroMOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-SEC")
    GM_PER_DeciM3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3-K")
    PER_YR = URIRef("http://qudt.org/vocab/unit/PER-YR")
    MilliBQ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-GM")
    BTU_IT_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-HR-DEG_F")
    ENZ_PER_L = URIRef("http://qudt.org/vocab/unit/ENZ-PER-L")
    PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/PER-MilliM3")
    PER_V = URIRef("http://qudt.org/vocab/unit/PER-V")
    KiloGM_F_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-SEC")
    BTU_IT_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_F")
    M3_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-PA")
    KiloM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC")
    LB_IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN-PER-SEC")
    KiloGM_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM2")
    DEG_C_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-MIN")
    Gamma = URIRef("http://qudt.org/vocab/unit/Gamma")
    PERCENT_PER_MilliM = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MilliM")
    PERCENT_PER_OHM = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-OHM")
    DEGREE_PLATO = URIRef("http://qudt.org/vocab/unit/DEGREE_PLATO")
    CentiM6 = URIRef("http://qudt.org/vocab/unit/CentiM6")
    MilliGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-K")
    N_CentiM = URIRef("http://qudt.org/vocab/unit/N-CentiM")
    V = URIRef("http://qudt.org/vocab/unit/V")
    KiloCAL_TH = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH")
    TeraOHM = URIRef("http://qudt.org/vocab/unit/TeraOHM")
    TONNE_PER_DAY = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY")
    EUR_PER_KiloW = URIRef("http://qudt.org/vocab/unit/EUR-PER-KiloW")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    C_M2_PER_V = URIRef("http://qudt.org/vocab/unit/C-M2-PER-V")
    LM_PER_M2 = URIRef("http://qudt.org/vocab/unit/LM-PER-M2")
    MicroGM = URIRef("http://qudt.org/vocab/unit/MicroGM")
    DEG_F_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC2")
    M = URIRef("http://qudt.org/vocab/unit/M")
    TORR = URIRef("http://qudt.org/vocab/unit/TORR")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    GM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    PER_WK = URIRef("http://qudt.org/vocab/unit/PER-WK")
    OZ_F_IN = URIRef("http://qudt.org/vocab/unit/OZ_F-IN")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    TONNE_PER_M3_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3-K")
    FT_H2O = URIRef("http://qudt.org/vocab/unit/FT_H2O")
    DeciM3_PER_HR = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-HR")
    OERSTED = URIRef("http://qudt.org/vocab/unit/OERSTED")
    MOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MOL-PER-MOL")
    NAT = URIRef("http://qudt.org/vocab/unit/NAT")
    MI_US_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/MI_US-PER-SEC2")
    ROD = URIRef("http://qudt.org/vocab/unit/ROD")
    DRAM_UK = URIRef("http://qudt.org/vocab/unit/DRAM_UK")
    MicroV_A_PER_K = URIRef("http://qudt.org/vocab/unit/MicroV-A-PER-K")
    MilliGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    MilliGM_PER_M3_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-MilliPA-SEC")
    REV_PER_HR = URIRef("http://qudt.org/vocab/unit/REV-PER-HR")
    GAUSS = URIRef("http://qudt.org/vocab/unit/GAUSS")
    MicroH_PER_M = URIRef("http://qudt.org/vocab/unit/MicroH-PER-M")
    N_M_PER_ARCMIN = URIRef("http://qudt.org/vocab/unit/N-M-PER-ARCMIN")
    KiloTONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloTONNE-PER-YR")
    LA_FT = URIRef("http://qudt.org/vocab/unit/LA_FT")
    TON_US_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_US-PER-YD3")
    MilloMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilloMOL-PER-L")
    MilliGM_PER_L_PA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-PA-SEC")
    CentiMOL_PER_L = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-L")
    LB_F_FT_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-FT-PER-IN")
    MilliW = URIRef("http://qudt.org/vocab/unit/MilliW")
    V_PER_MicroSEC = URIRef("http://qudt.org/vocab/unit/V-PER-MicroSEC")
    PicoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L")
    KiloGM_PER_M_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-MIN")
    GI_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-SEC")
    K = URIRef("http://qudt.org/vocab/unit/K")
    DEGREE_BAUME_US_HEAVY = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_HEAVY")
    KiloGM_PER_CentiM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-BAR")
    DeciM3 = URIRef("http://qudt.org/vocab/unit/DeciM3")
    DYN_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM")
    MegaGM = URIRef("http://qudt.org/vocab/unit/MegaGM")
    KiloBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBIT-PER-SEC")
    MicroGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-KiloGM")
    PERCENT_IN2_PER_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-IN2-PER-LB_F-SEC")
    M2_PER_GM = URIRef("http://qudt.org/vocab/unit/M2-PER-GM")
    FARAD_Stat = URIRef("http://qudt.org/vocab/unit/FARAD_Stat")
    KiloGM_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-M2")
    KiloYR = URIRef("http://qudt.org/vocab/unit/KiloYR")
    N_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-PER-KiloGM")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    MilliIN = URIRef("http://qudt.org/vocab/unit/MilliIN")
    BIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/BIT-PER-M2")
    HectoPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-BAR")
    TSP = URIRef("http://qudt.org/vocab/unit/TSP")
    PERCENT_PER_K = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-K")
    M_SEC2 = URIRef("http://qudt.org/vocab/unit/M-SEC2")
    PERCENT_FT_HR_PER_LB = URIRef("http://qudt.org/vocab/unit/PERCENT-FT-HR-PER-LB")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    LB_F_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-IN2")
    LB_HR_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT6")
    MicroL = URIRef("http://qudt.org/vocab/unit/MicroL")
    MebiBYTE = URIRef("http://qudt.org/vocab/unit/MebiBYTE")
    DEGREE_OECHSLE = URIRef("http://qudt.org/vocab/unit/DEGREE_OECHSLE")
    MegaEV_FemtoM = URIRef("http://qudt.org/vocab/unit/MegaEV-FemtoM")
    NanoM_PER_CentiM_PSI = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-PSI")
    L_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/L-PER-KiloGM")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    CentiM2_PER_ERG = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-ERG")
    MicroC = URIRef("http://qudt.org/vocab/unit/MicroC")
    MicroSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-SEC")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    LB_PER_IN3 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3")
    KiloLB_F_FT_PER_LB = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-LB")
    MilliM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DAY")
    OZ_HR_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-GAL_US")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    MilliGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HA")
    SLUG_PER_FT2 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT2")
    W_PER_M_DEG_C = URIRef("http://qudt.org/vocab/unit/W-PER-M-DEG_C")
    HeartBeat = URIRef("http://qudt.org/vocab/unit/HeartBeat")
    J_PER_M4 = URIRef("http://qudt.org/vocab/unit/J-PER-M4")
    LB_F_FT_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-FT-PER-IN")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    HR_FT2 = URIRef("http://qudt.org/vocab/unit/HR-FT2")
    J_M2 = URIRef("http://qudt.org/vocab/unit/J-M2")
    BTU_TH_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2")
    CM_H2O = URIRef("http://qudt.org/vocab/unit/CM_H2O")
    KiloBTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-FT2")
    PA_M0pt5 = URIRef("http://qudt.org/vocab/unit/PA-M0pt5")
    MilliGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-GM")
    PER_MilliGM = URIRef("http://qudt.org/vocab/unit/PER-MilliGM")
    PERCENT_PER_DektoKiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DektoKiloCount")
    PER_M_SR = URIRef("http://qudt.org/vocab/unit/PER-M-SR")
    PSI_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-L-PER-SEC")
    KiloMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-SEC")
    PERCENT_PER_DecaKiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaKiloCount")
    DEGREE_BAUME_US_HEAVY = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_HEAVY")
    TON_LONG_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_LONG-PER-YD3")
    ATM = URIRef("http://qudt.org/vocab/unit/ATM")
    GM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciL")
    MilliL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-KiloGM")
    NanoS_PER_M = URIRef("http://qudt.org/vocab/unit/NanoS-PER-M")
    TON_Metric_PER_M3 = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3")
    M6 = URIRef("http://qudt.org/vocab/unit/M6")
    DeciM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-M3")
    FT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-DEG_F")
    MicroGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-HR")
    MicroV_A_PER_K = URIRef("http://qudt.org/vocab/unit/MicroV-A-PER-K")
    TONNE_PER_MIN = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN")
    C_M2_PER_V = URIRef("http://qudt.org/vocab/unit/C-M2-PER-V")
    TONNE_PER_M3 = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3")
    GM_PER_L_K = URIRef("http://qudt.org/vocab/unit/GM-PER-L-K")
    BU_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-DAY")
    Denier = URIRef("http://qudt.org/vocab/unit/Denier")
    KiloGM_PER_M_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-DAY")
    W_PER_M2_K = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K")
    W_PER_M2_K = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K")
    YD = URIRef("http://qudt.org/vocab/unit/YD")
    N_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM2")
    LB_PER_M3 = URIRef("http://qudt.org/vocab/unit/LB-PER-M3")
    PA2_SEC = URIRef("http://qudt.org/vocab/unit/PA2-SEC")
    GAL_US = URIRef("http://qudt.org/vocab/unit/GAL_US")
    MilliR = URIRef("http://qudt.org/vocab/unit/MilliR")
    PERCENT_HR_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-CentiM3")
    LB_HR_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-GAL_US")
    AC = URIRef("http://qudt.org/vocab/unit/AC")
    GM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM")
    CASES_PER_KiloINDIV_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-KiloINDIV-YR")
    DEG_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC")
    MicroBQ = URIRef("http://qudt.org/vocab/unit/MicroBQ")
    ExaBIT_PER_M = URIRef("http://qudt.org/vocab/unit/ExaBIT-PER-M")
    PERCENT_PER_DecaK = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaK")
    FRACTION = URIRef("http://qudt.org/vocab/unit/FRACTION")
    GAL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-MIN")
    KiloYR = URIRef("http://qudt.org/vocab/unit/KiloYR")
    OZ_FT = URIRef("http://qudt.org/vocab/unit/OZ-FT")
    V = URIRef("http://qudt.org/vocab/unit/V")
    DEG_F_HR_FT2_PER_BTU_TH_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH-IN")
    FM = URIRef("http://qudt.org/vocab/unit/FM")
    GM_PER_L_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-L-MilliPA-SEC")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    SLUG_PER_DAY = URIRef("http://qudt.org/vocab/unit/SLUG-PER-DAY")
    N_M2 = URIRef("http://qudt.org/vocab/unit/N-M2")
    MegaPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-BAR")
    PSU = URIRef("http://qudt.org/vocab/unit/PSU")
    PER_SEC_M2_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2-SR")
    EUR_PER_KiloW = URIRef("http://qudt.org/vocab/unit/EUR-PER-KiloW")
    CD_PER_IN2 = URIRef("http://qudt.org/vocab/unit/CD-PER-IN2")
    IU_PER_L = URIRef("http://qudt.org/vocab/unit/IU-PER-L")
    MicroM_PER_K = URIRef("http://qudt.org/vocab/unit/MicroM-PER-K")
    A_SEC2 = URIRef("http://qudt.org/vocab/unit/A-SEC2")
    MI_US = URIRef("http://qudt.org/vocab/unit/MI_US")
    FT2_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT2-PER-SEC")
    MilliGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-BAR")
    YD3 = URIRef("http://qudt.org/vocab/unit/YD3")
    KiloL = URIRef("http://qudt.org/vocab/unit/KiloL")
    HectoPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-M3-PER-SEC")
    PER_WB = URIRef("http://qudt.org/vocab/unit/PER-WB")
    PIXEL = URIRef("http://qudt.org/vocab/unit/PIXEL")
    N_CentiM = URIRef("http://qudt.org/vocab/unit/N-CentiM")
    DEG_R_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-HR")
    OZ_VOL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-MIN")
    Standard = URIRef("http://qudt.org/vocab/unit/Standard")
    MegaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-M")
    KiloS = URIRef("http://qudt.org/vocab/unit/KiloS")
    KiloGM_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-MilliM2")
    CAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-K")
    HP_Electric = URIRef("http://qudt.org/vocab/unit/HP_Electric")
    PetaC = URIRef("http://qudt.org/vocab/unit/PetaC")
    MilliBAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-M3-PER-SEC")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    PDL_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/PDL-SEC-PER-IN2")
    SV_PER_MIN = URIRef("http://qudt.org/vocab/unit/SV-PER-MIN")
    BTU_TH_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT3")
    ExaW = URIRef("http://qudt.org/vocab/unit/ExaW")
    MOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL-PER-MIN")
    MegaW = URIRef("http://qudt.org/vocab/unit/MegaW")
    MegaOHM_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-M")
    MilliM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC")
    KiloCAL_IT_PER_HR_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-HR-M-DEG_C")
    LB = URIRef("http://qudt.org/vocab/unit/LB")
    DEGREE_API = URIRef("http://qudt.org/vocab/unit/DEGREE_API")
    M2_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-K")
    IN3_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN3-PER-MIN")
    MicroGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-SEC")
    MicroPA = URIRef("http://qudt.org/vocab/unit/MicroPA")
    MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC")
    LB_SEC_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-YD3")
    PER_MilliL = URIRef("http://qudt.org/vocab/unit/PER-MilliL")
    C_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM")
    KiloLB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-IN2")
    LB_F_PER_IN2_DEG_F = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-DEG_F")
    OZ_VOL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-HR")
    KiloGM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3")
    KiloGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-K")
    MOL_K = URIRef("http://qudt.org/vocab/unit/MOL-K")
    MilliGM_PER_L = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L")
    GM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY-BAR")
    KY = URIRef("http://qudt.org/vocab/unit/KY")
    BTU_IT_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_F")
    FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-SEC-DEG_F")
    M3_PER_HA = URIRef("http://qudt.org/vocab/unit/M3-PER-HA")
    MebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M3")
    Ci = URIRef("http://qudt.org/vocab/unit/Ci")
    PERCENT_FT_HR_PER_LB = URIRef("http://qudt.org/vocab/unit/PERCENT-FT-HR-PER-LB")
    TON_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_US-PER-DAY")
    DeciM = URIRef("http://qudt.org/vocab/unit/DeciM")
    IN_HG = URIRef("http://qudt.org/vocab/unit/IN_HG")
    BTU_TH = URIRef("http://qudt.org/vocab/unit/BTU_TH")
    M3_PER_M3 = URIRef("http://qudt.org/vocab/unit/M3-PER-M3")
    NanoS = URIRef("http://qudt.org/vocab/unit/NanoS")
    MilliDEG_C = URIRef("http://qudt.org/vocab/unit/MilliDEG_C")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    FT_LB_F = URIRef("http://qudt.org/vocab/unit/FT-LB_F")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/PER-M2-SEC")
    MegaW = URIRef("http://qudt.org/vocab/unit/MegaW")
    MilliBQ = URIRef("http://qudt.org/vocab/unit/MilliBQ")
    PicoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-KiloGM")
    MilliDARCY = URIRef("http://qudt.org/vocab/unit/MilliDARCY")
    CentiM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY")
    DEGREE_OECHSLE = URIRef("http://qudt.org/vocab/unit/DEGREE_OECHSLE")
    HeartBeat = URIRef("http://qudt.org/vocab/unit/HeartBeat")
    LB_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-DEG_F")
    W_PER_IN2 = URIRef("http://qudt.org/vocab/unit/W-PER-IN2")
    DEG_F_HR_FT2_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH")
    NanoJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoJ-PER-SEC")
    MilliGM_HR_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L-CentiM3")
    KiloCAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-MIN")
    GM_SEC_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L2")
    MilliL_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-K")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    LB_FT2 = URIRef("http://qudt.org/vocab/unit/LB-FT2")
    OZ_VOL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-SEC")
    BTU_IT_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_F")
    DEG_F_HR_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_IT")
    MilliGM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-BAR")
    LB_MIN_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-FT3")
    A2_SEC = URIRef("http://qudt.org/vocab/unit/A2-SEC")
    MicroM3 = URIRef("http://qudt.org/vocab/unit/MicroM3")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    MilliDEG_C = URIRef("http://qudt.org/vocab/unit/MilliDEG_C")
    TebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M")
    SolarMass = URIRef("http://qudt.org/vocab/unit/SolarMass")
    CD_PER_IN2 = URIRef("http://qudt.org/vocab/unit/CD-PER-IN2")
    DEATHS_PER_MegaINDIV_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-MegaINDIV-YR")
    GigaBIT = URIRef("http://qudt.org/vocab/unit/GigaBIT")
    KiloGM_PER_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-K")
    LB_PER_FT = URIRef("http://qudt.org/vocab/unit/LB-PER-FT")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    KiloGM_PER_CentiM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-BAR")
    PicoM = URIRef("http://qudt.org/vocab/unit/PicoM")
    FT_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-PER-HR")
    KiloW_PER_M2_K = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M2-K")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    NanoSEC = URIRef("http://qudt.org/vocab/unit/NanoSEC")
    NanoGM_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2-DAY")
    MegaGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-M3")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    MegaBAUD = URIRef("http://qudt.org/vocab/unit/MegaBAUD")
    TeraOHM = URIRef("http://qudt.org/vocab/unit/TeraOHM")
    LB_PER_LB = URIRef("http://qudt.org/vocab/unit/LB-PER-LB")
    QT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-SEC")
    PER_BAR = URIRef("http://qudt.org/vocab/unit/PER-BAR")
    K = URIRef("http://qudt.org/vocab/unit/K")
    LB_MIN_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK2")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    NanoGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-SEC")
    BTU_59DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_59DEG_F")
    BU_US = URIRef("http://qudt.org/vocab/unit/BU_US")
    PER_MO = URIRef("http://qudt.org/vocab/unit/PER-MO")
    ExbiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M")
    MilliBAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-L-PER-SEC")
    MicroMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2")
    LB_DEG_R = URIRef("http://qudt.org/vocab/unit/LB-DEG_R")
    KiloM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM2-PER-SEC2")
    TeraJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/TeraJ-PER-SEC")
    PERCENT_MIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-GAL_US")
    FT_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-PER-MIN")
    MilliA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliA-PER-BAR")
    J_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K")
    MilliOHM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-K")
    MicroH_PER_M = URIRef("http://qudt.org/vocab/unit/MicroH-PER-M")
    MilliARCSEC = URIRef("http://qudt.org/vocab/unit/MilliARCSEC")
    M3_PER_K = URIRef("http://qudt.org/vocab/unit/M3-PER-K")
    Flight = URIRef("http://qudt.org/vocab/unit/Flight")
    B = URIRef("http://qudt.org/vocab/unit/B")
    KiloGM_PER_KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloMOL")
    NanoMOL_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L-DAY")
    BBL_US_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-HR")
    PINT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-HR")
    HP_Boiler = URIRef("http://qudt.org/vocab/unit/HP_Boiler")
    MicroGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-HR")
    FT_HR_PER_IN3 = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-IN3")
    MegaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-HR")
    MilliSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-SEC")
    TON_Metric_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY")
    MOL_PER_GM_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-GM-HR")
    CentiM3_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN-K")
    DeciM2 = URIRef("http://qudt.org/vocab/unit/DeciM2")
    DEG_F_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-HR")
    BTU_IT_PER_SEC_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_R")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    LB_HR_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-YD3")
    SEC_PER_RAD_M3 = URIRef("http://qudt.org/vocab/unit/SEC-PER-RAD-M3")
    J_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K")
    J_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2")
    GigaW_HR = URIRef("http://qudt.org/vocab/unit/GigaW-HR")
    BTU_TH_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-FT2-HR-DEG_F")
    KiloGM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM2")
    OERSTED = URIRef("http://qudt.org/vocab/unit/OERSTED")
    CentiPOISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-BAR")
    TON_Metric_PER_MIN = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN")
    MOL_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-BAR")
    NanoGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2")
    MicroGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M2-DAY")
    GM_SEC_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L-M3")
    PlanckEnergy = URIRef("http://qudt.org/vocab/unit/PlanckEnergy")
    LB_MIN_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT6")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    YottaC = URIRef("http://qudt.org/vocab/unit/YottaC")
    PER_EV_M3 = URIRef("http://qudt.org/vocab/unit/PER-EV-M3")
    PK_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-MIN")
    HP_H2O = URIRef("http://qudt.org/vocab/unit/HP_H2O")
    FT3 = URIRef("http://qudt.org/vocab/unit/FT3")
    GM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-L-BAR")
    MilliIN = URIRef("http://qudt.org/vocab/unit/MilliIN")
    SLUG = URIRef("http://qudt.org/vocab/unit/SLUG")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    GRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/GRAY-PER-MIN")
    EUR_PER_W = URIRef("http://qudt.org/vocab/unit/EUR-PER-W")
    MicroM_PER_M = URIRef("http://qudt.org/vocab/unit/MicroM-PER-M")
    PER_PERCENT = URIRef("http://qudt.org/vocab/unit/PER-PERCENT")
    KiloGM_M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M2-PER-SEC")
    PERCENT_PER_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MilliPA-SEC")
    MIN_Angle = URIRef("http://qudt.org/vocab/unit/MIN_Angle")
    DRAM_UK = URIRef("http://qudt.org/vocab/unit/DRAM_UK")
    MilliL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-SEC")
    DEG_F_HR_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_TH")
    SLUG = URIRef("http://qudt.org/vocab/unit/SLUG")
    B = URIRef("http://qudt.org/vocab/unit/B")
    ERG_PER_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-SEC")
    MegaN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaN-M-PER-M2")
    NanoOHM = URIRef("http://qudt.org/vocab/unit/NanoOHM")
    KiloCAL_TH = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH")
    LB_FT2 = URIRef("http://qudt.org/vocab/unit/LB-FT2")
    MicroGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-K")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    AC_FT_US = URIRef("http://qudt.org/vocab/unit/AC-FT_US")
    WB_PER_MilliM = URIRef("http://qudt.org/vocab/unit/WB-PER-MilliM")
    GAL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-DAY")
    DYN_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM")
    CentiPOISE = URIRef("http://qudt.org/vocab/unit/CentiPOISE")
    KiloGM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC2")
    MebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M")
    J_PER_T2 = URIRef("http://qudt.org/vocab/unit/J-PER-T2")
    LB_T = URIRef("http://qudt.org/vocab/unit/LB_T")
    NUM_PER_YR = URIRef("http://qudt.org/vocab/unit/NUM-PER-YR")
    REV_PER_MIN = URIRef("http://qudt.org/vocab/unit/REV-PER-MIN")
    EV_PER_M = URIRef("http://qudt.org/vocab/unit/EV-PER-M")
    FARAD_Stat = URIRef("http://qudt.org/vocab/unit/FARAD_Stat")
    CentiM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-M3")
    PIXEL = URIRef("http://qudt.org/vocab/unit/PIXEL")
    MI_N_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI_N-PER-MIN")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    OZ_VOL_US = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US")
    PicoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-MilliL")
    MilliMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2-DAY")
    KiloGAUSS = URIRef("http://qudt.org/vocab/unit/KiloGAUSS")
    M2_HR_DEG_C_PER_KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/M2-HR-DEG_C-PER-KiloCAL_IT")
    BBL = URIRef("http://qudt.org/vocab/unit/BBL")
    MilliGM_HR_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M6")
    TON_SHORT_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR")
    NanoS_PER_M = URIRef("http://qudt.org/vocab/unit/NanoS-PER-M")
    MegaOHM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-KiloM")
    CAL_TH_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM-SEC-DEG_C")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    MI3 = URIRef("http://qudt.org/vocab/unit/MI3")
    CAL_TH_PER_G = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-G")
    ARCSEC = URIRef("http://qudt.org/vocab/unit/ARCSEC")
    DecaL = URIRef("http://qudt.org/vocab/unit/DecaL")
    GAL_US_DRY = URIRef("http://qudt.org/vocab/unit/GAL_US_DRY")
    MicroBQ = URIRef("http://qudt.org/vocab/unit/MicroBQ")
    SON = URIRef("http://qudt.org/vocab/unit/SON")
    FT_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT-PER-DAY")
    GM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3")
    MilLength = URIRef("http://qudt.org/vocab/unit/MilLength")
    W_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM")
    FT_HR_PER_IN3 = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-IN3")
    W_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM")
    YD_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD-PER-DEG_F")
    LB_PER_HR_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-HR-PSI")
    KiloGM_PER_M2_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC2")
    S = URIRef("http://qudt.org/vocab/unit/S")
    MO_MeanGREGORIAN = URIRef("http://qudt.org/vocab/unit/MO_MeanGREGORIAN")
    CAL_TH_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM-SEC-DEG_C")
    OZ_IN2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/OZ-IN2-PER-IN3-LB_F-SEC")
    GM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN-K")
    MegaC = URIRef("http://qudt.org/vocab/unit/MegaC")
    PA2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA2-PER-SEC2")
    BTU_IT_PER_HR_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2")
    PER_M_SR = URIRef("http://qudt.org/vocab/unit/PER-M-SR")
    KiloBIT = URIRef("http://qudt.org/vocab/unit/KiloBIT")
    MilliK_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliK-PER-BAR")
    TONNE_PER_HA = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA")
    MicroM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM-PER-MilliL")
    PicoSEC = URIRef("http://qudt.org/vocab/unit/PicoSEC")
    GT = URIRef("http://qudt.org/vocab/unit/GT")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    C = URIRef("http://qudt.org/vocab/unit/C")
    LB_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_US")
    CentiM3_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-K")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    MilliM_HGA = URIRef("http://qudt.org/vocab/unit/MilliM_HGA")
    PER_MOL = URIRef("http://qudt.org/vocab/unit/PER-MOL")
    SLUG_PER_DAY = URIRef("http://qudt.org/vocab/unit/SLUG-PER-DAY")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    KiloCAL_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM")
    HZ_M = URIRef("http://qudt.org/vocab/unit/HZ-M")
    KiloGM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC2")
    LB_MIN_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK2")
    TON_SHORT_PER_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR-DEG_F")
    N_M_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-M")
    CentiM_HG = URIRef("http://qudt.org/vocab/unit/CentiM_HG")
    KiloN_M = URIRef("http://qudt.org/vocab/unit/KiloN-M")
    KiloM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC")
    BTU_IT_PER_LB_F_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_R")
    KiloCAL_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM")
    L_PER_MOL = URIRef("http://qudt.org/vocab/unit/L-PER-MOL")
    DeciB_PER_KiloM = URIRef("http://qudt.org/vocab/unit/DeciB-PER-KiloM")
    M = URIRef("http://qudt.org/vocab/unit/M")
    C_Stat = URIRef("http://qudt.org/vocab/unit/C_Stat")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    KiloTONNE = URIRef("http://qudt.org/vocab/unit/KiloTONNE")
    BTU_IT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_F")
    BTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2")
    TeraHZ = URIRef("http://qudt.org/vocab/unit/TeraHZ")
    MilLength = URIRef("http://qudt.org/vocab/unit/MilLength")
    MilliV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliV-PER-MIN")
    MicroC = URIRef("http://qudt.org/vocab/unit/MicroC")
    DeciB_A = URIRef("http://qudt.org/vocab/unit/DeciB_A")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    KiloC_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M3")
    PDL = URIRef("http://qudt.org/vocab/unit/PDL")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    LB_F_FT = URIRef("http://qudt.org/vocab/unit/LB_F-FT")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    TON_Metric_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN-K")
    FemtoGM = URIRef("http://qudt.org/vocab/unit/FemtoGM")
    K = URIRef("http://qudt.org/vocab/unit/K")
    MOL_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-BAR")
    TONNE_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC-K")
    BEAT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BEAT-PER-MIN")
    MilliGM_PER_L = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L")
    GI_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-MIN")
    M2_PER_K = URIRef("http://qudt.org/vocab/unit/M2-PER-K")
    MilliBAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-BAR")
    MilliR_man = URIRef("http://qudt.org/vocab/unit/MilliR_man")
    POISE_PER_K = URIRef("http://qudt.org/vocab/unit/POISE-PER-K")
    W_PER_SR_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-SR-M2")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    L_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-M2")
    LB_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN2")
    MicroMOL_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-HR")
    N_M2_PER_A = URIRef("http://qudt.org/vocab/unit/N-M2-PER-A")
    TONNE_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN-BAR")
    LB_PER_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-DAY")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    M = URIRef("http://qudt.org/vocab/unit/M")
    PSU = URIRef("http://qudt.org/vocab/unit/PSU")
    ST = URIRef("http://qudt.org/vocab/unit/ST")
    NanoGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-MIN")
    PK_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-MIN")
    SLUG_PER_MIN = URIRef("http://qudt.org/vocab/unit/SLUG-PER-MIN")
    C_PER_MOL = URIRef("http://qudt.org/vocab/unit/C-PER-MOL")
    BTU_IT_PER_SEC_FT_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT-DEG_R")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    PER_DAY = URIRef("http://qudt.org/vocab/unit/PER-DAY")
    K_PER_W = URIRef("http://qudt.org/vocab/unit/K-PER-W")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    L_PER_L = URIRef("http://qudt.org/vocab/unit/L-PER-L")
    MicroOHM_M = URIRef("http://qudt.org/vocab/unit/MicroOHM-M")
    CD_PER_FT2 = URIRef("http://qudt.org/vocab/unit/CD-PER-FT2")
    KiloCAL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MIN")
    FT_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC2")
    TON_US_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_US-PER-HR")
    MOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3")
    MicroGM_PER_CentiM2_WK = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2-WK")
    GM_PER_L_POISE = URIRef("http://qudt.org/vocab/unit/GM-PER-L-POISE")
    IN_H2O = URIRef("http://qudt.org/vocab/unit/IN_H2O")
    MilliM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC2")
    PERCENT_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEG_C")
    A = URIRef("http://qudt.org/vocab/unit/A")
    MIN_Angle = URIRef("http://qudt.org/vocab/unit/MIN_Angle")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    SV_PER_SEC = URIRef("http://qudt.org/vocab/unit/SV-PER-SEC")
    BTU_IT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR-DEG_F")
    IN3_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN3-PER-MIN")
    MilliGM_MIN_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L2")
    MicroIN = URIRef("http://qudt.org/vocab/unit/MicroIN")
    ExaJ = URIRef("http://qudt.org/vocab/unit/ExaJ")
    A_M2_PER_J_SEC = URIRef("http://qudt.org/vocab/unit/A-M2-PER-J-SEC")
    PK_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-HR")
    J = URIRef("http://qudt.org/vocab/unit/J")
    T = URIRef("http://qudt.org/vocab/unit/T")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    N_PER_CentiM = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM")
    LB_SEC_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-YD3")
    LB_MIN_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN6")
    AC_FT = URIRef("http://qudt.org/vocab/unit/AC-FT")
    OERSTED_CentiM = URIRef("http://qudt.org/vocab/unit/OERSTED-CentiM")
    PER_L = URIRef("http://qudt.org/vocab/unit/PER-L")
    GM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-CentiM-PER-SEC")
    MegaDOLLAR_US_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MegaDOLLAR_US-PER-FLIGHT")
    FRAME_PER_SEC = URIRef("http://qudt.org/vocab/unit/FRAME-PER-SEC")
    TON_FG = URIRef("http://qudt.org/vocab/unit/TON_FG")
    CAL_TH = URIRef("http://qudt.org/vocab/unit/CAL_TH")
    TON_Metric_PER_M3 = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3")
    M2_PER_HZ = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ")
    PER_MilliL = URIRef("http://qudt.org/vocab/unit/PER-MilliL")
    PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PER-KiloGM")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    KiloW = URIRef("http://qudt.org/vocab/unit/KiloW")
    CentiM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-M3")
    NanoW = URIRef("http://qudt.org/vocab/unit/NanoW")
    FUR = URIRef("http://qudt.org/vocab/unit/FUR")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    MilliGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-SEC")
    W_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM")
    KiloGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloGM")
    PicoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-MilliL")
    DeciM3_PER_HR = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-HR")
    LB_SEC_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-FT3")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    NanoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/NanoW-PER-M2")
    TON_UK = URIRef("http://qudt.org/vocab/unit/TON_UK")
    FT_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT-PER-DAY")
    C2_M2_PER_J = URIRef("http://qudt.org/vocab/unit/C2-M2-PER-J")
    BARN = URIRef("http://qudt.org/vocab/unit/BARN")
    J_PER_M4 = URIRef("http://qudt.org/vocab/unit/J-PER-M4")
    KiloGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-BAR")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    KiloGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-BAR")
    PA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-L-PER-SEC")
    FT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-DEG_F")
    KiloW_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloW-HR-PER-M2")
    MegaA = URIRef("http://qudt.org/vocab/unit/MegaA")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    PER_DEG_C = URIRef("http://qudt.org/vocab/unit/PER-DEG_C")
    LB_MIN_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-IN3")
    M_SEC2 = URIRef("http://qudt.org/vocab/unit/M-SEC2")
    SLUG = URIRef("http://qudt.org/vocab/unit/SLUG")
    PER_MegaPA = URIRef("http://qudt.org/vocab/unit/PER-MegaPA")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    BTU_IT_FT = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT")
    BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN")
    W_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M3")
    NanoL = URIRef("http://qudt.org/vocab/unit/NanoL")
    MilliGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-GM")
    V_PER_L_MIN = URIRef("http://qudt.org/vocab/unit/V-PER-L-MIN")
    PER_MOL = URIRef("http://qudt.org/vocab/unit/PER-MOL")
    LB_PER_YD3 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD3")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    KiloLB_F_FT_PER_LB = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-LB")
    GM_PER_HR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR")
    MIN_Sidereal = URIRef("http://qudt.org/vocab/unit/MIN_Sidereal")
    KiloGM_F = URIRef("http://qudt.org/vocab/unit/KiloGM_F")
    PlanckArea = URIRef("http://qudt.org/vocab/unit/PlanckArea")
    PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2")
    KiloBAUD = URIRef("http://qudt.org/vocab/unit/KiloBAUD")
    PA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-BAR")
    BTU_IT_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT3")
    KiloPA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-M")
    PERCENT_IN2_PER_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-IN2-PER-LB_F-SEC")
    NanoGM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MicroL")
    W_PER_SR = URIRef("http://qudt.org/vocab/unit/W-PER-SR")
    DEG_C_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-K")
    POISE_PER_K = URIRef("http://qudt.org/vocab/unit/POISE-PER-K")
    CAL_TH_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-K")
    MOL_PER_M2_SEC_SR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-SR")
    PicoMOL_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M3-SEC")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    MicroG = URIRef("http://qudt.org/vocab/unit/MicroG")
    KiloLB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-FT")
    UnitPole = URIRef("http://qudt.org/vocab/unit/UnitPole")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    A_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM2")
    CAL_TH_PER_G = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-G")
    GM_PER_M = URIRef("http://qudt.org/vocab/unit/GM-PER-M")
    MicroFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-M")
    MilliL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-MIN")
    KiloGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloGM")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    FARAD_Ab = URIRef("http://qudt.org/vocab/unit/FARAD_Ab")
    PK_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-SEC")
    MicroGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2")
    FT_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC2")
    HectoPA = URIRef("http://qudt.org/vocab/unit/HectoPA")
    MicroMOL_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM-SEC")
    GAL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-DAY")
    MegaPA_M0dot5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0dot5")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    OZ_PER_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD3")
    PicoJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/PicoJ-PER-SEC")
    C_Stat = URIRef("http://qudt.org/vocab/unit/C_Stat")
    BTU_IT_PER_HR_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2")
    DeciB_ISO = URIRef("http://qudt.org/vocab/unit/DeciB_ISO")
    PK_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-MIN")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    OZ_PER_GAL = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    NUM_PER_HR = URIRef("http://qudt.org/vocab/unit/NUM-PER-HR")
    CentiM = URIRef("http://qudt.org/vocab/unit/CentiM")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    PER_MILLE_PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PER-PSI")
    IN_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC2")
    M3_PER_HA = URIRef("http://qudt.org/vocab/unit/M3-PER-HA")
    MilliM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DAY")
    MilliV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/MilliV-A_Reactive-PER-K")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    ATM_PER_M = URIRef("http://qudt.org/vocab/unit/ATM-PER-M")
    PicoGM_PER_GM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-GM")
    A_SEC = URIRef("http://qudt.org/vocab/unit/A-SEC")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    DeciN_M = URIRef("http://qudt.org/vocab/unit/DeciN-M")
    TON_Metric_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR")
    MilliGM_SEC_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M6")
    MilliA = URIRef("http://qudt.org/vocab/unit/MilliA")
    MicroMOL_PER_MicroMOL_DAY = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MicroMOL-DAY")
    HR_FT2 = URIRef("http://qudt.org/vocab/unit/HR-FT2")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    M3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL-SEC")
    W_PER_M2_K = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K")
    PINT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-HR")
    MilliGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-SEC")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    KiloGM_PER_M_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC2")
    M2_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-PA")
    GM_PER_M3 = URIRef("http://qudt.org/vocab/unit/GM-PER-M3")
    Da = URIRef("http://qudt.org/vocab/unit/Da")
    PK_US_DRY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY")
    MegaDOLLAR_US_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MegaDOLLAR_US-PER-FLIGHT")
    AC_FT = URIRef("http://qudt.org/vocab/unit/AC-FT")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    GAL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-SEC")
    SLUG_PER_FT2 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT2")
    CUP_US = URIRef("http://qudt.org/vocab/unit/CUP_US")
    CentiM3_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN-BAR")
    TeraV = URIRef("http://qudt.org/vocab/unit/TeraV")
    FC = URIRef("http://qudt.org/vocab/unit/FC")
    H_Stat = URIRef("http://qudt.org/vocab/unit/H_Stat")
    DeciBAR_PER_YR = URIRef("http://qudt.org/vocab/unit/DeciBAR-PER-YR")
    GigaBIT_PER_M = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-M")
    V_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/V-SEC-PER-M")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    NanoMOL_PER_MicroMOL_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL-DAY")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    PicoFARAD = URIRef("http://qudt.org/vocab/unit/PicoFARAD")
    MOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3")
    REV_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC2")
    W_PER_M_DEG_C = URIRef("http://qudt.org/vocab/unit/W-PER-M-DEG_C")
    IN = URIRef("http://qudt.org/vocab/unit/IN")
    MegaS_PER_M = URIRef("http://qudt.org/vocab/unit/MegaS-PER-M")
    EV_PER_K = URIRef("http://qudt.org/vocab/unit/EV-PER-K")
    FT_US = URIRef("http://qudt.org/vocab/unit/FT_US")
    LB_MIN_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-FT3")
    ATM_PER_M = URIRef("http://qudt.org/vocab/unit/ATM-PER-M")
    GM_PER_HR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR")
    PINT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-HR")
    L_PER_MIN = URIRef("http://qudt.org/vocab/unit/L-PER-MIN")
    PERCENT_SEC_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-FT3")
    MicroM_PER_K = URIRef("http://qudt.org/vocab/unit/MicroM-PER-K")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    GM = URIRef("http://qudt.org/vocab/unit/GM")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    KiloGM_PER_M_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC")
    GI_UK = URIRef("http://qudt.org/vocab/unit/GI_UK")
    KiloLB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-IN2")
    M2_PER_K = URIRef("http://qudt.org/vocab/unit/M2-PER-K")
    LB_SEC_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-IN3")
    N_M_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-M")
    MebiBYTE = URIRef("http://qudt.org/vocab/unit/MebiBYTE")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    TON_Metric_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC-K")
    KiloM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC2")
    KiloTONNE = URIRef("http://qudt.org/vocab/unit/KiloTONNE")
    YR = URIRef("http://qudt.org/vocab/unit/YR")
    PER_WB = URIRef("http://qudt.org/vocab/unit/PER-WB")
    KiloGM_PER_HA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HA")
    GigaPA_CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/GigaPA-CentiM3-PER-GM")
    PER_WK = URIRef("http://qudt.org/vocab/unit/PER-WK")
    MilliM3_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-GM")
    KiloEV = URIRef("http://qudt.org/vocab/unit/KiloEV")
    TON = URIRef("http://qudt.org/vocab/unit/TON")
    MilliM3_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-GM")
    MicroBQ = URIRef("http://qudt.org/vocab/unit/MicroBQ")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    MicroMOL_PER_MicroMOL_DAY = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MicroMOL-DAY")
    PERCENT_PER_MO = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MO")
    PA_PER_HR = URIRef("http://qudt.org/vocab/unit/PA-PER-HR")
    MOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MOL-PER-MOL")
    CentiM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY")
    GigaW = URIRef("http://qudt.org/vocab/unit/GigaW")
    T_M = URIRef("http://qudt.org/vocab/unit/T-M")
    M2_HZ4 = URIRef("http://qudt.org/vocab/unit/M2-HZ4")
    MilliBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-L")
    PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/PER-M2-SEC")
    GAL_US_DRY = URIRef("http://qudt.org/vocab/unit/GAL_US_DRY")
    MegaHZ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-K")
    NUM_PER_GM = URIRef("http://qudt.org/vocab/unit/NUM-PER-GM")
    MegaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBYTE-PER-SEC")
    CAL_TH_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-DEG_C")
    BU_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-SEC")
    BARAD = URIRef("http://qudt.org/vocab/unit/BARAD")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    TONNE_PER_HA = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA")
    W_PER_M2_K4 = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K4")
    HectoGM = URIRef("http://qudt.org/vocab/unit/HectoGM")
    ANGSTROM = URIRef("http://qudt.org/vocab/unit/ANGSTROM")
    MebiBYTE = URIRef("http://qudt.org/vocab/unit/MebiBYTE")
    REM = URIRef("http://qudt.org/vocab/unit/REM")
    BTU_IT_PER_MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB-DEG_F")
    KiloTONNE = URIRef("http://qudt.org/vocab/unit/KiloTONNE")
    KiloCAL = URIRef("http://qudt.org/vocab/unit/KiloCAL")
    KiloGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-K")
    GM_MilliM = URIRef("http://qudt.org/vocab/unit/GM-MilliM")
    KiloGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM2")
    LB_SEC_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-YD3")
    MilliGM_MIN_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M6")
    KiloGM_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MOL")
    C_Stat_PER_MOL = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-MOL")
    IN_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC-PSI")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    W_PER_M2_M = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M")
    FARAD_Ab = URIRef("http://qudt.org/vocab/unit/FARAD_Ab")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    PlanckCurrent = URIRef("http://qudt.org/vocab/unit/PlanckCurrent")
    MebiBIT = URIRef("http://qudt.org/vocab/unit/MebiBIT")
    NanoMOL_PER_CentiM3_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-CentiM3-HR")
    GM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM_F-PER-CentiM2")
    PERCENT_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-M3")
    W_M2 = URIRef("http://qudt.org/vocab/unit/W-M2")
    J_PER_KiloGM_K_PA = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-PA")
    V_Stat = URIRef("http://qudt.org/vocab/unit/V_Stat")
    A_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM2")
    MOL_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-SEC")
    W_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/W-PER-CentiM2")
    BTU_59DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_59DEG_F")
    BTU_IT_PER_LB_F_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_F")
    BTU_IT_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-HR-DEG_F")
    MicroFARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-KiloM")
    MilliM3_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-GM")
    BBL_UK_PET = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET")
    BTU_IT_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-SEC-DEG_F")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    KiloH = URIRef("http://qudt.org/vocab/unit/KiloH")
    MOMME_Pearl = URIRef("http://qudt.org/vocab/unit/MOMME_Pearl")
    GM_PER_CentiM2_YR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2-YR")
    KiloJ = URIRef("http://qudt.org/vocab/unit/KiloJ")
    PK_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-MIN")
    CentiM_H2O = URIRef("http://qudt.org/vocab/unit/CentiM_H2O")
    BBL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-DAY")
    BQ_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-SEC-PER-M3")
    PicoV_A = URIRef("http://qudt.org/vocab/unit/PicoV-A")
    KiloGM_PER_M_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC2")
    MicroGRAY = URIRef("http://qudt.org/vocab/unit/MicroGRAY")
    GM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC-BAR")
    TONNE_PER_M3_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3-K")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    SLUG_PER_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-SEC")
    MicroMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L-HR")
    PicoS = URIRef("http://qudt.org/vocab/unit/PicoS")
    MilliBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-KiloGM")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    YD_PER_PSI = URIRef("http://qudt.org/vocab/unit/YD-PER-PSI")
    DEG_R_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-MIN")
    DecaL = URIRef("http://qudt.org/vocab/unit/DecaL")
    BU_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-DAY")
    POISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/POISE-PER-BAR")
    V_PER_MicroSEC = URIRef("http://qudt.org/vocab/unit/V-PER-MicroSEC")
    WK = URIRef("http://qudt.org/vocab/unit/WK")
    OHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/OHM-PER-BAR")
    DecaM3 = URIRef("http://qudt.org/vocab/unit/DecaM3")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    KiloC_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M2")
    MI_US2 = URIRef("http://qudt.org/vocab/unit/MI_US2")
    MilliS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MilliS-PER-CentiM")
    LB_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-DEG_F")
    PERCENT_HR_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-IN3")
    MilliL_PER_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-K")
    ONE = URIRef("http://qudt.org/vocab/unit/ONE")
    CentiM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-M3")
    QT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_US-PER-DAY")
    PER_M_SEC = URIRef("http://qudt.org/vocab/unit/PER-M-SEC")
    GM_PER_M3 = URIRef("http://qudt.org/vocab/unit/GM-PER-M3")
    TON_Metric_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN-BAR")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    LB_F_FT = URIRef("http://qudt.org/vocab/unit/LB_F-FT")
    TONNE_PER_MO = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MO")
    PERCENT_PER_PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-PERCENT")
    MegaBAUD = URIRef("http://qudt.org/vocab/unit/MegaBAUD")
    GM_PER_M = URIRef("http://qudt.org/vocab/unit/GM-PER-M")
    LB_PER_M3 = URIRef("http://qudt.org/vocab/unit/LB-PER-M3")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    MilliRAD_R = URIRef("http://qudt.org/vocab/unit/MilliRAD_R")
    MicroSEC = URIRef("http://qudt.org/vocab/unit/MicroSEC")
    MilliARCSEC = URIRef("http://qudt.org/vocab/unit/MilliARCSEC")
    ONE = URIRef("http://qudt.org/vocab/unit/ONE")
    OZ_SEC_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-FT3")
    KiloGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY")
    GM_PER_L_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-L-MilliPA-SEC")
    BTU_IT_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-HR-DEG_F")
    PlanckPressure = URIRef("http://qudt.org/vocab/unit/PlanckPressure")
    M2_PER_SR = URIRef("http://qudt.org/vocab/unit/M2-PER-SR")
    W_SEC = URIRef("http://qudt.org/vocab/unit/W-SEC")
    MilliJ = URIRef("http://qudt.org/vocab/unit/MilliJ")
    EV_PER_T = URIRef("http://qudt.org/vocab/unit/EV-PER-T")
    PA_M0dot5 = URIRef("http://qudt.org/vocab/unit/PA-M0dot5")
    M3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC2")
    J_PER_MIN = URIRef("http://qudt.org/vocab/unit/J-PER-MIN")
    MilliW_PER_CentiM2_MicroM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-CentiM2-MicroM-SR")
    MI2 = URIRef("http://qudt.org/vocab/unit/MI2")
    MicroGM_PER_CentiM2_WK = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2-WK")
    MilliGM_PER_L_POISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-POISE")
    FT_HR_PER_IN3 = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-IN3")
    GM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-M2-DAY")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    MACH = URIRef("http://qudt.org/vocab/unit/MACH")
    GM_MIN_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L-M3")
    DEG_C_CentiM = URIRef("http://qudt.org/vocab/unit/DEG_C-CentiM")
    Z = URIRef("http://qudt.org/vocab/unit/Z")
    GigaC = URIRef("http://qudt.org/vocab/unit/GigaC")
    BU_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-HR")
    SEC_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-FT2")
    L = URIRef("http://qudt.org/vocab/unit/L")
    PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PER-KiloGM")
    MilliL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-MIN")
    IN_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-DEG_F")
    OZ_VOL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-HR")
    J_SEC_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-SEC-PER-MOL")
    H_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/H-PER-KiloOHM")
    BTU_IT_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB")
    NanoMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL")
    MicroMHO = URIRef("http://qudt.org/vocab/unit/MicroMHO")
    Hundredweight_UK = URIRef("http://qudt.org/vocab/unit/Hundredweight_UK")
    BBL_US_DRY = URIRef("http://qudt.org/vocab/unit/BBL_US_DRY")
    CAL_TH_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM2-K")
    PetaJ = URIRef("http://qudt.org/vocab/unit/PetaJ")
    MegaBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaBTU_IT-PER-HR")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    KiloCAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-MIN")
    MOL_LB_PER_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-LB")
    CAL_TH_PER_G = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-G")
    MilliL_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-BAR")
    FemtoGM = URIRef("http://qudt.org/vocab/unit/FemtoGM")
    GM_PER_M = URIRef("http://qudt.org/vocab/unit/GM-PER-M")
    MilliGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-K")
    ARE = URIRef("http://qudt.org/vocab/unit/ARE")
    FemtoC = URIRef("http://qudt.org/vocab/unit/FemtoC")
    LB_HR_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-GAL_UK")
    N_M2_PER_A = URIRef("http://qudt.org/vocab/unit/N-M2-PER-A")
    MicroFARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-KiloM")
    PDL_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-FT2")
    KiloBTU_TH = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH")
    CAL_TH_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2-MIN")
    MilliL_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY")
    H = URIRef("http://qudt.org/vocab/unit/H")
    KiloN_M = URIRef("http://qudt.org/vocab/unit/KiloN-M")
    CAL_20DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_20DEG_C")
    BTU_TH_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-SEC-DEG_F")
    BAR_PER_K = URIRef("http://qudt.org/vocab/unit/BAR-PER-K")
    V_PER_L_MIN = URIRef("http://qudt.org/vocab/unit/V-PER-L-MIN")
    NTU = URIRef("http://qudt.org/vocab/unit/NTU")
    GM_PER_MOL = URIRef("http://qudt.org/vocab/unit/GM-PER-MOL")
    SEC_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-FT2")
    BTU_TH_FT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-HR-FT2-DEG_F")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    K = URIRef("http://qudt.org/vocab/unit/K")
    GAL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-SEC")
    L_PER_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-BAR")
    LB_PER_FT3 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3")
    BTU_IT_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT-PER-FT2-HR-DEG_F")
    DeciN_M = URIRef("http://qudt.org/vocab/unit/DeciN-M")
    KiloBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBYTE-PER-SEC")
    TON_Metric_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR-BAR")
    MicroG = URIRef("http://qudt.org/vocab/unit/MicroG")
    IN3_PER_HR = URIRef("http://qudt.org/vocab/unit/IN3-PER-HR")
    NanoH = URIRef("http://qudt.org/vocab/unit/NanoH")
    H = URIRef("http://qudt.org/vocab/unit/H")
    A_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-PER-CentiM2")
    LB_F_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN")
    MegaPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-L-PER-SEC")
    N_PER_C = URIRef("http://qudt.org/vocab/unit/N-PER-C")
    KiloPA_A = URIRef("http://qudt.org/vocab/unit/KiloPA_A")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    BTU_IT_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC-DEG_F")
    A_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/A-PER-KiloGM")
    LB_F_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-IN2")
    GigaPA_CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/GigaPA-CentiM3-PER-GM")
    NanoMOL_PER_CentiM3_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-CentiM3-HR")
    IN_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC2")
    MilliGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-K")
    HectoPA_PER_HR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-HR")
    J_PER_GM_K = URIRef("http://qudt.org/vocab/unit/J-PER-GM-K")
    MicroN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroN-M-PER-M2")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    KiloGM_PER_M_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-HR")
    KiloGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN")
    IN4 = URIRef("http://qudt.org/vocab/unit/IN4")
    NanoT = URIRef("http://qudt.org/vocab/unit/NanoT")
    J_PER_SEC = URIRef("http://qudt.org/vocab/unit/J-PER-SEC")
    FT_HR_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-GAL_US")
    MicroS_PER_M = URIRef("http://qudt.org/vocab/unit/MicroS-PER-M")
    DeciC = URIRef("http://qudt.org/vocab/unit/DeciC")
    A_PER_K = URIRef("http://qudt.org/vocab/unit/A-PER-K")
    MicroMOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-SEC")
    MicroPA = URIRef("http://qudt.org/vocab/unit/MicroPA")
    CD_PER_IN2 = URIRef("http://qudt.org/vocab/unit/CD-PER-IN2")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    MilliJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-M2")
    DeciB_MilliW = URIRef("http://qudt.org/vocab/unit/DeciB-MilliW")
    PER_YD3 = URIRef("http://qudt.org/vocab/unit/PER-YD3")
    W_PER_M2_PA = URIRef("http://qudt.org/vocab/unit/W-PER-M2-PA")
    MicroT = URIRef("http://qudt.org/vocab/unit/MicroT")
    TON_Metric_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN-K")
    KiloBQ = URIRef("http://qudt.org/vocab/unit/KiloBQ")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    BTU_IT_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT3")
    L_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-K")
    FT_H2O_39dot2DEG_F = URIRef("http://qudt.org/vocab/unit/FT_H2O_39dot2DEG_F")
    KAT_PER_M3 = URIRef("http://qudt.org/vocab/unit/KAT-PER-M3")
    SLUG_PER_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-SEC")
    MI2 = URIRef("http://qudt.org/vocab/unit/MI2")
    KiloBTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-FT2")
    FT3_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT3-PER-DAY")
    KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    MIN_Angle = URIRef("http://qudt.org/vocab/unit/MIN_Angle")
    MO_MeanGREGORIAN = URIRef("http://qudt.org/vocab/unit/MO_MeanGREGORIAN")
    KiloGM_PER_M_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC2")
    J_PER_M = URIRef("http://qudt.org/vocab/unit/J-PER-M")
    CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM-SEC-DEG_C")
    KiloHZ_M = URIRef("http://qudt.org/vocab/unit/KiloHZ-M")
    M_KiloGM = URIRef("http://qudt.org/vocab/unit/M-KiloGM")
    PERCENT_PER_DektoKiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DektoKiloCount")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    AMU = URIRef("http://qudt.org/vocab/unit/AMU")
    MicroGRAY = URIRef("http://qudt.org/vocab/unit/MicroGRAY")
    KiloMOL_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3-K")
    CentiM3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL-SEC")
    LB_SEC_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-GAL_UK")
    PA_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-PER-BAR")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    NanoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L")
    YD3_PER_PSI = URIRef("http://qudt.org/vocab/unit/YD3-PER-PSI")
    MilliARCSEC = URIRef("http://qudt.org/vocab/unit/MilliARCSEC")
    MilliGM_SEC_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M3-CentiM3")
    DEG_C_PER_YR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-YR")
    YottaC = URIRef("http://qudt.org/vocab/unit/YottaC")
    L_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-BAR")
    MicroV_A = URIRef("http://qudt.org/vocab/unit/MicroV-A")
    NanoSV_PER_HR = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-HR")
    PicoGM = URIRef("http://qudt.org/vocab/unit/PicoGM")
    KiloN_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M3")
    YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD3-PER-SEC")
    CARAT = URIRef("http://qudt.org/vocab/unit/CARAT")
    ARCSEC = URIRef("http://qudt.org/vocab/unit/ARCSEC")
    LB_MIN_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-YD3")
    C_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-CentiM2")
    NanoS_PER_M = URIRef("http://qudt.org/vocab/unit/NanoS-PER-M")
    MHO = URIRef("http://qudt.org/vocab/unit/MHO")
    SV_PER_SEC = URIRef("http://qudt.org/vocab/unit/SV-PER-SEC")
    MilliA_HR_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliA-HR-PER-GM")
    GM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3")
    KiloPA_M2_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloPA-M2-PER-GM")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    A_PER_RAD = URIRef("http://qudt.org/vocab/unit/A-PER-RAD")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    BYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/BYTE-PER-SEC")
    DeciGM = URIRef("http://qudt.org/vocab/unit/DeciGM")
    DEATHS_PER_1000000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000000I-YR")
    W_M2_PER_SR = URIRef("http://qudt.org/vocab/unit/W-M2-PER-SR")
    MilliL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliL-PER-L")
    MegaA = URIRef("http://qudt.org/vocab/unit/MegaA")
    MegaC = URIRef("http://qudt.org/vocab/unit/MegaC")
    CARAT = URIRef("http://qudt.org/vocab/unit/CARAT")
    OZ_FT_SEC_PER_IN3_LB = URIRef("http://qudt.org/vocab/unit/OZ-FT-SEC-PER-IN3-LB")
    FemtoC = URIRef("http://qudt.org/vocab/unit/FemtoC")
    J = URIRef("http://qudt.org/vocab/unit/J")
    MicroCi = URIRef("http://qudt.org/vocab/unit/MicroCi")
    M2_HR_DEG_C_PER_KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/M2-HR-DEG_C-PER-KiloCAL_IT")
    GI_UK = URIRef("http://qudt.org/vocab/unit/GI_UK")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    MilliM2 = URIRef("http://qudt.org/vocab/unit/MilliM2")
    DEG_F_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-K")
    A_PER_A_HR = URIRef("http://qudt.org/vocab/unit/A-PER-A-HR")
    KiloV_A = URIRef("http://qudt.org/vocab/unit/KiloV-A")
    K_PER_BAR = URIRef("http://qudt.org/vocab/unit/K-PER-BAR")
    MicroM = URIRef("http://qudt.org/vocab/unit/MicroM")
    MilliPA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-BAR")
    M2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2")
    FRACTION = URIRef("http://qudt.org/vocab/unit/FRACTION")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    PA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M3-PER-SEC")
    SolarMass = URIRef("http://qudt.org/vocab/unit/SolarMass")
    PER_PlanckMass2 = URIRef("http://qudt.org/vocab/unit/PER-PlanckMass2")
    PlanckMass = URIRef("http://qudt.org/vocab/unit/PlanckMass")
    BU_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-MIN")
    H_Stat = URIRef("http://qudt.org/vocab/unit/H_Stat")
    N_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    KiloV_A = URIRef("http://qudt.org/vocab/unit/KiloV-A")
    T_M = URIRef("http://qudt.org/vocab/unit/T-M")
    M_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-V-SEC")
    CentiM2_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-CentiM3")
    MegaEV_FemtoM = URIRef("http://qudt.org/vocab/unit/MegaEV-FemtoM")
    DEGREE_PLATO = URIRef("http://qudt.org/vocab/unit/DEGREE_PLATO")
    RAD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC2")
    PER_SEC_SR_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR-M2")
    GM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-M2-DAY")
    PERCENT_PER_M = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-M")
    PlanckCurrentDensity = URIRef("http://qudt.org/vocab/unit/PlanckCurrentDensity")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    BTU_IT_IN_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-SEC-FT2-DEG_F")
    MilliPA_SEC_PER_K = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-K")
    TON_Metric_PER_M3 = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3")
    KiloWB = URIRef("http://qudt.org/vocab/unit/KiloWB")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    LB_HR_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-GAL_UK")
    PPQ = URIRef("http://qudt.org/vocab/unit/PPQ")
    MegaPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-L-PER-SEC")
    OZ_SEC_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-YD3")
    KiloN_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M")
    MilliBQ = URIRef("http://qudt.org/vocab/unit/MilliBQ")
    HectoPA_PER_HR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-HR")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    MegaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBYTE-PER-SEC")
    K_PER_K = URIRef("http://qudt.org/vocab/unit/K-PER-K")
    MegaFLOPS = URIRef("http://qudt.org/vocab/unit/MegaFLOPS")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    DEG_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG-PER-HR")
    GAL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-HR")
    BTU_IT_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC-DEG_F")
    OZ_FT_SEC_PER_IN3_LB = URIRef("http://qudt.org/vocab/unit/OZ-FT-SEC-PER-IN3-LB")
    HectoM = URIRef("http://qudt.org/vocab/unit/HectoM")
    W_PER_M2_K4 = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K4")
    MOHM = URIRef("http://qudt.org/vocab/unit/MOHM")
    PERM_23DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_23DEG_C")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    AMU = URIRef("http://qudt.org/vocab/unit/AMU")
    N_M_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-M")
    V_PER_MicroSEC = URIRef("http://qudt.org/vocab/unit/V-PER-MicroSEC")
    V_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Ab-PER-CentiM")
    DYN_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM")
    MicroM_PER_K = URIRef("http://qudt.org/vocab/unit/MicroM-PER-K")
    HA = URIRef("http://qudt.org/vocab/unit/HA")
    KiloN = URIRef("http://qudt.org/vocab/unit/KiloN")
    C4_M4_PER_J3 = URIRef("http://qudt.org/vocab/unit/C4-M4-PER-J3")
    KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A-HR")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    M_PER_YR = URIRef("http://qudt.org/vocab/unit/M-PER-YR")
    PA_PER_MIN = URIRef("http://qudt.org/vocab/unit/PA-PER-MIN")
    T_M = URIRef("http://qudt.org/vocab/unit/T-M")
    NanoOHM_M = URIRef("http://qudt.org/vocab/unit/NanoOHM-M")
    MilliN_M = URIRef("http://qudt.org/vocab/unit/MilliN-M")
    K_PER_BAR = URIRef("http://qudt.org/vocab/unit/K-PER-BAR")
    W_PER_FT2 = URIRef("http://qudt.org/vocab/unit/W-PER-FT2")
    KiloGM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-CentiM2")
    V_PER_PA = URIRef("http://qudt.org/vocab/unit/V-PER-PA")
    A_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-M3")
    LB_PER_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-PSI")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    LB_MIN_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK2")
    PER_DEG_C = URIRef("http://qudt.org/vocab/unit/PER-DEG_C")
    LB_PER_FT3_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3-PSI")
    LB_M = URIRef("http://qudt.org/vocab/unit/LB_M")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    THERM_US = URIRef("http://qudt.org/vocab/unit/THERM_US")
    C = URIRef("http://qudt.org/vocab/unit/C")
    MilliL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliL-PER-L")
    BTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR")
    V_PER_V = URIRef("http://qudt.org/vocab/unit/V-PER-V")
    PER_M_SEC = URIRef("http://qudt.org/vocab/unit/PER-M-SEC")
    GM_MilliM = URIRef("http://qudt.org/vocab/unit/GM-MilliM")
    GM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-BAR")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    GM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3")
    KiloGAUSS = URIRef("http://qudt.org/vocab/unit/KiloGAUSS")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    MilliDEG_C = URIRef("http://qudt.org/vocab/unit/MilliDEG_C")
    ExaBIT_PER_M = URIRef("http://qudt.org/vocab/unit/ExaBIT-PER-M")
    KN = URIRef("http://qudt.org/vocab/unit/KN")
    GigaC = URIRef("http://qudt.org/vocab/unit/GigaC")
    M3_PER_DAY = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY")
    KiloBTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH-PER-HR")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    PetaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/PetaBIT-PER-SEC")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    N_M_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-M")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    NanoGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DAY")
    T_M = URIRef("http://qudt.org/vocab/unit/T-M")
    MilliL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliL-PER-L")
    DEATHS_PER_1000000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000000I-YR")
    IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC")
    B = URIRef("http://qudt.org/vocab/unit/B")
    NanoW = URIRef("http://qudt.org/vocab/unit/NanoW")
    MilliGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC")
    WK = URIRef("http://qudt.org/vocab/unit/WK")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    LB_PER_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-HR")
    KiloCAL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-SEC")
    GM_PER_L = URIRef("http://qudt.org/vocab/unit/GM-PER-L")
    PER_OZ = URIRef("http://qudt.org/vocab/unit/PER-OZ")
    MilliRAD = URIRef("http://qudt.org/vocab/unit/MilliRAD")
    DEG_C_CentiM = URIRef("http://qudt.org/vocab/unit/DEG_C-CentiM")
    GRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/GRAY-PER-SEC")
    MESH = URIRef("http://qudt.org/vocab/unit/MESH")
    CASES_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-1000I-YR")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    PER_M_SEC = URIRef("http://qudt.org/vocab/unit/PER-M-SEC")
    MOL_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-K")
    PicoPA = URIRef("http://qudt.org/vocab/unit/PicoPA")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    BIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BIT-PER-SEC")
    PERCENT_HR_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-YD3")
    KiloR = URIRef("http://qudt.org/vocab/unit/KiloR")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    MicroMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-KiloGM")
    MilliN_PER_M = URIRef("http://qudt.org/vocab/unit/MilliN-PER-M")
    DeciB_W = URIRef("http://qudt.org/vocab/unit/DeciB-W")
    FT2_HR_DEG_F_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F-PER-BTU_IT")
    LB_PER_IN3_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3-PSI")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    CAL_TH_PER_G = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-G")
    DeciM2 = URIRef("http://qudt.org/vocab/unit/DeciM2")
    NanoGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-HR")
    J_PER_M = URIRef("http://qudt.org/vocab/unit/J-PER-M")
    PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PER-CentiM3")
    MilliPA = URIRef("http://qudt.org/vocab/unit/MilliPA")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    OZ_VOL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-DAY")
    MilliMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-GM")
    OZ_VOL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-DAY")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    KiloP = URIRef("http://qudt.org/vocab/unit/KiloP")
    L_PER_HR = URIRef("http://qudt.org/vocab/unit/L-PER-HR")
    OZ_SEC_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-FT3")
    FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-SEC")
    KiloBQ = URIRef("http://qudt.org/vocab/unit/KiloBQ")
    LB_F = URIRef("http://qudt.org/vocab/unit/LB_F")
    PINT_US = URIRef("http://qudt.org/vocab/unit/PINT_US")
    SH = URIRef("http://qudt.org/vocab/unit/SH")
    KiloTON_Metric = URIRef("http://qudt.org/vocab/unit/KiloTON_Metric")
    EUR_PER_KiloW_HR = URIRef("http://qudt.org/vocab/unit/EUR-PER-KiloW-HR")
    C_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM2")
    NanoM = URIRef("http://qudt.org/vocab/unit/NanoM")
    HectoPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-M3-PER-SEC")
    KiloGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-SEC")
    LB_PER_FT_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-DAY")
    DecaC = URIRef("http://qudt.org/vocab/unit/DecaC")
    V_PER_IN = URIRef("http://qudt.org/vocab/unit/V-PER-IN")
    MegaBQ = URIRef("http://qudt.org/vocab/unit/MegaBQ")
    RAD_PER_MIN = URIRef("http://qudt.org/vocab/unit/RAD-PER-MIN")
    BTU_TH_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_R")
    GI_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_US-PER-MIN")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    PER_T_M = URIRef("http://qudt.org/vocab/unit/PER-T-M")
    MOL_PER_M3_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-PA")
    CentiPOISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-BAR")
    J_SEC_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-SEC-PER-MOL")
    AWG = URIRef("http://qudt.org/vocab/unit/AWG")
    MOL_PER_L_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-L-K")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    OZ_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ-PER-MIN")
    BEAT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BEAT-PER-MIN")
    IN3_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN3-PER-MIN")
    KiloOHM_M = URIRef("http://qudt.org/vocab/unit/KiloOHM-M")
    PicoMOL = URIRef("http://qudt.org/vocab/unit/PicoMOL")
    MilliCi = URIRef("http://qudt.org/vocab/unit/MilliCi")
    MilliGM_MIN_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M3-CentiM3")
    MicroS_PER_M = URIRef("http://qudt.org/vocab/unit/MicroS-PER-M")
    TON_US_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_US-PER-YD3")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    TONNE_PER_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-BAR")
    GAL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-DAY")
    PER_BAR = URIRef("http://qudt.org/vocab/unit/PER-BAR")
    MOL_LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-MIN")
    ERG_PER_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-SEC")
    PT = URIRef("http://qudt.org/vocab/unit/PT")
    KiloC_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M2")
    EV_M2 = URIRef("http://qudt.org/vocab/unit/EV-M2")
    ExaW = URIRef("http://qudt.org/vocab/unit/ExaW")
    BARYE = URIRef("http://qudt.org/vocab/unit/BARYE")
    CAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-MIN")
    SLUG_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT-SEC")
    MilliC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M2")
    N_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG")
    MilliW_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-MilliGM")
    M2_HZ = URIRef("http://qudt.org/vocab/unit/M2-HZ")
    DecaPA = URIRef("http://qudt.org/vocab/unit/DecaPA")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    KiloBTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-FT2")
    GRAIN = URIRef("http://qudt.org/vocab/unit/GRAIN")
    DRAM_US = URIRef("http://qudt.org/vocab/unit/DRAM_US")
    LUX_SEC = URIRef("http://qudt.org/vocab/unit/LUX-SEC")
    NanoH = URIRef("http://qudt.org/vocab/unit/NanoH")
    KiloWB_PER_M = URIRef("http://qudt.org/vocab/unit/KiloWB-PER-M")
    TON_US_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_US-PER-HR")
    NAT_PER_SEC = URIRef("http://qudt.org/vocab/unit/NAT-PER-SEC")
    PicoA_PER_MicroMOL_L = URIRef("http://qudt.org/vocab/unit/PicoA-PER-MicroMOL-L")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    J_PER_KiloGM_K_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-M3")
    GM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-M2-DAY")
    K = URIRef("http://qudt.org/vocab/unit/K")
    BU_UK = URIRef("http://qudt.org/vocab/unit/BU_UK")
    K_M_PER_W = URIRef("http://qudt.org/vocab/unit/K-M-PER-W")
    CAL_TH_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM")
    CARAT = URIRef("http://qudt.org/vocab/unit/CARAT")
    GigaV_A_Reactive = URIRef("http://qudt.org/vocab/unit/GigaV-A_Reactive")
    MilliA = URIRef("http://qudt.org/vocab/unit/MilliA")
    KiloN_M_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-M")
    FARAD_Ab = URIRef("http://qudt.org/vocab/unit/FARAD_Ab")
    KiloGM_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-BAR")
    B = URIRef("http://qudt.org/vocab/unit/B")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    MI_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI-PER-MIN")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    MOL_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-K")
    failures_in_time = URIRef("http://qudt.org/vocab/unit/failures-in-time")
    NUM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/NUM-PER-KiloM2")
    BTU_IT_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_R")
    BTU_IT_PER_FT2_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR")
    AC_FT_US = URIRef("http://qudt.org/vocab/unit/AC-FT_US")
    MI_N = URIRef("http://qudt.org/vocab/unit/MI_N")
    CUP_US = URIRef("http://qudt.org/vocab/unit/CUP_US")
    MicroN = URIRef("http://qudt.org/vocab/unit/MicroN")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    PER_SEC_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR")
    AT_PER_M = URIRef("http://qudt.org/vocab/unit/AT-PER-M")
    HART_PER_SEC = URIRef("http://qudt.org/vocab/unit/HART-PER-SEC")
    M2_PER_N = URIRef("http://qudt.org/vocab/unit/M2-PER-N")
    TONNE_PER_HA = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA")
    MilliM3 = URIRef("http://qudt.org/vocab/unit/MilliM3")
    NanoOHM_M = URIRef("http://qudt.org/vocab/unit/NanoOHM-M")
    L_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/L-PER-KiloGM")
    MilliGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DeciL")
    MicroMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-KiloGM")
    ZeptoC = URIRef("http://qudt.org/vocab/unit/ZeptoC")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    MegaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBIT-PER-SEC")
    W_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-PER-KiloGM")
    DEG_C_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-SEC")
    GM_PER_M3_POISE = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-POISE")
    PFERDESTAERKE = URIRef("http://qudt.org/vocab/unit/PFERDESTAERKE")
    TON_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-DAY")
    GigaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBYTE-PER-SEC")
    DEG_F_HR_FT2_PER_BTU_TH_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH-IN")
    LB_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-DEG_F")
    LB_HR_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT6")
    MilliC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliC-PER-KiloGM")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    V_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Ab-PER-CentiM")
    CentiM = URIRef("http://qudt.org/vocab/unit/CentiM")
    MilliL_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY")
    BARN = URIRef("http://qudt.org/vocab/unit/BARN")
    RHE = URIRef("http://qudt.org/vocab/unit/RHE")
    RAD_PER_MIN = URIRef("http://qudt.org/vocab/unit/RAD-PER-MIN")
    BAR = URIRef("http://qudt.org/vocab/unit/BAR")
    H = URIRef("http://qudt.org/vocab/unit/H")
    MilliBAR = URIRef("http://qudt.org/vocab/unit/MilliBAR")
    KiloGM_PER_J = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-J")
    PPTM_PER_K = URIRef("http://qudt.org/vocab/unit/PPTM-PER-K")
    PA_SEC_PER_L = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-L")
    BBL_US = URIRef("http://qudt.org/vocab/unit/BBL_US")
    MilliV = URIRef("http://qudt.org/vocab/unit/MilliV")
    KiloGM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-FT2")
    STR = URIRef("http://qudt.org/vocab/unit/STR")
    PERCENT_FT2_PER_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-FT2-PER-LB_F-SEC")
    KiloM = URIRef("http://qudt.org/vocab/unit/KiloM")
    BARN_PER_EV = URIRef("http://qudt.org/vocab/unit/BARN-PER-EV")
    BAN = URIRef("http://qudt.org/vocab/unit/BAN")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    LB_PER_LB = URIRef("http://qudt.org/vocab/unit/LB-PER-LB")
    CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-GM")
    PER_CentiM = URIRef("http://qudt.org/vocab/unit/PER-CentiM")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    MilliWB = URIRef("http://qudt.org/vocab/unit/MilliWB")
    PA_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M")
    PER_M_NanoM = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM")
    BTU_IT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC")
    CentiM3_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR-BAR")
    K_PER_W = URIRef("http://qudt.org/vocab/unit/K-PER-W")
    MilliGM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR")
    DRAM_US = URIRef("http://qudt.org/vocab/unit/DRAM_US")
    BTU_IT_PER_LB_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F")
    GAL_UK = URIRef("http://qudt.org/vocab/unit/GAL_UK")
    J_PER_HR = URIRef("http://qudt.org/vocab/unit/J-PER-HR")
    BARAD = URIRef("http://qudt.org/vocab/unit/BARAD")
    KiloGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-K")
    LB_F_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-FT2")
    MilliRAD_R_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliRAD_R-PER-HR")
    GM_MilliM = URIRef("http://qudt.org/vocab/unit/GM-MilliM")
    MilliM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC")
    MegaHZ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-K")
    N_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-PER-RAD")
    KiloCAL_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM-SEC-DEG_C")
    OZ_PER_IN2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN2")
    CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-GM")
    H_Stat = URIRef("http://qudt.org/vocab/unit/H_Stat")
    PicoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-KiloGM")
    MI_US = URIRef("http://qudt.org/vocab/unit/MI_US")
    LB_F_FT = URIRef("http://qudt.org/vocab/unit/LB_F-FT")
    BAN = URIRef("http://qudt.org/vocab/unit/BAN")
    C_M2 = URIRef("http://qudt.org/vocab/unit/C-M2")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    KiloGM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3")
    M_K = URIRef("http://qudt.org/vocab/unit/M-K")
    MilliGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-GM")
    MI2 = URIRef("http://qudt.org/vocab/unit/MI2")
    M3_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-K")
    W_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-PER-M3")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    PINT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-SEC")
    MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/MOL-DEG_C")
    ERG = URIRef("http://qudt.org/vocab/unit/ERG")
    IN_PDL = URIRef("http://qudt.org/vocab/unit/IN-PDL")
    LB_PER_FT_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-HR")
    unit = URIRef("http://qudt.org/vocab/unit")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PER-M3-SEC")
    BTU_IT_PER_LB_MOL = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-MOL")
    KiloJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM")
    MilliGM_MIN_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M3-CentiM3")
    KiloGM_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-PA")
    ERG_PER_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-SEC")
    ERG_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM2-SEC")
    PERCENT_PER_DEG = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEG")
    PetaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/PetaBIT-PER-SEC")
    ERLANG = URIRef("http://qudt.org/vocab/unit/ERLANG")
    M3_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-M2")
    MegaBQ = URIRef("http://qudt.org/vocab/unit/MegaBQ")
    KiloCAL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-SEC")
    TebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M")
    DeciM2 = URIRef("http://qudt.org/vocab/unit/DeciM2")
    YD3_PER_HR = URIRef("http://qudt.org/vocab/unit/YD3-PER-HR")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-SEC")
    M2_HZ = URIRef("http://qudt.org/vocab/unit/M2-HZ")
    NanoSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-SEC")
    CentiST = URIRef("http://qudt.org/vocab/unit/CentiST")
    CWT_LONG = URIRef("http://qudt.org/vocab/unit/CWT_LONG")
    LB = URIRef("http://qudt.org/vocab/unit/LB")
    RAD_PER_HR = URIRef("http://qudt.org/vocab/unit/RAD-PER-HR")
    DEG_F_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-HR")
    MicroRAD = URIRef("http://qudt.org/vocab/unit/MicroRAD")
    C3_M_PER_J2 = URIRef("http://qudt.org/vocab/unit/C3-M-PER-J2")
    MilliGAL = URIRef("http://qudt.org/vocab/unit/MilliGAL")
    ZettaC = URIRef("http://qudt.org/vocab/unit/ZettaC")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    PERCENT_MIN_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-GAL_UK")
    FemtoGM = URIRef("http://qudt.org/vocab/unit/FemtoGM")
    M2_PER_M2 = URIRef("http://qudt.org/vocab/unit/M2-PER-M2")
    B = URIRef("http://qudt.org/vocab/unit/B")
    B = URIRef("http://qudt.org/vocab/unit/B")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    V_Ab_SEC = URIRef("http://qudt.org/vocab/unit/V_Ab-SEC")
    F = URIRef("http://qudt.org/vocab/unit/F")
    C_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-M2-PER-KiloGM")
    PINT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-SEC")
    GM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3")
    DEG_F_HR_FT2_PER_BTU_TH_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH-IN")
    TONNE_PER_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-BAR")
    MicroV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MicroV-A_Reactive")
    MegaN_M = URIRef("http://qudt.org/vocab/unit/MegaN-M")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    M3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-K")
    PER_K = URIRef("http://qudt.org/vocab/unit/PER-K")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    LB_MIN_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-GAL_US")
    PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/PER-M2-SEC")
    PER_WK = URIRef("http://qudt.org/vocab/unit/PER-WK")
    MicroGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    MicroL = URIRef("http://qudt.org/vocab/unit/MicroL")
    LB_PER_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-HR")
    PlanckCharge = URIRef("http://qudt.org/vocab/unit/PlanckCharge")
    KiloPA = URIRef("http://qudt.org/vocab/unit/KiloPA")
    FT = URIRef("http://qudt.org/vocab/unit/FT")
    OZ_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_US")
    GigaPA_CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/GigaPA-CentiM3-PER-GM")
    CentiL = URIRef("http://qudt.org/vocab/unit/CentiL")
    BTU_TH_FT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-HR-FT2-DEG_F")
    LB_SEC_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-IN3")
    SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-PER-FT2")
    OERSTED_CentiM = URIRef("http://qudt.org/vocab/unit/OERSTED-CentiM")
    N_PER_C = URIRef("http://qudt.org/vocab/unit/N-PER-C")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    KiloEV_PER_MicroM = URIRef("http://qudt.org/vocab/unit/KiloEV-PER-MicroM")
    DeciL_PER_GM = URIRef("http://qudt.org/vocab/unit/DeciL-PER-GM")
    KiloJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    GM_HR_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M6")
    MicroS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MicroS-PER-CentiM")
    IN_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC-PSI")
    FBM = URIRef("http://qudt.org/vocab/unit/FBM")
    K_PER_HR = URIRef("http://qudt.org/vocab/unit/K-PER-HR")
    BTU_IT_PER_FT2_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR")
    A = URIRef("http://qudt.org/vocab/unit/A")
    ERG_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM")
    MicroGM_PER_L = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L")
    PicoS_PER_M = URIRef("http://qudt.org/vocab/unit/PicoS-PER-M")
    MicroM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-M3")
    FT_LB_F = URIRef("http://qudt.org/vocab/unit/FT-LB_F")
    KiloGM_PER_M_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC")
    KiloA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloA-PER-K")
    KiloW = URIRef("http://qudt.org/vocab/unit/KiloW")
    LB_IN2 = URIRef("http://qudt.org/vocab/unit/LB-IN2")
    PK_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-DAY")
    PlanckCurrent = URIRef("http://qudt.org/vocab/unit/PlanckCurrent")
    TON_SHORT_PER_HR_PSI = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR-PSI")
    CentiM_H2O = URIRef("http://qudt.org/vocab/unit/CentiM_H2O")
    MilliWB = URIRef("http://qudt.org/vocab/unit/MilliWB")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    CentiM3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-K")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    TeraJ = URIRef("http://qudt.org/vocab/unit/TeraJ")
    DEG_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-MIN")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    DYN_SEC_PER_CentiM5 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM5")
    BTU_TH = URIRef("http://qudt.org/vocab/unit/BTU_TH")
    MilliMOL_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3-DAY")
    KiloPA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-M")
    GI_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-HR")
    KiloGM_F_M = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M")
    GM_PER_M3_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-MilliPA-SEC")
    K_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PER-SEC")
    MilliGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3")
    FT2_PER_HR = URIRef("http://qudt.org/vocab/unit/FT2-PER-HR")
    W_M2 = URIRef("http://qudt.org/vocab/unit/W-M2")
    T = URIRef("http://qudt.org/vocab/unit/T")
    MOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-SEC")
    GM_PER_CentiM_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM-SEC")
    W_PER_FT2 = URIRef("http://qudt.org/vocab/unit/W-PER-FT2")
    PER_L = URIRef("http://qudt.org/vocab/unit/PER-L")
    GM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR-BAR")
    FRACTION = URIRef("http://qudt.org/vocab/unit/FRACTION")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    MilliA_PER_L_MIN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-L-MIN")
    PA2_SEC = URIRef("http://qudt.org/vocab/unit/PA2-SEC")
    KiloWB_PER_M = URIRef("http://qudt.org/vocab/unit/KiloWB-PER-M")
    KiloBD = URIRef("http://qudt.org/vocab/unit/KiloBD")
    MegaJ_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M3")
    CUP_US = URIRef("http://qudt.org/vocab/unit/CUP_US")
    PK_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-DAY")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    MilliC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M2")
    KiloBQ = URIRef("http://qudt.org/vocab/unit/KiloBQ")
    CAL_TH_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2-SEC")
    RAD_R = URIRef("http://qudt.org/vocab/unit/RAD_R")
    NanoC = URIRef("http://qudt.org/vocab/unit/NanoC")
    TON_Metric_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN-K")
    KiloCAL_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2")
    BTU_IT_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_F")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    MegaEV_FemtoM = URIRef("http://qudt.org/vocab/unit/MegaEV-FemtoM")
    N_PER_CentiM = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM")
    BAR_PER_K = URIRef("http://qudt.org/vocab/unit/BAR-PER-K")
    V_PER_SEC = URIRef("http://qudt.org/vocab/unit/V-PER-SEC")
    MO_Synodic = URIRef("http://qudt.org/vocab/unit/MO_Synodic")
    ERG_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM2-SEC")
    PicoV = URIRef("http://qudt.org/vocab/unit/PicoV")
    BU_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-HR")
    FT3_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN")
    CWT_LONG = URIRef("http://qudt.org/vocab/unit/CWT_LONG")
    MO_MeanGREGORIAN = URIRef("http://qudt.org/vocab/unit/MO_MeanGREGORIAN")
    BTU_TH_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-FT2-HR-DEG_F")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    FARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/FARAD-PER-KiloM")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    M3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-BAR")
    MegaPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-M3-PER-SEC")
    NUM_PER_YR = URIRef("http://qudt.org/vocab/unit/NUM-PER-YR")
    H_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/H-PER-KiloOHM")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    CentiM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SEC")
    MI_US = URIRef("http://qudt.org/vocab/unit/MI_US")
    BTU_TH_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2")
    KiloGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-BAR")
    M_PER_MIN = URIRef("http://qudt.org/vocab/unit/M-PER-MIN")
    L_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/L-PER-KiloGM")
    MicroN = URIRef("http://qudt.org/vocab/unit/MicroN")
    TONNE_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC-BAR")
    GM_PER_CentiM2_YR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2-YR")
    FT_LB_F_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-HR")
    MegaOHM_PER_K = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-K")
    MicroC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M2")
    MilliOHM_M = URIRef("http://qudt.org/vocab/unit/MilliOHM-M")
    NUM_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/NUM-PER-MilliGM")
    KiloGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-PA-SEC")
    KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT")
    GM_PER_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY")
    MegaHZ_PER_T = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-T")
    W_PER_M2_PA = URIRef("http://qudt.org/vocab/unit/W-PER-M2-PA")
    M2_PER_GM_DRY = URIRef("http://qudt.org/vocab/unit/M2-PER-GM_DRY")
    TON_Metric_PER_SEC = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC")
    MegaHZ_M = URIRef("http://qudt.org/vocab/unit/MegaHZ-M")
    PER_M2 = URIRef("http://qudt.org/vocab/unit/PER-M2")
    CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-GM")
    BBL_UK_PET_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-MIN")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    IN4 = URIRef("http://qudt.org/vocab/unit/IN4")
    MilliGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-KiloGM")
    TeraBIT = URIRef("http://qudt.org/vocab/unit/TeraBIT")
    M2_K = URIRef("http://qudt.org/vocab/unit/M2-K")
    KiloA_HR = URIRef("http://qudt.org/vocab/unit/KiloA-HR")
    GI = URIRef("http://qudt.org/vocab/unit/GI")
    TON_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-DAY")
    MicroN = URIRef("http://qudt.org/vocab/unit/MicroN")
    GM_PER_DeciM3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3-K")
    M2_PER_SEC2_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2-K")
    MHO = URIRef("http://qudt.org/vocab/unit/MHO")
    N_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-RAD")
    MOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-SEC")
    PicoFARAD = URIRef("http://qudt.org/vocab/unit/PicoFARAD")
    KiloEV_PER_MicroM = URIRef("http://qudt.org/vocab/unit/KiloEV-PER-MicroM")
    IN = URIRef("http://qudt.org/vocab/unit/IN")
    FT_LB_F_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2-SEC")
    BTU_IT_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_F")
    OZ_PER_FT2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-FT2")
    OZ_VOL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-MIN")
    GigaPA = URIRef("http://qudt.org/vocab/unit/GigaPA")
    MOL_LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-MIN")
    PER_SEC_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR")
    PicoA_PER_MicroMOL_L = URIRef("http://qudt.org/vocab/unit/PicoA-PER-MicroMOL-L")
    PERM_0DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_0DEG_C")
    KiloL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloL-PER-HR")
    J = URIRef("http://qudt.org/vocab/unit/J")
    MicroM2 = URIRef("http://qudt.org/vocab/unit/MicroM2")
    MilliBQ_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-M2-DAY")
    A_PER_MilliM = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM")
    L_PER_K = URIRef("http://qudt.org/vocab/unit/L-PER-K")
    M3_PER_HR_K = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-K")
    PERCENT_HR_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-GAL_UK")
    MilliBQ = URIRef("http://qudt.org/vocab/unit/MilliBQ")
    MOL_PER_M2_SEC_M = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-M")
    PPM = URIRef("http://qudt.org/vocab/unit/PPM")
    LB_MIN_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-GAL_US")
    OZ_FT_HR_PER_IN3_LB = URIRef("http://qudt.org/vocab/unit/OZ-FT-HR-PER-IN3-LB")
    PicoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/PicoFARAD-PER-M")
    MilliL = URIRef("http://qudt.org/vocab/unit/MilliL")
    V_PER_M2 = URIRef("http://qudt.org/vocab/unit/V-PER-M2")
    KiloLB_F_FT_PER_LB = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-LB")
    PERCENT_PER_HectoBAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-HectoBAR")
    DeciB_MilliW_PER_MegaHZ = URIRef("http://qudt.org/vocab/unit/DeciB-MilliW-PER-MegaHZ")
    BTU_IT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_F")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    C_M2_PER_V = URIRef("http://qudt.org/vocab/unit/C-M2-PER-V")
    PicoA = URIRef("http://qudt.org/vocab/unit/PicoA")
    TEX = URIRef("http://qudt.org/vocab/unit/TEX")
    DEG_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC")
    M2_PER_HA = URIRef("http://qudt.org/vocab/unit/M2-PER-HA")
    KiloBTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-FT2")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    W_HR = URIRef("http://qudt.org/vocab/unit/W-HR")
    MilliGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC")
    BTU_IT_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_R")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    NanoMOL_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L-DAY")
    TEX = URIRef("http://qudt.org/vocab/unit/TEX")
    UnitPole = URIRef("http://qudt.org/vocab/unit/UnitPole")
    MilliMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-KiloGM")
    MilliGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-K")
    LB_M = URIRef("http://qudt.org/vocab/unit/LB_M")
    KiloWB_PER_M = URIRef("http://qudt.org/vocab/unit/KiloWB-PER-M")
    V2_PER_K2 = URIRef("http://qudt.org/vocab/unit/V2-PER-K2")
    RichterMagnitude = URIRef("http://qudt.org/vocab/unit/RichterMagnitude")
    SUSCEPTIBILITY_ELEC = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_ELEC")
    PER_IN2 = URIRef("http://qudt.org/vocab/unit/PER-IN2")
    MilliBQ = URIRef("http://qudt.org/vocab/unit/MilliBQ")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    FARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/FARAD-PER-KiloM")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    MilliV = URIRef("http://qudt.org/vocab/unit/MilliV")
    GigaN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaN-M-PER-M2")
    GM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL")
    L_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-BAR")
    M3_PER_M3 = URIRef("http://qudt.org/vocab/unit/M3-PER-M3")
    DRAM_US = URIRef("http://qudt.org/vocab/unit/DRAM_US")
    GRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/GRAY-PER-HR")
    BTU_IT_PER_FT2_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR")
    K = URIRef("http://qudt.org/vocab/unit/K")
    MilliGM_MIN_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M6")
    FARAD_Stat = URIRef("http://qudt.org/vocab/unit/FARAD_Stat")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    NanoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-KiloGM")
    PERCENT_RH = URIRef("http://qudt.org/vocab/unit/PERCENT_RH")
    M_PER_BAR = URIRef("http://qudt.org/vocab/unit/M-PER-BAR")
    AttoJ = URIRef("http://qudt.org/vocab/unit/AttoJ")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    BTU_TH_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-SEC-DEG_F")
    CAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC")
    DeciM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MOL")
    MegaJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-KiloGM")
    ERG_PER_CentiM = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    BBL_US_DRY = URIRef("http://qudt.org/vocab/unit/BBL_US_DRY")
    NanoM_PER_CentiM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-MegaPA")
    BTU_IT = URIRef("http://qudt.org/vocab/unit/BTU_IT")
    PK_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-DAY")
    W_PER_M2_M_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M-SR")
    KN_PER_SEC = URIRef("http://qudt.org/vocab/unit/KN-PER-SEC")
    PlanckPower = URIRef("http://qudt.org/vocab/unit/PlanckPower")
    MilliOHM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-K")
    TON = URIRef("http://qudt.org/vocab/unit/TON")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    MOL_LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-SEC")
    PSI_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-M3-PER-SEC")
    MilliSV = URIRef("http://qudt.org/vocab/unit/MilliSV")
    GigaC = URIRef("http://qudt.org/vocab/unit/GigaC")
    DEG_C_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-K")
    KiloGM_F_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-SEC")
    MicroCi = URIRef("http://qudt.org/vocab/unit/MicroCi")
    LB_DEG_R = URIRef("http://qudt.org/vocab/unit/LB-DEG_R")
    BU_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-MIN")
    MilliGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3")
    KiloGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-BAR")
    FT_SEC_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-GAL_UK")
    MilliPA_PER_M = URIRef("http://qudt.org/vocab/unit/MilliPA-PER-M")
    CentiPOISE = URIRef("http://qudt.org/vocab/unit/CentiPOISE")
    FemtoL = URIRef("http://qudt.org/vocab/unit/FemtoL")
    W_PER_M2_K = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K")
    KiloGM_F_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-MilliM2")
    MegaPSI = URIRef("http://qudt.org/vocab/unit/MegaPSI")
    GM = URIRef("http://qudt.org/vocab/unit/GM")
    PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2")
    NanoM_PER_MilliM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-MilliM-MegaPA")
    M2_PER_HZ_DEG = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ-DEG")
    TON_Metric_PER_SEC = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC")
    N = URIRef("http://qudt.org/vocab/unit/N")
    KiloGM_PER_CentiM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-BAR")
    ERLANG = URIRef("http://qudt.org/vocab/unit/ERLANG")
    MilliBAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-L-PER-SEC")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    K_M_PER_W = URIRef("http://qudt.org/vocab/unit/K-M-PER-W")
    LB_HR_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-FT3")
    FT_US = URIRef("http://qudt.org/vocab/unit/FT_US")
    NanoJ = URIRef("http://qudt.org/vocab/unit/NanoJ")
    KiloGM_PER_M3_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-PA")
    BTU_IT_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC-DEG_F")
    KiloLB_F = URIRef("http://qudt.org/vocab/unit/KiloLB_F")
    PA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-L-PER-SEC")
    PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/PER-MilliM3")
    DEG_C_CentiM = URIRef("http://qudt.org/vocab/unit/DEG_C-CentiM")
    KiloGM_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC2")
    SV_PER_HR = URIRef("http://qudt.org/vocab/unit/SV-PER-HR")
    FT2_HR_DEG_F_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F-PER-BTU_IT")
    NanoMOL_PER_CentiM3_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-CentiM3-HR")
    W_PER_GM = URIRef("http://qudt.org/vocab/unit/W-PER-GM")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    KiloCAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-MIN")
    MicroV = URIRef("http://qudt.org/vocab/unit/MicroV")
    M2_HZ3 = URIRef("http://qudt.org/vocab/unit/M2-HZ3")
    HectoBAR = URIRef("http://qudt.org/vocab/unit/HectoBAR")
    T = URIRef("http://qudt.org/vocab/unit/T")
    LB_HR_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-GAL_US")
    KiloM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC")
    PicoL = URIRef("http://qudt.org/vocab/unit/PicoL")
    LB_PER_YD3 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD3")
    LB_HR_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-IN3")
    MicroM = URIRef("http://qudt.org/vocab/unit/MicroM")
    OZ_SEC_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN6")
    PH = URIRef("http://qudt.org/vocab/unit/PH")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    YD3_PER_HR = URIRef("http://qudt.org/vocab/unit/YD3-PER-HR")
    HR_Sidereal = URIRef("http://qudt.org/vocab/unit/HR_Sidereal")
    KiloPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-BAR")
    BTU_60DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_60DEG_F")
    FT = URIRef("http://qudt.org/vocab/unit/FT")
    PERCENT_PER_HR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-HR")
    FT_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-PER-HR")
    CAL_TH_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-K")
    MicroGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3")
    DeciM3 = URIRef("http://qudt.org/vocab/unit/DeciM3")
    KiloGM_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-MilliM2")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    GM_PER_MIN = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN")
    GM_PER_GM = URIRef("http://qudt.org/vocab/unit/GM-PER-GM")
    MilliM_PER_YR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-YR")
    CentiGRAY = URIRef("http://qudt.org/vocab/unit/CentiGRAY")
    MegaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M3")
    TSP = URIRef("http://qudt.org/vocab/unit/TSP")
    GM_PER_M3 = URIRef("http://qudt.org/vocab/unit/GM-PER-M3")
    PER_MOL = URIRef("http://qudt.org/vocab/unit/PER-MOL")
    KiloBAUD = URIRef("http://qudt.org/vocab/unit/KiloBAUD")
    MilliM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DAY")
    MilliBAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-M3-PER-SEC")
    LB_PER_FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-LB_F-SEC")
    SLUG_PER_HR = URIRef("http://qudt.org/vocab/unit/SLUG-PER-HR")
    LB_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_UK")
    NUM_PER_GM = URIRef("http://qudt.org/vocab/unit/NUM-PER-GM")
    CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3")
    B = URIRef("http://qudt.org/vocab/unit/B")
    POISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/POISE-PER-BAR")
    PicoPA_PER_KiloM = URIRef("http://qudt.org/vocab/unit/PicoPA-PER-KiloM")
    EarthMass = URIRef("http://qudt.org/vocab/unit/EarthMass")
    MOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3")
    T = URIRef("http://qudt.org/vocab/unit/T")
    PSI_YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-YD3-PER-SEC")
    FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F")
    PSI_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-M3-PER-SEC")
    MegaJ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-K")
    B_PER_M = URIRef("http://qudt.org/vocab/unit/B-PER-M")
    MegaBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaBQ-PER-KiloGM")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    M_PER_K = URIRef("http://qudt.org/vocab/unit/M-PER-K")
    MilliV = URIRef("http://qudt.org/vocab/unit/MilliV")
    FT_SEC_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-GAL_UK")
    LB_MIN_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-GAL_US")
    NanoGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2")
    CAL_MEAN = URIRef("http://qudt.org/vocab/unit/CAL_MEAN")
    M3_PER_DAY = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY")
    MilliMOL = URIRef("http://qudt.org/vocab/unit/MilliMOL")
    FemtoL = URIRef("http://qudt.org/vocab/unit/FemtoL")
    BARYE = URIRef("http://qudt.org/vocab/unit/BARYE")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    M_PER_MIN = URIRef("http://qudt.org/vocab/unit/M-PER-MIN")
    YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD3-PER-SEC")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC")
    DEGREE_BAUME_US_LIGHT = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_LIGHT")
    MegaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M3")
    KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-SEC2")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    KiloTON_Metric = URIRef("http://qudt.org/vocab/unit/KiloTON_Metric")
    DARCY = URIRef("http://qudt.org/vocab/unit/DARCY")
    KiloGM_PER_M_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-HR")
    GM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2")
    KiloR = URIRef("http://qudt.org/vocab/unit/KiloR")
    LB_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-SEC")
    TeraJ = URIRef("http://qudt.org/vocab/unit/TeraJ")
    GigaBasePair = URIRef("http://qudt.org/vocab/unit/GigaBasePair")
    BAR = URIRef("http://qudt.org/vocab/unit/BAR")
    HectoPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-L-PER-SEC")
    SPIN_QUANTUM_NUMBER = URIRef("http://qudt.org/vocab/unit/SPIN_QUANTUM_NUMBER")
    V_A_Reactive = URIRef("http://qudt.org/vocab/unit/V-A_Reactive")
    NanoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-KiloGM")
    MicroMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L")
    HZ_PER_V = URIRef("http://qudt.org/vocab/unit/HZ-PER-V")
    PlanckVolt = URIRef("http://qudt.org/vocab/unit/PlanckVolt")
    MilliM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC")
    DRAM_UK = URIRef("http://qudt.org/vocab/unit/DRAM_UK")
    LB_PER_FT3_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3-DEG_F")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    FT_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC-DEG_F")
    CentiM_HG = URIRef("http://qudt.org/vocab/unit/CentiM_HG")
    FARAD_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/FARAD_Ab-PER-CentiM")
    PERCENT_PER_DecaCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaCount")
    DEG_C_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-MIN")
    LM_SEC = URIRef("http://qudt.org/vocab/unit/LM-SEC")
    PA_M = URIRef("http://qudt.org/vocab/unit/PA-M")
    SV_PER_HR = URIRef("http://qudt.org/vocab/unit/SV-PER-HR")
    DEG_F_HR_FT2_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH")
    TON_UK_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-YD3")
    PicoFARAD = URIRef("http://qudt.org/vocab/unit/PicoFARAD")
    R = URIRef("http://qudt.org/vocab/unit/R")
    B = URIRef("http://qudt.org/vocab/unit/B")
    MicroGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3")
    DeciTON_Metric = URIRef("http://qudt.org/vocab/unit/DeciTON_Metric")
    MilliC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M3")
    L_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/L-PER-KiloGM")
    HectoPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-M3-PER-SEC")
    A_Ab_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-CentiM2")
    LB_IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN-PER-SEC")
    GM_PER_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY")
    GM_PER_M = URIRef("http://qudt.org/vocab/unit/GM-PER-M")
    NanoL = URIRef("http://qudt.org/vocab/unit/NanoL")
    FemtoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-KiloGM")
    KiloGM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR")
    LB_HR_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-FT3")
    MicroGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-GM")
    OZ_IN2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/OZ-IN2-PER-IN3-LB_F-SEC")
    Standard = URIRef("http://qudt.org/vocab/unit/Standard")
    EV_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/EV-M2-PER-KiloGM")
    MegaPA_M0dot5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0dot5")
    DeciM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MIN")
    FT_LB_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-MIN")
    W_PER_SR = URIRef("http://qudt.org/vocab/unit/W-PER-SR")
    TON_Metric_PER_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-BAR")
    LB_SEC_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-GAL_US")
    PA_PER_MIN = URIRef("http://qudt.org/vocab/unit/PA-PER-MIN")
    PERCENT_PER_HectoBAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-HectoBAR")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    PER_L = URIRef("http://qudt.org/vocab/unit/PER-L")
    PER_M_NanoM = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM")
    SHANNON_PER_SEC = URIRef("http://qudt.org/vocab/unit/SHANNON-PER-SEC")
    GAL_US_DRY = URIRef("http://qudt.org/vocab/unit/GAL_US_DRY")
    HeartBeat = URIRef("http://qudt.org/vocab/unit/HeartBeat")
    A_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-PER-CentiM2")
    NanoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/NanoFARAD-PER-M")
    PPTR_VOL = URIRef("http://qudt.org/vocab/unit/PPTR_VOL")
    IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC")
    MicroGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-BAR")
    failures_in_time = URIRef("http://qudt.org/vocab/unit/failures-in-time")
    BU_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-HR")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    FT3_PER_MIN_FT2 = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN-FT2")
    M2_HZ3 = URIRef("http://qudt.org/vocab/unit/M2-HZ3")
    CAL_TH_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-DEG_C")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    LB_F = URIRef("http://qudt.org/vocab/unit/LB_F")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    N_PER_A = URIRef("http://qudt.org/vocab/unit/N-PER-A")
    BBL_US_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-SEC")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    Gs = URIRef("http://qudt.org/vocab/unit/Gs")
    KiloCAL_IT_PER_HR_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-HR-M-DEG_C")
    KiloGM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM")
    LB_MIN_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-YD3")
    FT_SEC_PER_IN3 = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-IN3")
    IN_HG = URIRef("http://qudt.org/vocab/unit/IN_HG")
    KiloA_HR = URIRef("http://qudt.org/vocab/unit/KiloA-HR")
    LB_MIN_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-YD3")
    MilliM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC2")
    KiloCAL = URIRef("http://qudt.org/vocab/unit/KiloCAL")
    EV_PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/EV-PER-ANGSTROM")
    W_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M2")
    PSI_IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-IN3-PER-SEC")
    MicroM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroM-PER-SEC")
    S_Stat = URIRef("http://qudt.org/vocab/unit/S_Stat")
    GA_Charriere = URIRef("http://qudt.org/vocab/unit/GA_Charriere")
    PER_DAY = URIRef("http://qudt.org/vocab/unit/PER-DAY")
    A_HR_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/A-HR-PER-KiloGM")
    DEG_F_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-HR")
    MilliGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-DAY")
    PERCENT_PER_HectoBAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-HectoBAR")
    V_PER_MilliM = URIRef("http://qudt.org/vocab/unit/V-PER-MilliM")
    NUM_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/NUM-PER-MilliM3")
    MilliA_PER_K = URIRef("http://qudt.org/vocab/unit/MilliA-PER-K")
    MilliGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    NanoS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/NanoS-PER-CentiM")
    PERCENT_PER_MO = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MO")
    BTU_IT_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-SEC-DEG_F")
    AttoJ = URIRef("http://qudt.org/vocab/unit/AttoJ")
    MilliOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-BAR")
    MilliGM_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-DAY")
    S_Stat = URIRef("http://qudt.org/vocab/unit/S_Stat")
    MDOLLAR_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MDOLLAR-PER-FLIGHT")
    BTU_TH_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT3")
    PERCENT_RH = URIRef("http://qudt.org/vocab/unit/PERCENT_RH")
    ExaJ = URIRef("http://qudt.org/vocab/unit/ExaJ")
    FT_LB_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-SEC")
    PlanckCurrentDensity = URIRef("http://qudt.org/vocab/unit/PlanckCurrentDensity")
    DEG_C_KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/DEG_C-KiloGM-PER-M2")
    M2_K = URIRef("http://qudt.org/vocab/unit/M2-K")
    MilliGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-SEC")
    MicroMOL_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM-SEC")
    GM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3")
    RAD_PER_HR = URIRef("http://qudt.org/vocab/unit/RAD-PER-HR")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    OZ_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN3")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    GM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3-K")
    LB_MOL = URIRef("http://qudt.org/vocab/unit/LB-MOL")
    RAD_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-MOL")
    TON_SHORT_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-YD3")
    OHM_CentiM = URIRef("http://qudt.org/vocab/unit/OHM-CentiM")
    TON_UK_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-YD3")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    MilliGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY")
    KiloGM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR")
    PicoSEC = URIRef("http://qudt.org/vocab/unit/PicoSEC")
    MilliR = URIRef("http://qudt.org/vocab/unit/MilliR")
    A_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/A-PER-KiloGM")
    S_Stat = URIRef("http://qudt.org/vocab/unit/S_Stat")
    TON_Metric_PER_HR_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR-K")
    YD_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD-PER-SEC")
    MilliM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM2-PER-SEC")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    MegaN_M = URIRef("http://qudt.org/vocab/unit/MegaN-M")
    GAL_US = URIRef("http://qudt.org/vocab/unit/GAL_US")
    PFUND = URIRef("http://qudt.org/vocab/unit/PFUND")
    MilliV_A_PER_K = URIRef("http://qudt.org/vocab/unit/MilliV-A-PER-K")
    MX = URIRef("http://qudt.org/vocab/unit/MX")
    GM_SEC_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L-CentiM3")
    GigaHZ = URIRef("http://qudt.org/vocab/unit/GigaHZ")
    LB_SEC_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-FT3")
    CentiM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC-K")
    M_PER_HR = URIRef("http://qudt.org/vocab/unit/M-PER-HR")
    C = URIRef("http://qudt.org/vocab/unit/C")
    KiloBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT")
    M2_PER_K = URIRef("http://qudt.org/vocab/unit/M2-PER-K")
    QUAD = URIRef("http://qudt.org/vocab/unit/QUAD")
    GAL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-DAY")
    V_PER_BAR = URIRef("http://qudt.org/vocab/unit/V-PER-BAR")
    M_PER_YR = URIRef("http://qudt.org/vocab/unit/M-PER-YR")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    NanoGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M3")
    PINT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-DAY")
    BBL = URIRef("http://qudt.org/vocab/unit/BBL")
    HectoPA = URIRef("http://qudt.org/vocab/unit/HectoPA")
    TON_Metric_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC-BAR")
    PINT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-SEC")
    KiloN_M = URIRef("http://qudt.org/vocab/unit/KiloN-M")
    GM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3-BAR")
    GigaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-SEC")
    PER_J2 = URIRef("http://qudt.org/vocab/unit/PER-J2")
    PER_V_A_SEC = URIRef("http://qudt.org/vocab/unit/PER-V-A-SEC")
    MicroGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-SEC")
    BTU_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-MIN")
    LB_F_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-SEC")
    MilliS_PER_M = URIRef("http://qudt.org/vocab/unit/MilliS-PER-M")
    KiloGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-K")
    M2_K = URIRef("http://qudt.org/vocab/unit/M2-K")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    A_PER_M2_K2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2-K2")
    DEG_C_CentiM = URIRef("http://qudt.org/vocab/unit/DEG_C-CentiM")
    GRAIN_PER_GAL = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL")
    TEX = URIRef("http://qudt.org/vocab/unit/TEX")
    KiloCAL_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2")
    LB_PER_IN3 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3")
    DEG_C_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-K")
    LB_PER_IN3_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3-DEG_F")
    GRAIN_PER_GAL = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL")
    GibiBIT = URIRef("http://qudt.org/vocab/unit/GibiBIT")
    KiloLB_F = URIRef("http://qudt.org/vocab/unit/KiloLB_F")
    OZ_HR_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-FT3")
    M3_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-K")
    PicoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/PicoW-PER-M2")
    MicroGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-MIN")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    BTU_IT_PER_MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB-DEG_F")
    CentiM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    BTU_IT = URIRef("http://qudt.org/vocab/unit/BTU_IT")
    PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PER-SEC2")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    LB_MIN_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-YD3")
    GigaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-PER-M")
    Hundredweight_US = URIRef("http://qudt.org/vocab/unit/Hundredweight_US")
    MicroSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-MIN")
    ATM_M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/ATM-M3-PER-MOL")
    KiloGM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MilliM")
    OZ_SEC_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-GAL_US")
    GM_PER_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY")
    MicroC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M2")
    PDL_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-FT2")
    MilliGM_PER_L = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L")
    NanoBQ = URIRef("http://qudt.org/vocab/unit/NanoBQ")
    MegaLB_F = URIRef("http://qudt.org/vocab/unit/MegaLB_F")
    A_HR = URIRef("http://qudt.org/vocab/unit/A-HR")
    H_Ab = URIRef("http://qudt.org/vocab/unit/H_Ab")
    KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-SEC2")
    MilliGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC")
    NanoC = URIRef("http://qudt.org/vocab/unit/NanoC")
    PK_UK = URIRef("http://qudt.org/vocab/unit/PK_UK")
    MicroFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-M")
    C_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM3")
    BTU_IT_PER_SEC_FT_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT-DEG_R")
    J = URIRef("http://qudt.org/vocab/unit/J")
    OZ_FT_SEC_PER_IN3_LB = URIRef("http://qudt.org/vocab/unit/OZ-FT-SEC-PER-IN3-LB")
    A = URIRef("http://qudt.org/vocab/unit/A")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    KiloEV_PER_MicroM = URIRef("http://qudt.org/vocab/unit/KiloEV-PER-MicroM")
    CentiGM = URIRef("http://qudt.org/vocab/unit/CentiGM")
    IN2 = URIRef("http://qudt.org/vocab/unit/IN2")
    TeraA = URIRef("http://qudt.org/vocab/unit/TeraA")
    L_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-HR-BAR")
    M2_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-HZ2")
    OZ_FT_SEC_PER_IN3_LB = URIRef("http://qudt.org/vocab/unit/OZ-FT-SEC-PER-IN3-LB")
    DecaC = URIRef("http://qudt.org/vocab/unit/DecaC")
    HA = URIRef("http://qudt.org/vocab/unit/HA")
    LB_PER_FT3_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3-PSI")
    BTU_TH_PER_FT2_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-HR")
    Ci = URIRef("http://qudt.org/vocab/unit/Ci")
    L_PER_HR = URIRef("http://qudt.org/vocab/unit/L-PER-HR")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    M3_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-K")
    LB_PER_FT_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-HR")
    KiloMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-KiloGM")
    PicoSEC = URIRef("http://qudt.org/vocab/unit/PicoSEC")
    E = URIRef("http://qudt.org/vocab/unit/E")
    SUSCEPTIBILITY_MAG = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_MAG")
    PicoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L")
    MicroC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M3")
    IN3_PER_HR = URIRef("http://qudt.org/vocab/unit/IN3-PER-HR")
    PPB = URIRef("http://qudt.org/vocab/unit/PPB")
    MicroMOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-SEC")
    FemtoL = URIRef("http://qudt.org/vocab/unit/FemtoL")
    PicoH = URIRef("http://qudt.org/vocab/unit/PicoH")
    BTU_IT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_F")
    MicroJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroJ-PER-SEC")
    M_K_PER_W = URIRef("http://qudt.org/vocab/unit/M-K-PER-W")
    C2_M2_PER_J = URIRef("http://qudt.org/vocab/unit/C2-M2-PER-J")
    PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-PSI")
    GigaBQ = URIRef("http://qudt.org/vocab/unit/GigaBQ")
    PER_SEC_M3 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M3")
    BIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BIT-PER-SEC")
    PK_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-DAY")
    BTU_IT_PER_LB_F_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_F")
    J = URIRef("http://qudt.org/vocab/unit/J")
    C_M2 = URIRef("http://qudt.org/vocab/unit/C-M2")
    KiloGRAY = URIRef("http://qudt.org/vocab/unit/KiloGRAY")
    L_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-BAR")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    PER_M_K = URIRef("http://qudt.org/vocab/unit/PER-M-K")
    MilliGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY")
    AU = URIRef("http://qudt.org/vocab/unit/AU")
    DEATHS_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000I-YR")
    N_PER_MilliM = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM")
    PA_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-PER-BAR")
    PERCENT_PER_IN = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-IN")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    MicroGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-GM")
    M3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM")
    CH = URIRef("http://qudt.org/vocab/unit/CH")
    MegaC = URIRef("http://qudt.org/vocab/unit/MegaC")
    MicroMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM")
    PERCENT_FT_SEC_PER_LB = URIRef("http://qudt.org/vocab/unit/PERCENT-FT-SEC-PER-LB")
    MilliV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliV-PER-MIN")
    L_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-HR-BAR")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    DeciM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-SEC")
    FT2 = URIRef("http://qudt.org/vocab/unit/FT2")
    B = URIRef("http://qudt.org/vocab/unit/B")
    S_Stat = URIRef("http://qudt.org/vocab/unit/S_Stat")
    M3_PER_DAY = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY")
    BTU_TH_PER_FT2_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-HR")
    MOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM")
    GM_HR_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L2")
    LB_SEC_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-IN3")
    MilliIN = URIRef("http://qudt.org/vocab/unit/MilliIN")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    K_DAY = URIRef("http://qudt.org/vocab/unit/K-DAY")
    NanoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L")
    MicroGAL_PER_M = URIRef("http://qudt.org/vocab/unit/MicroGAL-PER-M")
    KiloM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC2")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    MI_PER_SEC = URIRef("http://qudt.org/vocab/unit/MI-PER-SEC")
    V_PER_MilliM = URIRef("http://qudt.org/vocab/unit/V-PER-MilliM")
    MIL = URIRef("http://qudt.org/vocab/unit/MIL")
    FT_LB_F_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-HR")
    GAL_US_DRY = URIRef("http://qudt.org/vocab/unit/GAL_US_DRY")
    GRAIN_PER_GAL = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL")
    HectoPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-L-PER-SEC")
    PERCENT_FT2_PER_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-FT2-PER-LB_F-SEC")
    N_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM2")
    M3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL-SEC")
    KiloL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloL-PER-HR")
    MicroGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2")
    LB_PER_GAL = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL")
    M2_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-BAR")
    MicroATM = URIRef("http://qudt.org/vocab/unit/MicroATM")
    PicoSEC = URIRef("http://qudt.org/vocab/unit/PicoSEC")
    TORR = URIRef("http://qudt.org/vocab/unit/TORR")
    DeciTONNE = URIRef("http://qudt.org/vocab/unit/DeciTONNE")
    MDOLLAR_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MDOLLAR-PER-FLIGHT")
    AttoJ = URIRef("http://qudt.org/vocab/unit/AttoJ")
    PetaHZ = URIRef("http://qudt.org/vocab/unit/PetaHZ")
    KiloGM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-BAR")
    M_SEC2 = URIRef("http://qudt.org/vocab/unit/M-SEC2")
    V_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Ab-PER-CentiM")
    KiloW_HR = URIRef("http://qudt.org/vocab/unit/KiloW-HR")
    MIN_Angle = URIRef("http://qudt.org/vocab/unit/MIN_Angle")
    SEC_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-FT2")
    TeraJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/TeraJ-PER-SEC")
    M2_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-BAR")
    MegaV = URIRef("http://qudt.org/vocab/unit/MegaV")
    BTU_IT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC")
    PERCENT_PER_DAY = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DAY")
    CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-GM")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    GM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciL")
    QT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_US-PER-DAY")
    BBL_US_DRY = URIRef("http://qudt.org/vocab/unit/BBL_US_DRY")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    MicroMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2")
    NanoT = URIRef("http://qudt.org/vocab/unit/NanoT")
    GM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloM")
    N_M_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-M-PER-KiloGM")
    CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM-SEC-DEG_C")
    L_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-K")
    KiloV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive-HR")
    DYN_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM3")
    GigaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-SEC")
    LB_MIN_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-GAL_US")
    GigaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-PER-M")
    KiloGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-K")
    PER_SEC_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR")
    MilliIN = URIRef("http://qudt.org/vocab/unit/MilliIN")
    NanoMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL")
    MilliM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliM-PER-MIN")
    KiloN_M_PER_DEG_M = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-DEG-M")
    KiloBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-HR")
    MicroJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroJ-PER-SEC")
    GM_PER_M3_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-MilliPA-SEC")
    MicroT = URIRef("http://qudt.org/vocab/unit/MicroT")
    LB_PER_IN3 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    NanoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/NanoW-PER-M2")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    GibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M3")
    PERCENT_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-M3")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    M3_PER_HR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR")
    ERG_PER_CentiM = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM")
    Da = URIRef("http://qudt.org/vocab/unit/Da")
    H_Stat = URIRef("http://qudt.org/vocab/unit/H_Stat")
    MilliBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-KiloGM")
    DEG_R_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-SEC")
    V = URIRef("http://qudt.org/vocab/unit/V")
    C_Ab = URIRef("http://qudt.org/vocab/unit/C_Ab")
    GM_PER_MIN = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN")
    CAL_TH = URIRef("http://qudt.org/vocab/unit/CAL_TH")
    FemtoV = URIRef("http://qudt.org/vocab/unit/FemtoV")
    LB_F_PER_LB = URIRef("http://qudt.org/vocab/unit/LB_F-PER-LB")
    W_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-PER-M3")
    LB_F = URIRef("http://qudt.org/vocab/unit/LB_F")
    MilliGM_PER_L_CentiPOISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-CentiPOISE")
    KiloCAL = URIRef("http://qudt.org/vocab/unit/KiloCAL")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    MilliS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MilliS-PER-CentiM")
    NTU = URIRef("http://qudt.org/vocab/unit/NTU")
    KiloCAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-SEC")
    LB_HR_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-IN3")
    DEG_F_HR_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_IT")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    PINT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-HR")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    V_Stat_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-CentiM")
    K2 = URIRef("http://qudt.org/vocab/unit/K2")
    KiloM = URIRef("http://qudt.org/vocab/unit/KiloM")
    NanoM_PER_MilliM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-MilliM-MegaPA")
    GM_Carbon_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Carbon-PER-M2-DAY")
    PER_CentiM = URIRef("http://qudt.org/vocab/unit/PER-CentiM")
    GM_Carbon_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Carbon-PER-M2-DAY")
    DYN_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-CentiM")
    M2_PER_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ2")
    M2_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-V-SEC")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    WK = URIRef("http://qudt.org/vocab/unit/WK")
    BARYE = URIRef("http://qudt.org/vocab/unit/BARYE")
    MilliL_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-K")
    TON_Metric_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC-K")
    MOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3")
    FT2 = URIRef("http://qudt.org/vocab/unit/FT2")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    MI_PER_SEC = URIRef("http://qudt.org/vocab/unit/MI-PER-SEC")
    DEG_C_WK = URIRef("http://qudt.org/vocab/unit/DEG_C-WK")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    PetaC = URIRef("http://qudt.org/vocab/unit/PetaC")
    TON_US = URIRef("http://qudt.org/vocab/unit/TON_US")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    KiloC = URIRef("http://qudt.org/vocab/unit/KiloC")
    MicroM_PER_K = URIRef("http://qudt.org/vocab/unit/MicroM-PER-K")
    MilliL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-KiloGM")
    BTU_IT_PER_LB_MOL = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-MOL")
    MilliGM_MIN_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M3-L")
    PERCENT_PER_PA_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-PA-SEC")
    MegaS_PER_M = URIRef("http://qudt.org/vocab/unit/MegaS-PER-M")
    HectoL = URIRef("http://qudt.org/vocab/unit/HectoL")
    L_PER_K = URIRef("http://qudt.org/vocab/unit/L-PER-K")
    BTU_IT_PER_LB_MOL = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-MOL")
    SH = URIRef("http://qudt.org/vocab/unit/SH")
    V_A_PER_K = URIRef("http://qudt.org/vocab/unit/V-A-PER-K")
    MilliGM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M")
    NUM_PER_PicoL = URIRef("http://qudt.org/vocab/unit/NUM-PER-PicoL")
    MilliR = URIRef("http://qudt.org/vocab/unit/MilliR")
    NanoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MilliL")
    LB_F = URIRef("http://qudt.org/vocab/unit/LB_F")
    CUP_US = URIRef("http://qudt.org/vocab/unit/CUP_US")
    MilliGAL = URIRef("http://qudt.org/vocab/unit/MilliGAL")
    KiloGM_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-BAR")
    KiloOHM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-M")
    KiloV = URIRef("http://qudt.org/vocab/unit/KiloV")
    BBL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-MIN")
    CentiM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC")
    MilliN = URIRef("http://qudt.org/vocab/unit/MilliN")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    PER_MicroMOL_L = URIRef("http://qudt.org/vocab/unit/PER-MicroMOL-L")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    MilliGM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M")
    ExaBYTE = URIRef("http://qudt.org/vocab/unit/ExaBYTE")
    M = URIRef("http://qudt.org/vocab/unit/M")
    DEG_PER_M = URIRef("http://qudt.org/vocab/unit/DEG-PER-M")
    CAL_MEAN = URIRef("http://qudt.org/vocab/unit/CAL_MEAN")
    T = URIRef("http://qudt.org/vocab/unit/T")
    AMU = URIRef("http://qudt.org/vocab/unit/AMU")
    PA_M0pt5 = URIRef("http://qudt.org/vocab/unit/PA-M0pt5")
    A_SEC = URIRef("http://qudt.org/vocab/unit/A-SEC")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    OZ_HR_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN6")
    PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-PSI")
    AT = URIRef("http://qudt.org/vocab/unit/AT")
    PERCENT_PER_DecaKiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaKiloCount")
    MIL = URIRef("http://qudt.org/vocab/unit/MIL")
    MilliM2 = URIRef("http://qudt.org/vocab/unit/MilliM2")
    GM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-K")
    Stone_UK = URIRef("http://qudt.org/vocab/unit/Stone_UK")
    K_M2_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/K-M2-PER-KiloGM-SEC")
    DEG_F_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-HR")
    PlanckVolume = URIRef("http://qudt.org/vocab/unit/PlanckVolume")
    MicroMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM")
    MegaJ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-K")
    CentiM3_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY-K")
    MilliCi = URIRef("http://qudt.org/vocab/unit/MilliCi")
    OZ_VOL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-SEC")
    PlanckLength = URIRef("http://qudt.org/vocab/unit/PlanckLength")
    DeciB_W = URIRef("http://qudt.org/vocab/unit/DeciB-W")
    W_PER_SR = URIRef("http://qudt.org/vocab/unit/W-PER-SR")
    KN = URIRef("http://qudt.org/vocab/unit/KN")
    LB_PER_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-HR")
    SPIN_QUANTUM_NUMBER = URIRef("http://qudt.org/vocab/unit/SPIN_QUANTUM_NUMBER")
    OZ_VOL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-SEC")
    MilliC = URIRef("http://qudt.org/vocab/unit/MilliC")
    M = URIRef("http://qudt.org/vocab/unit/M")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    LB_IN2_PER_GAL_UK_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-GAL_UK-LB_F-SEC")
    NanoMOL_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L-DAY")
    LB_PER_FT_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-HR")
    KiloBTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH-PER-HR")
    KiloJ_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM-K")
    NAT = URIRef("http://qudt.org/vocab/unit/NAT")
    KIP_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KIP_F-PER-IN2")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    N_PER_A = URIRef("http://qudt.org/vocab/unit/N-PER-A")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    M2_PER_M2 = URIRef("http://qudt.org/vocab/unit/M2-PER-M2")
    MicroGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-MilliL")
    N_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M")
    TON_Metric_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY-K")
    PetaC = URIRef("http://qudt.org/vocab/unit/PetaC")
    KiloV_A_Reactive = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive")
    MilliM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-HR")
    MilliPA_SEC_PER_K = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-K")
    V_Ab = URIRef("http://qudt.org/vocab/unit/V_Ab")
    MilliH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-KiloOHM")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    DEGREE_OECHSLE = URIRef("http://qudt.org/vocab/unit/DEGREE_OECHSLE")
    MI2 = URIRef("http://qudt.org/vocab/unit/MI2")
    N_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-M-PER-M2")
    FARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/FARAD-PER-KiloM")
    MegaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBIT-PER-SEC")
    GigaJ = URIRef("http://qudt.org/vocab/unit/GigaJ")
    IN3_PER_LB = URIRef("http://qudt.org/vocab/unit/IN3-PER-LB")
    MilliSV = URIRef("http://qudt.org/vocab/unit/MilliSV")
    CentiM3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL-SEC")
    GM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC-BAR")
    KiloLB_F_FT_PER_LB = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-LB")
    LB_PER_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-HR")
    NUM_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/NUM-PER-MilliGM")
    LM_PER_M2 = URIRef("http://qudt.org/vocab/unit/LM-PER-M2")
    MilliK_PER_K = URIRef("http://qudt.org/vocab/unit/MilliK-PER-K")
    PERCENT_FT2_PER_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-FT2-PER-LB_F-SEC")
    PetaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/PetaBIT-PER-SEC")
    MilliA_PER_IN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-IN")
    PPM = URIRef("http://qudt.org/vocab/unit/PPM")
    LB_SEC_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-YD3")
    DEG_C_PER_YR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-YR")
    GigaPA = URIRef("http://qudt.org/vocab/unit/GigaPA")
    PER_M2 = URIRef("http://qudt.org/vocab/unit/PER-M2")
    J_PER_KiloGM_K_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-M3")
    FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-DEG_F")
    PER_V = URIRef("http://qudt.org/vocab/unit/PER-V")
    BIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BIT-PER-SEC")
    DEG_R_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-MIN")
    MilliGM_PER_L_CentiPOISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-CentiPOISE")
    J_PER_HR = URIRef("http://qudt.org/vocab/unit/J-PER-HR")
    Pennyweight = URIRef("http://qudt.org/vocab/unit/Pennyweight")
    W_PER_M2_M = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M")
    TON_SHIPPING_UK = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_UK")
    MilliA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/MilliA-PER-MilliM")
    KiloGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN")
    ERG_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM3")
    GM_PER_GM = URIRef("http://qudt.org/vocab/unit/GM-PER-GM")
    PER_SEC_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR")
    CAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-K")
    M2_PER_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ2")
    KiloW_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloW-HR-PER-M2")
    M = URIRef("http://qudt.org/vocab/unit/M")
    W_M2 = URIRef("http://qudt.org/vocab/unit/W-M2")
    W_HR_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-HR-PER-KiloGM")
    N_PER_MilliM = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM")
    QT_US = URIRef("http://qudt.org/vocab/unit/QT_US")
    OZ_FT_SEC_PER_IN3_LB = URIRef("http://qudt.org/vocab/unit/OZ-FT-SEC-PER-IN3-LB")
    PicoGM_PER_GM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-GM")
    FemtoSEC = URIRef("http://qudt.org/vocab/unit/FemtoSEC")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    PER_M_NanoM_SR = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM-SR")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    MilliW_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-MilliGM")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    NUM_PER_M2 = URIRef("http://qudt.org/vocab/unit/NUM-PER-M2")
    PT = URIRef("http://qudt.org/vocab/unit/PT")
    MilliJ = URIRef("http://qudt.org/vocab/unit/MilliJ")
    MilliA_IN2_PER_LB_F = URIRef("http://qudt.org/vocab/unit/MilliA-IN2-PER-LB_F")
    MilliW_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM-SR")
    CAL_TH_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM")
    DEG_PER_M = URIRef("http://qudt.org/vocab/unit/DEG-PER-M")
    MicroPA = URIRef("http://qudt.org/vocab/unit/MicroPA")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    QT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-MIN")
    BTU_TH_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR-FT2-DEG_F")
    PlanckEnergy = URIRef("http://qudt.org/vocab/unit/PlanckEnergy")
    MicroL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroL-PER-L")
    GI_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-DAY")
    AttoFARAD = URIRef("http://qudt.org/vocab/unit/AttoFARAD")
    BTU_IT_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC")
    MilliGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2")
    NanoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/NanoKAT-PER-L")
    BTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR")
    KiloBAR = URIRef("http://qudt.org/vocab/unit/KiloBAR")
    PPB = URIRef("http://qudt.org/vocab/unit/PPB")
    CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-GM")
    LB_PER_IN3_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3-DEG_F")
    GI_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-HR")
    M3_PER_K = URIRef("http://qudt.org/vocab/unit/M3-PER-K")
    YottaC = URIRef("http://qudt.org/vocab/unit/YottaC")
    CD_PER_LM = URIRef("http://qudt.org/vocab/unit/CD-PER-LM")
    A_SEC2 = URIRef("http://qudt.org/vocab/unit/A-SEC2")
    PINT = URIRef("http://qudt.org/vocab/unit/PINT")
    BBL_UK_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-SEC")
    H_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/H-PER-KiloOHM")
    BAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-M3-PER-SEC")
    C2_M2_PER_J = URIRef("http://qudt.org/vocab/unit/C2-M2-PER-J")
    OZ = URIRef("http://qudt.org/vocab/unit/OZ")
    W_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM-SR")
    MilliL_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-BAR")
    PlanckCurrent = URIRef("http://qudt.org/vocab/unit/PlanckCurrent")
    DEG_C_PER_M = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-M")
    CentiM_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-BAR")
    LB_HR_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-YD3")
    MilliM_HG = URIRef("http://qudt.org/vocab/unit/MilliM_HG")
    KibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M")
    PicoGM_PER_GM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-GM")
    LB_F_PER_YD = URIRef("http://qudt.org/vocab/unit/LB_F-PER-YD")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    PERM_23DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_23DEG_C")
    GM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/GM-PER-HR-K")
    MilliM4 = URIRef("http://qudt.org/vocab/unit/MilliM4")
    MegaV_PER_M = URIRef("http://qudt.org/vocab/unit/MegaV-PER-M")
    MegaEV_FemtoM = URIRef("http://qudt.org/vocab/unit/MegaEV-FemtoM")
    PicoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/PicoW-PER-M2")
    OZ_VOL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-SEC")
    GAL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-DAY")
    LM_HR = URIRef("http://qudt.org/vocab/unit/LM-HR")
    MicroGM = URIRef("http://qudt.org/vocab/unit/MicroGM")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    IN3_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN3-PER-MIN")
    CentiN_M = URIRef("http://qudt.org/vocab/unit/CentiN-M")
    M_PER_FARAD = URIRef("http://qudt.org/vocab/unit/M-PER-FARAD")
    MOL_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB")
    KiloGM_PER_DeciM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-K")
    LB_HR_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-IN3")
    M2_PER_SR = URIRef("http://qudt.org/vocab/unit/M2-PER-SR")
    EUR_PER_W_SEC = URIRef("http://qudt.org/vocab/unit/EUR-PER-W-SEC")
    GM_MIN_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M3-L")
    OZ_M = URIRef("http://qudt.org/vocab/unit/OZ_M")
    QT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_US-PER-HR")
    M2_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-BAR")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    DEG_F_SEC_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-SEC-PER-BTU_IT")
    KiloGM_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM2")
    TON_FG_HR = URIRef("http://qudt.org/vocab/unit/TON_FG-HR")
    KiloJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM")
    MilliS = URIRef("http://qudt.org/vocab/unit/MilliS")
    J_PER_KiloGM_K_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-M3")
    PER_V = URIRef("http://qudt.org/vocab/unit/PER-V")
    OZ_PER_IN2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN2")
    PERCENT_PER_DEGREE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEGREE")
    MOL_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-L-BAR")
    SPF = URIRef("http://qudt.org/vocab/unit/SPF")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    LB_DEG_R = URIRef("http://qudt.org/vocab/unit/LB-DEG_R")
    CentiM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC")
    LB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT")
    KiloM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC")
    MicroPA = URIRef("http://qudt.org/vocab/unit/MicroPA")
    PER_M_NanoM_SR = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM-SR")
    MicroPOISE = URIRef("http://qudt.org/vocab/unit/MicroPOISE")
    C_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM3")
    FT2_PER_HR = URIRef("http://qudt.org/vocab/unit/FT2-PER-HR")
    PER_K = URIRef("http://qudt.org/vocab/unit/PER-K")
    PicoS = URIRef("http://qudt.org/vocab/unit/PicoS")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    LB_PER_FT_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-DAY")
    DEG_C_WK = URIRef("http://qudt.org/vocab/unit/DEG_C-WK")
    MegaV_A = URIRef("http://qudt.org/vocab/unit/MegaV-A")
    MicroOHM = URIRef("http://qudt.org/vocab/unit/MicroOHM")
    K_SEC = URIRef("http://qudt.org/vocab/unit/K-SEC")
    LB_F = URIRef("http://qudt.org/vocab/unit/LB_F")
    BU_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-DAY")
    MegaS_PER_M = URIRef("http://qudt.org/vocab/unit/MegaS-PER-M")
    PERCENT_MIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-GAL_US")
    CentiBAR = URIRef("http://qudt.org/vocab/unit/CentiBAR")
    KiloCAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-MIN")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    NUM_PER_L = URIRef("http://qudt.org/vocab/unit/NUM-PER-L")
    PER_M_SEC = URIRef("http://qudt.org/vocab/unit/PER-M-SEC")
    GM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-CentiM-PER-SEC")
    MilliGM_SEC_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L-M3")
    GM_PER_HR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR")
    PINT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-MIN")
    CentiM3_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-CentiM3")
    ERG_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM-SEC")
    MilliH = URIRef("http://qudt.org/vocab/unit/MilliH")
    S_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/S-M2-PER-MOL")
    GI_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-SEC")
    M_PER_RAD = URIRef("http://qudt.org/vocab/unit/M-PER-RAD")
    IN_H2O_39dot2DEG_F = URIRef("http://qudt.org/vocab/unit/IN_H2O_39dot2DEG_F")
    M2_PER_GM = URIRef("http://qudt.org/vocab/unit/M2-PER-GM")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    TeraJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/TeraJ-PER-SEC")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    PER_MILLE_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PSI")
    PINT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-DAY")
    EV_SEC = URIRef("http://qudt.org/vocab/unit/EV-SEC")
    DEG_C2_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C2-PER-SEC")
    BTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR")
    NanoM_PER_CentiM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-MegaPA")
    L_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-K")
    CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-GM")
    MOL_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-SEC")
    MilliPA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-BAR")
    MicroMOL_PER_GM_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM-HR")
    KiloCAL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MIN")
    MI_UK3 = URIRef("http://qudt.org/vocab/unit/MI_UK3")
    MillionUSD_PER_YR = URIRef("http://qudt.org/vocab/unit/MillionUSD-PER-YR")
    REV_PER_MIN = URIRef("http://qudt.org/vocab/unit/REV-PER-MIN")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    BQ_PER_M2 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M2")
    T_Ab = URIRef("http://qudt.org/vocab/unit/T_Ab")
    CentiM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC-BAR")
    H = URIRef("http://qudt.org/vocab/unit/H")
    KiloGM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-K")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    M2_PER_GM_DRY = URIRef("http://qudt.org/vocab/unit/M2-PER-GM_DRY")
    WK = URIRef("http://qudt.org/vocab/unit/WK")
    MilliFARAD = URIRef("http://qudt.org/vocab/unit/MilliFARAD")
    M2_PER_SR = URIRef("http://qudt.org/vocab/unit/M2-PER-SR")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    KiloGM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3")
    NanoBQ = URIRef("http://qudt.org/vocab/unit/NanoBQ")
    TON_Metric_PER_SEC = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC")
    CentiPOISE = URIRef("http://qudt.org/vocab/unit/CentiPOISE")
    MOL_PER_TONNE = URIRef("http://qudt.org/vocab/unit/MOL-PER-TONNE")
    TON_F_US = URIRef("http://qudt.org/vocab/unit/TON_F_US")
    A_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-PER-CentiM2")
    BBL_US_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-HR")
    ExaC = URIRef("http://qudt.org/vocab/unit/ExaC")
    PER_V_A_SEC = URIRef("http://qudt.org/vocab/unit/PER-V-A-SEC")
    RAD_PER_HR = URIRef("http://qudt.org/vocab/unit/RAD-PER-HR")
    MegaOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-BAR")
    MebiBYTE = URIRef("http://qudt.org/vocab/unit/MebiBYTE")
    KAT_PER_L = URIRef("http://qudt.org/vocab/unit/KAT-PER-L")
    PER_J2 = URIRef("http://qudt.org/vocab/unit/PER-J2")
    FT_HG = URIRef("http://qudt.org/vocab/unit/FT_HG")
    TeraW = URIRef("http://qudt.org/vocab/unit/TeraW")
    NanoGM_PER_L = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-L")
    MI = URIRef("http://qudt.org/vocab/unit/MI")
    FUR = URIRef("http://qudt.org/vocab/unit/FUR")
    OHM_PER_K = URIRef("http://qudt.org/vocab/unit/OHM-PER-K")
    TeraC = URIRef("http://qudt.org/vocab/unit/TeraC")
    DeciM2 = URIRef("http://qudt.org/vocab/unit/DeciM2")
    KiloEV = URIRef("http://qudt.org/vocab/unit/KiloEV")
    SV_PER_MIN = URIRef("http://qudt.org/vocab/unit/SV-PER-MIN")
    W_PER_M2_PA = URIRef("http://qudt.org/vocab/unit/W-PER-M2-PA")
    MegaV = URIRef("http://qudt.org/vocab/unit/MegaV")
    RAD_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-KiloGM")
    MOL_K = URIRef("http://qudt.org/vocab/unit/MOL-K")
    PlanckImpedance = URIRef("http://qudt.org/vocab/unit/PlanckImpedance")
    MicroMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L")
    TON_Metric_PER_HA = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HA")
    PER_PA_SEC = URIRef("http://qudt.org/vocab/unit/PER-PA-SEC")
    PicoS_PER_M = URIRef("http://qudt.org/vocab/unit/PicoS-PER-M")
    PER_EV2 = URIRef("http://qudt.org/vocab/unit/PER-EV2")
    HectoBAR = URIRef("http://qudt.org/vocab/unit/HectoBAR")
    KY = URIRef("http://qudt.org/vocab/unit/KY")
    BTU_IT_PER_LB_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F")
    SLUG = URIRef("http://qudt.org/vocab/unit/SLUG")
    PER_HR = URIRef("http://qudt.org/vocab/unit/PER-HR")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    MESH = URIRef("http://qudt.org/vocab/unit/MESH")
    BTU_IT_PER_SEC_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_R")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    MilliBAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-L-PER-SEC")
    K = URIRef("http://qudt.org/vocab/unit/K")
    PlanckTemperature = URIRef("http://qudt.org/vocab/unit/PlanckTemperature")
    GigaBQ = URIRef("http://qudt.org/vocab/unit/GigaBQ")
    A_PER_MilliM = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM")
    RAD_R = URIRef("http://qudt.org/vocab/unit/RAD_R")
    J_PER_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-DAY")
    PIXEL = URIRef("http://qudt.org/vocab/unit/PIXEL")
    N_M2 = URIRef("http://qudt.org/vocab/unit/N-M2")
    KiloGM_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-M2")
    KiloGM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM2")
    MicroM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroM-PER-SEC")
    J_PER_MOL_K = URIRef("http://qudt.org/vocab/unit/J-PER-MOL-K")
    AttoSEC = URIRef("http://qudt.org/vocab/unit/AttoSEC")
    M2_PER_SR_J = URIRef("http://qudt.org/vocab/unit/M2-PER-SR-J")
    DeciGM = URIRef("http://qudt.org/vocab/unit/DeciGM")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    GM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-BAR")
    Ci = URIRef("http://qudt.org/vocab/unit/Ci")
    PA_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M")
    J_PER_M4 = URIRef("http://qudt.org/vocab/unit/J-PER-M4")
    EV_PER_K = URIRef("http://qudt.org/vocab/unit/EV-PER-K")
    DeciN_M = URIRef("http://qudt.org/vocab/unit/DeciN-M")
    LB_F_PER_LB = URIRef("http://qudt.org/vocab/unit/LB_F-PER-LB")
    MicroV_A = URIRef("http://qudt.org/vocab/unit/MicroV-A")
    HR_Sidereal = URIRef("http://qudt.org/vocab/unit/HR_Sidereal")
    DEG_F_SEC_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-SEC-PER-BTU_IT")
    SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-PER-FT2")
    KiloL = URIRef("http://qudt.org/vocab/unit/KiloL")
    YD3_PER_HR = URIRef("http://qudt.org/vocab/unit/YD3-PER-HR")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    HectoL = URIRef("http://qudt.org/vocab/unit/HectoL")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    TON_UK = URIRef("http://qudt.org/vocab/unit/TON_UK")
    FemtoM = URIRef("http://qudt.org/vocab/unit/FemtoM")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    KiloGM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM2")
    M3_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-BAR")
    CentiC = URIRef("http://qudt.org/vocab/unit/CentiC")
    MOL_PER_M2_SEC_SR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-SR")
    BTU_IT_PER_HR_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2")
    GibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M")
    KiloCAL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-SEC")
    CD_IN = URIRef("http://qudt.org/vocab/unit/CD_IN")
    KiloBAUD = URIRef("http://qudt.org/vocab/unit/KiloBAUD")
    IN3_PER_HR = URIRef("http://qudt.org/vocab/unit/IN3-PER-HR")
    BIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BIT-PER-SEC")
    DeciTON_Metric = URIRef("http://qudt.org/vocab/unit/DeciTON_Metric")
    CentiM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC-K")
    SLUG_PER_FT = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT")
    PT = URIRef("http://qudt.org/vocab/unit/PT")
    M2_PER_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ2")
    MicroMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-DAY")
    KiloW_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloW-HR-PER-M2")
    KiloJ_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-HR")
    MegaBAUD = URIRef("http://qudt.org/vocab/unit/MegaBAUD")
    YR_Sidereal = URIRef("http://qudt.org/vocab/unit/YR_Sidereal")
    N_PER_MilliM = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM")
    MegaW_HR = URIRef("http://qudt.org/vocab/unit/MegaW-HR")
    KN = URIRef("http://qudt.org/vocab/unit/KN")
    PERCENT_PER_DEGREE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEGREE")
    KiloS = URIRef("http://qudt.org/vocab/unit/KiloS")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    N_M_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-M")
    TON_US_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_US-PER-YD3")
    FemtoGM_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-L")
    W = URIRef("http://qudt.org/vocab/unit/W")
    A_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-PER-CentiM2")
    BTU_IT_PER_LB_F_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_R")
    MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/MOL_LB-DEG_F")
    KiloJ_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MIN")
    BU_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-SEC")
    MilliW_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM-SR")
    W_PER_M2_K4 = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K4")
    FemtoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-L")
    PERMEABILITY_EM_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_EM_REL")
    B_PER_M = URIRef("http://qudt.org/vocab/unit/B-PER-M")
    MegaW_HR = URIRef("http://qudt.org/vocab/unit/MegaW-HR")
    MOL_PER_KiloGM_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-PA")
    MegaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-SEC")
    OZ_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_US")
    MOL_PER_M2_SEC_M_SR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-M-SR")
    C_M2 = URIRef("http://qudt.org/vocab/unit/C-M2")
    K = URIRef("http://qudt.org/vocab/unit/K")
    K = URIRef("http://qudt.org/vocab/unit/K")
    GI_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_US-PER-MIN")
    PK_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-MIN")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    KiloL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloL-PER-HR")
    PK_UK = URIRef("http://qudt.org/vocab/unit/PK_UK")
    KIP_F = URIRef("http://qudt.org/vocab/unit/KIP_F")
    LB_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-DEG_F")
    R_PER_SEC = URIRef("http://qudt.org/vocab/unit/R-PER-SEC")
    GI_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_US-PER-HR")
    BQ_PER_M2 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M2")
    GM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-M2-DAY")
    M2_PER_GM = URIRef("http://qudt.org/vocab/unit/M2-PER-GM")
    W_PER_M_K = URIRef("http://qudt.org/vocab/unit/W-PER-M-K")
    OZ_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ-PER-DAY")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    BARN_PER_SR_EV = URIRef("http://qudt.org/vocab/unit/BARN-PER-SR-EV")
    BQ_PER_L = URIRef("http://qudt.org/vocab/unit/BQ-PER-L")
    FT2_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT2-PER-SEC")
    PlanckForce = URIRef("http://qudt.org/vocab/unit/PlanckForce")
    PERCENT_SEC_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-IN3")
    KiloJ_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MIN")
    MegaGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-M3")
    GI_US = URIRef("http://qudt.org/vocab/unit/GI_US")
    KiloCAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-GM-K")
    PINT_UK = URIRef("http://qudt.org/vocab/unit/PINT_UK")
    L_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-BAR")
    KiloGM_F_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-MilliM2")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    BTU_TH_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_R")
    OZ_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN3")
    FT2_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT2-PER-SEC")
    BTU_IT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR-DEG_F")
    M3_PER_HR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR")
    W_M2 = URIRef("http://qudt.org/vocab/unit/W-M2")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    A_M2 = URIRef("http://qudt.org/vocab/unit/A-M2")
    MicroC = URIRef("http://qudt.org/vocab/unit/MicroC")
    BU_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-DAY")
    OZ_VOL_US = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US")
    GigaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-HR")
    PERM_Metric_0DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_Metric_0DEG_C")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    BTU_TH_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR-FT2-DEG_F")
    CentiM3_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    KiloCAL = URIRef("http://qudt.org/vocab/unit/KiloCAL")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    FT2_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT2-PER-SEC")
    DecaPA = URIRef("http://qudt.org/vocab/unit/DecaPA")
    M2_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/M2-SEC-PER-RAD")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    PERCENT_PER_MO = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MO")
    MilliBAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-BAR")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    MicroS_PER_M = URIRef("http://qudt.org/vocab/unit/MicroS-PER-M")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    LB_PER_YD2 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD2")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    CAL_TH_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM")
    K_PER_W = URIRef("http://qudt.org/vocab/unit/K-PER-W")
    KiloMOL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-HR")
    KiloJ_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM-K")
    J = URIRef("http://qudt.org/vocab/unit/J")
    MicroN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroN-M-PER-M2")
    LB_PER_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-HR")
    M2_K = URIRef("http://qudt.org/vocab/unit/M2-K")
    KiloGM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM-PER-SEC")
    OHM_KiloM = URIRef("http://qudt.org/vocab/unit/OHM-KiloM")
    LB_HR_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-GAL_UK")
    KiloPOND = URIRef("http://qudt.org/vocab/unit/KiloPOND")
    LB_F_PER_YD = URIRef("http://qudt.org/vocab/unit/LB_F-PER-YD")
    MegaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBIT-PER-SEC")
    J = URIRef("http://qudt.org/vocab/unit/J")
    TSP = URIRef("http://qudt.org/vocab/unit/TSP")
    PER_MO = URIRef("http://qudt.org/vocab/unit/PER-MO")
    L_PER_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-BAR")
    ERG_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM-SEC")
    OZ_SEC_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-YD3")
    KiloGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC")
    KiloM = URIRef("http://qudt.org/vocab/unit/KiloM")
    KibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M3")
    MicroC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M3")
    MilliM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM2-PER-SEC")
    BTU_IT_PER_SEC_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2")
    T = URIRef("http://qudt.org/vocab/unit/T")
    C_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM3")
    GAUSS = URIRef("http://qudt.org/vocab/unit/GAUSS")
    BU_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-DAY")
    KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT")
    EUR_PER_KiloW_HR = URIRef("http://qudt.org/vocab/unit/EUR-PER-KiloW-HR")
    MilliBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-L")
    MicroSEC = URIRef("http://qudt.org/vocab/unit/MicroSEC")
    CentiM3_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-BAR")
    FT_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-PER-HR")
    STILB = URIRef("http://qudt.org/vocab/unit/STILB")
    GM = URIRef("http://qudt.org/vocab/unit/GM")
    GI_US = URIRef("http://qudt.org/vocab/unit/GI_US")
    GM_PER_DeciM3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3-K")
    MicroSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-SEC")
    N_M_PER_A = URIRef("http://qudt.org/vocab/unit/N-M-PER-A")
    ST_PER_BAR = URIRef("http://qudt.org/vocab/unit/ST-PER-BAR")
    SHANNON_PER_SEC = URIRef("http://qudt.org/vocab/unit/SHANNON-PER-SEC")
    PPTR = URIRef("http://qudt.org/vocab/unit/PPTR")
    BU_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-MIN")
    PERCENT_PER_MilliM = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MilliM")
    LB_MIN_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-IN3")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    MilliWB = URIRef("http://qudt.org/vocab/unit/MilliWB")
    V_PER_SEC = URIRef("http://qudt.org/vocab/unit/V-PER-SEC")
    M2_SR = URIRef("http://qudt.org/vocab/unit/M2-SR")
    POND = URIRef("http://qudt.org/vocab/unit/POND")
    HZ_PER_T = URIRef("http://qudt.org/vocab/unit/HZ-PER-T")
    MilliW_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-MilliGM")
    MOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM")
    K_PER_PA = URIRef("http://qudt.org/vocab/unit/K-PER-PA")
    MebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M")
    ARCMIN = URIRef("http://qudt.org/vocab/unit/ARCMIN")
    LunarMass = URIRef("http://qudt.org/vocab/unit/LunarMass")
    CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CentiM2-MIN")
    MilliGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY")
    N_M_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-RAD")
    CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-GM")
    V_A_PER_K = URIRef("http://qudt.org/vocab/unit/V-A-PER-K")
    NanoMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L-HR")
    N_M_PER_DEG_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG-M")
    N_PER_CentiM = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM")
    V_Ab = URIRef("http://qudt.org/vocab/unit/V_Ab")
    KiloGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-K")
    L_PER_DAY = URIRef("http://qudt.org/vocab/unit/L-PER-DAY")
    MilliSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-MIN")
    TON_UK = URIRef("http://qudt.org/vocab/unit/TON_UK")
    EUR_PER_KiloW = URIRef("http://qudt.org/vocab/unit/EUR-PER-KiloW")
    MOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC")
    MI_N_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI_N-PER-MIN")
    HP_Electric = URIRef("http://qudt.org/vocab/unit/HP_Electric")
    MI_N_PER_HR = URIRef("http://qudt.org/vocab/unit/MI_N-PER-HR")
    LB_F_IN_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN-PER-IN")
    MilliGM_SEC_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M3-CentiM3")
    OHM_Stat = URIRef("http://qudt.org/vocab/unit/OHM_Stat")
    N_M_PER_ARCMIN = URIRef("http://qudt.org/vocab/unit/N-M-PER-ARCMIN")
    Pennyweight = URIRef("http://qudt.org/vocab/unit/Pennyweight")
    CentiM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL")
    PER_LB = URIRef("http://qudt.org/vocab/unit/PER-LB")
    MOL_PER_KiloGM_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-BAR")
    KiloJ_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MOL")
    LB_SEC_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-GAL_UK")
    DYN_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-CentiM")
    CentiM_H2O = URIRef("http://qudt.org/vocab/unit/CentiM_H2O")
    KiloGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-K")
    MicroGM_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L-HR")
    LB_PER_GAL = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL")
    A_PER_M2_K2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2-K2")
    MilliPA_PER_M = URIRef("http://qudt.org/vocab/unit/MilliPA-PER-M")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    MHO = URIRef("http://qudt.org/vocab/unit/MHO")
    LB_MIN_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-IN3")
    PERCENT_MIN_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-YD3")
    KiloMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-KiloGM")
    PERMEABILITY_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_REL")
    PK_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-HR")
    PERM_Metric_23DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_Metric_23DEG_C")
    CAL_TH_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM")
    S_Stat = URIRef("http://qudt.org/vocab/unit/S_Stat")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    PA_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M")
    PicoA_PER_HectoPA = URIRef("http://qudt.org/vocab/unit/PicoA-PER-HectoPA")
    RAD_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-KiloGM")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    KiloJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM")
    MegaEV_FemtoM = URIRef("http://qudt.org/vocab/unit/MegaEV-FemtoM")
    KiloV_PER_M = URIRef("http://qudt.org/vocab/unit/KiloV-PER-M")
    W_PER_M = URIRef("http://qudt.org/vocab/unit/W-PER-M")
    UNKNOWN = URIRef("http://qudt.org/vocab/unit/UNKNOWN")
    OZ_TROY = URIRef("http://qudt.org/vocab/unit/OZ_TROY")
    PicoA = URIRef("http://qudt.org/vocab/unit/PicoA")
    KiloOHM = URIRef("http://qudt.org/vocab/unit/KiloOHM")
    HP_Metric = URIRef("http://qudt.org/vocab/unit/HP_Metric")
    M_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-PA")
    PicoV_A_Reactive = URIRef("http://qudt.org/vocab/unit/PicoV-A_Reactive")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    KiloL = URIRef("http://qudt.org/vocab/unit/KiloL")
    MegaPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-M3-PER-SEC")
    EUR_PER_W = URIRef("http://qudt.org/vocab/unit/EUR-PER-W")
    A_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM2")
    KiloGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-K")
    BTU_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-MIN")
    MilliL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-SEC")
    MicroN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroN-M-PER-M2")
    PicoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L")
    Debye = URIRef("http://qudt.org/vocab/unit/Debye")
    MilliL_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-BAR")
    N_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-RAD")
    M_H2O = URIRef("http://qudt.org/vocab/unit/M_H2O")
    GM_PER_HR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR")
    PDL_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/PDL-SEC-PER-IN2")
    W_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-PER-KiloGM")
    MilliGM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-K")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    LB_PER_FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-LB_F-SEC")
    PERCENT_SEC_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-GAL_US")
    NUM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/NUM-PER-KiloM2")
    MESH = URIRef("http://qudt.org/vocab/unit/MESH")
    K_M2_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/K-M2-PER-KiloGM-SEC")
    CentiPOISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-BAR")
    FRACTION = URIRef("http://qudt.org/vocab/unit/FRACTION")
    KiloCAL_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-HR")
    MilliGM_SEC_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M3-L")
    LB_MIN_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-GAL_UK")
    MilliL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-KiloGM")
    H_Stat = URIRef("http://qudt.org/vocab/unit/H_Stat")
    NanoA = URIRef("http://qudt.org/vocab/unit/NanoA")
    PER_CentiM = URIRef("http://qudt.org/vocab/unit/PER-CentiM")
    BTU_IT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MIN")
    LB_FT2 = URIRef("http://qudt.org/vocab/unit/LB-FT2")
    TON_LONG = URIRef("http://qudt.org/vocab/unit/TON_LONG")
    DEG_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC")
    OZ_PER_FT2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-FT2")
    DEG_C_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-MIN")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    BTU_IT_PER_HR_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2")
    KiloGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-K")
    MicroC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M3")
    J_M_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-M-PER-MOL")
    OHM_CentiM = URIRef("http://qudt.org/vocab/unit/OHM-CentiM")
    PlanckMass = URIRef("http://qudt.org/vocab/unit/PlanckMass")
    KiloGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PER-CentiM3")
    MicroPOISE = URIRef("http://qudt.org/vocab/unit/MicroPOISE")
    NanoH = URIRef("http://qudt.org/vocab/unit/NanoH")
    BTU_IT_PER_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL-DEG_F")
    KiloGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY")
    S_PER_CentiM = URIRef("http://qudt.org/vocab/unit/S-PER-CentiM")
    MegaPSI = URIRef("http://qudt.org/vocab/unit/MegaPSI")
    MilliN = URIRef("http://qudt.org/vocab/unit/MilliN")
    FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/FT2-PER-BTU_IT-IN")
    K_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PER-SEC")
    V_PER_MilliM = URIRef("http://qudt.org/vocab/unit/V-PER-MilliM")
    TON_Metric_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC-BAR")
    MilliHZ = URIRef("http://qudt.org/vocab/unit/MilliHZ")
    CentiM3_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY-K")
    CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-SEC")
    MegaW_HR = URIRef("http://qudt.org/vocab/unit/MegaW-HR")
    M_PER_YR = URIRef("http://qudt.org/vocab/unit/M-PER-YR")
    MilliGM_PER_M3_POISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-POISE")
    HR_Sidereal = URIRef("http://qudt.org/vocab/unit/HR_Sidereal")
    A_PER_CentiM = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM")
    MicroGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3")
    MegaOHM_KiloM = URIRef("http://qudt.org/vocab/unit/MegaOHM-KiloM")
    KiloGM_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MOL")
    PERCENT_SEC_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-L")
    OZ_VOL_UK = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    AMU = URIRef("http://qudt.org/vocab/unit/AMU")
    MegaV_A = URIRef("http://qudt.org/vocab/unit/MegaV-A")
    DEG_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC")
    RAD_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-KiloGM")
    NanoGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DeciL")
    MicroSEC = URIRef("http://qudt.org/vocab/unit/MicroSEC")
    TONNE = URIRef("http://qudt.org/vocab/unit/TONNE")
    ExbiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M3")
    KiloCAL_TH = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH")
    KiloGM_F_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-SEC")
    GigaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-HR")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    PER_HR = URIRef("http://qudt.org/vocab/unit/PER-HR")
    LB_IN2_PER_FT3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-FT3-LB_F-SEC")
    AttoA = URIRef("http://qudt.org/vocab/unit/AttoA")
    FT_SEC_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-GAL_UK")
    WK = URIRef("http://qudt.org/vocab/unit/WK")
    A_PER_J = URIRef("http://qudt.org/vocab/unit/A-PER-J")
    K = URIRef("http://qudt.org/vocab/unit/K")
    PicoGM_PER_GM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-GM")
    GigaPA_CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/GigaPA-CentiM3-PER-GM")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    FT_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-PER-MIN")
    MegaC = URIRef("http://qudt.org/vocab/unit/MegaC")
    TORR_PER_M = URIRef("http://qudt.org/vocab/unit/TORR-PER-M")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    FT_HR_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-GAL_UK")
    PER_V = URIRef("http://qudt.org/vocab/unit/PER-V")
    MilliJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-M2")
    N_M_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-RAD")
    AC_FT = URIRef("http://qudt.org/vocab/unit/AC-FT")
    MilliM_PER_DEG_C_M = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DEG_C-M")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    BU_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-HR")
    NanoS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/NanoS-PER-CentiM")
    PER_YR = URIRef("http://qudt.org/vocab/unit/PER-YR")
    IN_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN-PER-MIN")
    MicroGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-HR")
    DEG_F_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC2")
    MilliGM = URIRef("http://qudt.org/vocab/unit/MilliGM")
    GM_Carbon_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Carbon-PER-M2-DAY")
    LB_F_PER_YD = URIRef("http://qudt.org/vocab/unit/LB_F-PER-YD")
    H_PER_OHM = URIRef("http://qudt.org/vocab/unit/H-PER-OHM")
    KiloHZ_M = URIRef("http://qudt.org/vocab/unit/KiloHZ-M")
    PicoGM_PER_GM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-GM")
    PERCENT_HR_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-YD3")
    N_M2_PER_A = URIRef("http://qudt.org/vocab/unit/N-M2-PER-A")
    W_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM")
    DEG_C_PER_YR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-YR")
    TONNE_PER_SEC = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    M2_HZ = URIRef("http://qudt.org/vocab/unit/M2-HZ")
    V_Stat = URIRef("http://qudt.org/vocab/unit/V_Stat")
    KiloR = URIRef("http://qudt.org/vocab/unit/KiloR")
    MicroS_PER_M = URIRef("http://qudt.org/vocab/unit/MicroS-PER-M")
    MicroRAD = URIRef("http://qudt.org/vocab/unit/MicroRAD")
    TON_F_US = URIRef("http://qudt.org/vocab/unit/TON_F_US")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    LB_HR_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-GAL_UK")
    PER_MO = URIRef("http://qudt.org/vocab/unit/PER-MO")
    PH = URIRef("http://qudt.org/vocab/unit/PH")
    LB_MIN_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-YD3")
    MI3 = URIRef("http://qudt.org/vocab/unit/MI3")
    KiloOHM = URIRef("http://qudt.org/vocab/unit/KiloOHM")
    MilliOHM_M = URIRef("http://qudt.org/vocab/unit/MilliOHM-M")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    TONNE_PER_HA = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA")
    MilliGM_MIN_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M3-L")
    B = URIRef("http://qudt.org/vocab/unit/B")
    PDL_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/PDL-SEC-PER-IN2")
    J_PER_GM_K = URIRef("http://qudt.org/vocab/unit/J-PER-GM-K")
    C_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Ab-PER-CentiM2")
    YottaC = URIRef("http://qudt.org/vocab/unit/YottaC")
    N_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M")
    BTU_IT = URIRef("http://qudt.org/vocab/unit/BTU_IT")
    GM_PER_MilliL_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL-BAR")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    PA_M0dot5 = URIRef("http://qudt.org/vocab/unit/PA-M0dot5")
    PA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M3-PER-SEC")
    KiloGM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM")
    FT_LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2")
    N_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-PER-KiloGM")
    MicroW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroW-PER-M2")
    Hundredweight_UK = URIRef("http://qudt.org/vocab/unit/Hundredweight_UK")
    M2_PER_HA = URIRef("http://qudt.org/vocab/unit/M2-PER-HA")
    FT_PDL = URIRef("http://qudt.org/vocab/unit/FT-PDL")
    GM_MilliM = URIRef("http://qudt.org/vocab/unit/GM-MilliM")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    MicroFARAD = URIRef("http://qudt.org/vocab/unit/MicroFARAD")
    M3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-K")
    CHAIN_US = URIRef("http://qudt.org/vocab/unit/CHAIN_US")
    OHM_KiloM = URIRef("http://qudt.org/vocab/unit/OHM-KiloM")
    FM = URIRef("http://qudt.org/vocab/unit/FM")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    CentiMOL_PER_L = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-L")
    TON_Metric = URIRef("http://qudt.org/vocab/unit/TON_Metric")
    KiloGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-K")
    MegaHZ_PER_T = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-T")
    MilliL_PER_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-K")
    R = URIRef("http://qudt.org/vocab/unit/R")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    MilliW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2")
    MilliGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-SEC")
    PPQ = URIRef("http://qudt.org/vocab/unit/PPQ")
    W = URIRef("http://qudt.org/vocab/unit/W")
    J_PER_M3_K = URIRef("http://qudt.org/vocab/unit/J-PER-M3-K")
    MicroKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MicroKAT-PER-L")
    KN_PER_SEC = URIRef("http://qudt.org/vocab/unit/KN-PER-SEC")
    K_M_PER_W = URIRef("http://qudt.org/vocab/unit/K-M-PER-W")
    M2_PER_KiloW = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloW")
    LB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    PPTM = URIRef("http://qudt.org/vocab/unit/PPTM")
    A_PER_K = URIRef("http://qudt.org/vocab/unit/A-PER-K")
    YD3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD3-PER-DEG_F")
    A_Ab = URIRef("http://qudt.org/vocab/unit/A_Ab")
    J_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    BTU_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC")
    OHM_KiloM = URIRef("http://qudt.org/vocab/unit/OHM-KiloM")
    SLUG_PER_FT = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT")
    PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-PER-SEC")
    NUM_PER_YR = URIRef("http://qudt.org/vocab/unit/NUM-PER-YR")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    QT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_US-PER-DAY")
    KiloBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT")
    A_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-PER-CentiM2")
    MilliT = URIRef("http://qudt.org/vocab/unit/MilliT")
    J_PER_MIN = URIRef("http://qudt.org/vocab/unit/J-PER-MIN")
    FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F")
    MegaHZ = URIRef("http://qudt.org/vocab/unit/MegaHZ")
    MI_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI-PER-MIN")
    POISE_PER_PA = URIRef("http://qudt.org/vocab/unit/POISE-PER-PA")
    MOL_PER_TONNE = URIRef("http://qudt.org/vocab/unit/MOL-PER-TONNE")
    TONNE_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY-BAR")
    DEG_C_PER_YR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-YR")
    M_PER_YR = URIRef("http://qudt.org/vocab/unit/M-PER-YR")
    K_SEC = URIRef("http://qudt.org/vocab/unit/K-SEC")
    BARN = URIRef("http://qudt.org/vocab/unit/BARN")
    MicroM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-M3")
    TON_Metric_PER_M3 = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3")
    IU_PER_L = URIRef("http://qudt.org/vocab/unit/IU-PER-L")
    SH = URIRef("http://qudt.org/vocab/unit/SH")
    MilliL_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-BAR")
    J_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K")
    W = URIRef("http://qudt.org/vocab/unit/W")
    DeciM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-DAY")
    MDOLLAR_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MDOLLAR-PER-FLIGHT")
    MHO_Stat = URIRef("http://qudt.org/vocab/unit/MHO_Stat")
    FT_LB_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-MIN")
    KiloCAL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-SEC")
    TONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-YR")
    KiloA = URIRef("http://qudt.org/vocab/unit/KiloA")
    LB_PER_FT3 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3")
    MilliL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN")
    MicroC = URIRef("http://qudt.org/vocab/unit/MicroC")
    M6 = URIRef("http://qudt.org/vocab/unit/M6")
    FT_LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2")
    BBL_UK_PET_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-MIN")
    GT = URIRef("http://qudt.org/vocab/unit/GT")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    MicroW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroW-PER-M2")
    GigaOHM = URIRef("http://qudt.org/vocab/unit/GigaOHM")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    BQ_PER_M2 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M2")
    TONNE_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR-BAR")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    MOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-SEC")
    GM_PER_MilliM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM-BAR")
    GM_SEC_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L-M3")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    REV_PER_MIN = URIRef("http://qudt.org/vocab/unit/REV-PER-MIN")
    MI_US_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/MI_US-PER-SEC2")
    KibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M")
    NanoFARAD = URIRef("http://qudt.org/vocab/unit/NanoFARAD")
    DEG_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC2")
    FT3 = URIRef("http://qudt.org/vocab/unit/FT3")
    Debye = URIRef("http://qudt.org/vocab/unit/Debye")
    H = URIRef("http://qudt.org/vocab/unit/H")
    POISE = URIRef("http://qudt.org/vocab/unit/POISE")
    CD_PER_IN2 = URIRef("http://qudt.org/vocab/unit/CD-PER-IN2")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    MilliGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MilliL")
    KiloN = URIRef("http://qudt.org/vocab/unit/KiloN")
    N_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-RAD")
    DEG_C2_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C2-PER-SEC")
    DYN = URIRef("http://qudt.org/vocab/unit/DYN")
    MO_Synodic = URIRef("http://qudt.org/vocab/unit/MO_Synodic")
    MegaTOE = URIRef("http://qudt.org/vocab/unit/MegaTOE")
    PER_WK = URIRef("http://qudt.org/vocab/unit/PER-WK")
    MilliK_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliK-PER-BAR")
    LB_F_FT_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-FT-PER-IN")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    H_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/H_Stat-PER-CentiM")
    MicroGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-HR")
    MilliM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliM-PER-K")
    FT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-DEG_F")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    DECADE = URIRef("http://qudt.org/vocab/unit/DECADE")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A-HR")
    LB_FT2_PER_GAL_US_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-GAL_US-LB_F-SEC")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    TSP = URIRef("http://qudt.org/vocab/unit/TSP")
    MegaPA_M0pt5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0pt5")
    PetaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/PetaJ-PER-SEC")
    CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-GM")
    PER_YR = URIRef("http://qudt.org/vocab/unit/PER-YR")
    W_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M2")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    MilliM2 = URIRef("http://qudt.org/vocab/unit/MilliM2")
    N_M_PER_A = URIRef("http://qudt.org/vocab/unit/N-M-PER-A")
    FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F")
    L_PER_MIN = URIRef("http://qudt.org/vocab/unit/L-PER-MIN")
    PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PER-SEC2")
    N_CentiM = URIRef("http://qudt.org/vocab/unit/N-CentiM")
    MilliGM_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-HR")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    IN2 = URIRef("http://qudt.org/vocab/unit/IN2")
    MegaJ_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M3")
    V = URIRef("http://qudt.org/vocab/unit/V")
    PER_MicroMOL_L = URIRef("http://qudt.org/vocab/unit/PER-MicroMOL-L")
    MilliA_HR = URIRef("http://qudt.org/vocab/unit/MilliA-HR")
    TON_Assay = URIRef("http://qudt.org/vocab/unit/TON_Assay")
    MilliGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-HR")
    AttoC = URIRef("http://qudt.org/vocab/unit/AttoC")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    DIOPTER = URIRef("http://qudt.org/vocab/unit/DIOPTER")
    DEG_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC")
    M3_PER_K = URIRef("http://qudt.org/vocab/unit/M3-PER-K")
    A_PER_M2_K2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2-K2")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    MilliGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY")
    NanoGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M3")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    MicroGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-HR")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    FT_US = URIRef("http://qudt.org/vocab/unit/FT_US")
    MilliM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM2-PER-SEC")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    A_Ab_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-CentiM2")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    NanoM2 = URIRef("http://qudt.org/vocab/unit/NanoM2")
    PA_SEC_PER_K = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-K")
    TebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M3")
    KiloJ_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MOL")
    IN2 = URIRef("http://qudt.org/vocab/unit/IN2")
    MilliGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-K")
    BTU_IT_PER_HR_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_R")
    W_PER_SR_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-SR-M2")
    W_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/W-PER-CentiM2")
    DPI = URIRef("http://qudt.org/vocab/unit/DPI")
    IN_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC2")
    OZ_SEC_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-FT3")
    KiloPA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-M")
    ST_PER_K = URIRef("http://qudt.org/vocab/unit/ST-PER-K")
    PERMEABILITY_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_REL")
    BTU_IT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR-DEG_F")
    FT3_PER_PSI = URIRef("http://qudt.org/vocab/unit/FT3-PER-PSI")
    ANGSTROM = URIRef("http://qudt.org/vocab/unit/ANGSTROM")
    ERG_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM-SEC")
    W_HR_PER_L = URIRef("http://qudt.org/vocab/unit/W-HR-PER-L")
    C_PER_MOL = URIRef("http://qudt.org/vocab/unit/C-PER-MOL")
    MilliM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-M3")
    NanoGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-HR")
    MI = URIRef("http://qudt.org/vocab/unit/MI")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    C = URIRef("http://qudt.org/vocab/unit/C")
    MicroIN = URIRef("http://qudt.org/vocab/unit/MicroIN")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    CI_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CI-PER-KiloGM")
    MilliMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2")
    GM_PER_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-BAR")
    MilliGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HA")
    CentiM_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-HR")
    PSI_IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-IN3-PER-SEC")
    DRAM_US = URIRef("http://qudt.org/vocab/unit/DRAM_US")
    PetaBIT = URIRef("http://qudt.org/vocab/unit/PetaBIT")
    CentiM_H20_4DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_H20_4DEG_C")
    PERCENT_PER_DecaKiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaKiloCount")
    C_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM3")
    M3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-BAR")
    DEG_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC")
    MegaOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-BAR")
    MilliGM_PER_M3_CentiPOISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-CentiPOISE")
    K_PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PA-PER-SEC")
    K_M2_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/K-M2-PER-KiloGM-SEC")
    KiloLB_F_FT_PER_A = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-A")
    TON_Metric_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN-BAR")
    IN_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-DEG_F")
    MilliGAL_PER_MO = URIRef("http://qudt.org/vocab/unit/MilliGAL-PER-MO")
    K = URIRef("http://qudt.org/vocab/unit/K")
    BTU_IT_IN_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-HR-FT2-DEG_F")
    PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/PER-KiloGM-SEC")
    MicroSV = URIRef("http://qudt.org/vocab/unit/MicroSV")
    W_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/W-PER-CentiM2")
    MilliGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-K")
    PK_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-HR")
    FemtoC = URIRef("http://qudt.org/vocab/unit/FemtoC")
    BBL_UK_PET_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-DAY")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    CentiBAR = URIRef("http://qudt.org/vocab/unit/CentiBAR")
    MicroM3 = URIRef("http://qudt.org/vocab/unit/MicroM3")
    TON_Metric_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN-BAR")
    LB_PER_FT_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-MIN")
    TONNE = URIRef("http://qudt.org/vocab/unit/TONNE")
    PERCENT_HR_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-YD3")
    W_M_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-M-PER-M2-SR")
    PERCENT_PER_M = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-M")
    BTU_IT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_F")
    DEG_F_HR_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_IT")
    KiloPA_M2_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloPA-M2-PER-GM")
    A_HR_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-HR-PER-DEG_C")
    CentiM_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-K")
    T = URIRef("http://qudt.org/vocab/unit/T")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    GM_F = URIRef("http://qudt.org/vocab/unit/GM_F")
    M2_PER_M2 = URIRef("http://qudt.org/vocab/unit/M2-PER-M2")
    NanoFARAD = URIRef("http://qudt.org/vocab/unit/NanoFARAD")
    KiloCAL_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2")
    PER_MO = URIRef("http://qudt.org/vocab/unit/PER-MO")
    GI_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-SEC")
    N_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M")
    GM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2")
    DEGREE_BAUME_US_LIGHT = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_LIGHT")
    KiloGM_PER_M_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC")
    BU_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-SEC")
    GigaJ = URIRef("http://qudt.org/vocab/unit/GigaJ")
    PlanckTemperature = URIRef("http://qudt.org/vocab/unit/PlanckTemperature")
    MegaBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaBQ-PER-KiloGM")
    OZ_MIN_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-GAL_UK")
    T = URIRef("http://qudt.org/vocab/unit/T")
    BU_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-MIN")
    MilliA_PER_K = URIRef("http://qudt.org/vocab/unit/MilliA-PER-K")
    MicroMOL_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM-SEC")
    MegaBAUD = URIRef("http://qudt.org/vocab/unit/MegaBAUD")
    N_M_PER_M_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-M-RAD")
    DEGREE_BAUME = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME")
    FARAD_Ab = URIRef("http://qudt.org/vocab/unit/FARAD_Ab")
    TeraBIT = URIRef("http://qudt.org/vocab/unit/TeraBIT")
    MegaPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-M3-PER-SEC")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    OZ_HR_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN6")
    LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC")
    DeciC = URIRef("http://qudt.org/vocab/unit/DeciC")
    MilliM4 = URIRef("http://qudt.org/vocab/unit/MilliM4")
    L_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-MOL-SEC")
    YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD3-PER-SEC")
    MegaBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaBTU_IT-PER-HR")
    MicroGAL_PER_M = URIRef("http://qudt.org/vocab/unit/MicroGAL-PER-M")
    GM_PER_HZ = URIRef("http://qudt.org/vocab/unit/GM-PER-HZ")
    GR = URIRef("http://qudt.org/vocab/unit/GR")
    W_PER_M2_K = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K")
    NanoMOL_PER_MicroMOL_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL-DAY")
    GibiBIT = URIRef("http://qudt.org/vocab/unit/GibiBIT")
    OHM_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-PER-M")
    L_PER_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-SEC")
    M3_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-K")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    MilliM_HG = URIRef("http://qudt.org/vocab/unit/MilliM_HG")
    N_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M3")
    C_Stat = URIRef("http://qudt.org/vocab/unit/C_Stat")
    NanoSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-MIN")
    OZ_HR_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-FT3")
    C_Ab = URIRef("http://qudt.org/vocab/unit/C_Ab")
    KiloPA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-K")
    TeraV_A_Reactive = URIRef("http://qudt.org/vocab/unit/TeraV-A_Reactive")
    MilliFARAD = URIRef("http://qudt.org/vocab/unit/MilliFARAD")
    ST_PER_K = URIRef("http://qudt.org/vocab/unit/ST-PER-K")
    PERCENT_PER_PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-PERCENT")
    KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloM2")
    LB_FT2_PER_GAL_US_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-GAL_US-LB_F-SEC")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    FT_LB_F = URIRef("http://qudt.org/vocab/unit/FT-LB_F")
    MilliA_PER_LB_F_IN2 = URIRef("http://qudt.org/vocab/unit/MilliA-PER-LB_F-IN2")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    N_M_PER_MIN_Angle = URIRef("http://qudt.org/vocab/unit/N-M-PER-MIN_Angle")
    CentiM3_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR")
    PER_TON = URIRef("http://qudt.org/vocab/unit/PER-TON")
    LB_SEC_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN6")
    MilliBAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-M3-PER-SEC")
    PicoA_PER_HectoPA = URIRef("http://qudt.org/vocab/unit/PicoA-PER-HectoPA")
    BTU_IT_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    KiloGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-BAR")
    KiloM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-HR")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    BAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/BAR-PER-BAR")
    A_Stat = URIRef("http://qudt.org/vocab/unit/A_Stat")
    A_PER_M2_K2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2-K2")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    MicroGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3")
    QT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-DAY")
    PERCENT_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEG_C")
    MegaPA = URIRef("http://qudt.org/vocab/unit/MegaPA")
    KN_PER_SEC = URIRef("http://qudt.org/vocab/unit/KN-PER-SEC")
    A_MIN = URIRef("http://qudt.org/vocab/unit/A-MIN")
    KiloGM_PER_KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloMOL")
    BU_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-DAY")
    PER_HR = URIRef("http://qudt.org/vocab/unit/PER-HR")
    PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/PER-MilliM3")
    A_PER_J = URIRef("http://qudt.org/vocab/unit/A-PER-J")
    MegaLB_F = URIRef("http://qudt.org/vocab/unit/MegaLB_F")
    DEG2 = URIRef("http://qudt.org/vocab/unit/DEG2")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    ExaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/ExaJ-PER-SEC")
    MegaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M2")
    MilliMOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2-SEC")
    PERCENT_SEC_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-L")
    PetaHZ = URIRef("http://qudt.org/vocab/unit/PetaHZ")
    MilliV_PER_V = URIRef("http://qudt.org/vocab/unit/MilliV-PER-V")
    FT_LB_F_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-HR")
    MegaJ = URIRef("http://qudt.org/vocab/unit/MegaJ")
    PicoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L")
    IN_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN-PER-MIN")
    MegaEV = URIRef("http://qudt.org/vocab/unit/MegaEV")
    BBL_UK_PET_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-DAY")
    CORD = URIRef("http://qudt.org/vocab/unit/CORD")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    M_PER_PA = URIRef("http://qudt.org/vocab/unit/M-PER-PA")
    PlanckDensity = URIRef("http://qudt.org/vocab/unit/PlanckDensity")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    N_M2_PER_A = URIRef("http://qudt.org/vocab/unit/N-M2-PER-A")
    LB_SEC_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-IN3")
    MX = URIRef("http://qudt.org/vocab/unit/MX")
    M6 = URIRef("http://qudt.org/vocab/unit/M6")
    OZ_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ-PER-SEC")
    C_PER_MOL = URIRef("http://qudt.org/vocab/unit/C-PER-MOL")
    KiloCAL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-MIN")
    PlanckTemperature = URIRef("http://qudt.org/vocab/unit/PlanckTemperature")
    FRACTION = URIRef("http://qudt.org/vocab/unit/FRACTION")
    GM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    AttoFARAD = URIRef("http://qudt.org/vocab/unit/AttoFARAD")
    CentiM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY")
    KiloBTU_TH = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH")
    PINT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-SEC")
    GRAIN = URIRef("http://qudt.org/vocab/unit/GRAIN")
    NanoH_PER_M = URIRef("http://qudt.org/vocab/unit/NanoH-PER-M")
    GM_SEC_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M3-CentiM3")
    KiloC_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M2")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    KiloGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloGM")
    A_PER_RAD = URIRef("http://qudt.org/vocab/unit/A-PER-RAD")
    HR_PER_FT2 = URIRef("http://qudt.org/vocab/unit/HR-PER-FT2")
    EV = URIRef("http://qudt.org/vocab/unit/EV")
    NP = URIRef("http://qudt.org/vocab/unit/NP")
    MilliGM_MIN_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L2")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    PicoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-KiloGM")
    N_CentiM = URIRef("http://qudt.org/vocab/unit/N-CentiM")
    PARSEC = URIRef("http://qudt.org/vocab/unit/PARSEC")
    MicroFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-M")
    PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PER-SEC2")
    GAL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-SEC")
    GibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    DeciTON_Metric = URIRef("http://qudt.org/vocab/unit/DeciTON_Metric")
    KiloR = URIRef("http://qudt.org/vocab/unit/KiloR")
    KiloV_A_Reactive = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive")
    DecaM = URIRef("http://qudt.org/vocab/unit/DecaM")
    PA_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    SLUG_PER_FT2 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT2")
    IU_PER_MilliL = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliL")
    ANGSTROM3 = URIRef("http://qudt.org/vocab/unit/ANGSTROM3")
    GM_PER_L = URIRef("http://qudt.org/vocab/unit/GM-PER-L")
    HectoL = URIRef("http://qudt.org/vocab/unit/HectoL")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    V_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V-PER-CentiM")
    LB_IN2_PER_FT3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-FT3-LB_F-SEC")
    LY = URIRef("http://qudt.org/vocab/unit/LY")
    DeciS = URIRef("http://qudt.org/vocab/unit/DeciS")
    FATH = URIRef("http://qudt.org/vocab/unit/FATH")
    KiloPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-BAR")
    QT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_US-PER-SEC")
    DeciTON_Metric = URIRef("http://qudt.org/vocab/unit/DeciTON_Metric")
    DEG_F_HR_FT2_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    CentiST = URIRef("http://qudt.org/vocab/unit/CentiST")
    YD3_PER_DAY = URIRef("http://qudt.org/vocab/unit/YD3-PER-DAY")
    GM_PER_L_POISE = URIRef("http://qudt.org/vocab/unit/GM-PER-L-POISE")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    FT2 = URIRef("http://qudt.org/vocab/unit/FT2")
    L_PER_HR_K = URIRef("http://qudt.org/vocab/unit/L-PER-HR-K")
    LB_IN2 = URIRef("http://qudt.org/vocab/unit/LB-IN2")
    PK_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-MIN")
    KiloBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBIT-PER-SEC")
    LB_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-SEC")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    U = URIRef("http://qudt.org/vocab/unit/U")
    BTU_IT_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_R")
    FT_HR_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-GAL_UK")
    MOL_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-DeciM3")
    KiloGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC")
    KiloLB_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloLB-PER-HR")
    PPTM_PER_K = URIRef("http://qudt.org/vocab/unit/PPTM-PER-K")
    G = URIRef("http://qudt.org/vocab/unit/G")
    J = URIRef("http://qudt.org/vocab/unit/J")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    MOL_PER_L = URIRef("http://qudt.org/vocab/unit/MOL-PER-L")
    AU = URIRef("http://qudt.org/vocab/unit/AU")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    GI_US = URIRef("http://qudt.org/vocab/unit/GI_US")
    MegaGM = URIRef("http://qudt.org/vocab/unit/MegaGM")
    DecaARE = URIRef("http://qudt.org/vocab/unit/DecaARE")
    DWT = URIRef("http://qudt.org/vocab/unit/DWT")
    LM_SEC = URIRef("http://qudt.org/vocab/unit/LM-SEC")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    MilliGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3")
    LB_F_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-SEC")
    CAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC")
    DYN_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM3")
    L_PER_MIN = URIRef("http://qudt.org/vocab/unit/L-PER-MIN")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    IN_H2O = URIRef("http://qudt.org/vocab/unit/IN_H2O")
    GAL_IMP = URIRef("http://qudt.org/vocab/unit/GAL_IMP")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    LB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT")
    M3_PER_K = URIRef("http://qudt.org/vocab/unit/M3-PER-K")
    SLUG_PER_MIN = URIRef("http://qudt.org/vocab/unit/SLUG-PER-MIN")
    LB_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT2")
    L_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-HR-BAR")
    PERCENT_PER_IN = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-IN")
    PINT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-HR")
    NanoGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2")
    KiloGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-K")
    BTU_TH_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_R")
    MicroOHM_M = URIRef("http://qudt.org/vocab/unit/MicroOHM-M")
    GM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2")
    V_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V-PER-CentiM")
    DPI = URIRef("http://qudt.org/vocab/unit/DPI")
    MI3 = URIRef("http://qudt.org/vocab/unit/MI3")
    PicoM = URIRef("http://qudt.org/vocab/unit/PicoM")
    K_PER_W = URIRef("http://qudt.org/vocab/unit/K-PER-W")
    V = URIRef("http://qudt.org/vocab/unit/V")
    DeciS_PER_M = URIRef("http://qudt.org/vocab/unit/DeciS-PER-M")
    IN3 = URIRef("http://qudt.org/vocab/unit/IN3")
    GAL_US = URIRef("http://qudt.org/vocab/unit/GAL_US")
    MegaGM = URIRef("http://qudt.org/vocab/unit/MegaGM")
    MegaPA = URIRef("http://qudt.org/vocab/unit/MegaPA")
    W_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M2")
    MilliL_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-BAR")
    AttoFARAD = URIRef("http://qudt.org/vocab/unit/AttoFARAD")
    Kilo_FT3 = URIRef("http://qudt.org/vocab/unit/Kilo-FT3")
    MOL_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-K")
    M_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-K")
    GM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR-BAR")
    MilliGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2")
    FT = URIRef("http://qudt.org/vocab/unit/FT")
    PER_MO = URIRef("http://qudt.org/vocab/unit/PER-MO")
    STILB = URIRef("http://qudt.org/vocab/unit/STILB")
    MOL_PER_L_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-L-K")
    DeciM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MOL")
    CentiM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SEC")
    SV_PER_HR = URIRef("http://qudt.org/vocab/unit/SV-PER-HR")
    TONNE_PER_HA_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA-YR")
    PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-PER-SEC")
    CentiM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC")
    V_PER_SEC = URIRef("http://qudt.org/vocab/unit/V-PER-SEC")
    PlanckTemperature = URIRef("http://qudt.org/vocab/unit/PlanckTemperature")
    MilliGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2")
    A_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM2")
    J_M2 = URIRef("http://qudt.org/vocab/unit/J-M2")
    MilliGM_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-HR")
    MilliA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliA-PER-BAR")
    GigaOHM_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-M")
    NanoSV_PER_HR = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-HR")
    PINT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-MIN")
    FT_LB_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-MIN")
    KiloYR = URIRef("http://qudt.org/vocab/unit/KiloYR")
    OZ_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ-PER-MIN")
    DYN_M = URIRef("http://qudt.org/vocab/unit/DYN-M")
    PER_MilliL = URIRef("http://qudt.org/vocab/unit/PER-MilliL")
    N_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-PER-RAD")
    FemtoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-KiloGM")
    PicoA = URIRef("http://qudt.org/vocab/unit/PicoA")
    MilliL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M3")
    TON_Metric = URIRef("http://qudt.org/vocab/unit/TON_Metric")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    MicroBAR = URIRef("http://qudt.org/vocab/unit/MicroBAR")
    MilliL_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-K")
    M6 = URIRef("http://qudt.org/vocab/unit/M6")
    PER_J_M3 = URIRef("http://qudt.org/vocab/unit/PER-J-M3")
    LB_IN2 = URIRef("http://qudt.org/vocab/unit/LB-IN2")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    KiloBAR = URIRef("http://qudt.org/vocab/unit/KiloBAR")
    ElementaryCharge = URIRef("http://qudt.org/vocab/unit/ElementaryCharge")
    SEC2 = URIRef("http://qudt.org/vocab/unit/SEC2")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    W_PER_IN2 = URIRef("http://qudt.org/vocab/unit/W-PER-IN2")
    BBL_US_DRY = URIRef("http://qudt.org/vocab/unit/BBL_US_DRY")
    GigaA = URIRef("http://qudt.org/vocab/unit/GigaA")
    M2_K_PER_W = URIRef("http://qudt.org/vocab/unit/M2-K-PER-W")
    MOL_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-L-BAR")
    KiloGM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-FT2")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    Kilo_FT3 = URIRef("http://qudt.org/vocab/unit/Kilo-FT3")
    TON_FG = URIRef("http://qudt.org/vocab/unit/TON_FG")
    PicoPA = URIRef("http://qudt.org/vocab/unit/PicoPA")
    OZ_VOL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-SEC")
    C3_M_PER_J2 = URIRef("http://qudt.org/vocab/unit/C3-M-PER-J2")
    B_PER_M = URIRef("http://qudt.org/vocab/unit/B-PER-M")
    BTU_TH_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_F")
    UNKNOWN = URIRef("http://qudt.org/vocab/unit/UNKNOWN")
    NanoMOL_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL")
    IN_PER_2PiRAD = URIRef("http://qudt.org/vocab/unit/IN-PER-2PiRAD")
    NanoMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL")
    YottaC = URIRef("http://qudt.org/vocab/unit/YottaC")
    N_M_PER_M_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-M-RAD")
    DecaM = URIRef("http://qudt.org/vocab/unit/DecaM")
    J_PER_GM_K = URIRef("http://qudt.org/vocab/unit/J-PER-GM-K")
    MilliGM = URIRef("http://qudt.org/vocab/unit/MilliGM")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    A_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Stat-PER-CentiM2")
    DEG_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-MIN")
    MilliGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-BAR")
    PINT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-SEC")
    PetaC = URIRef("http://qudt.org/vocab/unit/PetaC")
    GM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM_F-PER-CentiM2")
    MilloMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilloMOL-PER-L")
    MilliGM_PER_L_PA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-PA-SEC")
    LB_F_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-SEC")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT2")
    MebiBYTE = URIRef("http://qudt.org/vocab/unit/MebiBYTE")
    GI_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-MIN")
    C_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    CentiMOL = URIRef("http://qudt.org/vocab/unit/CentiMOL")
    LB_PER_M3 = URIRef("http://qudt.org/vocab/unit/LB-PER-M3")
    SH = URIRef("http://qudt.org/vocab/unit/SH")
    V_PER_SEC = URIRef("http://qudt.org/vocab/unit/V-PER-SEC")
    M3_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-PA")
    IN3 = URIRef("http://qudt.org/vocab/unit/IN3")
    MACH = URIRef("http://qudt.org/vocab/unit/MACH")
    FT_LB_F = URIRef("http://qudt.org/vocab/unit/FT-LB_F")
    J = URIRef("http://qudt.org/vocab/unit/J")
    MilliM4 = URIRef("http://qudt.org/vocab/unit/MilliM4")
    PicoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-KiloGM")
    LB_IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN-PER-SEC")
    LANGLEY = URIRef("http://qudt.org/vocab/unit/LANGLEY")
    LB_PER_IN3 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3")
    MegaS = URIRef("http://qudt.org/vocab/unit/MegaS")
    MilliM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC2")
    OZ_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ-PER-MIN")
    DEG_C_WK = URIRef("http://qudt.org/vocab/unit/DEG_C-WK")
    BQ_PER_L = URIRef("http://qudt.org/vocab/unit/BQ-PER-L")
    ERG_PER_G = URIRef("http://qudt.org/vocab/unit/ERG-PER-G")
    H_PER_M = URIRef("http://qudt.org/vocab/unit/H-PER-M")
    BQ_PER_L = URIRef("http://qudt.org/vocab/unit/BQ-PER-L")
    NanoOHM = URIRef("http://qudt.org/vocab/unit/NanoOHM")
    A_HR_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-HR-PER-DEG_C")
    GM_PER_L_PA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-L-PA-SEC")
    L_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-K")
    MilliGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-SEC")
    MilliMOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2-SEC")
    GAL_IMP = URIRef("http://qudt.org/vocab/unit/GAL_IMP")
    LB_SEC_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-FT3")
    NUM_PER_L = URIRef("http://qudt.org/vocab/unit/NUM-PER-L")
    LY = URIRef("http://qudt.org/vocab/unit/LY")
    PicoFARAD = URIRef("http://qudt.org/vocab/unit/PicoFARAD")
    MegaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBYTE-PER-SEC")
    FT_HG = URIRef("http://qudt.org/vocab/unit/FT_HG")
    PERCENT_IN2_PER_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-IN2-PER-LB_F-SEC")
    PA_M0pt5 = URIRef("http://qudt.org/vocab/unit/PA-M0pt5")
    TON_US_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_US-PER-HR")
    FT3_PER_HR = URIRef("http://qudt.org/vocab/unit/FT3-PER-HR")
    KiloM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-HR")
    W_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM")
    PlanckForce = URIRef("http://qudt.org/vocab/unit/PlanckForce")
    FC = URIRef("http://qudt.org/vocab/unit/FC")
    IN3 = URIRef("http://qudt.org/vocab/unit/IN3")
    MegaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-SEC")
    CentiM3_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN-K")
    TON_SHORT = URIRef("http://qudt.org/vocab/unit/TON_SHORT")
    TON_Metric_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR")
    CentiM2_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-CentiM3")
    L = URIRef("http://qudt.org/vocab/unit/L")
    W_HR = URIRef("http://qudt.org/vocab/unit/W-HR")
    CAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC")
    BTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    NanoMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L-HR")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    MilliGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-CentiM2")
    PINT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-SEC")
    BTU_TH_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-HR-DEG_F")
    MilliRAD_R = URIRef("http://qudt.org/vocab/unit/MilliRAD_R")
    N_M_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-M")
    LM_HR = URIRef("http://qudt.org/vocab/unit/LM-HR")
    MilliGM_PER_M3_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-MilliPA-SEC")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    KiloGM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-CentiM2")
    CAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-MIN")
    MicroKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MicroKAT-PER-L")
    FRACTION = URIRef("http://qudt.org/vocab/unit/FRACTION")
    MilliT = URIRef("http://qudt.org/vocab/unit/MilliT")
    PebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M")
    MilliGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-K")
    KiloGM_F_M = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M")
    GAL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-HR")
    CORD = URIRef("http://qudt.org/vocab/unit/CORD")
    TON_SHORT_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-YD3")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    GI_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_US-PER-MIN")
    MicroG_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroG-PER-CentiM2")
    MilliGM_PER_L_POISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-POISE")
    MilliM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliM-PER-MIN")
    BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN")
    LB_F_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-SEC")
    HZ_PER_T = URIRef("http://qudt.org/vocab/unit/HZ-PER-T")
    J_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2")
    LB_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_UK")
    NanoGM_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2-DAY")
    J_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K")
    OZ_PER_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD3")
    BQ_PER_M2 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M2")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    N_M_PER_W0dot5 = URIRef("http://qudt.org/vocab/unit/N-M-PER-W0dot5")
    MilliA_PER_L_MIN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-L-MIN")
    MOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM")
    W_HR = URIRef("http://qudt.org/vocab/unit/W-HR")
    GigaBQ = URIRef("http://qudt.org/vocab/unit/GigaBQ")
    MilliL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN")
    EV_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/EV-M2-PER-KiloGM")
    DEG_R_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-MIN")
    K = URIRef("http://qudt.org/vocab/unit/K")
    PlanckVolume = URIRef("http://qudt.org/vocab/unit/PlanckVolume")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    GAL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-HR")
    MilliRAD = URIRef("http://qudt.org/vocab/unit/MilliRAD")
    MicroN_M = URIRef("http://qudt.org/vocab/unit/MicroN-M")
    OZ_MIN_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-GAL_US")
    CentiGM = URIRef("http://qudt.org/vocab/unit/CentiGM")
    CentiN = URIRef("http://qudt.org/vocab/unit/CentiN")
    LB_F_PER_LB = URIRef("http://qudt.org/vocab/unit/LB_F-PER-LB")
    PicoJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/PicoJ-PER-SEC")
    V_Stat = URIRef("http://qudt.org/vocab/unit/V_Stat")
    PER_M_SEC = URIRef("http://qudt.org/vocab/unit/PER-M-SEC")
    GM_PER_CentiM3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3-BAR")
    AttoC = URIRef("http://qudt.org/vocab/unit/AttoC")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    FRACTION = URIRef("http://qudt.org/vocab/unit/FRACTION")
    HectoPA = URIRef("http://qudt.org/vocab/unit/HectoPA")
    TON_Metric_PER_HA = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HA")
    PlanckVolt = URIRef("http://qudt.org/vocab/unit/PlanckVolt")
    V_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/V-A_Reactive-HR")
    KiloLB_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloLB-PER-HR")
    DeciGM = URIRef("http://qudt.org/vocab/unit/DeciGM")
    MicroH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-KiloOHM")
    KiloN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-M2")
    MilliR = URIRef("http://qudt.org/vocab/unit/MilliR")
    KiloGM_PER_L_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-K")
    BTU_IT_PER_SEC_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_R")
    GAL_IMP = URIRef("http://qudt.org/vocab/unit/GAL_IMP")
    TeraBQ = URIRef("http://qudt.org/vocab/unit/TeraBQ")
    PicoC = URIRef("http://qudt.org/vocab/unit/PicoC")
    TeraBQ = URIRef("http://qudt.org/vocab/unit/TeraBQ")
    KiloGM_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM2")
    PERCENT_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEG_C")
    PER_MOL = URIRef("http://qudt.org/vocab/unit/PER-MOL")
    MegaPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-BAR")
    M2_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-V-SEC")
    SEC_PER_M3_RAD = URIRef("http://qudt.org/vocab/unit/SEC-PER-M3-RAD")
    FT_LB_F_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2-SEC")
    HectoC = URIRef("http://qudt.org/vocab/unit/HectoC")
    ARE = URIRef("http://qudt.org/vocab/unit/ARE")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    LB_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-SEC")
    GT = URIRef("http://qudt.org/vocab/unit/GT")
    PER_IN3 = URIRef("http://qudt.org/vocab/unit/PER-IN3")
    CAL_TH_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM")
    MilliGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-K")
    KiloBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT")
    KiloGM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3")
    PlanckEnergy = URIRef("http://qudt.org/vocab/unit/PlanckEnergy")
    TON_LONG = URIRef("http://qudt.org/vocab/unit/TON_LONG")
    IN_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN-PER-MIN")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    MilliARCSEC = URIRef("http://qudt.org/vocab/unit/MilliARCSEC")
    MicroC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M2")
    YR = URIRef("http://qudt.org/vocab/unit/YR")
    PA_SEC_PER_K = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-K")
    DeciM3_PER_HR = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-HR")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    PERCENT_PER_DecaCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaCount")
    AT = URIRef("http://qudt.org/vocab/unit/AT")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    MilliL_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-BAR")
    LB_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-SEC")
    PetaBQ = URIRef("http://qudt.org/vocab/unit/PetaBQ")
    GM_SEC_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M3-L")
    PlanckArea = URIRef("http://qudt.org/vocab/unit/PlanckArea")
    MilliM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-KiloGM")
    MicroGM_PER_IN2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-IN2")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    PINT_US = URIRef("http://qudt.org/vocab/unit/PINT_US")
    SEC_PER_M3_RAD = URIRef("http://qudt.org/vocab/unit/SEC-PER-M3-RAD")
    PDL_FT = URIRef("http://qudt.org/vocab/unit/PDL-FT")
    KiloHZ = URIRef("http://qudt.org/vocab/unit/KiloHZ")
    ExbiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M2")
    FT_H2O = URIRef("http://qudt.org/vocab/unit/FT_H2O")
    MilliOHM_M = URIRef("http://qudt.org/vocab/unit/MilliOHM-M")
    C_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM-SEC")
    CentiM2_PER_SR_ERG = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SR-ERG")
    GM_PER_MilliL_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL-BAR")
    W_PER_GM = URIRef("http://qudt.org/vocab/unit/W-PER-GM")
    M2_PER_N = URIRef("http://qudt.org/vocab/unit/M2-PER-N")
    THM_US_PER_HR = URIRef("http://qudt.org/vocab/unit/THM_US-PER-HR")
    KiloGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY")
    MilliCi = URIRef("http://qudt.org/vocab/unit/MilliCi")
    KiloGM_PER_L_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-K")
    GM_PER_MilliM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM-BAR")
    CentiM_HG = URIRef("http://qudt.org/vocab/unit/CentiM_HG")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    MicroH = URIRef("http://qudt.org/vocab/unit/MicroH")
    GM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC-BAR")
    BU_US = URIRef("http://qudt.org/vocab/unit/BU_US")
    MilliPA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-BAR")
    LB_PER_GAL = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL")
    N_M_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-RAD")
    PER_KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/PER-KiloV-A-HR")
    PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/PER-KiloGM-SEC")
    TONNE_PER_SEC = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC")
    KiloS = URIRef("http://qudt.org/vocab/unit/KiloS")
    J_PER_MIN = URIRef("http://qudt.org/vocab/unit/J-PER-MIN")
    OZ_VOL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-SEC")
    NUM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NUM-PER-M3")
    MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/MOL-DEG_C")
    FemtoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-KiloGM")
    KiloM3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM3-PER-SEC2")
    CAL_TH_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM-SEC-DEG_C")
    GM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN-BAR")
    W_M2_PER_SR = URIRef("http://qudt.org/vocab/unit/W-M2-PER-SR")
    OZ_PER_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD3")
    BU_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-HR")
    MI_US = URIRef("http://qudt.org/vocab/unit/MI_US")
    NanoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/NanoKAT-PER-L")
    BU_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-MIN")
    KiloN_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M3")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    PER_MOL = URIRef("http://qudt.org/vocab/unit/PER-MOL")
    KiloCAL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MIN")
    LB_MIN_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US2")
    IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN3-PER-SEC")
    KiloCAL_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM-DEG_C")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    MilliM_PER_YR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-YR")
    GM_PER_L_CentiPOISE = URIRef("http://qudt.org/vocab/unit/GM-PER-L-CentiPOISE")
    MicroPA = URIRef("http://qudt.org/vocab/unit/MicroPA")
    MilliMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-L")
    KiloGM_M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M2-PER-SEC")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    MilliM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DAY")
    OZ_VOL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-DAY")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    N_M_PER_M_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-M-RAD")
    OZ_F = URIRef("http://qudt.org/vocab/unit/OZ_F")
    PicoMOL_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L-DAY")
    FemtoSEC = URIRef("http://qudt.org/vocab/unit/FemtoSEC")
    KiloGM_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-M2")
    MilliGM_PER_L = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L")
    TON_SHORT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-DEG_F")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    BTU_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC")
    FARAD_Ab = URIRef("http://qudt.org/vocab/unit/FARAD_Ab")
    PicoL = URIRef("http://qudt.org/vocab/unit/PicoL")
    PlanckFrequency = URIRef("http://qudt.org/vocab/unit/PlanckFrequency")
    MicroM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroM-PER-SEC")
    MilliN_PER_M = URIRef("http://qudt.org/vocab/unit/MilliN-PER-M")
    QT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_US-PER-HR")
    DWT = URIRef("http://qudt.org/vocab/unit/DWT")
    W_HR_PER_L = URIRef("http://qudt.org/vocab/unit/W-HR-PER-L")
    DeciBAR = URIRef("http://qudt.org/vocab/unit/DeciBAR")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    MIN = URIRef("http://qudt.org/vocab/unit/MIN")
    PER_J_M3 = URIRef("http://qudt.org/vocab/unit/PER-J-M3")
    QT_US = URIRef("http://qudt.org/vocab/unit/QT_US")
    MegaL = URIRef("http://qudt.org/vocab/unit/MegaL")
    KiloGM_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-BAR")
    GM_PER_HR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR")
    K_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-M-PER-SEC")
    M2_PER_KiloW = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloW")
    NanoA = URIRef("http://qudt.org/vocab/unit/NanoA")
    PPTR = URIRef("http://qudt.org/vocab/unit/PPTR")
    PER_MIN = URIRef("http://qudt.org/vocab/unit/PER-MIN")
    DEG_C_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-MIN")
    EV_SEC = URIRef("http://qudt.org/vocab/unit/EV-SEC")
    M_K = URIRef("http://qudt.org/vocab/unit/M-K")
    MegaS = URIRef("http://qudt.org/vocab/unit/MegaS")
    PER_J_M3 = URIRef("http://qudt.org/vocab/unit/PER-J-M3")
    OZ_PER_FT2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-FT2")
    MegaJ = URIRef("http://qudt.org/vocab/unit/MegaJ")
    GigaJ = URIRef("http://qudt.org/vocab/unit/GigaJ")
    MegaV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive-HR")
    C_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM2")
    BTU_IT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR-DEG_F")
    MegaPSI = URIRef("http://qudt.org/vocab/unit/MegaPSI")
    OZ_FT = URIRef("http://qudt.org/vocab/unit/OZ-FT")
    BQ_PER_L = URIRef("http://qudt.org/vocab/unit/BQ-PER-L")
    TON_Metric_PER_HR_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR-K")
    NanoSEC = URIRef("http://qudt.org/vocab/unit/NanoSEC")
    TON_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_US-PER-DAY")
    TORR_PER_M = URIRef("http://qudt.org/vocab/unit/TORR-PER-M")
    KiloV_PER_M = URIRef("http://qudt.org/vocab/unit/KiloV-PER-M")
    GigaW_HR = URIRef("http://qudt.org/vocab/unit/GigaW-HR")
    MilliFARAD = URIRef("http://qudt.org/vocab/unit/MilliFARAD")
    DecaM3 = URIRef("http://qudt.org/vocab/unit/DecaM3")
    HZ_M = URIRef("http://qudt.org/vocab/unit/HZ-M")
    MicroM3_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-MilliL")
    PER_MegaPA = URIRef("http://qudt.org/vocab/unit/PER-MegaPA")
    BTU_TH = URIRef("http://qudt.org/vocab/unit/BTU_TH")
    BTU_IT_PER_SEC_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2")
    L_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-BAR")
    V = URIRef("http://qudt.org/vocab/unit/V")
    GI_US = URIRef("http://qudt.org/vocab/unit/GI_US")
    FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC")
    KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-SEC2")
    MilliM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliM-PER-K")
    BU_US = URIRef("http://qudt.org/vocab/unit/BU_US")
    NanoOHM = URIRef("http://qudt.org/vocab/unit/NanoOHM")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    PER_PA_SEC = URIRef("http://qudt.org/vocab/unit/PER-PA-SEC")
    RAD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC2")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    J_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K")
    CentiM2_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-CentiM3")
    IU = URIRef("http://qudt.org/vocab/unit/IU")
    MilliGM_SEC_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L-M3")
    BIT_PER_M = URIRef("http://qudt.org/vocab/unit/BIT-PER-M")
    M3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-K")
    KiloPA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-K")
    PA_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-PER-BAR")
    K_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-M-PER-SEC")
    MilliBAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-M3-PER-SEC")
    NanoMOL_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    EarthMass = URIRef("http://qudt.org/vocab/unit/EarthMass")
    PER_MilliSEC = URIRef("http://qudt.org/vocab/unit/PER-MilliSEC")
    M2_PER_HZ = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ")
    FT_SEC_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-GAL_US")
    DYN_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-CentiM")
    DRAM_UK = URIRef("http://qudt.org/vocab/unit/DRAM_UK")
    M_K = URIRef("http://qudt.org/vocab/unit/M-K")
    GM_PER_L_PA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-L-PA-SEC")
    TONNE_PER_HR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR")
    NUM_PER_NanoL = URIRef("http://qudt.org/vocab/unit/NUM-PER-NanoL")
    C_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-M2-PER-KiloGM")
    LB_F_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN")
    KiloEV_PER_MicroM = URIRef("http://qudt.org/vocab/unit/KiloEV-PER-MicroM")
    KiloV_A_Reactive = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive")
    MI_US = URIRef("http://qudt.org/vocab/unit/MI_US")
    IU = URIRef("http://qudt.org/vocab/unit/IU")
    M_PER_K = URIRef("http://qudt.org/vocab/unit/M-PER-K")
    KiloV_A_PER_K = URIRef("http://qudt.org/vocab/unit/KiloV-A-PER-K")
    DAY_Sidereal = URIRef("http://qudt.org/vocab/unit/DAY_Sidereal")
    J_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-GM-DEG_C")
    KiloR = URIRef("http://qudt.org/vocab/unit/KiloR")
    GigaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-PER-M")
    M2_PER_SR_J = URIRef("http://qudt.org/vocab/unit/M2-PER-SR-J")
    BU_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-HR")
    N_CentiM = URIRef("http://qudt.org/vocab/unit/N-CentiM")
    CAL_TH_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM")
    MIL = URIRef("http://qudt.org/vocab/unit/MIL")
    PERCENT_HR_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-FT3")
    N_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM2")
    DYN_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM3")
    ERG_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM3")
    NanoSEC = URIRef("http://qudt.org/vocab/unit/NanoSEC")
    V_Stat = URIRef("http://qudt.org/vocab/unit/V_Stat")
    MicroGM_PER_CentiM2_WK = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2-WK")
    FT_LB_F_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2-SEC")
    MilliM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliM-PER-MIN")
    THM_US_PER_HR = URIRef("http://qudt.org/vocab/unit/THM_US-PER-HR")
    MOL_PER_M3_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-PA")
    MicroH_PER_M = URIRef("http://qudt.org/vocab/unit/MicroH-PER-M")
    LB = URIRef("http://qudt.org/vocab/unit/LB")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    MilliL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-GM")
    LB_PER_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-DAY")
    TON_FG = URIRef("http://qudt.org/vocab/unit/TON_FG")
    KiloCAL_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM")
    MilliBQ_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-M2-DAY")
    MilliG = URIRef("http://qudt.org/vocab/unit/MilliG")
    PINT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-SEC")
    MilliA = URIRef("http://qudt.org/vocab/unit/MilliA")
    BARAD = URIRef("http://qudt.org/vocab/unit/BARAD")
    FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F")
    K_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PER-SEC")
    HectoBAR = URIRef("http://qudt.org/vocab/unit/HectoBAR")
    FT3_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN")
    HZ_PER_T = URIRef("http://qudt.org/vocab/unit/HZ-PER-T")
    BU_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-DAY")
    MOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MOL-PER-MOL")
    CentiPOISE = URIRef("http://qudt.org/vocab/unit/CentiPOISE")
    DRAM_US = URIRef("http://qudt.org/vocab/unit/DRAM_US")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    TON_Metric_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY")
    MilliS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MilliS-PER-CentiM")
    MilliBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-L")
    MOL_LB_PER_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-LB")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    BIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/BIT-PER-M2")
    MicroM3_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-MilliL")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    MilliK_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliK-PER-BAR")
    V_Ab = URIRef("http://qudt.org/vocab/unit/V_Ab")
    TeraBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/TeraBIT-PER-SEC")
    BAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-L-PER-SEC")
    MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC")
    CentiM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC")
    FT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-DEG_F")
    IN_H2O_60DEG_F = URIRef("http://qudt.org/vocab/unit/IN_H2O_60DEG_F")
    J_PER_M = URIRef("http://qudt.org/vocab/unit/J-PER-M")
    MilliGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MilliL")
    PER_MegaK = URIRef("http://qudt.org/vocab/unit/PER-MegaK")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    GM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3")
    TEX = URIRef("http://qudt.org/vocab/unit/TEX")
    PERCENT_HR_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-FT3")
    MicroGM_PER_L = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L")
    KiloPA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-MilliM")
    PA_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC")
    PSI = URIRef("http://qudt.org/vocab/unit/PSI")
    DEG_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC2")
    CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM-SEC-DEG_C")
    HZ_PER_T = URIRef("http://qudt.org/vocab/unit/HZ-PER-T")
    KiloCAL_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM-DEG_C")
    RAD_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-KiloGM")
    NUM_PER_SEC = URIRef("http://qudt.org/vocab/unit/NUM-PER-SEC")
    MilliBAR = URIRef("http://qudt.org/vocab/unit/MilliBAR")
    V = URIRef("http://qudt.org/vocab/unit/V")
    GM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-K")
    FemtoA = URIRef("http://qudt.org/vocab/unit/FemtoA")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    TONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-YR")
    M3_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-K")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    HectoC = URIRef("http://qudt.org/vocab/unit/HectoC")
    YD3 = URIRef("http://qudt.org/vocab/unit/YD3")
    MicroW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroW-PER-M2")
    LB_PER_YD2 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD2")
    NP = URIRef("http://qudt.org/vocab/unit/NP")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    GigaPA = URIRef("http://qudt.org/vocab/unit/GigaPA")
    CORD = URIRef("http://qudt.org/vocab/unit/CORD")
    OZ_VOL_UK = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK")
    CAL_TH_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2-MIN")
    KiloGM_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-PA")
    TON_SHORT_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-YD3")
    PPT = URIRef("http://qudt.org/vocab/unit/PPT")
    EV_PER_T = URIRef("http://qudt.org/vocab/unit/EV-PER-T")
    BARN_PER_SR = URIRef("http://qudt.org/vocab/unit/BARN-PER-SR")
    BTU_IT_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-SEC-DEG_F")
    OZ_PER_YD2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD2")
    DEG_C_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-MIN")
    DWT = URIRef("http://qudt.org/vocab/unit/DWT")
    PicoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-KiloGM")
    MicroFARAD = URIRef("http://qudt.org/vocab/unit/MicroFARAD")
    NanoFARAD = URIRef("http://qudt.org/vocab/unit/NanoFARAD")
    MilliMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-KiloGM")
    DeciB_C = URIRef("http://qudt.org/vocab/unit/DeciB_C")
    J_PER_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-DAY")
    LB_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN2")
    KiloV_A_PER_K = URIRef("http://qudt.org/vocab/unit/KiloV-A-PER-K")
    PA_SEC_PER_K = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-K")
    MegaPA = URIRef("http://qudt.org/vocab/unit/MegaPA")
    GALILEO = URIRef("http://qudt.org/vocab/unit/GALILEO")
    LB_SEC_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-GAL_US")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    MicroM3_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-MilliL")
    KN_PER_SEC = URIRef("http://qudt.org/vocab/unit/KN-PER-SEC")
    LB_HR_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK2")
    DEG_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC")
    M3_PER_KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM-SEC2")
    RPK = URIRef("http://qudt.org/vocab/unit/RPK")
    SAMPLE_PER_SEC = URIRef("http://qudt.org/vocab/unit/SAMPLE-PER-SEC")
    ERG_PER_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-SEC")
    PicoM = URIRef("http://qudt.org/vocab/unit/PicoM")
    KiloGM_PER_HA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HA")
    MegaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-M")
    CentiM2_PER_ERG = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-ERG")
    KiloMOL_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3-K")
    LB_T = URIRef("http://qudt.org/vocab/unit/LB_T")
    BTU_IT_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT3")
    MilliTORR = URIRef("http://qudt.org/vocab/unit/MilliTORR")
    BTU_TH_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_R")
    RAYL = URIRef("http://qudt.org/vocab/unit/RAYL")
    N_M_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-M-PER-KiloGM")
    LB_F_FT = URIRef("http://qudt.org/vocab/unit/LB_F-FT")
    KiloW_PER_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M-DEG_C")
    GI_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_US-PER-DAY")
    KiloV = URIRef("http://qudt.org/vocab/unit/KiloV")
    KiloGM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-K")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    FT_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-PER-MIN")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    MilliA_HR = URIRef("http://qudt.org/vocab/unit/MilliA-HR")
    AC = URIRef("http://qudt.org/vocab/unit/AC")
    PicoMOL_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M3-SEC")
    MicroBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-L")
    MegaV = URIRef("http://qudt.org/vocab/unit/MegaV")
    J_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2-DAY")
    KAT_PER_L = URIRef("http://qudt.org/vocab/unit/KAT-PER-L")
    PER_L = URIRef("http://qudt.org/vocab/unit/PER-L")
    MegaPSI = URIRef("http://qudt.org/vocab/unit/MegaPSI")
    MicroH = URIRef("http://qudt.org/vocab/unit/MicroH")
    MilliBAR = URIRef("http://qudt.org/vocab/unit/MilliBAR")
    MegaHZ_PER_T = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-T")
    MilliM_H2O = URIRef("http://qudt.org/vocab/unit/MilliM_H2O")
    NanoMOL_PER_MicroMOL_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL-DAY")
    A_HR_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-DeciM3")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    MilliGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-K")
    THM_US = URIRef("http://qudt.org/vocab/unit/THM_US")
    BU_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-DAY")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    NanoGM_PER_L = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-L")
    EUR_PER_M2 = URIRef("http://qudt.org/vocab/unit/EUR-PER-M2")
    PERCENT_PER_MO = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MO")
    ARCMIN = URIRef("http://qudt.org/vocab/unit/ARCMIN")
    BTU_IT_IN_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-SEC-FT2-DEG_F")
    BTU_IT_PER_HR_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_R")
    BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN")
    CD_PER_M2 = URIRef("http://qudt.org/vocab/unit/CD-PER-M2")
    ARCMIN = URIRef("http://qudt.org/vocab/unit/ARCMIN")
    MilliGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3")
    MilliRAD_R = URIRef("http://qudt.org/vocab/unit/MilliRAD_R")
    FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F")
    MegaN = URIRef("http://qudt.org/vocab/unit/MegaN")
    MilliL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M3")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    QT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-MIN")
    KiloBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-HR")
    KiloW = URIRef("http://qudt.org/vocab/unit/KiloW")
    A_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-M3")
    PebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M3")
    EUR_PER_M2 = URIRef("http://qudt.org/vocab/unit/EUR-PER-M2")
    TeraW = URIRef("http://qudt.org/vocab/unit/TeraW")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    DEG_C_GROWING_CEREAL_DAY = URIRef("http://qudt.org/vocab/unit/DEG_C_GROWING_CEREAL-DAY")
    MicroL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroL-PER-L")
    KiloV_PER_M = URIRef("http://qudt.org/vocab/unit/KiloV-PER-M")
    PK_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-HR")
    MegaBAR = URIRef("http://qudt.org/vocab/unit/MegaBAR")
    GigaW_HR = URIRef("http://qudt.org/vocab/unit/GigaW-HR")
    HR_Sidereal = URIRef("http://qudt.org/vocab/unit/HR_Sidereal")
    OZ_VOL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-MIN")
    GM_Nitrogen_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Nitrogen-PER-M2-DAY")
    PER_V = URIRef("http://qudt.org/vocab/unit/PER-V")
    PicoS = URIRef("http://qudt.org/vocab/unit/PicoS")
    M_K_PER_W = URIRef("http://qudt.org/vocab/unit/M-K-PER-W")
    MIN_Angle = URIRef("http://qudt.org/vocab/unit/MIN_Angle")
    MicroL = URIRef("http://qudt.org/vocab/unit/MicroL")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    NanoOHM = URIRef("http://qudt.org/vocab/unit/NanoOHM")
    K_PER_PA = URIRef("http://qudt.org/vocab/unit/K-PER-PA")
    PicoV = URIRef("http://qudt.org/vocab/unit/PicoV")
    GM_MIN_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L-M3")
    M_PER_PA = URIRef("http://qudt.org/vocab/unit/M-PER-PA")
    S_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/S-M2-PER-MOL")
    V2_PER_K2 = URIRef("http://qudt.org/vocab/unit/V2-PER-K2")
    KiloGM_PER_HA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HA")
    FemtoA = URIRef("http://qudt.org/vocab/unit/FemtoA")
    FT_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-PER-HR")
    GALILEO = URIRef("http://qudt.org/vocab/unit/GALILEO")
    OZ_MIN_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-GAL_UK")
    WK = URIRef("http://qudt.org/vocab/unit/WK")
    CentiM3_PER_HR_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR-K")
    MicroGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-KiloGM")
    CD_PER_M2 = URIRef("http://qudt.org/vocab/unit/CD-PER-M2")
    LB_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_US")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    MilliV_PER_M = URIRef("http://qudt.org/vocab/unit/MilliV-PER-M")
    NanoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MilliL")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    MilliBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-L")
    IN3_PER_LB = URIRef("http://qudt.org/vocab/unit/IN3-PER-LB")
    FT2_PER_HR = URIRef("http://qudt.org/vocab/unit/FT2-PER-HR")
    FT3_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT3-PER-SEC")
    SUSCEPTIBILITY_ELEC = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_ELEC")
    SEC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/SEC-PER-KiloGM")
    HZ_M = URIRef("http://qudt.org/vocab/unit/HZ-M")
    M_PER_HR = URIRef("http://qudt.org/vocab/unit/M-PER-HR")
    MilliR_man = URIRef("http://qudt.org/vocab/unit/MilliR_man")
    MicroJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroJ-PER-SEC")
    BREATH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BREATH-PER-MIN")
    PER_SEC_M2_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2-SR")
    BARN = URIRef("http://qudt.org/vocab/unit/BARN")
    KiloOHM_PER_K = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-K")
    V_A_PER_K = URIRef("http://qudt.org/vocab/unit/V-A-PER-K")
    W_M2 = URIRef("http://qudt.org/vocab/unit/W-M2")
    DEG_F_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-HR")
    HectoGM = URIRef("http://qudt.org/vocab/unit/HectoGM")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    BTU_39DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_39DEG_F")
    M_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-PA")
    MicroSV = URIRef("http://qudt.org/vocab/unit/MicroSV")
    S = URIRef("http://qudt.org/vocab/unit/S")
    TON_FG_HR = URIRef("http://qudt.org/vocab/unit/TON_FG-HR")
    C_Ab = URIRef("http://qudt.org/vocab/unit/C_Ab")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    MicroSEC = URIRef("http://qudt.org/vocab/unit/MicroSEC")
    M3_PER_M3 = URIRef("http://qudt.org/vocab/unit/M3-PER-M3")
    OZ_F_IN = URIRef("http://qudt.org/vocab/unit/OZ_F-IN")
    NanoM_PER_CentiM_PSI = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-PSI")
    KiloGM_F_M_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-CentiM2")
    PicoJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/PicoJ-PER-SEC")
    AT_PER_IN = URIRef("http://qudt.org/vocab/unit/AT-PER-IN")
    MicroA = URIRef("http://qudt.org/vocab/unit/MicroA")
    CAL_TH_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM-SEC-DEG_C")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    CAL_TH_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-DEG_C")
    BFT = URIRef("http://qudt.org/vocab/unit/BFT")
    BU_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-DAY")
    OZ_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ-PER-DAY")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    MilliMOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2-SEC")
    C2_M2_PER_J = URIRef("http://qudt.org/vocab/unit/C2-M2-PER-J")
    KiloCAL_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-HR")
    BAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-M3-PER-SEC")
    TONNE_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR-BAR")
    MicroMOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-SEC")
    ERG_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM")
    MilliPA_PER_M = URIRef("http://qudt.org/vocab/unit/MilliPA-PER-M")
    ARE = URIRef("http://qudt.org/vocab/unit/ARE")
    MilliL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-MIN")
    MegaV_PER_M = URIRef("http://qudt.org/vocab/unit/MegaV-PER-M")
    HZ_M = URIRef("http://qudt.org/vocab/unit/HZ-M")
    CAL_IT = URIRef("http://qudt.org/vocab/unit/CAL_IT")
    PA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-L-PER-SEC")
    BTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR")
    A_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/A-PER-KiloGM")
    SEC2 = URIRef("http://qudt.org/vocab/unit/SEC2")
    MilliV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliV-PER-MIN")
    DEATHS_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000I-YR")
    LB_HR_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN6")
    TON_US_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_US-PER-HR")
    MilliGM_PER_L = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L")
    MicroL = URIRef("http://qudt.org/vocab/unit/MicroL")
    MilliW_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM-SR")
    SV_PER_SEC = URIRef("http://qudt.org/vocab/unit/SV-PER-SEC")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    KiloN_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-DEG")
    TebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M")
    GM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-CentiM-PER-SEC")
    PSI_PER_IN = URIRef("http://qudt.org/vocab/unit/PSI-PER-IN")
    MilliFARAD = URIRef("http://qudt.org/vocab/unit/MilliFARAD")
    PetaV_A = URIRef("http://qudt.org/vocab/unit/PetaV-A")
    GM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-M2-DAY")
    M2_SR = URIRef("http://qudt.org/vocab/unit/M2-SR")
    NanoM = URIRef("http://qudt.org/vocab/unit/NanoM")
    KibiBYTE = URIRef("http://qudt.org/vocab/unit/KibiBYTE")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    KiloW = URIRef("http://qudt.org/vocab/unit/KiloW")
    PSI = URIRef("http://qudt.org/vocab/unit/PSI")
    KiloN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-M2")
    TONNE_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN-BAR")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    BAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-M3-PER-SEC")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    GM_Nitrogen_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Nitrogen-PER-M2-DAY")
    PER_MilliL = URIRef("http://qudt.org/vocab/unit/PER-MilliL")
    MegaEV = URIRef("http://qudt.org/vocab/unit/MegaEV")
    MilliH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-OHM")
    PERM_23DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_23DEG_C")
    GRAIN = URIRef("http://qudt.org/vocab/unit/GRAIN")
    M_PER_K = URIRef("http://qudt.org/vocab/unit/M-PER-K")
    KiloW_PER_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M-DEG_C")
    MegaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M3")
    TON_FG_HR = URIRef("http://qudt.org/vocab/unit/TON_FG-HR")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    KiloGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-BAR")
    TONNE_PER_HA = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA")
    BU_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-SEC")
    KiloTON_Metric = URIRef("http://qudt.org/vocab/unit/KiloTON_Metric")
    LB_SEC_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK2")
    M2_PER_SR = URIRef("http://qudt.org/vocab/unit/M2-PER-SR")
    BTU_TH_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB")
    MicroGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-KiloGM")
    DecaARE = URIRef("http://qudt.org/vocab/unit/DecaARE")
    PA_M0dot5 = URIRef("http://qudt.org/vocab/unit/PA-M0dot5")
    L_PER_HR = URIRef("http://qudt.org/vocab/unit/L-PER-HR")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    DeciM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-DAY")
    L_PER_MOL = URIRef("http://qudt.org/vocab/unit/L-PER-MOL")
    MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/MOL_LB-DEG_F")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    GI_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_US-PER-SEC")
    MilliW_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM-SR")
    PER_WK = URIRef("http://qudt.org/vocab/unit/PER-WK")
    MilliL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M2-DAY")
    KiloPA = URIRef("http://qudt.org/vocab/unit/KiloPA")
    LA = URIRef("http://qudt.org/vocab/unit/LA")
    S = URIRef("http://qudt.org/vocab/unit/S")
    MilliC = URIRef("http://qudt.org/vocab/unit/MilliC")
    PER_LB = URIRef("http://qudt.org/vocab/unit/PER-LB")
    EV_PER_T = URIRef("http://qudt.org/vocab/unit/EV-PER-T")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    DEGREE_BALLING = URIRef("http://qudt.org/vocab/unit/DEGREE_BALLING")
    CFU = URIRef("http://qudt.org/vocab/unit/CFU")
    BTU_IT_IN_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-SEC-FT2-DEG_F")
    GM_PER_M3_CentiPOISE = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-CentiPOISE")
    PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/PER-M2-SEC")
    SLUG_PER_MIN = URIRef("http://qudt.org/vocab/unit/SLUG-PER-MIN")
    FT_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-PER-HR")
    MicroMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-SEC")
    GibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M2")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    MX = URIRef("http://qudt.org/vocab/unit/MX")
    DeciB_M = URIRef("http://qudt.org/vocab/unit/DeciB_M")
    J_PER_T2 = URIRef("http://qudt.org/vocab/unit/J-PER-T2")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    M2_K_PER_W = URIRef("http://qudt.org/vocab/unit/M2-K-PER-W")
    CentiN_M = URIRef("http://qudt.org/vocab/unit/CentiN-M")
    V = URIRef("http://qudt.org/vocab/unit/V")
    MicroRAD = URIRef("http://qudt.org/vocab/unit/MicroRAD")
    PERCENT_MIN_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-FT3")
    FemtoSEC = URIRef("http://qudt.org/vocab/unit/FemtoSEC")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    FM = URIRef("http://qudt.org/vocab/unit/FM")
    S = URIRef("http://qudt.org/vocab/unit/S")
    Kilo_FT3 = URIRef("http://qudt.org/vocab/unit/Kilo-FT3")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    MegaOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-BAR")
    DEG_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-MIN")
    KiloLB_F = URIRef("http://qudt.org/vocab/unit/KiloLB_F")
    KiloMIL_Circ = URIRef("http://qudt.org/vocab/unit/KiloMIL_Circ")
    M5 = URIRef("http://qudt.org/vocab/unit/M5")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    GM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/GM-PER-HR-K")
    SUSCEPTIBILITY_ELEC = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_ELEC")
    B = URIRef("http://qudt.org/vocab/unit/B")
    OHM_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-PER-M")
    LB_PER_M3 = URIRef("http://qudt.org/vocab/unit/LB-PER-M3")
    M3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    V_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-PER-CentiM")
    GigaOHM = URIRef("http://qudt.org/vocab/unit/GigaOHM")
    PER_T_M = URIRef("http://qudt.org/vocab/unit/PER-T-M")
    LB_T = URIRef("http://qudt.org/vocab/unit/LB_T")
    M2_PER_N = URIRef("http://qudt.org/vocab/unit/M2-PER-N")
    MicroBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-L")
    GAL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-SEC")
    PER_DEG_F = URIRef("http://qudt.org/vocab/unit/PER-DEG_F")
    MicroGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M2-DAY")
    KiloCAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-SEC")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    KiloGM_F = URIRef("http://qudt.org/vocab/unit/KiloGM_F")
    PA2_SEC = URIRef("http://qudt.org/vocab/unit/PA2-SEC")
    KiloCAL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MIN")
    DeciM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MIN")
    GM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM")
    CentiM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY")
    DeciB_M = URIRef("http://qudt.org/vocab/unit/DeciB_M")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    KiloMOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-MIN")
    GI_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-MIN")
    H = URIRef("http://qudt.org/vocab/unit/H")
    MilliGM_MIN_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M3-L")
    MilliC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M3")
    W_PER_M2_K = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K")
    T_Ab = URIRef("http://qudt.org/vocab/unit/T_Ab")
    BBL_UK_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-HR")
    PicoGM_PER_GM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-GM")
    MicroM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroM-PER-SEC")
    J_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-GM-DEG_C")
    LB_F_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN")
    GM_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/GM-PER-DEG_C")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    KiloN_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M2")
    MilliW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2")
    TON_SHORT_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-YD3")
    TON = URIRef("http://qudt.org/vocab/unit/TON")
    KIP_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KIP_F-PER-IN2")
    MilliW_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM")
    BTU_IT_PER_SEC_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2")
    KiloWB_PER_M = URIRef("http://qudt.org/vocab/unit/KiloWB-PER-M")
    NUM_PER_M = URIRef("http://qudt.org/vocab/unit/NUM-PER-M")
    FT_LA = URIRef("http://qudt.org/vocab/unit/FT-LA")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    KiloGM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC2")
    BBL_UK_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-SEC")
    KiloGM_PER_MegaBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MegaBTU_IT")
    OZ_SEC_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-GAL_UK")
    L_PER_L = URIRef("http://qudt.org/vocab/unit/L-PER-L")
    PER_K = URIRef("http://qudt.org/vocab/unit/PER-K")
    LB_MIN_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-FT3")
    OZ_F_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ_F-PER-IN3")
    NanoS = URIRef("http://qudt.org/vocab/unit/NanoS")
    KiloJ_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-HR")
    MicroV = URIRef("http://qudt.org/vocab/unit/MicroV")
    MilliL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC")
    KiloGM_PER_L = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L")
    MilliM_PER_DEG_C_M = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DEG_C-M")
    MicroMOL_PER_MicroMOL_DAY = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MicroMOL-DAY")
    M5 = URIRef("http://qudt.org/vocab/unit/M5")
    GigaBQ = URIRef("http://qudt.org/vocab/unit/GigaBQ")
    GAL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-MIN")
    PER_SEC_M2_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2-SR")
    PINT_US = URIRef("http://qudt.org/vocab/unit/PINT_US")
    KiloGM_PER_MegaBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MegaBTU_IT")
    DEGREE_BAUME = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    M2_PER_KiloW = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloW")
    DeciS = URIRef("http://qudt.org/vocab/unit/DeciS")
    ERG_CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-CentiM2-PER-GM")
    KiloGM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM2-PER-SEC2")
    PER_J2 = URIRef("http://qudt.org/vocab/unit/PER-J2")
    YR_Common = URIRef("http://qudt.org/vocab/unit/YR_Common")
    LB_PER_MIN_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN-PSI")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    IN3_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN3-PER-MIN")
    MicroSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-SEC")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    KiloGM_F_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-SEC")
    MilliGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-K")
    M2_HR_DEG_C_PER_KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/M2-HR-DEG_C-PER-KiloCAL_IT")
    AC_FT = URIRef("http://qudt.org/vocab/unit/AC-FT")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    FemtoJ = URIRef("http://qudt.org/vocab/unit/FemtoJ")
    J_PER_M4 = URIRef("http://qudt.org/vocab/unit/J-PER-M4")
    KiloA_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M2")
    A_HR_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-DeciM3")
    MegaPA_PER_K = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-K")
    KN_PER_SEC = URIRef("http://qudt.org/vocab/unit/KN-PER-SEC")
    GibiBIT = URIRef("http://qudt.org/vocab/unit/GibiBIT")
    KiloGM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    FT3_PER_PSI = URIRef("http://qudt.org/vocab/unit/FT3-PER-PSI")
    PicoGM_PER_L = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-L")
    LB_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-DEG_F")
    MilliN = URIRef("http://qudt.org/vocab/unit/MilliN")
    CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-SEC")
    MilliL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC")
    W_PER_M_K = URIRef("http://qudt.org/vocab/unit/W-PER-M-K")
    DeciM = URIRef("http://qudt.org/vocab/unit/DeciM")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    MilliM_HG = URIRef("http://qudt.org/vocab/unit/MilliM_HG")
    KiloS = URIRef("http://qudt.org/vocab/unit/KiloS")
    MegaBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaBTU_IT-PER-HR")
    MI_PER_SEC = URIRef("http://qudt.org/vocab/unit/MI-PER-SEC")
    A_HR_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/A-HR-PER-KiloGM")
    M_PER_BAR = URIRef("http://qudt.org/vocab/unit/M-PER-BAR")
    PlanckDensity = URIRef("http://qudt.org/vocab/unit/PlanckDensity")
    CentiM3_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    W = URIRef("http://qudt.org/vocab/unit/W")
    OZ_VOL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-DAY")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    ATM_T = URIRef("http://qudt.org/vocab/unit/ATM_T")
    HeartBeat = URIRef("http://qudt.org/vocab/unit/HeartBeat")
    IN_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC2")
    KiloW_HR = URIRef("http://qudt.org/vocab/unit/KiloW-HR")
    DEG2 = URIRef("http://qudt.org/vocab/unit/DEG2")
    MACH = URIRef("http://qudt.org/vocab/unit/MACH")
    KiloJ_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-HR")
    AC = URIRef("http://qudt.org/vocab/unit/AC")
    LB_PER_GAL = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL")
    M3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM")
    GM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2")
    PERCENT_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-M3")
    Gamma = URIRef("http://qudt.org/vocab/unit/Gamma")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    C4_M4_PER_J3 = URIRef("http://qudt.org/vocab/unit/C4-M4-PER-J3")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    CentiM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC-BAR")
    OCTET_PER_SEC = URIRef("http://qudt.org/vocab/unit/OCTET-PER-SEC")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    EU_PER_L = URIRef("http://qudt.org/vocab/unit/EU-PER-L")
    NanoGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DeciL")
    CAL_IT_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM-K")
    RAD_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-KiloGM")
    GM_HR_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M3-CentiM3")
    LB_PER_IN3 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3")
    GM_PER_M3_POISE = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-POISE")
    LB_PER_IN = URIRef("http://qudt.org/vocab/unit/LB-PER-IN")
    SLUG_PER_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-SEC")
    MOL_LB_PER_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-LB")
    L_PER_DAY = URIRef("http://qudt.org/vocab/unit/L-PER-DAY")
    YD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/YD-PER-SEC2")
    MicroMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    MegaC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M2")
    GM = URIRef("http://qudt.org/vocab/unit/GM")
    KiloGM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-K")
    KiloSEC = URIRef("http://qudt.org/vocab/unit/KiloSEC")
    BIT_PER_M = URIRef("http://qudt.org/vocab/unit/BIT-PER-M")
    DEG_C_WK = URIRef("http://qudt.org/vocab/unit/DEG_C-WK")
    MicroKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MicroKAT-PER-L")
    MilliA_IN2_PER_LB_F = URIRef("http://qudt.org/vocab/unit/MilliA-IN2-PER-LB_F")
    DeciL_PER_GM = URIRef("http://qudt.org/vocab/unit/DeciL-PER-GM")
    TEX = URIRef("http://qudt.org/vocab/unit/TEX")
    WB_PER_MilliM = URIRef("http://qudt.org/vocab/unit/WB-PER-MilliM")
    H = URIRef("http://qudt.org/vocab/unit/H")
    KiloGM_PER_M_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-DAY")
    PicoA_PER_HectoPA = URIRef("http://qudt.org/vocab/unit/PicoA-PER-HectoPA")
    DEG_C_PER_BAR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-BAR")
    MicroL = URIRef("http://qudt.org/vocab/unit/MicroL")
    DEG_C_PER_YR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-YR")
    TONNE_PER_SEC = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    HectoPA_PER_HR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-HR")
    KiloHZ = URIRef("http://qudt.org/vocab/unit/KiloHZ")
    MicroPOISE = URIRef("http://qudt.org/vocab/unit/MicroPOISE")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    KiloGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloGM")
    OZ_FT2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/OZ-FT2-PER-IN3-LB_F-SEC")
    DEG_F_HR_FT2_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT")
    PA_PER_HR = URIRef("http://qudt.org/vocab/unit/PA-PER-HR")
    PERCENT_HR_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-YD3")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    CentiN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/CentiN-M-PER-M2")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    KiloGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-BAR")
    FT_LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2")
    L_PER_HR = URIRef("http://qudt.org/vocab/unit/L-PER-HR")
    KiloGM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM-PER-SEC")
    M2_PER_KiloW = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloW")
    KiloPA_M2_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloPA-M2-PER-GM")
    MilliGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-BAR")
    BTU_59DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_59DEG_F")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    DEGREE_TWADDELL = URIRef("http://qudt.org/vocab/unit/DEGREE_TWADDELL")
    M3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM")
    NAT = URIRef("http://qudt.org/vocab/unit/NAT")
    AC_FT = URIRef("http://qudt.org/vocab/unit/AC-FT")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    BAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/BAR-PER-BAR")
    BTU_IT_PER_LB_F_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_R")
    MicroGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-MIN")
    LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    MegaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-HR")
    MilliOHM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-M")
    MilliM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-M3")
    SLUG_PER_DAY = URIRef("http://qudt.org/vocab/unit/SLUG-PER-DAY")
    DecaARE = URIRef("http://qudt.org/vocab/unit/DecaARE")
    A_PER_RAD = URIRef("http://qudt.org/vocab/unit/A-PER-RAD")
    CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-SEC")
    M2_PER_HZ_DEG = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ-DEG")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    YD2 = URIRef("http://qudt.org/vocab/unit/YD2")
    MicroMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L-HR")
    J_PER_KiloGM_K_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-M3")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    MilliOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-BAR")
    NanoGM = URIRef("http://qudt.org/vocab/unit/NanoGM")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    TON_Metric_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY-BAR")
    CentiM_PER_KiloYR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-KiloYR")
    YD_PER_HR = URIRef("http://qudt.org/vocab/unit/YD-PER-HR")
    FT4 = URIRef("http://qudt.org/vocab/unit/FT4")
    KiloPA = URIRef("http://qudt.org/vocab/unit/KiloPA")
    LB_PER_GAL = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL")
    M_PER_DEG_C_M = URIRef("http://qudt.org/vocab/unit/M-PER-DEG_C-M")
    M = URIRef("http://qudt.org/vocab/unit/M")
    KiloGM_M = URIRef("http://qudt.org/vocab/unit/KiloGM-M")
    B = URIRef("http://qudt.org/vocab/unit/B")
    TON_Metric_PER_MIN = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN")
    GAL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-SEC")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    NanoMOL_PER_CentiM3_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-CentiM3-HR")
    W_PER_M2_K = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K")
    GM_PER_CentiM3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3-BAR")
    MegaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M3")
    EUR_PER_W_HR = URIRef("http://qudt.org/vocab/unit/EUR-PER-W-HR")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    MilliBQ_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-M2-DAY")
    KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloGM-K")
    PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/PER-M2-SEC")
    PER_MILLE_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PSI")
    OHM_Stat = URIRef("http://qudt.org/vocab/unit/OHM_Stat")
    KiloA_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M2")
    M3_PER_DAY = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY")
    FT3_PER_MIN_FT2 = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN-FT2")
    PCA = URIRef("http://qudt.org/vocab/unit/PCA")
    DEG_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-MIN")
    KiloPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-BAR")
    MicroG_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroG-PER-CentiM2")
    PlanckPower = URIRef("http://qudt.org/vocab/unit/PlanckPower")
    FM = URIRef("http://qudt.org/vocab/unit/FM")
    MegaA_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaA-PER-M2")
    LB_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-MOL-DEG_F")
    GM_SEC_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L2")
    KiloS = URIRef("http://qudt.org/vocab/unit/KiloS")
    SV_PER_SEC = URIRef("http://qudt.org/vocab/unit/SV-PER-SEC")
    PER_J_M3 = URIRef("http://qudt.org/vocab/unit/PER-J-M3")
    KiloJ = URIRef("http://qudt.org/vocab/unit/KiloJ")
    PERCENT_PER_DEG = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEG")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    LM_HR = URIRef("http://qudt.org/vocab/unit/LM-HR")
    MilliM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliM-PER-K")
    BTU_TH_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-FT2-HR-DEG_F")
    PERMEABILITY_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_REL")
    NanoSEC = URIRef("http://qudt.org/vocab/unit/NanoSEC")
    GM_PER_M = URIRef("http://qudt.org/vocab/unit/GM-PER-M")
    ARE = URIRef("http://qudt.org/vocab/unit/ARE")
    MilliJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-M2")
    MilliV_A = URIRef("http://qudt.org/vocab/unit/MilliV-A")
    J_PER_M3_K = URIRef("http://qudt.org/vocab/unit/J-PER-M3-K")
    NanoM_PER_CentiM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-MegaPA")
    W_PER_FT2 = URIRef("http://qudt.org/vocab/unit/W-PER-FT2")
    PER_J = URIRef("http://qudt.org/vocab/unit/PER-J")
    J_SEC_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-SEC-PER-MOL")
    KiloGM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC2")
    LA_FT = URIRef("http://qudt.org/vocab/unit/LA_FT")
    GigaOHM = URIRef("http://qudt.org/vocab/unit/GigaOHM")
    CentiST = URIRef("http://qudt.org/vocab/unit/CentiST")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    NanoOHM_M = URIRef("http://qudt.org/vocab/unit/NanoOHM-M")
    BTU_TH_PER_FT2_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-HR")
    ROD = URIRef("http://qudt.org/vocab/unit/ROD")
    PERMITTIVITY_REL = URIRef("http://qudt.org/vocab/unit/PERMITTIVITY_REL")
    MilliM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-KiloGM")
    CentiM_HG = URIRef("http://qudt.org/vocab/unit/CentiM_HG")
    KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloM2")
    KiloBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-HR")
    ZettaC = URIRef("http://qudt.org/vocab/unit/ZettaC")
    KiloBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBYTE-PER-SEC")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    M2_PER_N = URIRef("http://qudt.org/vocab/unit/M2-PER-N")
    PA2_SEC = URIRef("http://qudt.org/vocab/unit/PA2-SEC")
    FT3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT3-PER-DEG_F")
    FemtoFARAD = URIRef("http://qudt.org/vocab/unit/FemtoFARAD")
    PSI_IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-IN3-PER-SEC")
    MicroGM_PER_L = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L")
    MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC")
    OZ_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ-PER-HR")
    IN3_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN3-PER-MIN")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    HZ_PER_V = URIRef("http://qudt.org/vocab/unit/HZ-PER-V")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    CAL_TH_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-DEG_C")
    FT3_PER_PSI = URIRef("http://qudt.org/vocab/unit/FT3-PER-PSI")
    BBL_US = URIRef("http://qudt.org/vocab/unit/BBL_US")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    KiloBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBIT-PER-SEC")
    C_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM-SEC")
    MicroH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-KiloOHM")
    MilliGRAY = URIRef("http://qudt.org/vocab/unit/MilliGRAY")
    PFERDESTAERKE = URIRef("http://qudt.org/vocab/unit/PFERDESTAERKE")
    PPTR = URIRef("http://qudt.org/vocab/unit/PPTR")
    AT = URIRef("http://qudt.org/vocab/unit/AT")
    MicroOHM = URIRef("http://qudt.org/vocab/unit/MicroOHM")
    PicoSEC = URIRef("http://qudt.org/vocab/unit/PicoSEC")
    DECADE = URIRef("http://qudt.org/vocab/unit/DECADE")
    M_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-BAR")
    YD3_PER_HR = URIRef("http://qudt.org/vocab/unit/YD3-PER-HR")
    GAL_UK = URIRef("http://qudt.org/vocab/unit/GAL_UK")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    KiloWB = URIRef("http://qudt.org/vocab/unit/KiloWB")
    KiloJ_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-DAY")
    HectoPA_PER_M = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-M")
    KiloGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-BAR")
    A_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-M3")
    MilliGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-CentiM2")
    GigaOHM = URIRef("http://qudt.org/vocab/unit/GigaOHM")
    MicroJ = URIRef("http://qudt.org/vocab/unit/MicroJ")
    GM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN-K")
    MegaV_A_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A-HR")
    C_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM-SEC")
    MegaBQ = URIRef("http://qudt.org/vocab/unit/MegaBQ")
    KiloMIL_Circ = URIRef("http://qudt.org/vocab/unit/KiloMIL_Circ")
    K_M_PER_W = URIRef("http://qudt.org/vocab/unit/K-M-PER-W")
    PERCENT_PER_MO = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MO")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    MicroW = URIRef("http://qudt.org/vocab/unit/MicroW")
    YR_Common = URIRef("http://qudt.org/vocab/unit/YR_Common")
    PER_MIN = URIRef("http://qudt.org/vocab/unit/PER-MIN")
    MicroM2 = URIRef("http://qudt.org/vocab/unit/MicroM2")
    Gamma = URIRef("http://qudt.org/vocab/unit/Gamma")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    M = URIRef("http://qudt.org/vocab/unit/M")
    PK_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-DAY")
    MilliGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-SEC")
    MilliR = URIRef("http://qudt.org/vocab/unit/MilliR")
    MilliBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-KiloGM")
    KiloGM_PER_HA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HA")
    KiloV_A = URIRef("http://qudt.org/vocab/unit/KiloV-A")
    NanoS_PER_M = URIRef("http://qudt.org/vocab/unit/NanoS-PER-M")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    M2_K_PER_W = URIRef("http://qudt.org/vocab/unit/M2-K-PER-W")
    OZ_SEC_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-GAL_US")
    ATM_T_PER_M = URIRef("http://qudt.org/vocab/unit/ATM_T-PER-M")
    NanoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/NanoW-PER-M2")
    N_PER_A = URIRef("http://qudt.org/vocab/unit/N-PER-A")
    FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-SEC")
    TON_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_US-PER-DAY")
    A = URIRef("http://qudt.org/vocab/unit/A")
    QT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-DAY")
    MilliMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-MOL")
    N = URIRef("http://qudt.org/vocab/unit/N")
    GigaBIT_PER_M = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-M")
    DEG_C_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-HR")
    M2_SR = URIRef("http://qudt.org/vocab/unit/M2-SR")
    MilliGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-BAR")
    TON_SHORT_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    KiloM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloM-PER-DAY")
    LB_PER_IN3_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3-DEG_F")
    PER_MegaPA = URIRef("http://qudt.org/vocab/unit/PER-MegaPA")
    OZ_VOL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-HR")
    PDL_IN = URIRef("http://qudt.org/vocab/unit/PDL-IN")
    MicroBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-KiloGM")
    Quarter_UK = URIRef("http://qudt.org/vocab/unit/Quarter_UK")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    DeciS_PER_M = URIRef("http://qudt.org/vocab/unit/DeciS-PER-M")
    PK_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-DAY")
    GM_PER_HZ = URIRef("http://qudt.org/vocab/unit/GM-PER-HZ")
    BBL_US_DRY = URIRef("http://qudt.org/vocab/unit/BBL_US_DRY")
    NAT = URIRef("http://qudt.org/vocab/unit/NAT")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    C4_M4_PER_J3 = URIRef("http://qudt.org/vocab/unit/C4-M4-PER-J3")
    PDL_PER_IN2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-IN2")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    W = URIRef("http://qudt.org/vocab/unit/W")
    BTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2")
    FT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-DEG_F")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    MilliR_man = URIRef("http://qudt.org/vocab/unit/MilliR_man")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-PER-FT2")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    TONNE_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN-K")
    YD3_PER_DAY = URIRef("http://qudt.org/vocab/unit/YD3-PER-DAY")
    ExaBYTE = URIRef("http://qudt.org/vocab/unit/ExaBYTE")
    FemtoJ = URIRef("http://qudt.org/vocab/unit/FemtoJ")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    MicroV_PER_M = URIRef("http://qudt.org/vocab/unit/MicroV-PER-M")
    OHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/OHM-PER-BAR")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    KiloV_PER_M = URIRef("http://qudt.org/vocab/unit/KiloV-PER-M")
    J_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2-DAY")
    KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-SEC2")
    PERCENT_MIN_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-IN3")
    PicoGM_PER_L = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-L")
    ZeptoC = URIRef("http://qudt.org/vocab/unit/ZeptoC")
    TONNE_PER_SEC = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC")
    DecaGM = URIRef("http://qudt.org/vocab/unit/DecaGM")
    ERG_PER_G = URIRef("http://qudt.org/vocab/unit/ERG-PER-G")
    MicroMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2")
    DeciB_W = URIRef("http://qudt.org/vocab/unit/DeciB-W")
    PERCENT_FT2_PER_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-FT2-PER-LB_F-SEC")
    FT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-DEG_F")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    L_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-K")
    PDL_IN = URIRef("http://qudt.org/vocab/unit/PDL-IN")
    N_M2_PER_A = URIRef("http://qudt.org/vocab/unit/N-M2-PER-A")
    KiloGM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM2-PER-SEC2")
    W_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/W-PER-CentiM2")
    GM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3")
    OZ_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ-PER-SEC")
    ANGSTROM = URIRef("http://qudt.org/vocab/unit/ANGSTROM")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    DeciB_MilliW_PER_MegaHZ = URIRef("http://qudt.org/vocab/unit/DeciB-MilliW-PER-MegaHZ")
    L_PER_HR_K = URIRef("http://qudt.org/vocab/unit/L-PER-HR-K")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    M_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-BAR")
    CentiM_PER_KiloYR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-KiloYR")
    PINT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-DAY")
    KiloN_M = URIRef("http://qudt.org/vocab/unit/KiloN-M")
    M3_PER_DAY = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY")
    MilliGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-CentiM2")
    PA_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M")
    MicroFARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-KiloM")
    REV_PER_HR = URIRef("http://qudt.org/vocab/unit/REV-PER-HR")
    MOL_PER_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-HR")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    NanoV_A_Reactive = URIRef("http://qudt.org/vocab/unit/NanoV-A_Reactive")
    MOL_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-L-BAR")
    GM_PER_CentiM3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3-BAR")
    KiloGM_F = URIRef("http://qudt.org/vocab/unit/KiloGM_F")
    MilliV = URIRef("http://qudt.org/vocab/unit/MilliV")
    PER_SEC_M2_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2-SR")
    M4_PER_SEC = URIRef("http://qudt.org/vocab/unit/M4-PER-SEC")
    C_M2_PER_V = URIRef("http://qudt.org/vocab/unit/C-M2-PER-V")
    ONE = URIRef("http://qudt.org/vocab/unit/ONE")
    J_PER_T2 = URIRef("http://qudt.org/vocab/unit/J-PER-T2")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    V_PER_PA = URIRef("http://qudt.org/vocab/unit/V-PER-PA")
    WB_M = URIRef("http://qudt.org/vocab/unit/WB-M")
    BU_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-HR")
    PERCENT_PER_OHM = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-OHM")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-SEC")
    FA = URIRef("http://qudt.org/vocab/unit/FA")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    GI_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_US-PER-SEC")
    MicroMOL_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM-SEC")
    DEG_F_HR_FT2_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    ZeptoC = URIRef("http://qudt.org/vocab/unit/ZeptoC")
    LB_PER_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-DAY")
    YD3_PER_DAY = URIRef("http://qudt.org/vocab/unit/YD3-PER-DAY")
    DecaGM = URIRef("http://qudt.org/vocab/unit/DecaGM")
    MilliM4 = URIRef("http://qudt.org/vocab/unit/MilliM4")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    PicoC = URIRef("http://qudt.org/vocab/unit/PicoC")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    PA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-L-PER-SEC")
    CAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    KiloGM_PER_M_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-MIN")
    PER_KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/PER-KiloV-A-HR")
    FT3_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN")
    LB_IN2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-IN3-LB_F-SEC")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    PERCENT_PER_KiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-KiloCount")
    ANGSTROM = URIRef("http://qudt.org/vocab/unit/ANGSTROM")
    MilliM_PER_DEG_C_M = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DEG_C-M")
    MilliCi = URIRef("http://qudt.org/vocab/unit/MilliCi")
    M3_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-BAR")
    DEATHS_PER_1000000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000000I-YR")
    BTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR")
    A_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM2")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    KAT_PER_MicroL = URIRef("http://qudt.org/vocab/unit/KAT-PER-MicroL")
    PER_M_NanoM = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM")
    TON_SHIPPING_US = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_US")
    W = URIRef("http://qudt.org/vocab/unit/W")
    MI2 = URIRef("http://qudt.org/vocab/unit/MI2")
    CAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-MIN")
    A_PER_CentiM = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM")
    MilliA_SEC = URIRef("http://qudt.org/vocab/unit/MilliA-SEC")
    MilliOHM = URIRef("http://qudt.org/vocab/unit/MilliOHM")
    LB_HR_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-FT3")
    KiloGM_PER_GigaJ = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-GigaJ")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    MicroPOISE = URIRef("http://qudt.org/vocab/unit/MicroPOISE")
    DeciB_MilliW_PER_MegaHZ = URIRef("http://qudt.org/vocab/unit/DeciB-MilliW-PER-MegaHZ")
    L_PER_MOL = URIRef("http://qudt.org/vocab/unit/L-PER-MOL")
    KiloGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC")
    NanoGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M2-PA-SEC")
    MilliSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-MIN")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    LunarMass = URIRef("http://qudt.org/vocab/unit/LunarMass")
    CentiM = URIRef("http://qudt.org/vocab/unit/CentiM")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    TONNE_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR-BAR")
    TORR = URIRef("http://qudt.org/vocab/unit/TORR")
    BARN = URIRef("http://qudt.org/vocab/unit/BARN")
    POISE_PER_PA = URIRef("http://qudt.org/vocab/unit/POISE-PER-PA")
    KiloGM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-CentiM2")
    KiloOHM_M = URIRef("http://qudt.org/vocab/unit/KiloOHM-M")
    MIN_Angle = URIRef("http://qudt.org/vocab/unit/MIN_Angle")
    BTU_TH_PER_FT2_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-MIN")
    PSI_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-M3-PER-SEC")
    N_M_PER_DEG_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG-M")
    KiloGM_PER_L = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L")
    RAD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC2")
    BTU_TH_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB")
    KiloCAL_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-HR")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    YoctoC = URIRef("http://qudt.org/vocab/unit/YoctoC")
    W_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-PER-KiloGM")
    DEG_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC")
    OZ_FT = URIRef("http://qudt.org/vocab/unit/OZ-FT")
    PicoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/PicoW-PER-M2")
    M2_PER_SEC2_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2-K")
    ERG = URIRef("http://qudt.org/vocab/unit/ERG")
    GM_MIN_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M6")
    C2_M2_PER_J = URIRef("http://qudt.org/vocab/unit/C2-M2-PER-J")
    BIOT = URIRef("http://qudt.org/vocab/unit/BIOT")
    W_PER_M2_M_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M-SR")
    GAL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-MIN")
    LB_PER_FT3_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3-PSI")
    GRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/GRAY-PER-SEC")
    GAUGE_FR = URIRef("http://qudt.org/vocab/unit/GAUGE_FR")
    GigaBQ = URIRef("http://qudt.org/vocab/unit/GigaBQ")
    PINT_UK = URIRef("http://qudt.org/vocab/unit/PINT_UK")
    KiloCAL_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2")
    OZ_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ-PER-HR")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    CAL_TH_PER_G = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-G")
    A_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-PER-DEG_C")
    KibiBIT = URIRef("http://qudt.org/vocab/unit/KibiBIT")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    MilliGM_PER_M3_POISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-POISE")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    PlanckPressure = URIRef("http://qudt.org/vocab/unit/PlanckPressure")
    MilliGM_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-DAY")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    YR_Common = URIRef("http://qudt.org/vocab/unit/YR_Common")
    Stone_UK = URIRef("http://qudt.org/vocab/unit/Stone_UK")
    BQ_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-SEC-PER-M3")
    LB_PER_LB = URIRef("http://qudt.org/vocab/unit/LB-PER-LB")
    PicoW = URIRef("http://qudt.org/vocab/unit/PicoW")
    MilliGM_HR_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L-M3")
    LB_PER_IN3_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3-PSI")
    CentiM6 = URIRef("http://qudt.org/vocab/unit/CentiM6")
    KiloM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC-BAR")
    BTU_IT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC")
    GigaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-SEC")
    IN4 = URIRef("http://qudt.org/vocab/unit/IN4")
    MilliN = URIRef("http://qudt.org/vocab/unit/MilliN")
    BTU_IT_PER_LB_MOL = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-MOL")
    KiloCAL_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL")
    CAL_TH_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM2-K")
    BBL_US_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-SEC")
    V_PER_PA = URIRef("http://qudt.org/vocab/unit/V-PER-PA")
    GigaEV = URIRef("http://qudt.org/vocab/unit/GigaEV")
    M = URIRef("http://qudt.org/vocab/unit/M")
    MO_Synodic = URIRef("http://qudt.org/vocab/unit/MO_Synodic")
    BU_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-MIN")
    PDL_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-SEC-PER-FT2")
    CWT_SHORT = URIRef("http://qudt.org/vocab/unit/CWT_SHORT")
    MilliN_M = URIRef("http://qudt.org/vocab/unit/MilliN-M")
    MilliGM_SEC_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M6")
    TON_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-DAY")
    LB_PER_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-DAY")
    HectoBAR = URIRef("http://qudt.org/vocab/unit/HectoBAR")
    PERCENT_SEC_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-L")
    NanoMOL_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-GM-SEC")
    PA_SEC_PER_L = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-L")
    PER_J = URIRef("http://qudt.org/vocab/unit/PER-J")
    A_HR_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-DeciM3")
    PERCENT_MIN_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-CentiM3")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    FT3_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN")
    BBL_UK_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-HR")
    CentiM_H2O_4DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_H2O_4DEG_C")
    BIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/BIT-PER-M3")
    DeciBAR_PER_YR = URIRef("http://qudt.org/vocab/unit/DeciBAR-PER-YR")
    CAL_MEAN = URIRef("http://qudt.org/vocab/unit/CAL_MEAN")
    NUM_PER_HectoGM = URIRef("http://qudt.org/vocab/unit/NUM-PER-HectoGM")
    KiloPA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-M")
    MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC")
    LB_PER_YD2 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD2")
    SLUG_PER_HR = URIRef("http://qudt.org/vocab/unit/SLUG-PER-HR")
    MegaOHM_KiloM = URIRef("http://qudt.org/vocab/unit/MegaOHM-KiloM")
    MilliKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MilliKAT-PER-L")
    KiloGM_PER_HA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HA")
    PPM = URIRef("http://qudt.org/vocab/unit/PPM")
    IN_PDL = URIRef("http://qudt.org/vocab/unit/IN-PDL")
    KY = URIRef("http://qudt.org/vocab/unit/KY")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    KiloM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM2-PER-SEC2")
    KiloV_PER_M = URIRef("http://qudt.org/vocab/unit/KiloV-PER-M")
    TON_LONG = URIRef("http://qudt.org/vocab/unit/TON_LONG")
    LM_PER_W = URIRef("http://qudt.org/vocab/unit/LM-PER-W")
    MicroM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM-PER-MilliL")
    MicroPOISE = URIRef("http://qudt.org/vocab/unit/MicroPOISE")
    REM = URIRef("http://qudt.org/vocab/unit/REM")
    C_M2 = URIRef("http://qudt.org/vocab/unit/C-M2")
    GM_MIN_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M6")
    GI_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-DAY")
    IN_PER_PSI = URIRef("http://qudt.org/vocab/unit/IN-PER-PSI")
    QT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-HR")
    BAUD = URIRef("http://qudt.org/vocab/unit/BAUD")
    KiloCAL_IT_PER_HR_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-HR-M-DEG_C")
    GM_PER_M = URIRef("http://qudt.org/vocab/unit/GM-PER-M")
    BTU_IT_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_R")
    FemtoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-L")
    MACH = URIRef("http://qudt.org/vocab/unit/MACH")
    IN3_PER_HR = URIRef("http://qudt.org/vocab/unit/IN3-PER-HR")
    GM_PER_CentiM_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM-SEC")
    TON_Metric_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC-K")
    IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN3-PER-SEC")
    FT3_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN")
    PicoMOL = URIRef("http://qudt.org/vocab/unit/PicoMOL")
    Standard = URIRef("http://qudt.org/vocab/unit/Standard")
    BAR_PER_K = URIRef("http://qudt.org/vocab/unit/BAR-PER-K")
    CentiM3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-K")
    GI = URIRef("http://qudt.org/vocab/unit/GI")
    IU_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliGM")
    DeciM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-KiloGM")
    L_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-M2")
    KiloJ = URIRef("http://qudt.org/vocab/unit/KiloJ")
    MicroS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MicroS-PER-CentiM")
    DeciB_M = URIRef("http://qudt.org/vocab/unit/DeciB_M")
    K_PER_M = URIRef("http://qudt.org/vocab/unit/K-PER-M")
    MicroGRAY = URIRef("http://qudt.org/vocab/unit/MicroGRAY")
    KiloC_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M2")
    MegaV_PER_M = URIRef("http://qudt.org/vocab/unit/MegaV-PER-M")
    CentiM3_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-BAR")
    PER_MOL = URIRef("http://qudt.org/vocab/unit/PER-MOL")
    TON_Metric_PER_HA = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HA")
    GR = URIRef("http://qudt.org/vocab/unit/GR")
    MI_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI-PER-MIN")
    CAL_15_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_15_DEG_C")
    GM_PER_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    OHM_Stat = URIRef("http://qudt.org/vocab/unit/OHM_Stat")
    BAN = URIRef("http://qudt.org/vocab/unit/BAN")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    PA_M = URIRef("http://qudt.org/vocab/unit/PA-M")
    KiloLB_F_FT_PER_LB = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-LB")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    MilliL_PER_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-K")
    FT_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC-DEG_F")
    CentiGRAY = URIRef("http://qudt.org/vocab/unit/CentiGRAY")
    KiloGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY")
    K = URIRef("http://qudt.org/vocab/unit/K")
    KiloGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC")
    MicroMOL = URIRef("http://qudt.org/vocab/unit/MicroMOL")
    KiloGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-PA-SEC")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    MilliGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DeciL")
    ERG_SEC = URIRef("http://qudt.org/vocab/unit/ERG-SEC")
    PER_SEC_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR")
    IN3_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN3-PER-MIN")
    Stone_UK = URIRef("http://qudt.org/vocab/unit/Stone_UK")
    A_PER_J = URIRef("http://qudt.org/vocab/unit/A-PER-J")
    LM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LM-PER-FT2")
    QT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_US-PER-MIN")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    V_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V-PER-CentiM")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    MilliM4 = URIRef("http://qudt.org/vocab/unit/MilliM4")
    HeartBeat = URIRef("http://qudt.org/vocab/unit/HeartBeat")
    CentiM_H20_4DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_H20_4DEG_C")
    FA = URIRef("http://qudt.org/vocab/unit/FA")
    KiloW_PER_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M-DEG_C")
    MicroMOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-SEC")
    ExbiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M")
    MicroM_PER_N = URIRef("http://qudt.org/vocab/unit/MicroM-PER-N")
    BTU_TH_PER_FT2_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-HR")
    NUM_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/NUM-PER-MilliM3")
    KiloGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-BAR")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    GM_PER_L = URIRef("http://qudt.org/vocab/unit/GM-PER-L")
    M2_K_PER_W = URIRef("http://qudt.org/vocab/unit/M2-K-PER-W")
    J = URIRef("http://qudt.org/vocab/unit/J")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    LB_F_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN")
    BTU_IT_PER_SEC_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_R")
    PHON = URIRef("http://qudt.org/vocab/unit/PHON")
    PicoV_A = URIRef("http://qudt.org/vocab/unit/PicoV-A")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    FT3 = URIRef("http://qudt.org/vocab/unit/FT3")
    M2_K = URIRef("http://qudt.org/vocab/unit/M2-K")
    FT_LB_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-MIN")
    ExaBYTE = URIRef("http://qudt.org/vocab/unit/ExaBYTE")
    H = URIRef("http://qudt.org/vocab/unit/H")
    MACH = URIRef("http://qudt.org/vocab/unit/MACH")
    GM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-CentiM-PER-SEC")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    A = URIRef("http://qudt.org/vocab/unit/A")
    MilliGM_HR_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M6")
    IN2 = URIRef("http://qudt.org/vocab/unit/IN2")
    IN4 = URIRef("http://qudt.org/vocab/unit/IN4")
    MI_N_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI_N-PER-MIN")
    OZ_VOL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-MIN")
    MilliGM_PER_M3_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-MilliPA-SEC")
    DYN_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM")
    GigaPA = URIRef("http://qudt.org/vocab/unit/GigaPA")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    RAD_PER_MIN = URIRef("http://qudt.org/vocab/unit/RAD-PER-MIN")
    MegaBIT = URIRef("http://qudt.org/vocab/unit/MegaBIT")
    MilliRAD = URIRef("http://qudt.org/vocab/unit/MilliRAD")
    H_PER_M = URIRef("http://qudt.org/vocab/unit/H-PER-M")
    W_PER_M2_K4 = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K4")
    J_PER_KiloGM_K_PA = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-PA")
    MOMME_Pearl = URIRef("http://qudt.org/vocab/unit/MOMME_Pearl")
    W = URIRef("http://qudt.org/vocab/unit/W")
    PINT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-DAY")
    LB_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC-PSI")
    MOL_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-SEC")
    LB_FT2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-IN3-LB_F-SEC")
    PSI_YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-YD3-PER-SEC")
    K_DAY = URIRef("http://qudt.org/vocab/unit/K-DAY")
    BU_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-DAY")
    GAL_UK = URIRef("http://qudt.org/vocab/unit/GAL_UK")
    MilliGM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR")
    KiloJ_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM-K")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    MicroH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-OHM")
    CAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-K")
    PPTH_PER_HR = URIRef("http://qudt.org/vocab/unit/PPTH-PER-HR")
    KiloW_HR = URIRef("http://qudt.org/vocab/unit/KiloW-HR")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    CAL_TH = URIRef("http://qudt.org/vocab/unit/CAL_TH")
    NUM_PER_M = URIRef("http://qudt.org/vocab/unit/NUM-PER-M")
    YD_PER_PSI = URIRef("http://qudt.org/vocab/unit/YD-PER-PSI")
    TON_UK = URIRef("http://qudt.org/vocab/unit/TON_UK")
    TONNE_PER_M3 = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3")
    LB_SEC_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN6")
    KiloGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC")
    LB_F_PER_IN2_DEG_F = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-DEG_F")
    KiloN_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M2")
    DeciB_C = URIRef("http://qudt.org/vocab/unit/DeciB_C")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    MilliPA = URIRef("http://qudt.org/vocab/unit/MilliPA")
    MicroMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MOL")
    MI3 = URIRef("http://qudt.org/vocab/unit/MI3")
    BU_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-SEC")
    GALILEO = URIRef("http://qudt.org/vocab/unit/GALILEO")
    CAL_TH_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2")
    BIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BIT-PER-SEC")
    FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-SEC")
    KIP_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KIP_F-PER-IN2")
    MIN_Sidereal = URIRef("http://qudt.org/vocab/unit/MIN_Sidereal")
    GM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloGM")
    HART = URIRef("http://qudt.org/vocab/unit/HART")
    GAL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-HR")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    PicoW = URIRef("http://qudt.org/vocab/unit/PicoW")
    NanoMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-M2-DAY")
    GM_HR_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L-CentiM3")
    KiloCAL = URIRef("http://qudt.org/vocab/unit/KiloCAL")
    NUM_PER_YR = URIRef("http://qudt.org/vocab/unit/NUM-PER-YR")
    PIXEL = URIRef("http://qudt.org/vocab/unit/PIXEL")
    M3_PER_C = URIRef("http://qudt.org/vocab/unit/M3-PER-C")
    A_PER_M2_K2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2-K2")
    C_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM")
    PER_MILLE_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PSI")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    KiloBAR = URIRef("http://qudt.org/vocab/unit/KiloBAR")
    MicroFARAD = URIRef("http://qudt.org/vocab/unit/MicroFARAD")
    TON_Metric_PER_MIN = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN")
    AT_PER_M = URIRef("http://qudt.org/vocab/unit/AT-PER-M")
    GigaEV = URIRef("http://qudt.org/vocab/unit/GigaEV")
    QT_US = URIRef("http://qudt.org/vocab/unit/QT_US")
    MilliL_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR")
    LB_F = URIRef("http://qudt.org/vocab/unit/LB_F")
    CAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-MIN")
    LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT2")
    KiloPA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-M")
    MilliRAD_R = URIRef("http://qudt.org/vocab/unit/MilliRAD_R")
    S = URIRef("http://qudt.org/vocab/unit/S")
    GM_PER_M = URIRef("http://qudt.org/vocab/unit/GM-PER-M")
    A_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM2")
    RAD_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-MOL")
    DYN = URIRef("http://qudt.org/vocab/unit/DYN")
    POISE_PER_PA = URIRef("http://qudt.org/vocab/unit/POISE-PER-PA")
    BTU_IT_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_F")
    N_PER_A = URIRef("http://qudt.org/vocab/unit/N-PER-A")
    DEG_R_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-SEC")
    GI_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-MIN")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    J_PER_M3_K = URIRef("http://qudt.org/vocab/unit/J-PER-M3-K")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    PER_M_SEC = URIRef("http://qudt.org/vocab/unit/PER-M-SEC")
    KiloCAL_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    MilliMOL_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3-DAY")
    KiloGM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3")
    MegaPA_PER_K = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-K")
    ERG_PER_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-SEC")
    W_PER_M2_K4 = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K4")
    FemtoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-L")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    CUP = URIRef("http://qudt.org/vocab/unit/CUP")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    PK_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-SEC")
    OZ_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ-PER-HR")
    N_M_PER_DEG_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG-M")
    MegaTONNE = URIRef("http://qudt.org/vocab/unit/MegaTONNE")
    WB_M = URIRef("http://qudt.org/vocab/unit/WB-M")
    M2_PER_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ2")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    IN_H2O = URIRef("http://qudt.org/vocab/unit/IN_H2O")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    OZ_TROY = URIRef("http://qudt.org/vocab/unit/OZ_TROY")
    FA = URIRef("http://qudt.org/vocab/unit/FA")
    YR_Sidereal = URIRef("http://qudt.org/vocab/unit/YR_Sidereal")
    DEGREE_PLATO = URIRef("http://qudt.org/vocab/unit/DEGREE_PLATO")
    GAUGE_FR = URIRef("http://qudt.org/vocab/unit/GAUGE_FR")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    LB_F_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-FT2")
    PetaC = URIRef("http://qudt.org/vocab/unit/PetaC")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    PER_WK = URIRef("http://qudt.org/vocab/unit/PER-WK")
    A = URIRef("http://qudt.org/vocab/unit/A")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/PER-M2-SEC")
    HeartBeat = URIRef("http://qudt.org/vocab/unit/HeartBeat")
    KiloGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-K")
    PER_LB = URIRef("http://qudt.org/vocab/unit/PER-LB")
    CentiM3_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY-BAR")
    PK_UK = URIRef("http://qudt.org/vocab/unit/PK_UK")
    LB_FT2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-IN3-LB_F-SEC")
    MegaJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-KiloGM")
    MI2 = URIRef("http://qudt.org/vocab/unit/MI2")
    V_Ab_SEC = URIRef("http://qudt.org/vocab/unit/V_Ab-SEC")
    LA_FT = URIRef("http://qudt.org/vocab/unit/LA_FT")
    MilliM_HGA = URIRef("http://qudt.org/vocab/unit/MilliM_HGA")
    LB_IN2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-IN3-LB_F-SEC")
    MilliS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MilliS-PER-CentiM")
    DEG_F_HR_FT2_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT")
    C_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM2")
    EUR_PER_KiloW_HR = URIRef("http://qudt.org/vocab/unit/EUR-PER-KiloW-HR")
    BIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/BIT-PER-M2")
    LB_MIN_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-FT3")
    MilliM_PER_DEG_C_M = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DEG_C-M")
    MilliGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-K")
    MilliM_H2O = URIRef("http://qudt.org/vocab/unit/MilliM_H2O")
    LB_IN2_PER_GAL_US_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-GAL_US-LB_F-SEC")
    L_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/L-PER-KiloGM")
    CentiM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC-BAR")
    PT = URIRef("http://qudt.org/vocab/unit/PT")
    DYN_SEC_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM")
    KiloBTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-FT2")
    ARE = URIRef("http://qudt.org/vocab/unit/ARE")
    LB_HR_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-YD3")
    J_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-M2-PER-KiloGM")
    BTU_IT_PER_LB_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F")
    W_HR = URIRef("http://qudt.org/vocab/unit/W-HR")
    BTU_IT_PER_MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB-DEG_F")
    KiloL = URIRef("http://qudt.org/vocab/unit/KiloL")
    FemtoC = URIRef("http://qudt.org/vocab/unit/FemtoC")
    GigaBIT = URIRef("http://qudt.org/vocab/unit/GigaBIT")
    FemtoGM = URIRef("http://qudt.org/vocab/unit/FemtoGM")
    V_PER_MilliM = URIRef("http://qudt.org/vocab/unit/V-PER-MilliM")
    N_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-PER-KiloGM")
    V_A_HR = URIRef("http://qudt.org/vocab/unit/V-A-HR")
    BTU_IT_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_R")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PER-M3-SEC")
    LB_HR_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-FT3")
    N_M_PER_A = URIRef("http://qudt.org/vocab/unit/N-M-PER-A")
    GM_PER_M2 = URIRef("http://qudt.org/vocab/unit/GM-PER-M2")
    MicroH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-OHM")
    KiloOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-BAR")
    A_PER_J = URIRef("http://qudt.org/vocab/unit/A-PER-J")
    K_M = URIRef("http://qudt.org/vocab/unit/K-M")
    KiloCAL_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM")
    M4_PER_SEC = URIRef("http://qudt.org/vocab/unit/M4-PER-SEC")
    MilliGAL = URIRef("http://qudt.org/vocab/unit/MilliGAL")
    FT3 = URIRef("http://qudt.org/vocab/unit/FT3")
    BTU_TH_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT3")
    OHM_PER_K = URIRef("http://qudt.org/vocab/unit/OHM-PER-K")
    TON_Metric_PER_M3 = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3")
    MIL_Circ = URIRef("http://qudt.org/vocab/unit/MIL_Circ")
    TeraHZ = URIRef("http://qudt.org/vocab/unit/TeraHZ")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-PER-SEC")
    RAD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC2")
    MilliM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliM-PER-MIN")
    LUX_HR = URIRef("http://qudt.org/vocab/unit/LUX-HR")
    CentiM_PER_YR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-YR")
    YD3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD3-PER-DEG_F")
    PSI_PER_PSI = URIRef("http://qudt.org/vocab/unit/PSI-PER-PSI")
    J_PER_SEC = URIRef("http://qudt.org/vocab/unit/J-PER-SEC")
    RT = URIRef("http://qudt.org/vocab/unit/RT")
    TON_Metric_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC-K")
    RPK = URIRef("http://qudt.org/vocab/unit/RPK")
    CFU = URIRef("http://qudt.org/vocab/unit/CFU")
    PicoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/PicoFARAD-PER-M")
    TON_Metric_PER_M3_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3-K")
    ENZ_PER_L = URIRef("http://qudt.org/vocab/unit/ENZ-PER-L")
    PA_PER_HR = URIRef("http://qudt.org/vocab/unit/PA-PER-HR")
    KiloSEC = URIRef("http://qudt.org/vocab/unit/KiloSEC")
    PER_HR = URIRef("http://qudt.org/vocab/unit/PER-HR")
    LB_MIN_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN6")
    EUR_PER_KiloW_HR = URIRef("http://qudt.org/vocab/unit/EUR-PER-KiloW-HR")
    SLUG_PER_HR = URIRef("http://qudt.org/vocab/unit/SLUG-PER-HR")
    GM_PER_K = URIRef("http://qudt.org/vocab/unit/GM-PER-K")
    PER_TON = URIRef("http://qudt.org/vocab/unit/PER-TON")
    MilliGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-SEC")
    OZ_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ-PER-HR")
    LB_F_IN_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN-PER-IN")
    KiloW_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloW-HR-PER-M2")
    KiloCAL_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM-DEG_C")
    GigaFLOPS = URIRef("http://qudt.org/vocab/unit/GigaFLOPS")
    FT2_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT2-PER-SEC")
    HART = URIRef("http://qudt.org/vocab/unit/HART")
    MHO_Stat = URIRef("http://qudt.org/vocab/unit/MHO_Stat")
    BTU_IT_PER_MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB-DEG_F")
    PER_MIN = URIRef("http://qudt.org/vocab/unit/PER-MIN")
    KiloPA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-MilliM")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    FT3_PER_MIN_FT2 = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN-FT2")
    FT_LB_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-MIN")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    MicroPA = URIRef("http://qudt.org/vocab/unit/MicroPA")
    KiloLB_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloLB-PER-HR")
    PINT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-DAY")
    SLUG = URIRef("http://qudt.org/vocab/unit/SLUG")
    OZ_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ-PER-HR")
    DEG_F_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-HR")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    MilliW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    HP = URIRef("http://qudt.org/vocab/unit/HP")
    MicroN_M = URIRef("http://qudt.org/vocab/unit/MicroN-M")
    MicroW = URIRef("http://qudt.org/vocab/unit/MicroW")
    MOL_LB_PER_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-LB")
    BTU_60DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_60DEG_F")
    BBL_UK_PET_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-MIN")
    GigaW = URIRef("http://qudt.org/vocab/unit/GigaW")
    KiloBTU_TH = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH")
    PERCENT_HR_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-GAL_UK")
    HART = URIRef("http://qudt.org/vocab/unit/HART")
    MicroM = URIRef("http://qudt.org/vocab/unit/MicroM")
    RAD_PER_MIN = URIRef("http://qudt.org/vocab/unit/RAD-PER-MIN")
    DEG_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG-PER-HR")
    GM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC-BAR")
    KiloMOL_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3-K")
    PA_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M")
    M3_PER_HR_K = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-K")
    KiloPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-BAR")
    M3_PER_C = URIRef("http://qudt.org/vocab/unit/M3-PER-C")
    MOL_LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-SEC")
    J_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2")
    A_PER_CentiM = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    PDL_FT = URIRef("http://qudt.org/vocab/unit/PDL-FT")
    TON_Metric_PER_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-K")
    PA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M3-PER-SEC")
    DEG_R_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-HR")
    TON_SHORT_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-YD3")
    KiloGM_PER_DeciM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-K")
    MicroM2 = URIRef("http://qudt.org/vocab/unit/MicroM2")
    DeciL_PER_GM = URIRef("http://qudt.org/vocab/unit/DeciL-PER-GM")
    PER_EV2 = URIRef("http://qudt.org/vocab/unit/PER-EV2")
    DWT = URIRef("http://qudt.org/vocab/unit/DWT")
    MicroM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroM-PER-SEC")
    TONNE_PER_HR_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR-K")
    TeraOHM = URIRef("http://qudt.org/vocab/unit/TeraOHM")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    M2_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-V-SEC")
    IN_PER_YR = URIRef("http://qudt.org/vocab/unit/IN-PER-YR")
    BTU_IT = URIRef("http://qudt.org/vocab/unit/BTU_IT")
    KiloOHM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-M")
    CentiM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL")
    OHM_PER_MI = URIRef("http://qudt.org/vocab/unit/OHM-PER-MI")
    KiloA_HR = URIRef("http://qudt.org/vocab/unit/KiloA-HR")
    FT_LB_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-SEC")
    MilliV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliV-PER-MIN")
    MegaEV_FemtoM = URIRef("http://qudt.org/vocab/unit/MegaEV-FemtoM")
    MebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M")
    Denier = URIRef("http://qudt.org/vocab/unit/Denier")
    TON_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-DAY")
    PFERDESTAERKE = URIRef("http://qudt.org/vocab/unit/PFERDESTAERKE")
    H_PER_OHM = URIRef("http://qudt.org/vocab/unit/H-PER-OHM")
    GR = URIRef("http://qudt.org/vocab/unit/GR")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    PicoMOL_PER_M_W_SEC = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M-W-SEC")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    PicoPA = URIRef("http://qudt.org/vocab/unit/PicoPA")
    MegaFLOPS = URIRef("http://qudt.org/vocab/unit/MegaFLOPS")
    MilliGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2")
    V_Stat = URIRef("http://qudt.org/vocab/unit/V_Stat")
    MI_N_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI_N-PER-MIN")
    M3_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-M2")
    PicoL = URIRef("http://qudt.org/vocab/unit/PicoL")
    V_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-PER-CentiM")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    CentiM_PER_KiloYR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-KiloYR")
    LB_F_PER_YD = URIRef("http://qudt.org/vocab/unit/LB_F-PER-YD")
    M3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM")
    KiloS = URIRef("http://qudt.org/vocab/unit/KiloS")
    OZ_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ-PER-DAY")
    OZ_VOL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-DAY")
    MegaOHM = URIRef("http://qudt.org/vocab/unit/MegaOHM")
    MilliGM = URIRef("http://qudt.org/vocab/unit/MilliGM")
    MilliW_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM-SR")
    THM_US_PER_HR = URIRef("http://qudt.org/vocab/unit/THM_US-PER-HR")
    MilliL_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR")
    DeciM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-SEC")
    GRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/GRAY-PER-SEC")
    M_PER_MIN = URIRef("http://qudt.org/vocab/unit/M-PER-MIN")
    MegaPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-M3-PER-SEC")
    MilliL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliL-PER-L")
    KiloGM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-BAR")
    PERCENT_HR_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-CentiM3")
    PebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M")
    KiloCAL_Mean = URIRef("http://qudt.org/vocab/unit/KiloCAL_Mean")
    PERMEABILITY_EM_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_EM_REL")
    BTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2")
    BU_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-HR")
    TONNE_PER_M3 = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    BTU_TH_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-SEC-DEG_F")
    N = URIRef("http://qudt.org/vocab/unit/N")
    DEG_F_HR_FT2_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT")
    WB_M = URIRef("http://qudt.org/vocab/unit/WB-M")
    POISE_PER_PA = URIRef("http://qudt.org/vocab/unit/POISE-PER-PA")
    GAL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-MIN")
    FT3_PER_MIN_FT2 = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN-FT2")
    BU_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-DAY")
    CAL_IT_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM")
    TONNE_PER_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-K")
    CentiM_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-BAR")
    MicroSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-SEC")
    GigaHZ = URIRef("http://qudt.org/vocab/unit/GigaHZ")
    MilliKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MilliKAT-PER-L")
    PPQ = URIRef("http://qudt.org/vocab/unit/PPQ")
    NanoMOL_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL")
    KiloGM_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-MilliM2")
    NanoM_PER_MilliM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-MilliM-MegaPA")
    C_PER_MOL = URIRef("http://qudt.org/vocab/unit/C-PER-MOL")
    MOL_PER_TONNE = URIRef("http://qudt.org/vocab/unit/MOL-PER-TONNE")
    H = URIRef("http://qudt.org/vocab/unit/H")
    PPTR = URIRef("http://qudt.org/vocab/unit/PPTR")
    TONNE_PER_HR_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR-K")
    ERG_SEC = URIRef("http://qudt.org/vocab/unit/ERG-SEC")
    FT_LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2")
    TONNE_PER_HR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR")
    BTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloMOL")
    LB_HR_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-IN3")
    GibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M")
    M = URIRef("http://qudt.org/vocab/unit/M")
    N = URIRef("http://qudt.org/vocab/unit/N")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    FemtoFARAD = URIRef("http://qudt.org/vocab/unit/FemtoFARAD")
    TON_US_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_US-PER-HR")
    MicroW = URIRef("http://qudt.org/vocab/unit/MicroW")
    LB_IN2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-IN3-LB_F-SEC")
    KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-SEC2")
    GigaW = URIRef("http://qudt.org/vocab/unit/GigaW")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    PERCENT_SEC_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-GAL_UK")
    S_PER_CentiM = URIRef("http://qudt.org/vocab/unit/S-PER-CentiM")
    BTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR")
    J_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K")
    BARN = URIRef("http://qudt.org/vocab/unit/BARN")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    MilliS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MilliS-PER-CentiM")
    MilliS_PER_M = URIRef("http://qudt.org/vocab/unit/MilliS-PER-M")
    GAL_US = URIRef("http://qudt.org/vocab/unit/GAL_US")
    TON_Metric_PER_MIN = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    NUM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NUM-PER-MicroL")
    TON_SHORT_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    C_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM")
    KiloGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY")
    PERCENT_MIN_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-IN3")
    GRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/GRAY-PER-HR")
    GRAIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL_US")
    MilliL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M3")
    L_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-BAR")
    MilliGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DeciL")
    GAUSS = URIRef("http://qudt.org/vocab/unit/GAUSS")
    RPK = URIRef("http://qudt.org/vocab/unit/RPK")
    ExbiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M3")
    MilliOHM = URIRef("http://qudt.org/vocab/unit/MilliOHM")
    PetaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/PetaBIT-PER-SEC")
    FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC")
    MegaV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive-HR")
    DEG_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG-PER-HR")
    KiloBQ = URIRef("http://qudt.org/vocab/unit/KiloBQ")
    KiloV_A = URIRef("http://qudt.org/vocab/unit/KiloV-A")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    NanoGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DeciL")
    M3_PER_C = URIRef("http://qudt.org/vocab/unit/M3-PER-C")
    PHON = URIRef("http://qudt.org/vocab/unit/PHON")
    NanoGM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MicroL")
    KiloPA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-MilliM")
    CD_PER_LM = URIRef("http://qudt.org/vocab/unit/CD-PER-LM")
    BTU_IT_PER_MOL_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB")
    LA = URIRef("http://qudt.org/vocab/unit/LA")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    RAD_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-MOL")
    KiloV = URIRef("http://qudt.org/vocab/unit/KiloV")
    TON_SHORT_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-YD3")
    E = URIRef("http://qudt.org/vocab/unit/E")
    KiloLB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-FT")
    MegaPA = URIRef("http://qudt.org/vocab/unit/MegaPA")
    DeciM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MIN")
    W_PER_GM = URIRef("http://qudt.org/vocab/unit/W-PER-GM")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    KiloGM_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-M2")
    MebiBYTE = URIRef("http://qudt.org/vocab/unit/MebiBYTE")
    V_PER_M2 = URIRef("http://qudt.org/vocab/unit/V-PER-M2")
    KiloBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBIT-PER-SEC")
    GRAIN_PER_GAL = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL")
    SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-PER-FT2")
    MilliBQ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-GM")
    MegaEV_PER_SpeedOfLight = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-SpeedOfLight")
    C = URIRef("http://qudt.org/vocab/unit/C")
    SH = URIRef("http://qudt.org/vocab/unit/SH")
    MilliM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-HR")
    GM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloM")
    CLO = URIRef("http://qudt.org/vocab/unit/CLO")
    PER_H = URIRef("http://qudt.org/vocab/unit/PER-H")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    MilliGM_PER_L_PA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-PA-SEC")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    M3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC2")
    DecaL = URIRef("http://qudt.org/vocab/unit/DecaL")
    IN2_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN2-PER-SEC")
    NanoL = URIRef("http://qudt.org/vocab/unit/NanoL")
    POISE_PER_PA = URIRef("http://qudt.org/vocab/unit/POISE-PER-PA")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    OZ_MIN_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-YD3")
    CentiM_PER_YR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-YR")
    LB_HR_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-IN3")
    M2_HZ4 = URIRef("http://qudt.org/vocab/unit/M2-HZ4")
    KiloGM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM")
    LB_PER_YD2 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD2")
    THERM_US = URIRef("http://qudt.org/vocab/unit/THERM_US")
    ZeptoC = URIRef("http://qudt.org/vocab/unit/ZeptoC")
    N_PER_C = URIRef("http://qudt.org/vocab/unit/N-PER-C")
    MegaPA_M0dot5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0dot5")
    KiloR = URIRef("http://qudt.org/vocab/unit/KiloR")
    OZ_VOL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-SEC")
    W_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-PER-KiloGM")
    MicroGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-KiloGM")
    MicroL = URIRef("http://qudt.org/vocab/unit/MicroL")
    GM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR-BAR")
    HP_Boiler = URIRef("http://qudt.org/vocab/unit/HP_Boiler")
    N_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-PER-KiloGM")
    M3_PER_K = URIRef("http://qudt.org/vocab/unit/M3-PER-K")
    T = URIRef("http://qudt.org/vocab/unit/T")
    PINT = URIRef("http://qudt.org/vocab/unit/PINT")
    TON_US = URIRef("http://qudt.org/vocab/unit/TON_US")
    GM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-L-BAR")
    PERCENT_PER_10KiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-10KiloCount")
    GM_HR_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M6")
    GM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR-BAR")
    IN3_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN3-PER-MIN")
    RT = URIRef("http://qudt.org/vocab/unit/RT")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    MicroGM_PER_IN2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-IN2")
    HR_FT2 = URIRef("http://qudt.org/vocab/unit/HR-FT2")
    OZ_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN3")
    NanoMOL_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-GM-SEC")
    CAL_IT_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    KiloGM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM2-PER-SEC2")
    KiloA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M")
    PicoMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M2-DAY")
    REM_PER_SEC = URIRef("http://qudt.org/vocab/unit/REM-PER-SEC")
    OHM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/OHM-PER-KiloM")
    FT_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-PER-MIN")
    C = URIRef("http://qudt.org/vocab/unit/C")
    HectoC = URIRef("http://qudt.org/vocab/unit/HectoC")
    YD = URIRef("http://qudt.org/vocab/unit/YD")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    IN3_PER_HR = URIRef("http://qudt.org/vocab/unit/IN3-PER-HR")
    TeraHZ = URIRef("http://qudt.org/vocab/unit/TeraHZ")
    NanoGM_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2-DAY")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    OZ_F = URIRef("http://qudt.org/vocab/unit/OZ_F")
    L_PER_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-BAR")
    KiloW_PER_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M-DEG_C")
    KiloC_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M2")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    THM_US_PER_HR = URIRef("http://qudt.org/vocab/unit/THM_US-PER-HR")
    QT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_US-PER-MIN")
    PERCENT_MIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-M3")
    FT_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC2")
    STILB = URIRef("http://qudt.org/vocab/unit/STILB")
    FT2_PER_HR = URIRef("http://qudt.org/vocab/unit/FT2-PER-HR")
    C_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM2")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    LB_HR_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK2")
    PCA = URIRef("http://qudt.org/vocab/unit/PCA")
    TON_LONG_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_LONG-PER-YD3")
    A_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM2")
    MicroMOL = URIRef("http://qudt.org/vocab/unit/MicroMOL")
    CentiM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-M3")
    BAN = URIRef("http://qudt.org/vocab/unit/BAN")
    GAL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-MIN")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    MicroN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroN-M-PER-M2")
    STR = URIRef("http://qudt.org/vocab/unit/STR")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    PER_SEC_SR_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR-M2")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    DEG_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC")
    GM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL")
    PER_H = URIRef("http://qudt.org/vocab/unit/PER-H")
    KiloCAL_IT_PER_HR_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-HR-M-DEG_C")
    MIN = URIRef("http://qudt.org/vocab/unit/MIN")
    MilliBQ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-GM")
    TONNE = URIRef("http://qudt.org/vocab/unit/TONNE")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    PER_BAR = URIRef("http://qudt.org/vocab/unit/PER-BAR")
    L_PER_HR = URIRef("http://qudt.org/vocab/unit/L-PER-HR")
    M_PER_PA = URIRef("http://qudt.org/vocab/unit/M-PER-PA")
    YoctoC = URIRef("http://qudt.org/vocab/unit/YoctoC")
    GAL_US_DRY = URIRef("http://qudt.org/vocab/unit/GAL_US_DRY")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    TON_SHORT_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-YD3")
    LB_SEC_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-YD3")
    CP = URIRef("http://qudt.org/vocab/unit/CP")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    J_PER_GM_K = URIRef("http://qudt.org/vocab/unit/J-PER-GM-K")
    FA = URIRef("http://qudt.org/vocab/unit/FA")
    MicroA = URIRef("http://qudt.org/vocab/unit/MicroA")
    PER_HR = URIRef("http://qudt.org/vocab/unit/PER-HR")
    PicoPA_PER_KiloM = URIRef("http://qudt.org/vocab/unit/PicoPA-PER-KiloM")
    LB_MIN_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN6")
    MACH = URIRef("http://qudt.org/vocab/unit/MACH")
    NAT_PER_SEC = URIRef("http://qudt.org/vocab/unit/NAT-PER-SEC")
    LM_SEC = URIRef("http://qudt.org/vocab/unit/LM-SEC")
    IN_HG = URIRef("http://qudt.org/vocab/unit/IN_HG")
    GAL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-HR")
    MilliPA_PER_M = URIRef("http://qudt.org/vocab/unit/MilliPA-PER-M")
    CentiMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-KiloGM")
    V_PER_M2 = URIRef("http://qudt.org/vocab/unit/V-PER-M2")
    FT_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT-PER-DAY")
    TeraJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/TeraJ-PER-SEC")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    LB_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-SEC")
    M2_HZ = URIRef("http://qudt.org/vocab/unit/M2-HZ")
    PERCENT_PER_DecaCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaCount")
    MilliBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-KiloGM")
    MicroRAD = URIRef("http://qudt.org/vocab/unit/MicroRAD")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    RPK = URIRef("http://qudt.org/vocab/unit/RPK")
    KiloN = URIRef("http://qudt.org/vocab/unit/KiloN")
    ANGSTROM3 = URIRef("http://qudt.org/vocab/unit/ANGSTROM3")
    B = URIRef("http://qudt.org/vocab/unit/B")
    GigaBQ = URIRef("http://qudt.org/vocab/unit/GigaBQ")
    PERCENT_PER_HR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-HR")
    FT_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC2")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    NanoGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DAY")
    BTU_IT_IN_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-HR-FT2-DEG_F")
    GRAIN_PER_GAL = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL")
    MilliL_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY")
    OZ_VOL_US = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US")
    PINT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-SEC")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    LB_MIN_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-YD3")
    GM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM")
    MIN_Angle = URIRef("http://qudt.org/vocab/unit/MIN_Angle")
    MilliGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MilliL")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    MegaOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-BAR")
    M3_PER_HA = URIRef("http://qudt.org/vocab/unit/M3-PER-HA")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    MilliGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN")
    M2_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-V-SEC")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    PicoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-KiloGM")
    W_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-SEC-PER-M2")
    KAT_PER_L = URIRef("http://qudt.org/vocab/unit/KAT-PER-L")
    DEG_F_HR_FT2_PER_BTU_TH_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH-IN")
    DYN_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-CentiM")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    BARN_PER_SR_EV = URIRef("http://qudt.org/vocab/unit/BARN-PER-SR-EV")
    FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-SEC-DEG_F")
    M3_PER_C = URIRef("http://qudt.org/vocab/unit/M3-PER-C")
    PINT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-SEC")
    FUR = URIRef("http://qudt.org/vocab/unit/FUR")
    KiloGM_PER_KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloMOL")
    CAL_TH_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-K")
    PicoMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M3")
    TeraBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/TeraBIT-PER-SEC")
    CentiL = URIRef("http://qudt.org/vocab/unit/CentiL")
    DEG_C2_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C2-PER-SEC")
    MicroGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-SEC")
    V_IN2_PER_LB_F = URIRef("http://qudt.org/vocab/unit/V-IN2-PER-LB_F")
    DEG_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-MIN")
    RAD_PER_HR = URIRef("http://qudt.org/vocab/unit/RAD-PER-HR")
    IN_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC-PSI")
    M_PER_HR = URIRef("http://qudt.org/vocab/unit/M-PER-HR")
    EV_PER_M = URIRef("http://qudt.org/vocab/unit/EV-PER-M")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    TON_FG = URIRef("http://qudt.org/vocab/unit/TON_FG")
    KiloGM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-BAR")
    GM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-CentiM-PER-SEC")
    J_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K")
    N_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM2")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    TeraHZ = URIRef("http://qudt.org/vocab/unit/TeraHZ")
    LB_F_FT = URIRef("http://qudt.org/vocab/unit/LB_F-FT")
    KiloTONNE = URIRef("http://qudt.org/vocab/unit/KiloTONNE")
    MOL_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-K")
    GM = URIRef("http://qudt.org/vocab/unit/GM")
    MilliGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-SEC")
    J_PER_GM_K = URIRef("http://qudt.org/vocab/unit/J-PER-GM-K")
    A2_SEC = URIRef("http://qudt.org/vocab/unit/A2-SEC")
    MebiBIT = URIRef("http://qudt.org/vocab/unit/MebiBIT")
    KiloV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive-HR")
    LB_HR_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-GAL_US")
    MicroM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-M3")
    FARAD_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/FARAD_Ab-PER-CentiM")
    RHE = URIRef("http://qudt.org/vocab/unit/RHE")
    KiloGM_PER_M_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC")
    PERMEABILITY_EM_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_EM_REL")
    GM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-K")
    PicoA = URIRef("http://qudt.org/vocab/unit/PicoA")
    M3_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-BAR")
    KiloGM_F = URIRef("http://qudt.org/vocab/unit/KiloGM_F")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/M2-PER-MOL")
    KiloGM_PER_M_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-DAY")
    NanoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MilliL")
    PERCENT_PER_HectoBAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-HectoBAR")
    YD_PER_PSI = URIRef("http://qudt.org/vocab/unit/YD-PER-PSI")
    Standard = URIRef("http://qudt.org/vocab/unit/Standard")
    IN_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-DEG_F")
    MegaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M3")
    REV_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC2")
    GigaHZ = URIRef("http://qudt.org/vocab/unit/GigaHZ")
    POISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/POISE-PER-BAR")
    KiloGAUSS = URIRef("http://qudt.org/vocab/unit/KiloGAUSS")
    MilliJ = URIRef("http://qudt.org/vocab/unit/MilliJ")
    M2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2")
    MicroSV = URIRef("http://qudt.org/vocab/unit/MicroSV")
    W_PER_M2_K = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K")
    MilliM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-KiloGM")
    PetaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/PetaBIT-PER-SEC")
    L_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-K")
    MilliMOL = URIRef("http://qudt.org/vocab/unit/MilliMOL")
    MilliV_PER_V = URIRef("http://qudt.org/vocab/unit/MilliV-PER-V")
    Kilo_FT3 = URIRef("http://qudt.org/vocab/unit/Kilo-FT3")
    KiloOHM_M = URIRef("http://qudt.org/vocab/unit/KiloOHM-M")
    MegaJ_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M3")
    NanoV = URIRef("http://qudt.org/vocab/unit/NanoV")
    PERCENT_PER_BAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-BAR")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    IN_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-DEG_F")
    DeciM = URIRef("http://qudt.org/vocab/unit/DeciM")
    MilliL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-MIN")
    PA_SEC_PER_L = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-L")
    MegaS_PER_M = URIRef("http://qudt.org/vocab/unit/MegaS-PER-M")
    RAYL = URIRef("http://qudt.org/vocab/unit/RAYL")
    TONNE_PER_SEC = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC")
    NanoH_PER_M = URIRef("http://qudt.org/vocab/unit/NanoH-PER-M")
    MI2 = URIRef("http://qudt.org/vocab/unit/MI2")
    DEG_F_HR_FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT-IN")
    KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-SEC2")
    HectoL = URIRef("http://qudt.org/vocab/unit/HectoL")
    DWT = URIRef("http://qudt.org/vocab/unit/DWT")
    FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-SEC-DEG_F")
    K_PER_MIN = URIRef("http://qudt.org/vocab/unit/K-PER-MIN")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    IN_H2O_60DEG_F = URIRef("http://qudt.org/vocab/unit/IN_H2O_60DEG_F")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    PPM_PER_K = URIRef("http://qudt.org/vocab/unit/PPM-PER-K")
    V_Ab = URIRef("http://qudt.org/vocab/unit/V_Ab")
    J_PER_GM_K = URIRef("http://qudt.org/vocab/unit/J-PER-GM-K")
    MegaBAUD = URIRef("http://qudt.org/vocab/unit/MegaBAUD")
    K_M2_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/K-M2-PER-KiloGM-SEC")
    J_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K")
    DEG_C_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-HR")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    V2_PER_K2 = URIRef("http://qudt.org/vocab/unit/V2-PER-K2")
    SLUG = URIRef("http://qudt.org/vocab/unit/SLUG")
    W_PER_SR = URIRef("http://qudt.org/vocab/unit/W-PER-SR")
    J_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-M2-PER-KiloGM")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    CentiMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-KiloGM")
    V_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-PER-CentiM")
    ERG_PER_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-SEC")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    KiloN_M_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-M")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    MegaA = URIRef("http://qudt.org/vocab/unit/MegaA")
    DEG_C_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-SEC")
    MilliA_HR = URIRef("http://qudt.org/vocab/unit/MilliA-HR")
    PA_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M")
    KiloM = URIRef("http://qudt.org/vocab/unit/KiloM")
    PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/PER-KiloGM2")
    PH = URIRef("http://qudt.org/vocab/unit/PH")
    DEG_F_HR_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_IT")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    PER_IN3 = URIRef("http://qudt.org/vocab/unit/PER-IN3")
    CentiM_PER_YR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-YR")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/MOL_LB-DEG_F")
    P = URIRef("http://qudt.org/vocab/unit/P")
    QT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_US-PER-SEC")
    MilliL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M2-DAY")
    TON_Assay = URIRef("http://qudt.org/vocab/unit/TON_Assay")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    N_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-M-PER-M2")
    PER_M2 = URIRef("http://qudt.org/vocab/unit/PER-M2")
    OZ_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ-PER-HR")
    N_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-PER-KiloGM")
    Z = URIRef("http://qudt.org/vocab/unit/Z")
    PER_MO = URIRef("http://qudt.org/vocab/unit/PER-MO")
    MilliGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-KiloGM")
    MicroBAR = URIRef("http://qudt.org/vocab/unit/MicroBAR")
    K_PER_T = URIRef("http://qudt.org/vocab/unit/K-PER-T")
    MicroOHM = URIRef("http://qudt.org/vocab/unit/MicroOHM")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    PlanckTemperature = URIRef("http://qudt.org/vocab/unit/PlanckTemperature")
    MilliMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2-DAY")
    BTU_TH_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC-FT2-DEG_F")
    PER_KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/PER-KiloV-A-HR")
    PINT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-HR")
    PicoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/PicoW-PER-M2")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    OZ_PER_IN2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN2")
    PlanckForce = URIRef("http://qudt.org/vocab/unit/PlanckForce")
    FT_HR_PER_IN3 = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-IN3")
    L_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-K")
    MilliJ = URIRef("http://qudt.org/vocab/unit/MilliJ")
    MilliA = URIRef("http://qudt.org/vocab/unit/MilliA")
    AU = URIRef("http://qudt.org/vocab/unit/AU")
    MilliGM_HR_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L-CentiM3")
    OZ_HR_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN6")
    IN_PER_2PiRAD = URIRef("http://qudt.org/vocab/unit/IN-PER-2PiRAD")
    LB_PER_YD3 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD3")
    E_h = URIRef("http://qudt.org/vocab/unit/E_h")
    IN_HG = URIRef("http://qudt.org/vocab/unit/IN_HG")
    NanoOHM = URIRef("http://qudt.org/vocab/unit/NanoOHM")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    L_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-K")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    MilliM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliM-PER-K")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    PicoC = URIRef("http://qudt.org/vocab/unit/PicoC")
    PicoPA = URIRef("http://qudt.org/vocab/unit/PicoPA")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    H_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/H_Stat-PER-CentiM")
    BTU_TH = URIRef("http://qudt.org/vocab/unit/BTU_TH")
    HZ_M = URIRef("http://qudt.org/vocab/unit/HZ-M")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    MegaJ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-K")
    T_Ab = URIRef("http://qudt.org/vocab/unit/T_Ab")
    KiloCi = URIRef("http://qudt.org/vocab/unit/KiloCi")
    GigaEV = URIRef("http://qudt.org/vocab/unit/GigaEV")
    ElementaryCharge = URIRef("http://qudt.org/vocab/unit/ElementaryCharge")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    PINT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-HR")
    BBL_UK_PET_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-MIN")
    THM_EEC = URIRef("http://qudt.org/vocab/unit/THM_EEC")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    AU = URIRef("http://qudt.org/vocab/unit/AU")
    HectoPA_PER_HR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-HR")
    LB_SEC_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK2")
    KiloGM_PER_M_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-HR")
    PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/PER-M2-SEC")
    PERCENT_HR_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-GAL_US")
    BTU_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC")
    SEC_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-FT2")
    PER_MO = URIRef("http://qudt.org/vocab/unit/PER-MO")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    CentiM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SEC")
    MilliM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    MicroC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M2")
    K_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PER-SEC")
    DeciTONNE = URIRef("http://qudt.org/vocab/unit/DeciTONNE")
    M3_PER_HR_K = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-K")
    KiloM3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM3-PER-SEC2")
    BREATH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BREATH-PER-MIN")
    KiloGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY")
    PER_H = URIRef("http://qudt.org/vocab/unit/PER-H")
    PicoMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M2-DAY")
    YR_Sidereal = URIRef("http://qudt.org/vocab/unit/YR_Sidereal")
    FT_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC-DEG_F")
    QT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_US-PER-HR")
    LB_DEG_R = URIRef("http://qudt.org/vocab/unit/LB-DEG_R")
    KiloGM_F_M_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-CentiM2")
    MilliV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliV-PER-MIN")
    KiloN_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M")
    KN = URIRef("http://qudt.org/vocab/unit/KN")
    WB_PER_MilliM = URIRef("http://qudt.org/vocab/unit/WB-PER-MilliM")
    KN_PER_SEC = URIRef("http://qudt.org/vocab/unit/KN-PER-SEC")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    ExaJ = URIRef("http://qudt.org/vocab/unit/ExaJ")
    BBL_US_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-SEC")
    PINT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-HR")
    KiloGM_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-M2")
    K_PER_M = URIRef("http://qudt.org/vocab/unit/K-PER-M")
    J_PER_SEC = URIRef("http://qudt.org/vocab/unit/J-PER-SEC")
    MicroMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM")
    NanoM_PER_MilliM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-MilliM-MegaPA")
    DeciM3 = URIRef("http://qudt.org/vocab/unit/DeciM3")
    MilliBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-KiloGM")
    M3_PER_HA = URIRef("http://qudt.org/vocab/unit/M3-PER-HA")
    FA = URIRef("http://qudt.org/vocab/unit/FA")
    GM_PER_MilliL_K = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL-K")
    KiloM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloM-PER-DAY")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    TON_Metric_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY")
    M3_PER_M3 = URIRef("http://qudt.org/vocab/unit/M3-PER-M3")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    MillionUSD_PER_YR = URIRef("http://qudt.org/vocab/unit/MillionUSD-PER-YR")
    IN4 = URIRef("http://qudt.org/vocab/unit/IN4")
    POND = URIRef("http://qudt.org/vocab/unit/POND")
    BTU_IT_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT3")
    NanoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-KiloGM")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    DeciN_M = URIRef("http://qudt.org/vocab/unit/DeciN-M")
    LB_MIN_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-IN3")
    PSI_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-L-PER-SEC")
    KiloGM_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-M2")
    KiloV_A = URIRef("http://qudt.org/vocab/unit/KiloV-A")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    KiloGM_F_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-MilliM2")
    CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3")
    MilliGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN")
    DEG_R_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-HR")
    KiloGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN")
    MicroM3_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-MilliL")
    MilliGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-HR")
    TON_SHORT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-DEG_F")
    M5 = URIRef("http://qudt.org/vocab/unit/M5")
    M2_PER_KiloW = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloW")
    CentiM3_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY-K")
    MicroOHM_M = URIRef("http://qudt.org/vocab/unit/MicroOHM-M")
    PetaJ = URIRef("http://qudt.org/vocab/unit/PetaJ")
    C = URIRef("http://qudt.org/vocab/unit/C")
    MilliBQ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-GM")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    GI_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_US-PER-MIN")
    HectoPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-M3-PER-SEC")
    LB_SEC_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN6")
    MilliM_HGA = URIRef("http://qudt.org/vocab/unit/MilliM_HGA")
    GI_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-MIN")
    KiloBQ = URIRef("http://qudt.org/vocab/unit/KiloBQ")
    H_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/H_Stat-PER-CentiM")
    PlanckFrequency_Ang = URIRef("http://qudt.org/vocab/unit/PlanckFrequency_Ang")
    MilliSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-SEC")
    NanoS_PER_M = URIRef("http://qudt.org/vocab/unit/NanoS-PER-M")
    PERCENT_PER_OHM = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-OHM")
    N_M_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-M")
    DECADE = URIRef("http://qudt.org/vocab/unit/DECADE")
    KiloGM_PER_L = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L")
    SAMPLE_PER_SEC = URIRef("http://qudt.org/vocab/unit/SAMPLE-PER-SEC")
    CentiGM = URIRef("http://qudt.org/vocab/unit/CentiGM")
    CentiMOL = URIRef("http://qudt.org/vocab/unit/CentiMOL")
    MicroBAR = URIRef("http://qudt.org/vocab/unit/MicroBAR")
    DeciM = URIRef("http://qudt.org/vocab/unit/DeciM")
    YD = URIRef("http://qudt.org/vocab/unit/YD")
    PicoFARAD = URIRef("http://qudt.org/vocab/unit/PicoFARAD")
    B = URIRef("http://qudt.org/vocab/unit/B")
    NUM_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/NUM-PER-MilliM3")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    GM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY-K")
    L_PER_L = URIRef("http://qudt.org/vocab/unit/L-PER-L")
    KiloGM_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-M2")
    MilliGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    QT_UK = URIRef("http://qudt.org/vocab/unit/QT_UK")
    Da = URIRef("http://qudt.org/vocab/unit/Da")
    PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/PER-MilliM3")
    MilliC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliC-PER-KiloGM")
    C_Stat = URIRef("http://qudt.org/vocab/unit/C_Stat")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    PERCENT_HR_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-L")
    A_PER_CentiM = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM")
    MegaN = URIRef("http://qudt.org/vocab/unit/MegaN")
    IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN3-PER-SEC")
    BARN_PER_SR = URIRef("http://qudt.org/vocab/unit/BARN-PER-SR")
    PERMEABILITY_EM_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_EM_REL")
    MilliPA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-BAR")
    PicoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/PicoKAT-PER-L")
    A_M2 = URIRef("http://qudt.org/vocab/unit/A-M2")
    TeraW = URIRef("http://qudt.org/vocab/unit/TeraW")
    C_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-CentiM2")
    J_PER_M = URIRef("http://qudt.org/vocab/unit/J-PER-M")
    MicroGAL_PER_M = URIRef("http://qudt.org/vocab/unit/MicroGAL-PER-M")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    CAL_TH_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-DEG_C")
    FA = URIRef("http://qudt.org/vocab/unit/FA")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    Flight = URIRef("http://qudt.org/vocab/unit/Flight")
    L_PER_DAY = URIRef("http://qudt.org/vocab/unit/L-PER-DAY")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    DEG_R_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-SEC")
    Denier = URIRef("http://qudt.org/vocab/unit/Denier")
    GM_F = URIRef("http://qudt.org/vocab/unit/GM_F")
    KiloGM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-BAR")
    LB_IN2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-IN3-LB_F-SEC")
    MilliGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DeciL")
    OHM_Stat = URIRef("http://qudt.org/vocab/unit/OHM_Stat")
    LB_SEC_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-IN3")
    K_PER_W = URIRef("http://qudt.org/vocab/unit/K-PER-W")
    N_M_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-M")
    NUM_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/NUM-PER-MilliM3")
    W_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M2")
    TONNE_PER_HA_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA-YR")
    MicroIN = URIRef("http://qudt.org/vocab/unit/MicroIN")
    RAD_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-MOL")
    BTU_TH_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_R")
    MicroM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM-PER-MilliL")
    YR_Sidereal = URIRef("http://qudt.org/vocab/unit/YR_Sidereal")
    M_PER_K = URIRef("http://qudt.org/vocab/unit/M-PER-K")
    MegaA_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaA-PER-M2")
    MegaV_PER_M = URIRef("http://qudt.org/vocab/unit/MegaV-PER-M")
    MicroTORR = URIRef("http://qudt.org/vocab/unit/MicroTORR")
    PicoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/PicoFARAD-PER-M")
    H_PER_OHM = URIRef("http://qudt.org/vocab/unit/H-PER-OHM")
    KiloGM_PER_M3_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-PA")
    ONE = URIRef("http://qudt.org/vocab/unit/ONE")
    W = URIRef("http://qudt.org/vocab/unit/W")
    BAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-M3-PER-SEC")
    MOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2")
    MilliGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-BAR")
    CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CentiM2-MIN")
    MegaLB_F = URIRef("http://qudt.org/vocab/unit/MegaLB_F")
    OZ_SEC_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-GAL_US")
    CD_PER_FT2 = URIRef("http://qudt.org/vocab/unit/CD-PER-FT2")
    LB_SEC_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US2")
    PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PER-SEC2")
    K_PER_K = URIRef("http://qudt.org/vocab/unit/K-PER-K")
    NanoW = URIRef("http://qudt.org/vocab/unit/NanoW")
    KiloCAL_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-HR")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    A2_SEC = URIRef("http://qudt.org/vocab/unit/A2-SEC")
    BBL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-DAY")
    MilliL_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-K")
    MOL_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-DeciM3")
    MicroIN = URIRef("http://qudt.org/vocab/unit/MicroIN")
    GigaV = URIRef("http://qudt.org/vocab/unit/GigaV")
    V = URIRef("http://qudt.org/vocab/unit/V")
    V_PER_MilliM = URIRef("http://qudt.org/vocab/unit/V-PER-MilliM")
    CFU = URIRef("http://qudt.org/vocab/unit/CFU")
    BBL_US_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-HR")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    MilliN_PER_M = URIRef("http://qudt.org/vocab/unit/MilliN-PER-M")
    GM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3-K")
    FT_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-PER-MIN")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    DEG_R_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-HR")
    KiloM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-HR")
    BTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR")
    LB_PER_FT3 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3")
    DEG_C_PER_M = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-M")
    KiloCAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-MIN")
    MegaPSI = URIRef("http://qudt.org/vocab/unit/MegaPSI")
    GM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN-K")
    PER_M_SR = URIRef("http://qudt.org/vocab/unit/PER-M-SR")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    PERCENT_PER_DAY = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DAY")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    MilliGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-K")
    PicoMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M2-DAY")
    TeraJ = URIRef("http://qudt.org/vocab/unit/TeraJ")
    M_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-V-SEC")
    DEGREE_BAUME_US_HEAVY = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_HEAVY")
    M_PER_K = URIRef("http://qudt.org/vocab/unit/M-PER-K")
    KiloGM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC2")
    GM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC")
    KiloC_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M3")
    TON = URIRef("http://qudt.org/vocab/unit/TON")
    Gs = URIRef("http://qudt.org/vocab/unit/Gs")
    PPTR_VOL = URIRef("http://qudt.org/vocab/unit/PPTR_VOL")
    RAD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC2")
    A = URIRef("http://qudt.org/vocab/unit/A")
    PA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M3-PER-SEC")
    OZ_PER_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD3")
    PER_L = URIRef("http://qudt.org/vocab/unit/PER-L")
    CAL_TH_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2-MIN")
    GM_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/GM-PER-DEG_C")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    GM_PER_HR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR")
    GAL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-SEC")
    DEG_F_SEC_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-SEC-PER-BTU_TH")
    PlanckCurrent = URIRef("http://qudt.org/vocab/unit/PlanckCurrent")
    MOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC")
    NUM_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/NUM-PER-MilliM3")
    OZ_PER_YD2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD2")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    KiloV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive-HR")
    DEGREE_BALLING = URIRef("http://qudt.org/vocab/unit/DEGREE_BALLING")
    KiloGM_PER_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-K")
    MegaV_PER_M = URIRef("http://qudt.org/vocab/unit/MegaV-PER-M")
    GI_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-SEC")
    E_h = URIRef("http://qudt.org/vocab/unit/E_h")
    DecaL = URIRef("http://qudt.org/vocab/unit/DecaL")
    ExaC = URIRef("http://qudt.org/vocab/unit/ExaC")
    PINT_US_DRY = URIRef("http://qudt.org/vocab/unit/PINT_US_DRY")
    MicroBQ = URIRef("http://qudt.org/vocab/unit/MicroBQ")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    OZ_FT = URIRef("http://qudt.org/vocab/unit/OZ-FT")
    KiloV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive-HR")
    E_h = URIRef("http://qudt.org/vocab/unit/E_h")
    LB_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-SEC")
    M2_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/M2-SEC-PER-RAD")
    MicroMOL_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM-SEC")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    FemtoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-KiloGM")
    OZ_PER_FT2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-FT2")
    MilliR = URIRef("http://qudt.org/vocab/unit/MilliR")
    BARN = URIRef("http://qudt.org/vocab/unit/BARN")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    GRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/GRAY-PER-HR")
    M_PER_FARAD = URIRef("http://qudt.org/vocab/unit/M-PER-FARAD")
    BTU_IT_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_R")
    M3_PER_C = URIRef("http://qudt.org/vocab/unit/M3-PER-C")
    LUX_SEC = URIRef("http://qudt.org/vocab/unit/LUX-SEC")
    LB_F_PER_LB = URIRef("http://qudt.org/vocab/unit/LB_F-PER-LB")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    PA_PER_K = URIRef("http://qudt.org/vocab/unit/PA-PER-K")
    PER_TONNE = URIRef("http://qudt.org/vocab/unit/PER-TONNE")
    N_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM2")
    IU_PER_MilliL = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliL")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    ENZ_PER_L = URIRef("http://qudt.org/vocab/unit/ENZ-PER-L")
    LB_HR_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-IN3")
    K_PER_PA = URIRef("http://qudt.org/vocab/unit/K-PER-PA")
    K_PER_W = URIRef("http://qudt.org/vocab/unit/K-PER-W")
    C_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM3")
    PER_LB = URIRef("http://qudt.org/vocab/unit/PER-LB")
    LB_PER_FT = URIRef("http://qudt.org/vocab/unit/LB-PER-FT")
    C_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM2")
    MilliM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-HR")
    C4_M4_PER_J3 = URIRef("http://qudt.org/vocab/unit/C4-M4-PER-J3")
    REV_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC2")
    PK_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-DAY")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    FARAD_Stat = URIRef("http://qudt.org/vocab/unit/FARAD_Stat")
    SH = URIRef("http://qudt.org/vocab/unit/SH")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    M2_PER_GM = URIRef("http://qudt.org/vocab/unit/M2-PER-GM")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    CAL_MEAN = URIRef("http://qudt.org/vocab/unit/CAL_MEAN")
    H_PER_M = URIRef("http://qudt.org/vocab/unit/H-PER-M")
    W_PER_SR = URIRef("http://qudt.org/vocab/unit/W-PER-SR")
    GM_PER_M2 = URIRef("http://qudt.org/vocab/unit/GM-PER-M2")
    MilliJ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-GM")
    YD3_PER_HR = URIRef("http://qudt.org/vocab/unit/YD3-PER-HR")
    LB_HR_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-GAL_UK")
    GI_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_US-PER-HR")
    PT = URIRef("http://qudt.org/vocab/unit/PT")
    BTU_TH_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT3")
    BTU_IT_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB")
    MicroGM_PER_L = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L")
    W_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M2")
    M3_PER_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-BAR")
    BARN_PER_EV = URIRef("http://qudt.org/vocab/unit/BARN-PER-EV")
    CentiM3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-K")
    KY = URIRef("http://qudt.org/vocab/unit/KY")
    U = URIRef("http://qudt.org/vocab/unit/U")
    Flight = URIRef("http://qudt.org/vocab/unit/Flight")
    BTU_IT_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-HR-DEG_F")
    IN3_PER_LB = URIRef("http://qudt.org/vocab/unit/IN3-PER-LB")
    MicroFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-M")
    MilliGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HA")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    Hundredweight_US = URIRef("http://qudt.org/vocab/unit/Hundredweight_US")
    YR_Common = URIRef("http://qudt.org/vocab/unit/YR_Common")
    MilliOHM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-M")
    PER_MilliGM = URIRef("http://qudt.org/vocab/unit/PER-MilliGM")
    CentiM3_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR-BAR")
    PERMEABILITY_EM_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_EM_REL")
    T_M = URIRef("http://qudt.org/vocab/unit/T-M")
    MilliGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-DAY")
    DeciS_PER_M = URIRef("http://qudt.org/vocab/unit/DeciS-PER-M")
    KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A-HR")
    PERCENT_PER_HR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-HR")
    GM_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/GM-PER-DEG_C")
    KiloCAL_TH = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH")
    PicoGM = URIRef("http://qudt.org/vocab/unit/PicoGM")
    MilliBQ = URIRef("http://qudt.org/vocab/unit/MilliBQ")
    LB_MIN_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK2")
    CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-GM")
    OZ_PER_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD3")
    NanoM_PER_CentiM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-MegaPA")
    MilliA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/MilliA-PER-MilliM")
    LB_HR_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-YD3")
    LB_MIN_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-IN3")
    MilliMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-GM")
    MilliL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-GM")
    ERG_SEC = URIRef("http://qudt.org/vocab/unit/ERG-SEC")
    PERCENT_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEG_C")
    PER_SEC_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR")
    PER_MilliSEC = URIRef("http://qudt.org/vocab/unit/PER-MilliSEC")
    EUR_PER_KiloW = URIRef("http://qudt.org/vocab/unit/EUR-PER-KiloW")
    TON_Metric_PER_SEC = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC")
    NanoM_PER_CentiM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-MegaPA")
    FT3_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT3-PER-SEC")
    CentiC = URIRef("http://qudt.org/vocab/unit/CentiC")
    N_M_PER_W0dot5 = URIRef("http://qudt.org/vocab/unit/N-M-PER-W0dot5")
    LB_PER_IN = URIRef("http://qudt.org/vocab/unit/LB-PER-IN")
    KiloN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-M2")
    BAN = URIRef("http://qudt.org/vocab/unit/BAN")
    DEG_F_HR_FT2_PER_BTU_TH_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH-IN")
    H_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/H_Stat-PER-CentiM")
    W = URIRef("http://qudt.org/vocab/unit/W")
    MicroM3_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-MilliL")
    MegaPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-M3-PER-SEC")
    PlanckCurrentDensity = URIRef("http://qudt.org/vocab/unit/PlanckCurrentDensity")
    NanoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-KiloGM")
    PERCENT_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-CentiM3")
    DEG_F_HR_FT2_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT")
    BTU_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-MIN")
    MilliM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM2-PER-SEC")
    FT_LB_F_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2-SEC")
    GI_US = URIRef("http://qudt.org/vocab/unit/GI_US")
    N_M_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-RAD")
    MOL_PER_L_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-L-K")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    TON_Metric_PER_HR_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR-K")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    BBL_UK_PET_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-MIN")
    A_HR_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-HR-PER-DEG_C")
    PA_PER_M = URIRef("http://qudt.org/vocab/unit/PA-PER-M")
    LB_PER_FT3 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3")
    MOL_LB_PER_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-LB")
    H_Stat = URIRef("http://qudt.org/vocab/unit/H_Stat")
    TeraW_HR = URIRef("http://qudt.org/vocab/unit/TeraW-HR")
    PER_M2 = URIRef("http://qudt.org/vocab/unit/PER-M2")
    FemtoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-L")
    MegaPA_M0dot5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0dot5")
    LB_MIN_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-GAL_UK")
    MilliBAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-L-PER-SEC")
    MOL_PER_TONNE = URIRef("http://qudt.org/vocab/unit/MOL-PER-TONNE")
    DEG_C_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-HR")
    BTU_TH_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-HR-DEG_F")
    PERCENT_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEG_C")
    MilliWB = URIRef("http://qudt.org/vocab/unit/MilliWB")
    PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PER-CentiM3")
    PERCENT_PER_BAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-BAR")
    LB_F_PER_IN2_DEG_F = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-DEG_F")
    MegaGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-HA")
    MilliM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DAY")
    MegaDOLLAR_US_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MegaDOLLAR_US-PER-FLIGHT")
    PER_SEC_M3 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M3")
    PA_PER_M = URIRef("http://qudt.org/vocab/unit/PA-PER-M")
    MicroG = URIRef("http://qudt.org/vocab/unit/MicroG")
    LB_PER_FT = URIRef("http://qudt.org/vocab/unit/LB-PER-FT")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    KAT_PER_MicroL = URIRef("http://qudt.org/vocab/unit/KAT-PER-MicroL")
    DEG_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG-PER-MIN")
    ExaC = URIRef("http://qudt.org/vocab/unit/ExaC")
    NanoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-KiloGM")
    KiloMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-SEC")
    LB_MIN_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-GAL_UK")
    KiloBAUD = URIRef("http://qudt.org/vocab/unit/KiloBAUD")
    PicoMOL_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M3-SEC")
    MilliV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MilliV-A_Reactive")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    MilliBAR = URIRef("http://qudt.org/vocab/unit/MilliBAR")
    ARE = URIRef("http://qudt.org/vocab/unit/ARE")
    GAL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-SEC")
    KiloOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-BAR")
    LB_PER_FT = URIRef("http://qudt.org/vocab/unit/LB-PER-FT")
    LB_PER_FT3 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    DEG_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC")
    GM_PER_K = URIRef("http://qudt.org/vocab/unit/GM-PER-K")
    GM_PER_DeciM3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3-K")
    BTU_IT_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT3")
    MegaV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive-HR")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    GAL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-MIN")
    MilliL_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-K")
    KiloGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-K")
    DeciB_C = URIRef("http://qudt.org/vocab/unit/DeciB_C")
    NanoSEC = URIRef("http://qudt.org/vocab/unit/NanoSEC")
    LM_PER_M2 = URIRef("http://qudt.org/vocab/unit/LM-PER-M2")
    MicroG = URIRef("http://qudt.org/vocab/unit/MicroG")
    MilliA_SEC = URIRef("http://qudt.org/vocab/unit/MilliA-SEC")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    BBL_UK_PET_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-MIN")
    CWT_LONG = URIRef("http://qudt.org/vocab/unit/CWT_LONG")
    PERCENT_SEC_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-YD3")
    OZ_F_IN = URIRef("http://qudt.org/vocab/unit/OZ_F-IN")
    C = URIRef("http://qudt.org/vocab/unit/C")
    MACH = URIRef("http://qudt.org/vocab/unit/MACH")
    QT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_US-PER-MIN")
    W_HR = URIRef("http://qudt.org/vocab/unit/W-HR")
    FT_H2O = URIRef("http://qudt.org/vocab/unit/FT_H2O")
    CentiM_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-BAR")
    DeciB_MilliW = URIRef("http://qudt.org/vocab/unit/DeciB-MilliW")
    YD3_PER_PSI = URIRef("http://qudt.org/vocab/unit/YD3-PER-PSI")
    DEG_F_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-HR")
    MicroGM_PER_L = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L")
    MilliC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliC-PER-KiloGM")
    MicroFARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-KiloM")
    W_PER_M = URIRef("http://qudt.org/vocab/unit/W-PER-M")
    PER_EV_M3 = URIRef("http://qudt.org/vocab/unit/PER-EV-M3")
    HZ_M = URIRef("http://qudt.org/vocab/unit/HZ-M")
    MilliGRAY = URIRef("http://qudt.org/vocab/unit/MilliGRAY")
    M2_PER_N = URIRef("http://qudt.org/vocab/unit/M2-PER-N")
    PA_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PA-M2-PER-KiloGM")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    FT2_PER_HR = URIRef("http://qudt.org/vocab/unit/FT2-PER-HR")
    BAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-L-PER-SEC")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    GigaFLOPS = URIRef("http://qudt.org/vocab/unit/GigaFLOPS")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    GI_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_US-PER-DAY")
    GAL_US = URIRef("http://qudt.org/vocab/unit/GAL_US")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    DEGREE_PLATO = URIRef("http://qudt.org/vocab/unit/DEGREE_PLATO")
    PHON = URIRef("http://qudt.org/vocab/unit/PHON")
    TONNE_PER_SEC = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC")
    KiloA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M")
    QT_US = URIRef("http://qudt.org/vocab/unit/QT_US")
    MicroS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MicroS-PER-CentiM")
    MilliDARCY = URIRef("http://qudt.org/vocab/unit/MilliDARCY")
    TON_Metric_PER_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-BAR")
    HA = URIRef("http://qudt.org/vocab/unit/HA")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    GigaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-HR")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    KiloV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive-HR")
    K_PER_MIN = URIRef("http://qudt.org/vocab/unit/K-PER-MIN")
    KiloJ_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MIN")
    IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC")
    MilliDEG_C = URIRef("http://qudt.org/vocab/unit/MilliDEG_C")
    KiloGM_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MOL")
    W = URIRef("http://qudt.org/vocab/unit/W")
    N_M_PER_M_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-M-RAD")
    FT_LA = URIRef("http://qudt.org/vocab/unit/FT-LA")
    SLUG_PER_FT3 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT3")
    QT_UK = URIRef("http://qudt.org/vocab/unit/QT_UK")
    MilliC = URIRef("http://qudt.org/vocab/unit/MilliC")
    BTU_MEAN = URIRef("http://qudt.org/vocab/unit/BTU_MEAN")
    KAT_PER_M3 = URIRef("http://qudt.org/vocab/unit/KAT-PER-M3")
    TON_US_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_US-PER-HR")
    A_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM2")
    DYN_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-CentiM")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    NanoOHM = URIRef("http://qudt.org/vocab/unit/NanoOHM")
    BBL_US_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-HR")
    SLUG_PER_HR = URIRef("http://qudt.org/vocab/unit/SLUG-PER-HR")
    KiloCAL_TH = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH")
    M2_HZ4 = URIRef("http://qudt.org/vocab/unit/M2-HZ4")
    PERCENT_PER_V = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-V")
    A_PER_J = URIRef("http://qudt.org/vocab/unit/A-PER-J")
    MegaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-SEC")
    PicoGM = URIRef("http://qudt.org/vocab/unit/PicoGM")
    PERCENT_FT2_PER_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-FT2-PER-LB_F-SEC")
    CentiN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/CentiN-M-PER-M2")
    PER_V_A_SEC = URIRef("http://qudt.org/vocab/unit/PER-V-A-SEC")
    PER_MegaK = URIRef("http://qudt.org/vocab/unit/PER-MegaK")
    KiloCAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-SEC")
    BQ_PER_L = URIRef("http://qudt.org/vocab/unit/BQ-PER-L")
    MilliMOL_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3-DAY")
    NanoH_PER_M = URIRef("http://qudt.org/vocab/unit/NanoH-PER-M")
    DeciM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-SEC")
    LB_F = URIRef("http://qudt.org/vocab/unit/LB_F")
    BBL = URIRef("http://qudt.org/vocab/unit/BBL")
    SON = URIRef("http://qudt.org/vocab/unit/SON")
    MicroSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-MIN")
    POISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/POISE-PER-BAR")
    AT_PER_M = URIRef("http://qudt.org/vocab/unit/AT-PER-M")
    V_M = URIRef("http://qudt.org/vocab/unit/V-M")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    IN_HG_32DEG_F = URIRef("http://qudt.org/vocab/unit/IN_HG_32DEG_F")
    OZ_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN3")
    CentiST = URIRef("http://qudt.org/vocab/unit/CentiST")
    M_PER_FARAD = URIRef("http://qudt.org/vocab/unit/M-PER-FARAD")
    PINT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-DAY")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    FARAD_Stat = URIRef("http://qudt.org/vocab/unit/FARAD_Stat")
    TON_SHORT = URIRef("http://qudt.org/vocab/unit/TON_SHORT")
    BBL_US_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-HR")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    MilliJ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-GM")
    OZ_PER_YD2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD2")
    N_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM2")
    TON_SHORT = URIRef("http://qudt.org/vocab/unit/TON_SHORT")
    KiloGM_PER_HA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HA")
    BTU_TH_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-FT2-HR-DEG_F")
    GigaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-HR")
    OZ_HR_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-YD3")
    TONNE_PER_DAY = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY")
    MegaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-SEC")
    N_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-PER-M3")
    MegaHZ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-K")
    DEG_F_HR_FT2_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH")
    PER_M_SR = URIRef("http://qudt.org/vocab/unit/PER-M-SR")
    LB_PER_FT = URIRef("http://qudt.org/vocab/unit/LB-PER-FT")
    GM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloGM")
    MI_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI-PER-MIN")
    MicroMOL_PER_GM_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM-HR")
    MicroC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M3")
    PetaA = URIRef("http://qudt.org/vocab/unit/PetaA")
    NanoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MilliL")
    PERCENT_MIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-GAL_US")
    PPTR = URIRef("http://qudt.org/vocab/unit/PPTR")
    ARCSEC = URIRef("http://qudt.org/vocab/unit/ARCSEC")
    RAD_PER_MIN = URIRef("http://qudt.org/vocab/unit/RAD-PER-MIN")
    OZ_MIN_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN6")
    CentiM2_PER_ERG = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-ERG")
    unit = URIRef("http://qudt.org/vocab/unit")
    M3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC2")
    DYN_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM")
    LM_PER_M2 = URIRef("http://qudt.org/vocab/unit/LM-PER-M2")
    LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC")
    MilliGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-KiloGM")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    PetaJ = URIRef("http://qudt.org/vocab/unit/PetaJ")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    BTU_IT_IN_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-SEC-FT2-DEG_F")
    KiloGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY")
    L_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-K")
    GM_SEC_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M6")
    DeciM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MIN")
    IN_H2O = URIRef("http://qudt.org/vocab/unit/IN_H2O")
    NUM_PER_M = URIRef("http://qudt.org/vocab/unit/NUM-PER-M")
    PER_J = URIRef("http://qudt.org/vocab/unit/PER-J")
    BU_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-SEC")
    BTU_IT = URIRef("http://qudt.org/vocab/unit/BTU_IT")
    PERCENT_FT_HR_PER_LB = URIRef("http://qudt.org/vocab/unit/PERCENT-FT-HR-PER-LB")
    A_PER_PA = URIRef("http://qudt.org/vocab/unit/A-PER-PA")
    DEG_C_PER_M = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-M")
    GibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M3")
    KiloP = URIRef("http://qudt.org/vocab/unit/KiloP")
    BAUD = URIRef("http://qudt.org/vocab/unit/BAUD")
    NanoW = URIRef("http://qudt.org/vocab/unit/NanoW")
    MilliN_PER_M = URIRef("http://qudt.org/vocab/unit/MilliN-PER-M")
    BTU_IT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_F")
    PlanckMomentum = URIRef("http://qudt.org/vocab/unit/PlanckMomentum")
    DeciL_PER_GM = URIRef("http://qudt.org/vocab/unit/DeciL-PER-GM")
    PERCENT_PER_DAY = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DAY")
    MicroOHM = URIRef("http://qudt.org/vocab/unit/MicroOHM")
    PERCENT_HR_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-IN3")
    BU_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-HR")
    PicoW = URIRef("http://qudt.org/vocab/unit/PicoW")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    KiloGM_PER_M2_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC2")
    TON_Metric_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN-K")
    MilliL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M3")
    CASES_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-1000I-YR")
    SLUG_PER_FT = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT")
    DEG_F_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-K")
    MegaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M2")
    PlanckCurrent = URIRef("http://qudt.org/vocab/unit/PlanckCurrent")
    SLUG = URIRef("http://qudt.org/vocab/unit/SLUG")
    NanoMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L-HR")
    KiloGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY")
    REV_PER_HR = URIRef("http://qudt.org/vocab/unit/REV-PER-HR")
    BIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BIT-PER-SEC")
    MilliPA = URIRef("http://qudt.org/vocab/unit/MilliPA")
    L_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-BAR")
    FR = URIRef("http://qudt.org/vocab/unit/FR")
    MilliL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-GM")
    MegaC = URIRef("http://qudt.org/vocab/unit/MegaC")
    SLUG_PER_MIN = URIRef("http://qudt.org/vocab/unit/SLUG-PER-MIN")
    NAT = URIRef("http://qudt.org/vocab/unit/NAT")
    BTU_IT_PER_SEC_FT_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT-DEG_R")
    BTU_IT_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT3")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    PERCENT_MIN_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-YD3")
    BTU_IT_PER_SEC_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_R")
    KiloC_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M3")
    MicroSV = URIRef("http://qudt.org/vocab/unit/MicroSV")
    GM_PER_L_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-L-MilliPA-SEC")
    N_M_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-RAD")
    QT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-DAY")
    L_PER_K = URIRef("http://qudt.org/vocab/unit/L-PER-K")
    MilliK_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliK-PER-BAR")
    TORR_PER_M = URIRef("http://qudt.org/vocab/unit/TORR-PER-M")
    YD3_PER_DAY = URIRef("http://qudt.org/vocab/unit/YD3-PER-DAY")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    ATM_T_PER_M = URIRef("http://qudt.org/vocab/unit/ATM_T-PER-M")
    CentiN_M = URIRef("http://qudt.org/vocab/unit/CentiN-M")
    MilliC = URIRef("http://qudt.org/vocab/unit/MilliC")
    ExbiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M2")
    PER_HR = URIRef("http://qudt.org/vocab/unit/PER-HR")
    GM_SEC_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M6")
    MicroW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroW-PER-M2")
    PER_PA_SEC = URIRef("http://qudt.org/vocab/unit/PER-PA-SEC")
    CAL_TH = URIRef("http://qudt.org/vocab/unit/CAL_TH")
    A = URIRef("http://qudt.org/vocab/unit/A")
    K2 = URIRef("http://qudt.org/vocab/unit/K2")
    V_PER_IN = URIRef("http://qudt.org/vocab/unit/V-PER-IN")
    V_PER_SEC = URIRef("http://qudt.org/vocab/unit/V-PER-SEC")
    BTU_TH_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-SEC-DEG_F")
    CAL_TH_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM-K")
    MilliL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-KiloGM")
    DEG_C_GROWING_CEREAL_DAY = URIRef("http://qudt.org/vocab/unit/DEG_C_GROWING_CEREAL-DAY")
    KiloV_A_PER_K = URIRef("http://qudt.org/vocab/unit/KiloV-A-PER-K")
    MicroFARAD = URIRef("http://qudt.org/vocab/unit/MicroFARAD")
    C_Stat = URIRef("http://qudt.org/vocab/unit/C_Stat")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    KiloHZ = URIRef("http://qudt.org/vocab/unit/KiloHZ")
    EV_PER_M = URIRef("http://qudt.org/vocab/unit/EV-PER-M")
    KiloA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M")
    A_Stat = URIRef("http://qudt.org/vocab/unit/A_Stat")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    PERCENT_PER_K = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-K")
    MilliGM_PER_L_CentiPOISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-CentiPOISE")
    CentiM_H20_4DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_H20_4DEG_C")
    KiloM = URIRef("http://qudt.org/vocab/unit/KiloM")
    KiloMOL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-HR")
    IN_PER_YR = URIRef("http://qudt.org/vocab/unit/IN-PER-YR")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    MilliA_PER_K = URIRef("http://qudt.org/vocab/unit/MilliA-PER-K")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    KN_PER_SEC = URIRef("http://qudt.org/vocab/unit/KN-PER-SEC")
    MOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3")
    MilliA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/MilliA-PER-MilliM")
    NanoFARAD = URIRef("http://qudt.org/vocab/unit/NanoFARAD")
    M3_PER_M3 = URIRef("http://qudt.org/vocab/unit/M3-PER-M3")
    LB_HR_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-GAL_US")
    MicroC = URIRef("http://qudt.org/vocab/unit/MicroC")
    CentiM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-M3")
    MilliOHM_M = URIRef("http://qudt.org/vocab/unit/MilliOHM-M")
    DeciM3_PER_HR = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-HR")
    MIL = URIRef("http://qudt.org/vocab/unit/MIL")
    TON_Metric_PER_HA = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HA")
    MilliGM_PER_L_POISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-POISE")
    C_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM")
    DEG_F_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-HR")
    PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/PER-M2-SEC")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    N_M_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-RAD")
    OZ_PER_GAL = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL")
    PERCENT_HR_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-IN3")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    W_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-PER-KiloGM")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    DEG_R_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-MIN")
    MilliGM_MIN_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L-CentiM3")
    GigaOHM = URIRef("http://qudt.org/vocab/unit/GigaOHM")
    PetaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/PetaJ-PER-SEC")
    KiloC_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M3")
    LB_MIN_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-FT3")
    MicroG = URIRef("http://qudt.org/vocab/unit/MicroG")
    J_M2 = URIRef("http://qudt.org/vocab/unit/J-M2")
    BBL_UK_PET_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-DAY")
    PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/PER-MilliM3")
    MilliGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-SEC")
    KiloGM_M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M2-PER-SEC")
    TeraW_HR = URIRef("http://qudt.org/vocab/unit/TeraW-HR")
    MilliL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-KiloGM")
    BAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-M3-PER-SEC")
    MebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M3")
    FT3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT3-PER-DEG_F")
    MicroMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L-HR")
    PERCENT_PER_BAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-BAR")
    MilliGM_MIN_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M6")
    MicroM_PER_N = URIRef("http://qudt.org/vocab/unit/MicroM-PER-N")
    MegaN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaN-M-PER-M2")
    LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT2")
    OERSTED_CentiM = URIRef("http://qudt.org/vocab/unit/OERSTED-CentiM")
    ExbiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M3")
    BTU_IT = URIRef("http://qudt.org/vocab/unit/BTU_IT")
    MilliGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-KiloGM")
    LB_MIN_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-GAL_UK")
    NanoN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/NanoN-M-PER-M2")
    PA_PER_M = URIRef("http://qudt.org/vocab/unit/PA-PER-M")
    MicroS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MicroS-PER-CentiM")
    KiloGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-K")
    H_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/H_Stat-PER-CentiM")
    PER_SR = URIRef("http://qudt.org/vocab/unit/PER-SR")
    CentiPOISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-BAR")
    C = URIRef("http://qudt.org/vocab/unit/C")
    GigaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-HR")
    MilliMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-MOL")
    MilliGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-BAR")
    DEG_F_SEC_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-SEC-PER-BTU_IT")
    GI_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-MIN")
    LM_PER_M2 = URIRef("http://qudt.org/vocab/unit/LM-PER-M2")
    NUM_PER_M = URIRef("http://qudt.org/vocab/unit/NUM-PER-M")
    GM_PER_M = URIRef("http://qudt.org/vocab/unit/GM-PER-M")
    EV_PER_K = URIRef("http://qudt.org/vocab/unit/EV-PER-K")
    GM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2")
    J_PER_M = URIRef("http://qudt.org/vocab/unit/J-PER-M")
    KiloMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-SEC")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    DEG_C_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-MIN")
    ExaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/ExaBIT-PER-SEC")
    KIP_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KIP_F-PER-IN2")
    FRACTION = URIRef("http://qudt.org/vocab/unit/FRACTION")
    W_PER_M = URIRef("http://qudt.org/vocab/unit/W-PER-M")
    PK_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-SEC")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    EV_SEC = URIRef("http://qudt.org/vocab/unit/EV-SEC")
    MilliGAL_PER_MO = URIRef("http://qudt.org/vocab/unit/MilliGAL-PER-MO")
    KiloJ_PER_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-K")
    DecaPA = URIRef("http://qudt.org/vocab/unit/DecaPA")
    LB_SEC_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-GAL_US")
    PER_MILLE_PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PER-PSI")
    NUM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/NUM-PER-KiloM2")
    PPM_PER_K = URIRef("http://qudt.org/vocab/unit/PPM-PER-K")
    LB_SEC_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-IN3")
    PicoMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M3")
    RHE = URIRef("http://qudt.org/vocab/unit/RHE")
    M3_PER_MIN = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN")
    J_M_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-M-PER-MOL")
    KiloGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN")
    Quarter_UK = URIRef("http://qudt.org/vocab/unit/Quarter_UK")
    V_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V-PER-CentiM")
    MilliC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliC-PER-KiloGM")
    MilliPA = URIRef("http://qudt.org/vocab/unit/MilliPA")
    NAT = URIRef("http://qudt.org/vocab/unit/NAT")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC")
    NanoBQ_PER_L = URIRef("http://qudt.org/vocab/unit/NanoBQ-PER-L")
    MI_N = URIRef("http://qudt.org/vocab/unit/MI_N")
    DEG_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG-PER-HR")
    NanoM = URIRef("http://qudt.org/vocab/unit/NanoM")
    PetaJ = URIRef("http://qudt.org/vocab/unit/PetaJ")
    GM_PER_HR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR")
    W_PER_M2_PA = URIRef("http://qudt.org/vocab/unit/W-PER-M2-PA")
    FUR_Long = URIRef("http://qudt.org/vocab/unit/FUR_Long")
    MilliGAL = URIRef("http://qudt.org/vocab/unit/MilliGAL")
    HectoGM = URIRef("http://qudt.org/vocab/unit/HectoGM")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    BBL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-MIN")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    A_PER_CentiM = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM")
    TON_UK_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-YD3")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    DEG_R = URIRef("http://qudt.org/vocab/unit/DEG_R")
    KiloCAL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-SEC")
    KiloCAL_Mean = URIRef("http://qudt.org/vocab/unit/KiloCAL_Mean")
    IN_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN-PER-MIN")
    MicroSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-SEC")
    TON_Metric_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY-BAR")
    MilliL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M2-DAY")
    M2_PER_N = URIRef("http://qudt.org/vocab/unit/M2-PER-N")
    LB_F = URIRef("http://qudt.org/vocab/unit/LB_F")
    W = URIRef("http://qudt.org/vocab/unit/W")
    UnitPole = URIRef("http://qudt.org/vocab/unit/UnitPole")
    SEC_PER_M = URIRef("http://qudt.org/vocab/unit/SEC-PER-M")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    V_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Ab-PER-CentiM")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    CentiM_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-HR")
    GM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloGM")
    PER_MO = URIRef("http://qudt.org/vocab/unit/PER-MO")
    T = URIRef("http://qudt.org/vocab/unit/T")
    OHM_PER_MI = URIRef("http://qudt.org/vocab/unit/OHM-PER-MI")
    FT2 = URIRef("http://qudt.org/vocab/unit/FT2")
    NanoMOL_PER_MicroMOL_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL-DAY")
    TeraJ = URIRef("http://qudt.org/vocab/unit/TeraJ")
    N_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M")
    GigaFLOPS = URIRef("http://qudt.org/vocab/unit/GigaFLOPS")
    V = URIRef("http://qudt.org/vocab/unit/V")
    OZ_VOL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-SEC")
    OZ_VOL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-SEC")
    PERCENT_FT_SEC_PER_LB = URIRef("http://qudt.org/vocab/unit/PERCENT-FT-SEC-PER-LB")
    ST = URIRef("http://qudt.org/vocab/unit/ST")
    MHO_Stat = URIRef("http://qudt.org/vocab/unit/MHO_Stat")
    V_PER_MilliM = URIRef("http://qudt.org/vocab/unit/V-PER-MilliM")
    QT_US = URIRef("http://qudt.org/vocab/unit/QT_US")
    KiloW_HR = URIRef("http://qudt.org/vocab/unit/KiloW-HR")
    OERSTED = URIRef("http://qudt.org/vocab/unit/OERSTED")
    LB_PER_YD3 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD3")
    A_MIN = URIRef("http://qudt.org/vocab/unit/A-MIN")
    K_M = URIRef("http://qudt.org/vocab/unit/K-M")
    MOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM")
    MegaPSI = URIRef("http://qudt.org/vocab/unit/MegaPSI")
    ERG_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM-SEC")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    KiloOHM = URIRef("http://qudt.org/vocab/unit/KiloOHM")
    MegaC = URIRef("http://qudt.org/vocab/unit/MegaC")
    TON_Metric_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR-BAR")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    PER_DAY = URIRef("http://qudt.org/vocab/unit/PER-DAY")
    MegaBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaBTU_IT-PER-HR")
    KiloGM_PER_L_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-K")
    L = URIRef("http://qudt.org/vocab/unit/L")
    MilliM3_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-GM")
    GigaW_HR = URIRef("http://qudt.org/vocab/unit/GigaW-HR")
    NanoGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    LY = URIRef("http://qudt.org/vocab/unit/LY")
    GRAIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-M3")
    PER_MilliGM = URIRef("http://qudt.org/vocab/unit/PER-MilliGM")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    CH = URIRef("http://qudt.org/vocab/unit/CH")
    KiloJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM")
    A_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Stat-PER-CentiM2")
    CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CentiM2-MIN")
    AU = URIRef("http://qudt.org/vocab/unit/AU")
    M3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM")
    TON_Metric_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR")
    PK_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-SEC")
    KiloM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-HR")
    PicoMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L-HR")
    BTU_IT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_F")
    DEG_C_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-MIN")
    MicroG_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroG-PER-CentiM2")
    PicoA = URIRef("http://qudt.org/vocab/unit/PicoA")
    MilliGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-BAR")
    PPTM = URIRef("http://qudt.org/vocab/unit/PPTM")
    GibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M")
    BTU_TH_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_R")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    NUM_PER_HA = URIRef("http://qudt.org/vocab/unit/NUM-PER-HA")
    EV_SEC = URIRef("http://qudt.org/vocab/unit/EV-SEC")
    FT = URIRef("http://qudt.org/vocab/unit/FT")
    CentiM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-M3")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    LB_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-DEG_F")
    CUP_US = URIRef("http://qudt.org/vocab/unit/CUP_US")
    K_PER_K = URIRef("http://qudt.org/vocab/unit/K-PER-K")
    PER_IN2 = URIRef("http://qudt.org/vocab/unit/PER-IN2")
    CAL_IT_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-DEG_C")
    KiloPA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-K")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    MI_N_PER_HR = URIRef("http://qudt.org/vocab/unit/MI_N-PER-HR")
    IN2 = URIRef("http://qudt.org/vocab/unit/IN2")
    BTU_IT_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-IN2-SEC")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    PINT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-DAY")
    PINT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-DAY")
    C3_M_PER_J2 = URIRef("http://qudt.org/vocab/unit/C3-M-PER-J2")
    MOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM")
    PINT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-MIN")
    C_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM")
    MilliW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2")
    LB_MIN_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT6")
    KiloOHM = URIRef("http://qudt.org/vocab/unit/KiloOHM")
    LB_MIN_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-FT3")
    MicroV = URIRef("http://qudt.org/vocab/unit/MicroV")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    GM_SEC_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L2")
    MicroGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-DeciL")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    MilliGRAY = URIRef("http://qudt.org/vocab/unit/MilliGRAY")
    BTU_IT_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-HR-DEG_F")
    THM_US = URIRef("http://qudt.org/vocab/unit/THM_US")
    PERCENT_MIN_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-YD3")
    LB_IN2_PER_FT3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-FT3-LB_F-SEC")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    DEG_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC")
    MilliA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/MilliA-PER-MilliM")
    DecaM3 = URIRef("http://qudt.org/vocab/unit/DecaM3")
    M4 = URIRef("http://qudt.org/vocab/unit/M4")
    KiloGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-BAR")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    PetaJ = URIRef("http://qudt.org/vocab/unit/PetaJ")
    FemtoJ = URIRef("http://qudt.org/vocab/unit/FemtoJ")
    SLUG_PER_FT3 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT3")
    MilliA_IN2_PER_LB_F = URIRef("http://qudt.org/vocab/unit/MilliA-IN2-PER-LB_F")
    MilliM3_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-GM")
    TSP = URIRef("http://qudt.org/vocab/unit/TSP")
    KiloPA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-M")
    PER_M2 = URIRef("http://qudt.org/vocab/unit/PER-M2")
    NanoGM_PER_L = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-L")
    TON_Metric_PER_HA = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HA")
    IN_PER_PSI = URIRef("http://qudt.org/vocab/unit/IN-PER-PSI")
    PERCENT_PER_PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-PERCENT")
    KiloGM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MilliM")
    KiloGM_F_M_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-CentiM2")
    MOHM = URIRef("http://qudt.org/vocab/unit/MOHM")
    PK_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-MIN")
    MIN_Sidereal = URIRef("http://qudt.org/vocab/unit/MIN_Sidereal")
    CentiM_H2O_4DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_H2O_4DEG_C")
    MilliL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-GM")
    MilliL_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-K")
    N_M2_PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/N-M2-PER-KiloGM2")
    LB_F_PER_IN2_DEG_F = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-DEG_F")
    DEG_R = URIRef("http://qudt.org/vocab/unit/DEG_R")
    QT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_US-PER-MIN")
    KiloA = URIRef("http://qudt.org/vocab/unit/KiloA")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    AttoJ = URIRef("http://qudt.org/vocab/unit/AttoJ")
    MIN = URIRef("http://qudt.org/vocab/unit/MIN")
    MilliGRAY = URIRef("http://qudt.org/vocab/unit/MilliGRAY")
    NanoGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M2-PA-SEC")
    A_HR = URIRef("http://qudt.org/vocab/unit/A-HR")
    TebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M3")
    FT_HR_PER_IN3 = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-IN3")
    THM_EEC = URIRef("http://qudt.org/vocab/unit/THM_EEC")
    FT_H2O = URIRef("http://qudt.org/vocab/unit/FT_H2O")
    Z = URIRef("http://qudt.org/vocab/unit/Z")
    J_PER_KiloGM_K_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-M3")
    CentiM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY")
    TONNE_PER_MO = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MO")
    C = URIRef("http://qudt.org/vocab/unit/C")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    KiloCAL_IT_PER_HR_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-HR-M-DEG_C")
    IN_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN-PER-MIN")
    A_HR_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/A-HR-PER-KiloGM")
    KiloCAL_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL")
    DEATHS_PER_KiloINDIV_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-KiloINDIV-YR")
    LB_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-SEC")
    KiloGM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC2")
    MicroT = URIRef("http://qudt.org/vocab/unit/MicroT")
    N_M2 = URIRef("http://qudt.org/vocab/unit/N-M2")
    PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PER-KiloGM")
    CentiMOL_PER_L = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-L")
    KiloGM_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-M2")
    PicoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/PicoW-PER-M2")
    QT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_US-PER-DAY")
    MilliS = URIRef("http://qudt.org/vocab/unit/MilliS")
    BAN = URIRef("http://qudt.org/vocab/unit/BAN")
    ERG_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM3")
    MOL_LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-MIN")
    KiloA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloA-PER-K")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    MilliJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-M2")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    V_PER_SEC = URIRef("http://qudt.org/vocab/unit/V-PER-SEC")
    RAD_PER_HR = URIRef("http://qudt.org/vocab/unit/RAD-PER-HR")
    MilliPA = URIRef("http://qudt.org/vocab/unit/MilliPA")
    M3_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-BAR")
    CAL_TH_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM2-K")
    FT_LB_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-MIN")
    MegaGM = URIRef("http://qudt.org/vocab/unit/MegaGM")
    KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloMOL")
    LB_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-DEG_F")
    N_M_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-M-PER-KiloGM")
    PER_FT3 = URIRef("http://qudt.org/vocab/unit/PER-FT3")
    M_PER_PA = URIRef("http://qudt.org/vocab/unit/M-PER-PA")
    KiloHZ = URIRef("http://qudt.org/vocab/unit/KiloHZ")
    MegaA_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaA-PER-M2")
    T_M = URIRef("http://qudt.org/vocab/unit/T-M")
    GM_SEC_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L2")
    A_M2_PER_J_SEC = URIRef("http://qudt.org/vocab/unit/A-M2-PER-J-SEC")
    MicroSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-MIN")
    N_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM2")
    M3_PER_PA = URIRef("http://qudt.org/vocab/unit/M3-PER-PA")
    FA = URIRef("http://qudt.org/vocab/unit/FA")
    FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-DEG_F")
    A_PER_J = URIRef("http://qudt.org/vocab/unit/A-PER-J")
    BTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2")
    KiloGM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3")
    N_M_PER_MIN_Angle = URIRef("http://qudt.org/vocab/unit/N-M-PER-MIN_Angle")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    MOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL-PER-MIN")
    KiloGM_M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M2-PER-SEC")
    KiloGM_PER_M_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-HR")
    MicroC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M3")
    TON_LONG = URIRef("http://qudt.org/vocab/unit/TON_LONG")
    BTU_IT_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-SEC-DEG_F")
    L_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-BAR")
    U = URIRef("http://qudt.org/vocab/unit/U")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    PicoSEC = URIRef("http://qudt.org/vocab/unit/PicoSEC")
    GM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3")
    PER_T_M = URIRef("http://qudt.org/vocab/unit/PER-T-M")
    PERCENT_PER_DektoKiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DektoKiloCount")
    PER_KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/PER-KiloV-A-HR")
    MilliSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-SEC")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    TONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-YR")
    BTU_IT_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT-PER-FT2-HR-DEG_F")
    B = URIRef("http://qudt.org/vocab/unit/B")
    NanoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-KiloGM")
    PERCENT_MIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-M3")
    N_PER_CentiM = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM")
    RT = URIRef("http://qudt.org/vocab/unit/RT")
    HA = URIRef("http://qudt.org/vocab/unit/HA")
    W_M2 = URIRef("http://qudt.org/vocab/unit/W-M2")
    MOL_PER_M2_SEC_M = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-M")
    PER_SR = URIRef("http://qudt.org/vocab/unit/PER-SR")
    KibiBYTE = URIRef("http://qudt.org/vocab/unit/KibiBYTE")
    MegaEV = URIRef("http://qudt.org/vocab/unit/MegaEV")
    C_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM2")
    TONNE_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3-BAR")
    OZ_M = URIRef("http://qudt.org/vocab/unit/OZ_M")
    NanoM2 = URIRef("http://qudt.org/vocab/unit/NanoM2")
    LY = URIRef("http://qudt.org/vocab/unit/LY")
    BTU_IT_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-HR-DEG_F")
    IN_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC2")
    MilliM_PER_YR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-YR")
    MilliGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-K")
    DeciM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-SEC")
    MilliGM_SEC_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L-CentiM3")
    A_M2 = URIRef("http://qudt.org/vocab/unit/A-M2")
    ST_PER_K = URIRef("http://qudt.org/vocab/unit/ST-PER-K")
    KiloBQ = URIRef("http://qudt.org/vocab/unit/KiloBQ")
    AWG = URIRef("http://qudt.org/vocab/unit/AWG")
    NanoGM_PER_L = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-L")
    BTU_IT_IN_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-SEC-FT2-DEG_F")
    KiloBQ = URIRef("http://qudt.org/vocab/unit/KiloBQ")
    KiloGM_PER_M_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-DAY")
    LB_SEC_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-FT3")
    MegaJ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-K")
    PA_SEC_PER_K = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-K")
    PlanckArea = URIRef("http://qudt.org/vocab/unit/PlanckArea")
    J_M_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-M-PER-MOL")
    OZ_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_UK")
    GAUSS = URIRef("http://qudt.org/vocab/unit/GAUSS")
    YR_TROPICAL = URIRef("http://qudt.org/vocab/unit/YR_TROPICAL")
    MilliL_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY")
    TON_SHORT = URIRef("http://qudt.org/vocab/unit/TON_SHORT")
    H_Stat = URIRef("http://qudt.org/vocab/unit/H_Stat")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    MilliGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HA")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    MOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-SEC")
    MilliGM_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-HR")
    NanoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MilliL")
    TONNE_PER_HA = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    CentiM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY")
    GM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-M2-DAY")
    EUR_PER_W_HR = URIRef("http://qudt.org/vocab/unit/EUR-PER-W-HR")
    CentiM_PER_KiloYR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-KiloYR")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    M2_PER_HA = URIRef("http://qudt.org/vocab/unit/M2-PER-HA")
    EV_PER_M = URIRef("http://qudt.org/vocab/unit/EV-PER-M")
    PER_SEC_M3 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M3")
    MegaEV = URIRef("http://qudt.org/vocab/unit/MegaEV")
    KiloPA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-K")
    MegaEV_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-CentiM")
    DeciB_ISO = URIRef("http://qudt.org/vocab/unit/DeciB_ISO")
    IN3 = URIRef("http://qudt.org/vocab/unit/IN3")
    LB_SEC_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT6")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    MicroATM = URIRef("http://qudt.org/vocab/unit/MicroATM")
    MilliGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MilliL")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    W = URIRef("http://qudt.org/vocab/unit/W")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    MilliGM_MIN_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M6")
    FT_SEC_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-GAL_US")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    DeciM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-SEC")
    W_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM-SR")
    M3_PER_M3 = URIRef("http://qudt.org/vocab/unit/M3-PER-M3")
    MicroSV = URIRef("http://qudt.org/vocab/unit/MicroSV")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    CORD = URIRef("http://qudt.org/vocab/unit/CORD")
    CentiM3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL-SEC")
    PA_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-PER-BAR")
    PER_MilliSEC = URIRef("http://qudt.org/vocab/unit/PER-MilliSEC")
    YD3_PER_PSI = URIRef("http://qudt.org/vocab/unit/YD3-PER-PSI")
    TON_SHORT = URIRef("http://qudt.org/vocab/unit/TON_SHORT")
    MilliA = URIRef("http://qudt.org/vocab/unit/MilliA")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    GM_HR_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M3-CentiM3")
    Gamma = URIRef("http://qudt.org/vocab/unit/Gamma")
    J = URIRef("http://qudt.org/vocab/unit/J")
    N_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-RAD")
    K_PER_MIN = URIRef("http://qudt.org/vocab/unit/K-PER-MIN")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PER-SEC2")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    FT_US = URIRef("http://qudt.org/vocab/unit/FT_US")
    KiloGM_PER_MegaBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MegaBTU_IT")
    MegaJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-KiloGM")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    V_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/V-SEC-PER-M")
    KiloGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC")
    MegaPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-BAR")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    LB_PER_FT_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-MIN")
    H_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/H-PER-KiloOHM")
    PER_CentiM = URIRef("http://qudt.org/vocab/unit/PER-CentiM")
    V_PER_MilliM = URIRef("http://qudt.org/vocab/unit/V-PER-MilliM")
    MilliA_HR_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliA-HR-PER-GM")
    MegaEV_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-CentiM")
    KiloGM_PER_M_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC2")
    OZ_F_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ_F-PER-IN3")
    IN = URIRef("http://qudt.org/vocab/unit/IN")
    ERG_PER_CentiM = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM")
    PicoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/PicoKAT-PER-L")
    KiloL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloL-PER-HR")
    J_PER_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-DAY")
    KiloM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloM-PER-DAY")
    M_K_PER_W = URIRef("http://qudt.org/vocab/unit/M-K-PER-W")
    ERG_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM")
    NanoS_PER_M = URIRef("http://qudt.org/vocab/unit/NanoS-PER-M")
    S_PER_CentiM = URIRef("http://qudt.org/vocab/unit/S-PER-CentiM")
    M2_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-V-SEC")
    MilliL_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-K")
    PHOT = URIRef("http://qudt.org/vocab/unit/PHOT")
    GAL_IMP = URIRef("http://qudt.org/vocab/unit/GAL_IMP")
    RT = URIRef("http://qudt.org/vocab/unit/RT")
    KiloEV_PER_MicroM = URIRef("http://qudt.org/vocab/unit/KiloEV-PER-MicroM")
    MicroMHO = URIRef("http://qudt.org/vocab/unit/MicroMHO")
    CUP = URIRef("http://qudt.org/vocab/unit/CUP")
    PERCENT_SEC_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-L")
    POISE = URIRef("http://qudt.org/vocab/unit/POISE")
    SEC_PER_M3_RAD = URIRef("http://qudt.org/vocab/unit/SEC-PER-M3-RAD")
    KiloGM_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-BAR")
    BTU_IT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_F")
    KiloGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC")
    C = URIRef("http://qudt.org/vocab/unit/C")
    LB_SEC_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-GAL_US")
    MilliL_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-BAR")
    MilliH = URIRef("http://qudt.org/vocab/unit/MilliH")
    GM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL")
    KiloC_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M3")
    PK_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-DAY")
    BU_UK = URIRef("http://qudt.org/vocab/unit/BU_UK")
    MegaGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-HA")
    MilliM4 = URIRef("http://qudt.org/vocab/unit/MilliM4")
    L_PER_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-BAR")
    TONNE_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY-K")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    MI_US = URIRef("http://qudt.org/vocab/unit/MI_US")
    MilliMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-L")
    DeciL = URIRef("http://qudt.org/vocab/unit/DeciL")
    FT3_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT3-PER-DAY")
    NanoGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-MIN")
    PER_PlanckMass2 = URIRef("http://qudt.org/vocab/unit/PER-PlanckMass2")
    T = URIRef("http://qudt.org/vocab/unit/T")
    HP = URIRef("http://qudt.org/vocab/unit/HP")
    PER_MilliGM = URIRef("http://qudt.org/vocab/unit/PER-MilliGM")
    BTU_IT_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-HR-DEG_F")
    GM_SEC_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M3-CentiM3")
    BARN_PER_SR = URIRef("http://qudt.org/vocab/unit/BARN-PER-SR")
    N = URIRef("http://qudt.org/vocab/unit/N")
    HectoPA = URIRef("http://qudt.org/vocab/unit/HectoPA")
    FT_HG = URIRef("http://qudt.org/vocab/unit/FT_HG")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    OZ_F = URIRef("http://qudt.org/vocab/unit/OZ_F")
    FT_H2O = URIRef("http://qudt.org/vocab/unit/FT_H2O")
    T_M = URIRef("http://qudt.org/vocab/unit/T-M")
    M2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2")
    GM_PER_MIN = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN")
    GAL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-HR")
    PH = URIRef("http://qudt.org/vocab/unit/PH")
    M3_PER_DAY = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY")
    C_Stat_PER_MOL = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-MOL")
    KN_PER_SEC = URIRef("http://qudt.org/vocab/unit/KN-PER-SEC")
    CentiM2_PER_SR_ERG = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SR-ERG")
    PK_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-MIN")
    PetaHZ = URIRef("http://qudt.org/vocab/unit/PetaHZ")
    DEG_C_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-SEC")
    PER_SEC_M3 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M3")
    MOL_PER_L = URIRef("http://qudt.org/vocab/unit/MOL-PER-L")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    KiloEV_PER_MicroM = URIRef("http://qudt.org/vocab/unit/KiloEV-PER-MicroM")
    MilliA_PER_LB_F_IN2 = URIRef("http://qudt.org/vocab/unit/MilliA-PER-LB_F-IN2")
    OZ_VOL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-DAY")
    TeraC = URIRef("http://qudt.org/vocab/unit/TeraC")
    MilliGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-CentiM2")
    FT_HR_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-GAL_UK")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    CentiM3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL-SEC")
    M = URIRef("http://qudt.org/vocab/unit/M")
    PetaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/PetaJ-PER-SEC")
    MilliHZ = URIRef("http://qudt.org/vocab/unit/MilliHZ")
    CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-GM")
    GRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/GRAY-PER-MIN")
    DeciB_A = URIRef("http://qudt.org/vocab/unit/DeciB_A")
    GM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC")
    LB_F = URIRef("http://qudt.org/vocab/unit/LB_F")
    CentiM3_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR")
    BTU_IT_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT-PER-FT2-HR-DEG_F")
    CORD = URIRef("http://qudt.org/vocab/unit/CORD")
    NanoGM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MicroL")
    MegaPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-L-PER-SEC")
    C_PER_MOL = URIRef("http://qudt.org/vocab/unit/C-PER-MOL")
    DEG_F_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC2")
    MI_US = URIRef("http://qudt.org/vocab/unit/MI_US")
    LB_SEC_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-GAL_UK")
    V_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Ab-PER-CentiM")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    BTU_IT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR-DEG_F")
    MilliMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-KiloGM")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    PER_HR = URIRef("http://qudt.org/vocab/unit/PER-HR")
    LY = URIRef("http://qudt.org/vocab/unit/LY")
    A_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM2")
    GAL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-SEC")
    KiloJ_PER_KiloV = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloV")
    LB_HR_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-FT3")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    S = URIRef("http://qudt.org/vocab/unit/S")
    HR_PER_FT2 = URIRef("http://qudt.org/vocab/unit/HR-PER-FT2")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    PERCENT_PER_MO = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MO")
    LB_FT2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-IN3-LB_F-SEC")
    TON_Metric_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC-BAR")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    EV_PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/EV-PER-ANGSTROM")
    NanoGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M2-PA-SEC")
    L_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-K")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    KiloGM_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-M2")
    MilliGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-HR")
    ERG_PER_G = URIRef("http://qudt.org/vocab/unit/ERG-PER-G")
    TON_SHORT_PER_HR_PSI = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR-PSI")
    KiloW_HR = URIRef("http://qudt.org/vocab/unit/KiloW-HR")
    V_Stat = URIRef("http://qudt.org/vocab/unit/V_Stat")
    PicoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/PicoW-PER-M2")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    HectoPA_PER_K = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-K")
    PER_M_SEC = URIRef("http://qudt.org/vocab/unit/PER-M-SEC")
    LB_F_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-FT2")
    GM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC-K")
    M4 = URIRef("http://qudt.org/vocab/unit/M4")
    CentiM = URIRef("http://qudt.org/vocab/unit/CentiM")
    BU_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-MIN")
    BBL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-MIN")
    PA_PER_K = URIRef("http://qudt.org/vocab/unit/PA-PER-K")
    TON_FG = URIRef("http://qudt.org/vocab/unit/TON_FG")
    PER_RAD = URIRef("http://qudt.org/vocab/unit/PER-RAD")
    FT_LB_F_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-HR")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    M2_PER_SR = URIRef("http://qudt.org/vocab/unit/M2-PER-SR")
    PA_PER_K = URIRef("http://qudt.org/vocab/unit/PA-PER-K")
    DeciB_MilliW_PER_MegaHZ = URIRef("http://qudt.org/vocab/unit/DeciB-MilliW-PER-MegaHZ")
    GM = URIRef("http://qudt.org/vocab/unit/GM")
    KiloGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    LB_DEG_R = URIRef("http://qudt.org/vocab/unit/LB-DEG_R")
    DeciM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-KiloGM")
    TON_LONG = URIRef("http://qudt.org/vocab/unit/TON_LONG")
    KiloN_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M2")
    GI_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_US-PER-HR")
    KY = URIRef("http://qudt.org/vocab/unit/KY")
    TeraV_A = URIRef("http://qudt.org/vocab/unit/TeraV-A")
    NanoMOL_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L-DAY")
    KiloM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-HR")
    MilliL_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-K")
    MilliL_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-K")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    PDL_PER_IN = URIRef("http://qudt.org/vocab/unit/PDL-PER-IN")
    M3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC2")
    PlanckVolume = URIRef("http://qudt.org/vocab/unit/PlanckVolume")
    GM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3")
    MOL_PER_GM_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-GM-HR")
    MilliA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/MilliA-PER-MilliM")
    YD2 = URIRef("http://qudt.org/vocab/unit/YD2")
    G = URIRef("http://qudt.org/vocab/unit/G")
    AC = URIRef("http://qudt.org/vocab/unit/AC")
    MegaS_PER_M = URIRef("http://qudt.org/vocab/unit/MegaS-PER-M")
    KiloMOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-MIN")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    KiloGM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-BAR")
    LB_SEC_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-GAL_UK")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    PERCENT_HR_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-YD3")
    MicroM_PER_N = URIRef("http://qudt.org/vocab/unit/MicroM-PER-N")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    FT_H2O_39dot2DEG_F = URIRef("http://qudt.org/vocab/unit/FT_H2O_39dot2DEG_F")
    LB_PER_IN3 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3")
    MilliGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-HR")
    NP = URIRef("http://qudt.org/vocab/unit/NP")
    MilliSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-SEC")
    OZ_VOL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-MIN")
    V_A_Reactive = URIRef("http://qudt.org/vocab/unit/V-A_Reactive")
    MicroV = URIRef("http://qudt.org/vocab/unit/MicroV")
    MicroMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-SEC")
    CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM-SEC-DEG_C")
    MegaC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M2")
    KiloW_PER_M_K = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M-K")
    MicroS = URIRef("http://qudt.org/vocab/unit/MicroS")
    KiloS_PER_M = URIRef("http://qudt.org/vocab/unit/KiloS-PER-M")
    KiloW_HR = URIRef("http://qudt.org/vocab/unit/KiloW-HR")
    IN_HG_60DEG_F = URIRef("http://qudt.org/vocab/unit/IN_HG_60DEG_F")
    MilliM_PER_YR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-YR")
    DEG_C_PER_BAR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-BAR")
    GM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-L-BAR")
    PER_KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/PER-KiloV-A-HR")
    MegaOHM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-KiloM")
    KiloBQ = URIRef("http://qudt.org/vocab/unit/KiloBQ")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    MicroPA = URIRef("http://qudt.org/vocab/unit/MicroPA")
    MOL_PER_M2_SEC_M = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-M")
    TON_Metric_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR")
    TON_Metric_PER_HR_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR-K")
    PA_PER_HR = URIRef("http://qudt.org/vocab/unit/PA-PER-HR")
    FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-DEG_F")
    HZ_PER_V = URIRef("http://qudt.org/vocab/unit/HZ-PER-V")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    GRAIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL_US")
    HectoPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-L-PER-SEC")
    BTU_IT_PER_FT2_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR")
    MicroOHM_M = URIRef("http://qudt.org/vocab/unit/MicroOHM-M")
    TON_Metric_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY-K")
    MO_Synodic = URIRef("http://qudt.org/vocab/unit/MO_Synodic")
    TONNE_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY-BAR")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    BAN = URIRef("http://qudt.org/vocab/unit/BAN")
    DeciB_Z = URIRef("http://qudt.org/vocab/unit/DeciB_Z")
    LB_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN2")
    KiloGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM2")
    LB = URIRef("http://qudt.org/vocab/unit/LB")
    TONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-YR")
    MilliGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MilliL")
    HectoPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-M3-PER-SEC")
    BU_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-HR")
    MilliGM_SEC_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L-M3")
    KiloCAL_IT_PER_HR_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-HR-M-DEG_C")
    OZ_VOL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-MIN")
    OHM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/OHM-PER-KiloM")
    DeciB_PER_KiloM = URIRef("http://qudt.org/vocab/unit/DeciB-PER-KiloM")
    M2_PER_N = URIRef("http://qudt.org/vocab/unit/M2-PER-N")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    ExaW = URIRef("http://qudt.org/vocab/unit/ExaW")
    KiloBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBIT-PER-SEC")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    GigaPA_CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/GigaPA-CentiM3-PER-GM")
    BTU_TH_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT3")
    MilliPA_SEC_PER_K = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-K")
    BTU_IT_PER_LB_F_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_F")
    DEG_R_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-SEC")
    DEG_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-MIN")
    M6 = URIRef("http://qudt.org/vocab/unit/M6")
    N_M_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-RAD")
    MilliM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-KiloGM")
    M3_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-K")
    MilliW = URIRef("http://qudt.org/vocab/unit/MilliW")
    MIL_Circ = URIRef("http://qudt.org/vocab/unit/MIL_Circ")
    MegaGM = URIRef("http://qudt.org/vocab/unit/MegaGM")
    KiloGM_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-YR")
    W = URIRef("http://qudt.org/vocab/unit/W")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    MegaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M3")
    MegaGM = URIRef("http://qudt.org/vocab/unit/MegaGM")
    MicroM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroM-PER-SEC")
    LB_SEC_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-GAL_UK")
    KiloGM_PER_M3_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-PA")
    MI_PER_HR = URIRef("http://qudt.org/vocab/unit/MI-PER-HR")
    CentiGM = URIRef("http://qudt.org/vocab/unit/CentiGM")
    PER_MegaK = URIRef("http://qudt.org/vocab/unit/PER-MegaK")
    NanoSV_PER_HR = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-HR")
    DecaL = URIRef("http://qudt.org/vocab/unit/DecaL")
    PK_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-HR")
    HA = URIRef("http://qudt.org/vocab/unit/HA")
    CAL_TH_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-DEG_C")
    GM_PER_K = URIRef("http://qudt.org/vocab/unit/GM-PER-K")
    QT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-MIN")
    V_PER_MicroSEC = URIRef("http://qudt.org/vocab/unit/V-PER-MicroSEC")
    PH = URIRef("http://qudt.org/vocab/unit/PH")
    OZ_PER_FT2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-FT2")
    TSP = URIRef("http://qudt.org/vocab/unit/TSP")
    CAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-MIN")
    MilliV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/MilliV-A_Reactive-PER-K")
    OZ_VOL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-SEC")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    PPTR = URIRef("http://qudt.org/vocab/unit/PPTR")
    M3_PER_KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM-SEC2")
    MegaN = URIRef("http://qudt.org/vocab/unit/MegaN")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    L_PER_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-SEC")
    MegaW_HR = URIRef("http://qudt.org/vocab/unit/MegaW-HR")
    OZ_VOL_US = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US")
    V2_PER_K2 = URIRef("http://qudt.org/vocab/unit/V2-PER-K2")
    BBL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-MIN")
    MilliT = URIRef("http://qudt.org/vocab/unit/MilliT")
    HectoL = URIRef("http://qudt.org/vocab/unit/HectoL")
    LB_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN2")
    AttoJ_SEC = URIRef("http://qudt.org/vocab/unit/AttoJ-SEC")
    DEG_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG-PER-HR")
    MOHM = URIRef("http://qudt.org/vocab/unit/MOHM")
    IN3 = URIRef("http://qudt.org/vocab/unit/IN3")
    GM_PER_CentiM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM-BAR")
    K_PER_MIN = URIRef("http://qudt.org/vocab/unit/K-PER-MIN")
    MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/MOL-DEG_C")
    OZ_PER_YD2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD2")
    KiloW_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloW-HR-PER-M2")
    A_PER_RAD = URIRef("http://qudt.org/vocab/unit/A-PER-RAD")
    FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC")
    V_PER_L_MIN = URIRef("http://qudt.org/vocab/unit/V-PER-L-MIN")
    N_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-RAD")
    KiloC_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M3")
    W_PER_M2_M_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M-SR")
    GRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/GRAY-PER-SEC")
    A_SEC = URIRef("http://qudt.org/vocab/unit/A-SEC")
    MegaN_M = URIRef("http://qudt.org/vocab/unit/MegaN-M")
    KiloJ_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MOL")
    M2_HZ4 = URIRef("http://qudt.org/vocab/unit/M2-HZ4")
    DEG_R_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-MIN")
    TON_Metric = URIRef("http://qudt.org/vocab/unit/TON_Metric")
    T = URIRef("http://qudt.org/vocab/unit/T")
    OHM_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-PER-M")
    OHM_CentiM = URIRef("http://qudt.org/vocab/unit/OHM-CentiM")
    POISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/POISE-PER-BAR")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    DEG_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-MIN")
    MicroGM_PER_IN2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-IN2")
    OHM_Stat = URIRef("http://qudt.org/vocab/unit/OHM_Stat")
    SLUG_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT-SEC")
    CD_IN = URIRef("http://qudt.org/vocab/unit/CD_IN")
    REV_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC2")
    YD_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD-PER-DEG_F")
    BTU_IT_PER_LB_F_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_F")
    PERCENT_HR_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-GAL_US")
    MilliDARCY = URIRef("http://qudt.org/vocab/unit/MilliDARCY")
    MilliN = URIRef("http://qudt.org/vocab/unit/MilliN")
    PicoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/PicoFARAD-PER-M")
    DeciTONNE = URIRef("http://qudt.org/vocab/unit/DeciTONNE")
    MilliL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-MIN")
    KiloBAUD = URIRef("http://qudt.org/vocab/unit/KiloBAUD")
    MOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3")
    GM_PER_GM = URIRef("http://qudt.org/vocab/unit/GM-PER-GM")
    K_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/K-PER-SEC2")
    DEG_R = URIRef("http://qudt.org/vocab/unit/DEG_R")
    Quarter_UK = URIRef("http://qudt.org/vocab/unit/Quarter_UK")
    N_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-RAD")
    LB_PER_FT_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-HR")
    KiloMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3")
    MHO_Stat = URIRef("http://qudt.org/vocab/unit/MHO_Stat")
    NanoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/NanoFARAD-PER-M")
    LB_HR_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT6")
    MicroM_PER_N = URIRef("http://qudt.org/vocab/unit/MicroM-PER-N")
    KiloGM_PER_J = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-J")
    M2_PER_SEC2_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2-K")
    NanoV_A = URIRef("http://qudt.org/vocab/unit/NanoV-A")
    MilliGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN")
    H = URIRef("http://qudt.org/vocab/unit/H")
    GM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM_F-PER-CentiM2")
    MicroN_M = URIRef("http://qudt.org/vocab/unit/MicroN-M")
    ANGSTROM3 = URIRef("http://qudt.org/vocab/unit/ANGSTROM3")
    T = URIRef("http://qudt.org/vocab/unit/T")
    NP = URIRef("http://qudt.org/vocab/unit/NP")
    DEGREE_BAUME_US_HEAVY = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_HEAVY")
    KiloGM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM2-PER-SEC2")
    M2_PER_SR = URIRef("http://qudt.org/vocab/unit/M2-PER-SR")
    MicroM2 = URIRef("http://qudt.org/vocab/unit/MicroM2")
    BU_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-SEC")
    CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    CFU = URIRef("http://qudt.org/vocab/unit/CFU")
    PERCENT_MIN_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-GAL_UK")
    TON_US = URIRef("http://qudt.org/vocab/unit/TON_US")
    NanoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/NanoKAT-PER-L")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    ST = URIRef("http://qudt.org/vocab/unit/ST")
    KiloGM_PER_M_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC2")
    MilliMOL = URIRef("http://qudt.org/vocab/unit/MilliMOL")
    PPM = URIRef("http://qudt.org/vocab/unit/PPM")
    PicoM = URIRef("http://qudt.org/vocab/unit/PicoM")
    KiloS_PER_M = URIRef("http://qudt.org/vocab/unit/KiloS-PER-M")
    NanoSEC = URIRef("http://qudt.org/vocab/unit/NanoSEC")
    K_PER_W = URIRef("http://qudt.org/vocab/unit/K-PER-W")
    LB_SEC_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US2")
    REM = URIRef("http://qudt.org/vocab/unit/REM")
    BTU_IT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC")
    MilliDEG_C = URIRef("http://qudt.org/vocab/unit/MilliDEG_C")
    MilliGM_HR_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L-M3")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    BTU_IT_PER_LB_F_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_F")
    MilliGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-HR")
    FT_HR_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-GAL_US")
    OZ_MIN_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-FT3")
    FARAD_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/FARAD_Ab-PER-CentiM")
    C_Stat = URIRef("http://qudt.org/vocab/unit/C_Stat")
    MilliPA = URIRef("http://qudt.org/vocab/unit/MilliPA")
    DYN_SEC_PER_CentiM5 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM5")
    FemtoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-KiloGM")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    LB_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC-PSI")
    KiloM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM2-PER-SEC2")
    BAR = URIRef("http://qudt.org/vocab/unit/BAR")
    YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD3-PER-SEC")
    MicroM2 = URIRef("http://qudt.org/vocab/unit/MicroM2")
    OZ_VOL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-HR")
    IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC")
    MegaC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M2")
    CWT_SHORT = URIRef("http://qudt.org/vocab/unit/CWT_SHORT")
    Da = URIRef("http://qudt.org/vocab/unit/Da")
    L_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-BAR")
    J = URIRef("http://qudt.org/vocab/unit/J")
    BTU_IT = URIRef("http://qudt.org/vocab/unit/BTU_IT")
    R = URIRef("http://qudt.org/vocab/unit/R")
    MilliGM_PER_L_CentiPOISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-CentiPOISE")
    BBL_UK_PET_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-DAY")
    FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-SEC")
    KiloCAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-GM-K")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    H_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/H_Stat-PER-CentiM")
    C_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM2")
    DecaM = URIRef("http://qudt.org/vocab/unit/DecaM")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    TeraBQ = URIRef("http://qudt.org/vocab/unit/TeraBQ")
    A_PER_J = URIRef("http://qudt.org/vocab/unit/A-PER-J")
    DEGREE_BAUME_US_HEAVY = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_HEAVY")
    J_PER_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-DAY")
    MegaPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-L-PER-SEC")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    NanoJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoJ-PER-SEC")
    LB_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC-DEG_F")
    KiloGM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR")
    M2_PER_HZ = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ")
    M2_PER_HA = URIRef("http://qudt.org/vocab/unit/M2-PER-HA")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    OZ_MIN_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-GAL_US")
    GAUSS = URIRef("http://qudt.org/vocab/unit/GAUSS")
    BTU_TH_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-FT2-HR-DEG_F")
    J_PER_GM = URIRef("http://qudt.org/vocab/unit/J-PER-GM")
    CAL_15_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_15_DEG_C")
    CentiM_PER_KiloYR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-KiloYR")
    BU_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-SEC")
    MegaN_M = URIRef("http://qudt.org/vocab/unit/MegaN-M")
    BARN_PER_SR_EV = URIRef("http://qudt.org/vocab/unit/BARN-PER-SR-EV")
    FM = URIRef("http://qudt.org/vocab/unit/FM")
    NanoGM = URIRef("http://qudt.org/vocab/unit/NanoGM")
    BBL_UK_PET = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET")
    MicroT = URIRef("http://qudt.org/vocab/unit/MicroT")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    DAY_Sidereal = URIRef("http://qudt.org/vocab/unit/DAY_Sidereal")
    MilliGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-HR")
    LB_HR_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-YD3")
    QUAD = URIRef("http://qudt.org/vocab/unit/QUAD")
    M4 = URIRef("http://qudt.org/vocab/unit/M4")
    MilLength = URIRef("http://qudt.org/vocab/unit/MilLength")
    MicroGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-HR")
    ERG_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM-SEC")
    DEG_C_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-MIN")
    HZ_PER_V = URIRef("http://qudt.org/vocab/unit/HZ-PER-V")
    A_M2_PER_J_SEC = URIRef("http://qudt.org/vocab/unit/A-M2-PER-J-SEC")
    DARCY = URIRef("http://qudt.org/vocab/unit/DARCY")
    DecaC = URIRef("http://qudt.org/vocab/unit/DecaC")
    J = URIRef("http://qudt.org/vocab/unit/J")
    MegaS = URIRef("http://qudt.org/vocab/unit/MegaS")
    PERCENT_PER_M = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-M")
    MegaPA_PER_K = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-K")
    NanoGM_PER_L = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-L")
    LB_PER_M3 = URIRef("http://qudt.org/vocab/unit/LB-PER-M3")
    BTU_TH_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-HR-DEG_F")
    K_PER_HR = URIRef("http://qudt.org/vocab/unit/K-PER-HR")
    LB_IN2_PER_FT3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-FT3-LB_F-SEC")
    PER_KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/PER-KiloV-A-HR")
    KiloW_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloW-HR-PER-M2")
    RAYL = URIRef("http://qudt.org/vocab/unit/RAYL")
    MilliGM_SEC_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M3-L")
    NUM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/NUM-PER-KiloM2")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    CAL_TH_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM-SEC-DEG_C")
    GI_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_US-PER-MIN")
    PER_GigaEV2 = URIRef("http://qudt.org/vocab/unit/PER-GigaEV2")
    PER_MOL = URIRef("http://qudt.org/vocab/unit/PER-MOL")
    LB_MIN_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-GAL_US")
    DeciGM = URIRef("http://qudt.org/vocab/unit/DeciGM")
    PINT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-DAY")
    MOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL-PER-MIN")
    MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC")
    MegaOHM = URIRef("http://qudt.org/vocab/unit/MegaOHM")
    TONNE_PER_HR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR")
    MilliR = URIRef("http://qudt.org/vocab/unit/MilliR")
    M2_PER_N = URIRef("http://qudt.org/vocab/unit/M2-PER-N")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    M3_PER_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-BAR")
    GM_HR_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L-M3")
    KiloGM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MilliM")
    PER_BAR = URIRef("http://qudt.org/vocab/unit/PER-BAR")
    GM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL")
    KiloJ_PER_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-K")
    DEG_F_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-K")
    CAL_IT_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM-K")
    CentiM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC")
    CentiM3_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-CentiM3")
    CentiM3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL-SEC")
    W = URIRef("http://qudt.org/vocab/unit/W")
    V_A_HR = URIRef("http://qudt.org/vocab/unit/V-A-HR")
    FT_PDL = URIRef("http://qudt.org/vocab/unit/FT-PDL")
    QT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-MIN")
    MegaEV = URIRef("http://qudt.org/vocab/unit/MegaEV")
    MilliV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliV-PER-MIN")
    K = URIRef("http://qudt.org/vocab/unit/K")
    POISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/POISE-PER-BAR")
    OZ_FT_HR_PER_IN3_LB = URIRef("http://qudt.org/vocab/unit/OZ-FT-HR-PER-IN3-LB")
    NanoFARAD = URIRef("http://qudt.org/vocab/unit/NanoFARAD")
    OZ_HR_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-GAL_UK")
    SHANNON_PER_SEC = URIRef("http://qudt.org/vocab/unit/SHANNON-PER-SEC")
    KiloGM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC2")
    PK_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-HR")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    C_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Ab-PER-CentiM2")
    MIL = URIRef("http://qudt.org/vocab/unit/MIL")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    MilliL_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-BAR")
    DPI = URIRef("http://qudt.org/vocab/unit/DPI")
    MicroATM = URIRef("http://qudt.org/vocab/unit/MicroATM")
    NanoM_PER_MilliM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-MilliM-MegaPA")
    KiloBTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH-PER-HR")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    BBL_UK_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-HR")
    GI_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-HR")
    NanoS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/NanoS-PER-CentiM")
    C_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-CentiM2")
    L_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-K")
    NAT_PER_SEC = URIRef("http://qudt.org/vocab/unit/NAT-PER-SEC")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    GigaOHM_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-M")
    TON = URIRef("http://qudt.org/vocab/unit/TON")
    MilliR_man = URIRef("http://qudt.org/vocab/unit/MilliR_man")
    TONNE_PER_M3_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3-K")
    LB_FT2_PER_GAL_UK_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-GAL_UK-LB_F-SEC")
    NanoH_PER_M = URIRef("http://qudt.org/vocab/unit/NanoH-PER-M")
    MX = URIRef("http://qudt.org/vocab/unit/MX")
    H_Stat = URIRef("http://qudt.org/vocab/unit/H_Stat")
    FemtoV = URIRef("http://qudt.org/vocab/unit/FemtoV")
    H_PER_OHM = URIRef("http://qudt.org/vocab/unit/H-PER-OHM")
    KiloGM_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-MilliM2")
    KiloN_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M")
    QT_US_DRY = URIRef("http://qudt.org/vocab/unit/QT_US_DRY")
    PPT = URIRef("http://qudt.org/vocab/unit/PPT")
    CentiM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-M3")
    MOL_PER_M3_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-PA")
    LB_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC-DEG_F")
    GA_Charriere = URIRef("http://qudt.org/vocab/unit/GA_Charriere")
    DEG_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG-PER-MIN")
    FT_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-PER-MIN")
    MegaEV = URIRef("http://qudt.org/vocab/unit/MegaEV")
    RT = URIRef("http://qudt.org/vocab/unit/RT")
    MicroGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-SEC")
    DeciB_C = URIRef("http://qudt.org/vocab/unit/DeciB_C")
    KiloOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-BAR")
    L_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-BAR")
    CWT_SHORT = URIRef("http://qudt.org/vocab/unit/CWT_SHORT")
    GM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY-K")
    DeciM3_PER_HR = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-HR")
    LB_PER_MIN_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN-PSI")
    GigaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBYTE-PER-SEC")
    KiloGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN")
    LB_HR_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-FT3")
    LB_HR_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT6")
    DEG_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG-PER-MIN")
    PicoW_PER_CentiM2_L = URIRef("http://qudt.org/vocab/unit/PicoW-PER-CentiM2-L")
    KiloCAL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-MIN")
    M2_HZ4 = URIRef("http://qudt.org/vocab/unit/M2-HZ4")
    PERM_US = URIRef("http://qudt.org/vocab/unit/PERM_US")
    MilliOHM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-M")
    MIN_Angle = URIRef("http://qudt.org/vocab/unit/MIN_Angle")
    MilliA_HR_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliA-HR-PER-GM")
    MilliA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliA-PER-BAR")
    KiloGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-K")
    MicroA_PER_K = URIRef("http://qudt.org/vocab/unit/MicroA-PER-K")
    OZ_MIN_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-YD3")
    LB_MIN_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-FT3")
    V_Stat = URIRef("http://qudt.org/vocab/unit/V_Stat")
    KiloMOL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-HR")
    M3_PER_HR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR")
    LB_HR_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-GAL_UK")
    ZOLL = URIRef("http://qudt.org/vocab/unit/ZOLL")
    FT3_PER_HR = URIRef("http://qudt.org/vocab/unit/FT3-PER-HR")
    KiloN_M = URIRef("http://qudt.org/vocab/unit/KiloN-M")
    MI_US = URIRef("http://qudt.org/vocab/unit/MI_US")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    MicroGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3")
    C_Stat_PER_MOL = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-MOL")
    PHOT = URIRef("http://qudt.org/vocab/unit/PHOT")
    M2_PER_SEC2_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2-K")
    BTU_IT_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_R")
    MegaEV = URIRef("http://qudt.org/vocab/unit/MegaEV")
    PlanckPower = URIRef("http://qudt.org/vocab/unit/PlanckPower")
    LM_HR = URIRef("http://qudt.org/vocab/unit/LM-HR")
    MilliH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-KiloOHM")
    B_PER_M = URIRef("http://qudt.org/vocab/unit/B-PER-M")
    MicroGM_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L-HR")
    HectoPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-BAR")
    MilliGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-K")
    FT_HR_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-GAL_US")
    FT_LB_F_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-HR")
    CentiM3_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN-K")
    TONNE_PER_DAY = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    MicroGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-BAR")
    MilliM_HG = URIRef("http://qudt.org/vocab/unit/MilliM_HG")
    PHOT = URIRef("http://qudt.org/vocab/unit/PHOT")
    MegaGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-M3")
    MegaHZ_M = URIRef("http://qudt.org/vocab/unit/MegaHZ-M")
    MilliL_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY")
    PERCENT_HR_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-CentiM3")
    FemtoMOL = URIRef("http://qudt.org/vocab/unit/FemtoMOL")
    MegaEV_PER_SpeedOfLight = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-SpeedOfLight")
    NanoW = URIRef("http://qudt.org/vocab/unit/NanoW")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    GM_PER_MOL = URIRef("http://qudt.org/vocab/unit/GM-PER-MOL")
    MilliGM_SEC_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M3-CentiM3")
    T = URIRef("http://qudt.org/vocab/unit/T")
    PicoS_PER_M = URIRef("http://qudt.org/vocab/unit/PicoS-PER-M")
    IN_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC-DEG_F")
    N_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-PER-RAD")
    MilliGM_SEC_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L2")
    MilliGM_MIN_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L2")
    GT = URIRef("http://qudt.org/vocab/unit/GT")
    MicroL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroL-PER-L")
    OZ_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_US")
    M2_PER_GM_DRY = URIRef("http://qudt.org/vocab/unit/M2-PER-GM_DRY")
    N_M_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-M")
    IN_PER_2PiRAD = URIRef("http://qudt.org/vocab/unit/IN-PER-2PiRAD")
    ElementaryCharge = URIRef("http://qudt.org/vocab/unit/ElementaryCharge")
    LB_HR_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-IN3")
    MilliL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliL-PER-L")
    KiloS_PER_M = URIRef("http://qudt.org/vocab/unit/KiloS-PER-M")
    MilliH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-KiloOHM")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    MegaOHM = URIRef("http://qudt.org/vocab/unit/MegaOHM")
    M_PER_K = URIRef("http://qudt.org/vocab/unit/M-PER-K")
    PERCENT_HR_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-GAL_UK")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    PERCENT_SEC_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-YD3")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    KiloGM_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-M2")
    MicroA_PER_K = URIRef("http://qudt.org/vocab/unit/MicroA-PER-K")
    IN2 = URIRef("http://qudt.org/vocab/unit/IN2")
    KiloC_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M2")
    CAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC")
    CentiM_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-K")
    KiloFARAD = URIRef("http://qudt.org/vocab/unit/KiloFARAD")
    PA_M0dot5 = URIRef("http://qudt.org/vocab/unit/PA-M0dot5")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    BTU_IT_PER_LB_MOL = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-MOL")
    SEC_PER_RAD_M3 = URIRef("http://qudt.org/vocab/unit/SEC-PER-RAD-M3")
    OHM_CentiM = URIRef("http://qudt.org/vocab/unit/OHM-CentiM")
    DEG_PER_M = URIRef("http://qudt.org/vocab/unit/DEG-PER-M")
    KiloJ_PER_KiloV = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloV")
    MilliMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    TON = URIRef("http://qudt.org/vocab/unit/TON")
    MilliT = URIRef("http://qudt.org/vocab/unit/MilliT")
    unit = URIRef("http://qudt.org/vocab/unit")
    MilliGM_MIN_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M3-CentiM3")
    MilliBQ = URIRef("http://qudt.org/vocab/unit/MilliBQ")
    CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-GM")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    KiloGM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM2")
    PicoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/PicoFARAD-PER-M")
    DeciS_PER_M = URIRef("http://qudt.org/vocab/unit/DeciS-PER-M")
    M2_PER_SEC2_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2-K")
    LB_F_PER_LB = URIRef("http://qudt.org/vocab/unit/LB_F-PER-LB")
    MicroMOL_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM-SEC")
    W_PER_M_K = URIRef("http://qudt.org/vocab/unit/W-PER-M-K")
    KibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M")
    GM_F = URIRef("http://qudt.org/vocab/unit/GM_F")
    N_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM2")
    MicroGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-MilliL")
    KiloGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-K")
    DARCY = URIRef("http://qudt.org/vocab/unit/DARCY")
    OZ_VOL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-SEC")
    BTU_IT_PER_LB_F_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_F")
    ERG_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM-SEC")
    GI = URIRef("http://qudt.org/vocab/unit/GI")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    GM_PER_M3_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-MilliPA-SEC")
    KiloGM_PER_J = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-J")
    MilliL_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-K")
    NanoH = URIRef("http://qudt.org/vocab/unit/NanoH")
    GI = URIRef("http://qudt.org/vocab/unit/GI")
    KiloLB_F_FT_PER_A = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-A")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    KiloGM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR")
    MilliM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-BAR")
    FT_LA = URIRef("http://qudt.org/vocab/unit/FT-LA")
    MilliBQ_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-M2-DAY")
    PSI_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-M3-PER-SEC")
    KiloC_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M3")
    BTU_IT_PER_SEC_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2")
    TON_Metric_PER_M3 = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3")
    V = URIRef("http://qudt.org/vocab/unit/V")
    PER_IN2 = URIRef("http://qudt.org/vocab/unit/PER-IN2")
    KiloW_PER_M_K = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M-K")
    J = URIRef("http://qudt.org/vocab/unit/J")
    GM_PER_M3_PA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-PA-SEC")
    OZ_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ-PER-SEC")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    MilliTORR = URIRef("http://qudt.org/vocab/unit/MilliTORR")
    CentiM3_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY-BAR")
    LB_MIN_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-YD3")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    WB_PER_MilliM = URIRef("http://qudt.org/vocab/unit/WB-PER-MilliM")
    HeartBeat = URIRef("http://qudt.org/vocab/unit/HeartBeat")
    PicoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-KiloGM")
    N = URIRef("http://qudt.org/vocab/unit/N")
    KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A-HR")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    BTU_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC")
    FT_SEC_PER_IN3 = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-IN3")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    MilliMOL = URIRef("http://qudt.org/vocab/unit/MilliMOL")
    N_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-PER-KiloGM")
    OERSTED_CentiM = URIRef("http://qudt.org/vocab/unit/OERSTED-CentiM")
    DWT = URIRef("http://qudt.org/vocab/unit/DWT")
    OZ_VOL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-MIN")
    W_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/W-PER-CentiM2")
    KiloHZ = URIRef("http://qudt.org/vocab/unit/KiloHZ")
    IN_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN-PER-MIN")
    N_M_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-RAD")
    OHM_PER_MI = URIRef("http://qudt.org/vocab/unit/OHM-PER-MI")
    EUR_PER_W = URIRef("http://qudt.org/vocab/unit/EUR-PER-W")
    PERCENT_RH = URIRef("http://qudt.org/vocab/unit/PERCENT_RH")
    M3_PER_K = URIRef("http://qudt.org/vocab/unit/M3-PER-K")
    MicroATM = URIRef("http://qudt.org/vocab/unit/MicroATM")
    MilliMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-L")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    MicroOHM_M = URIRef("http://qudt.org/vocab/unit/MicroOHM-M")
    GigaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-SEC")
    A = URIRef("http://qudt.org/vocab/unit/A")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    MilliGM_MIN_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M3-L")
    PER_CentiM = URIRef("http://qudt.org/vocab/unit/PER-CentiM")
    PA_PER_K = URIRef("http://qudt.org/vocab/unit/PA-PER-K")
    KiloGM_PER_M_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC2")
    HectoPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-M3-PER-SEC")
    KAT_PER_MicroL = URIRef("http://qudt.org/vocab/unit/KAT-PER-MicroL")
    PPM = URIRef("http://qudt.org/vocab/unit/PPM")
    HectoPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-L-PER-SEC")
    MicroW = URIRef("http://qudt.org/vocab/unit/MicroW")
    KiloGM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM-PER-SEC")
    L_PER_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-SEC")
    TSP = URIRef("http://qudt.org/vocab/unit/TSP")
    HectoM = URIRef("http://qudt.org/vocab/unit/HectoM")
    YD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/YD-PER-SEC2")
    E = URIRef("http://qudt.org/vocab/unit/E")
    KiloA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloA-PER-K")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    N = URIRef("http://qudt.org/vocab/unit/N")
    KiloW_PER_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M-DEG_C")
    MegaPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-BAR")
    KiloGM_F_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-MilliM2")
    MicroMHO = URIRef("http://qudt.org/vocab/unit/MicroMHO")
    PER_SEC_SR_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR-M2")
    DEGREE_API = URIRef("http://qudt.org/vocab/unit/DEGREE_API")
    DeciBAR = URIRef("http://qudt.org/vocab/unit/DeciBAR")
    C3_M_PER_J2 = URIRef("http://qudt.org/vocab/unit/C3-M-PER-J2")
    MilliW_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-MilliGM")
    LB_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC-PSI")
    SLUG_PER_FT = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT")
    CentiM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC")
    A = URIRef("http://qudt.org/vocab/unit/A")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    FT4 = URIRef("http://qudt.org/vocab/unit/FT4")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    DecaM3 = URIRef("http://qudt.org/vocab/unit/DecaM3")
    NanoJ = URIRef("http://qudt.org/vocab/unit/NanoJ")
    C_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-CentiM2")
    AttoFARAD = URIRef("http://qudt.org/vocab/unit/AttoFARAD")
    L_PER_HR = URIRef("http://qudt.org/vocab/unit/L-PER-HR")
    KiloLB_F = URIRef("http://qudt.org/vocab/unit/KiloLB_F")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    KiloGM_PER_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA")
    LB_T = URIRef("http://qudt.org/vocab/unit/LB_T")
    NanoH = URIRef("http://qudt.org/vocab/unit/NanoH")
    BBL_UK_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-HR")
    NanoA_PER_K = URIRef("http://qudt.org/vocab/unit/NanoA-PER-K")
    OZ_MIN_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-GAL_UK")
    MilliM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliM-PER-K")
    IN_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC2")
    ROD = URIRef("http://qudt.org/vocab/unit/ROD")
    FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-DEG_F")
    GAUGE_FR = URIRef("http://qudt.org/vocab/unit/GAUGE_FR")
    MicroV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/MicroV-A_Reactive-PER-K")
    PlanckFrequency = URIRef("http://qudt.org/vocab/unit/PlanckFrequency")
    TeraFLOPS = URIRef("http://qudt.org/vocab/unit/TeraFLOPS")
    KiloTON_Metric = URIRef("http://qudt.org/vocab/unit/KiloTON_Metric")
    TON_US_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_US-PER-HR")
    MegaOHM_PER_K = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-K")
    HP_Electric = URIRef("http://qudt.org/vocab/unit/HP_Electric")
    L_PER_HR_K = URIRef("http://qudt.org/vocab/unit/L-PER-HR-K")
    PERM_Metric = URIRef("http://qudt.org/vocab/unit/PERM_Metric")
    BTU_IT_PER_LB_F_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_R")
    M_PER_DEG_C_M = URIRef("http://qudt.org/vocab/unit/M-PER-DEG_C-M")
    MilliM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-BAR")
    CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CentiM2-MIN")
    WK = URIRef("http://qudt.org/vocab/unit/WK")
    PicoMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M3")
    KiloV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive-PER-K")
    FT_HG = URIRef("http://qudt.org/vocab/unit/FT_HG")
    MegaW = URIRef("http://qudt.org/vocab/unit/MegaW")
    PERCENT_FT2_PER_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-FT2-PER-LB_F-SEC")
    MOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3")
    M2_PER_J = URIRef("http://qudt.org/vocab/unit/M2-PER-J")
    HART_PER_SEC = URIRef("http://qudt.org/vocab/unit/HART-PER-SEC")
    BU_UK = URIRef("http://qudt.org/vocab/unit/BU_UK")
    DEG_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-MIN")
    CAL_TH_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-K")
    BTU_IT_PER_SEC_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2")
    TON_Assay = URIRef("http://qudt.org/vocab/unit/TON_Assay")
    LB_PER_FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-LB_F-SEC")
    L_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-K")
    KiloJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM")
    MicroL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroL-PER-L")
    FT_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT-PER-DAY")
    A_Ab_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-CentiM2")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    NanoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/NanoW-PER-M2")
    S = URIRef("http://qudt.org/vocab/unit/S")
    MOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL-PER-MIN")
    MegaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M3")
    MilliL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliL-PER-L")
    MicroA_PER_K = URIRef("http://qudt.org/vocab/unit/MicroA-PER-K")
    NUM_PER_YR = URIRef("http://qudt.org/vocab/unit/NUM-PER-YR")
    DecaPA = URIRef("http://qudt.org/vocab/unit/DecaPA")
    PicoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-KiloGM")
    NanoM_PER_CentiM_PSI = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-PSI")
    PicoSEC = URIRef("http://qudt.org/vocab/unit/PicoSEC")
    LB_MIN_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US2")
    MilliGAL_PER_MO = URIRef("http://qudt.org/vocab/unit/MilliGAL-PER-MO")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    J_PER_T2 = URIRef("http://qudt.org/vocab/unit/J-PER-T2")
    MI_US2 = URIRef("http://qudt.org/vocab/unit/MI_US2")
    OHM_KiloM = URIRef("http://qudt.org/vocab/unit/OHM-KiloM")
    MicroBQ = URIRef("http://qudt.org/vocab/unit/MicroBQ")
    A_PER_J = URIRef("http://qudt.org/vocab/unit/A-PER-J")
    A_Ab = URIRef("http://qudt.org/vocab/unit/A_Ab")
    MilliGM_SEC_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L2")
    PicoW_PER_CentiM2_L = URIRef("http://qudt.org/vocab/unit/PicoW-PER-CentiM2-L")
    C3_M_PER_J2 = URIRef("http://qudt.org/vocab/unit/C3-M-PER-J2")
    CentiM2_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-CentiM3")
    CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CentiM2-MIN")
    CentiST = URIRef("http://qudt.org/vocab/unit/CentiST")
    FARAD_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/FARAD_Ab-PER-CentiM")
    MilliGRAY = URIRef("http://qudt.org/vocab/unit/MilliGRAY")
    GM_HR_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L-M3")
    BAR = URIRef("http://qudt.org/vocab/unit/BAR")
    CentiM3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-BAR")
    N_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M3")
    C_Ab = URIRef("http://qudt.org/vocab/unit/C_Ab")
    KibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    KiloM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC2")
    PicoW_PER_CentiM2_L = URIRef("http://qudt.org/vocab/unit/PicoW-PER-CentiM2-L")
    J_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K")
    MilliL = URIRef("http://qudt.org/vocab/unit/MilliL")
    MilliL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-SEC")
    SLUG_PER_DAY = URIRef("http://qudt.org/vocab/unit/SLUG-PER-DAY")
    M_KiloGM = URIRef("http://qudt.org/vocab/unit/M-KiloGM")
    NUM_PER_NanoL = URIRef("http://qudt.org/vocab/unit/NUM-PER-NanoL")
    IN_PDL = URIRef("http://qudt.org/vocab/unit/IN-PDL")
    L_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/L-PER-MicroMOL")
    DEG_F_HR_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_TH")
    GR = URIRef("http://qudt.org/vocab/unit/GR")
    FT2_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT2-PER-SEC")
    MicroS = URIRef("http://qudt.org/vocab/unit/MicroS")
    MicroS = URIRef("http://qudt.org/vocab/unit/MicroS")
    PER_M_NanoM = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM")
    PERM_Metric = URIRef("http://qudt.org/vocab/unit/PERM_Metric")
    C_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM")
    FARAD_Stat = URIRef("http://qudt.org/vocab/unit/FARAD_Stat")
    BTU_TH_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_R")
    GM_PER_M3_PA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-PA-SEC")
    KiloOHM = URIRef("http://qudt.org/vocab/unit/KiloOHM")
    MOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    MegaGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-M3")
    MilliGM_PER_L_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-MilliPA-SEC")
    LB_PER_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-HR")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    FARAD_Stat = URIRef("http://qudt.org/vocab/unit/FARAD_Stat")
    PER_L = URIRef("http://qudt.org/vocab/unit/PER-L")
    MicroA_PER_K = URIRef("http://qudt.org/vocab/unit/MicroA-PER-K")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    PicoMOL_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L-DAY")
    PlanckMass = URIRef("http://qudt.org/vocab/unit/PlanckMass")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloMOL")
    PicoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-KiloGM")
    OZ_VOL_US = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    MegaPA_M0pt5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0pt5")
    TON_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-DAY")
    PicoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-MilliL")
    PER_J2 = URIRef("http://qudt.org/vocab/unit/PER-J2")
    BBL_UK_PET_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-DAY")
    N_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-RAD")
    MegaV_A = URIRef("http://qudt.org/vocab/unit/MegaV-A")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    FC = URIRef("http://qudt.org/vocab/unit/FC")
    M3_PER_K = URIRef("http://qudt.org/vocab/unit/M3-PER-K")
    W_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-PER-M3")
    MicroM3 = URIRef("http://qudt.org/vocab/unit/MicroM3")
    KiloV_A_PER_K = URIRef("http://qudt.org/vocab/unit/KiloV-A-PER-K")
    KiloGM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-BAR")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    CentiM4 = URIRef("http://qudt.org/vocab/unit/CentiM4")
    N_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-PER-M3")
    M2_HZ = URIRef("http://qudt.org/vocab/unit/M2-HZ")
    PERCENT_SEC_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-YD3")
    TON_Register = URIRef("http://qudt.org/vocab/unit/TON_Register")
    KiloGM_PER_L = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L")
    U = URIRef("http://qudt.org/vocab/unit/U")
    RT = URIRef("http://qudt.org/vocab/unit/RT")
    GI_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-MIN")
    IN_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-DEG_F")
    M2_PER_HZ_DEG = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ-DEG")
    MicroBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-L")
    PSI = URIRef("http://qudt.org/vocab/unit/PSI")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    NanoGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-SEC")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    OZ_VOL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-MIN")
    V_PER_L_MIN = URIRef("http://qudt.org/vocab/unit/V-PER-L-MIN")
    DEG_C_PER_BAR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-BAR")
    MilliM3 = URIRef("http://qudt.org/vocab/unit/MilliM3")
    YD_PER_PSI = URIRef("http://qudt.org/vocab/unit/YD-PER-PSI")
    HP_Boiler = URIRef("http://qudt.org/vocab/unit/HP_Boiler")
    OZ_VOL_UK = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    KiloW_PER_M2_K = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M2-K")
    CWT_SHORT = URIRef("http://qudt.org/vocab/unit/CWT_SHORT")
    L_PER_MIN = URIRef("http://qudt.org/vocab/unit/L-PER-MIN")
    FT3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT3-PER-DEG_F")
    DEG_C_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-K")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    N_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-PER-RAD")
    SolarMass = URIRef("http://qudt.org/vocab/unit/SolarMass")
    PlanckImpedance = URIRef("http://qudt.org/vocab/unit/PlanckImpedance")
    M2_PER_M2 = URIRef("http://qudt.org/vocab/unit/M2-PER-M2")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    N_CentiM = URIRef("http://qudt.org/vocab/unit/N-CentiM")
    LA = URIRef("http://qudt.org/vocab/unit/LA")
    OZ_MIN_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-YD3")
    MebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M2")
    YoctoC = URIRef("http://qudt.org/vocab/unit/YoctoC")
    HP_Brake = URIRef("http://qudt.org/vocab/unit/HP_Brake")
    PicoGM_PER_L = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-L")
    KiloCAL = URIRef("http://qudt.org/vocab/unit/KiloCAL")
    MilliJ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-GM")
    CentiC = URIRef("http://qudt.org/vocab/unit/CentiC")
    N_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG")
    DEG_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-MIN")
    CAL_IT = URIRef("http://qudt.org/vocab/unit/CAL_IT")
    TONNE_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY-K")
    KiloCAL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-SEC")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    DRAM_UK = URIRef("http://qudt.org/vocab/unit/DRAM_UK")
    L_PER_MIN = URIRef("http://qudt.org/vocab/unit/L-PER-MIN")
    PFERDESTAERKE = URIRef("http://qudt.org/vocab/unit/PFERDESTAERKE")
    DeciM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-KiloGM")
    CentiPOISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-BAR")
    NanoGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DeciL")
    V = URIRef("http://qudt.org/vocab/unit/V")
    PER_J_M3 = URIRef("http://qudt.org/vocab/unit/PER-J-M3")
    MX = URIRef("http://qudt.org/vocab/unit/MX")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    W_HR = URIRef("http://qudt.org/vocab/unit/W-HR")
    MicroM_PER_M = URIRef("http://qudt.org/vocab/unit/MicroM-PER-M")
    ATM = URIRef("http://qudt.org/vocab/unit/ATM")
    DeciB_PER_KiloM = URIRef("http://qudt.org/vocab/unit/DeciB-PER-KiloM")
    KiloGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-BAR")
    M_K = URIRef("http://qudt.org/vocab/unit/M-K")
    MegaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-SEC")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    CAL_TH_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2-MIN")
    DEG_F_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC2")
    KiloN_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M")
    BTU_TH_FT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-HR-FT2-DEG_F")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    BTU_IT_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-SEC-DEG_F")
    DYN_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM2")
    PicoPA_PER_KiloM = URIRef("http://qudt.org/vocab/unit/PicoPA-PER-KiloM")
    PA_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC2")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    KAT_PER_MicroL = URIRef("http://qudt.org/vocab/unit/KAT-PER-MicroL")
    M3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-BAR")
    PicoH = URIRef("http://qudt.org/vocab/unit/PicoH")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    PDL_PER_IN2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-IN2")
    M_PER_FARAD = URIRef("http://qudt.org/vocab/unit/M-PER-FARAD")
    KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A-HR")
    H_Ab = URIRef("http://qudt.org/vocab/unit/H_Ab")
    BBL_UK_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-SEC")
    KiloGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-K")
    MegaJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-KiloGM")
    TONNE = URIRef("http://qudt.org/vocab/unit/TONNE")
    PERCENT_HR_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-GAL_US")
    PERCENT_PER_PA_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-PA-SEC")
    FT2_HR_DEG_F_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F-PER-BTU_IT")
    GigaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-SEC")
    A_Ab_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-CentiM2")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    GRAIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-M3")
    DeciB_M = URIRef("http://qudt.org/vocab/unit/DeciB_M")
    OHM_CentiM = URIRef("http://qudt.org/vocab/unit/OHM-CentiM")
    MilliGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY")
    MicroC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M2")
    FemtoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-KiloGM")
    PER_SEC_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR")
    Ci = URIRef("http://qudt.org/vocab/unit/Ci")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    GM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL")
    BTU_IT_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_R")
    DeciN = URIRef("http://qudt.org/vocab/unit/DeciN")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    W_SEC = URIRef("http://qudt.org/vocab/unit/W-SEC")
    DRAM_UK = URIRef("http://qudt.org/vocab/unit/DRAM_UK")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    ST_PER_K = URIRef("http://qudt.org/vocab/unit/ST-PER-K")
    MicroGM_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L-HR")
    GM_PER_CentiM3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3-BAR")
    DecaM = URIRef("http://qudt.org/vocab/unit/DecaM")
    MOMME_Textile = URIRef("http://qudt.org/vocab/unit/MOMME_Textile")
    MilliC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M2")
    CD_IN = URIRef("http://qudt.org/vocab/unit/CD_IN")
    V = URIRef("http://qudt.org/vocab/unit/V")
    PSI_PER_PSI = URIRef("http://qudt.org/vocab/unit/PSI-PER-PSI")
    CentiM3_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN-BAR")
    BBL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-DAY")
    C_M2 = URIRef("http://qudt.org/vocab/unit/C-M2")
    A_PER_M2_K2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2-K2")
    ExaV_A = URIRef("http://qudt.org/vocab/unit/ExaV-A")
    MicroM3 = URIRef("http://qudt.org/vocab/unit/MicroM3")
    W_PER_SR = URIRef("http://qudt.org/vocab/unit/W-PER-SR")
    GAL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-MIN")
    OZ_VOL_US = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US")
    V_PER_L_MIN = URIRef("http://qudt.org/vocab/unit/V-PER-L-MIN")
    IN3 = URIRef("http://qudt.org/vocab/unit/IN3")
    CentiM3_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR")
    KAT_PER_MicroL = URIRef("http://qudt.org/vocab/unit/KAT-PER-MicroL")
    MilliR = URIRef("http://qudt.org/vocab/unit/MilliR")
    PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/PER-KiloGM2")
    GM_PER_HZ = URIRef("http://qudt.org/vocab/unit/GM-PER-HZ")
    V_PER_MilliM = URIRef("http://qudt.org/vocab/unit/V-PER-MilliM")
    TON_Metric_PER_SEC = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC")
    KiloGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-PA-SEC")
    DEG_C_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-K")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    DAY_Sidereal = URIRef("http://qudt.org/vocab/unit/DAY_Sidereal")
    K_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PER-SEC")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    FemtoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-L")
    DeciB_PER_KiloM = URIRef("http://qudt.org/vocab/unit/DeciB-PER-KiloM")
    KiloW = URIRef("http://qudt.org/vocab/unit/KiloW")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    M_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-BAR")
    MI_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI-PER-MIN")
    BTU_IT_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-SEC-DEG_F")
    KiloCAL_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2")
    GI_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-SEC")
    MilliGM_MIN_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L-CentiM3")
    LB_F_IN_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN-PER-IN")
    BREATH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BREATH-PER-MIN")
    PER_IN3 = URIRef("http://qudt.org/vocab/unit/PER-IN3")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    MilliL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-GM")
    MilliMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-MOL")
    MicroC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M2")
    PINT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-MIN")
    K_M_PER_W = URIRef("http://qudt.org/vocab/unit/K-M-PER-W")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    MilliC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliC-PER-KiloGM")
    YD3_PER_DAY = URIRef("http://qudt.org/vocab/unit/YD3-PER-DAY")
    N = URIRef("http://qudt.org/vocab/unit/N")
    KiloCAL_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM")
    M2_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-HZ2")
    M_PER_MIN = URIRef("http://qudt.org/vocab/unit/M-PER-MIN")
    MilliC = URIRef("http://qudt.org/vocab/unit/MilliC")
    NanoMOL_PER_MicroMOL_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL-DAY")
    MilliA_HR_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliA-HR-PER-GM")
    KiloN_M = URIRef("http://qudt.org/vocab/unit/KiloN-M")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    LB_HR_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-YD3")
    L_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-K")
    GM_PER_M3_POISE = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-POISE")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    NanoMOL_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL")
    C_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM3")
    LUX_HR = URIRef("http://qudt.org/vocab/unit/LUX-HR")
    W_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM-SR")
    GM_PER_K = URIRef("http://qudt.org/vocab/unit/GM-PER-K")
    GM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM_F-PER-CentiM2")
    KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloGM-K")
    PDL_PER_IN2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-IN2")
    GM_PER_MOL = URIRef("http://qudt.org/vocab/unit/GM-PER-MOL")
    LB_PER_MIN_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN-DEG_F")
    CM_H2O = URIRef("http://qudt.org/vocab/unit/CM_H2O")
    TON_LONG_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_LONG-PER-YD3")
    TONNE_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN-K")
    AC_FT_US = URIRef("http://qudt.org/vocab/unit/AC-FT_US")
    MicroGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3")
    OZ_VOL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-DAY")
    MilliFARAD = URIRef("http://qudt.org/vocab/unit/MilliFARAD")
    PERCENT_MIN_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-GAL_UK")
    MilliMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2")
    C_Ab = URIRef("http://qudt.org/vocab/unit/C_Ab")
    OZ_IN2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/OZ-IN2-PER-IN3-LB_F-SEC")
    Standard = URIRef("http://qudt.org/vocab/unit/Standard")
    GR = URIRef("http://qudt.org/vocab/unit/GR")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    BTU_TH_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR-FT2-DEG_F")
    PicoL = URIRef("http://qudt.org/vocab/unit/PicoL")
    PicoA_PER_MicroMOL_L = URIRef("http://qudt.org/vocab/unit/PicoA-PER-MicroMOL-L")
    MicroGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-MilliL")
    ZettaC = URIRef("http://qudt.org/vocab/unit/ZettaC")
    LB_PER_YD3 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD3")
    QT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-HR")
    S = URIRef("http://qudt.org/vocab/unit/S")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    LB_HR_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-FT3")
    CentiM3_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-BAR")
    FARAD_Ab = URIRef("http://qudt.org/vocab/unit/FARAD_Ab")
    LB_MOL = URIRef("http://qudt.org/vocab/unit/LB-MOL")
    YD_PER_HR = URIRef("http://qudt.org/vocab/unit/YD-PER-HR")
    BTU_IT_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC")
    TON_Assay = URIRef("http://qudt.org/vocab/unit/TON_Assay")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    KiloGM_PER_L_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-K")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    BTU_IT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC")
    C_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM-SEC")
    MO_MeanJulian = URIRef("http://qudt.org/vocab/unit/MO_MeanJulian")
    PPM_PER_K = URIRef("http://qudt.org/vocab/unit/PPM-PER-K")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    GM_PER_L = URIRef("http://qudt.org/vocab/unit/GM-PER-L")
    IN_HG = URIRef("http://qudt.org/vocab/unit/IN_HG")
    J_PER_M4 = URIRef("http://qudt.org/vocab/unit/J-PER-M4")
    K = URIRef("http://qudt.org/vocab/unit/K")
    BU_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-SEC")
    C_M2_PER_V = URIRef("http://qudt.org/vocab/unit/C-M2-PER-V")
    PicoA_PER_HectoPA = URIRef("http://qudt.org/vocab/unit/PicoA-PER-HectoPA")
    A_M2_PER_J_SEC = URIRef("http://qudt.org/vocab/unit/A-M2-PER-J-SEC")
    K_PER_K = URIRef("http://qudt.org/vocab/unit/K-PER-K")
    MOL_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-K")
    IN_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC-PSI")
    CentiL = URIRef("http://qudt.org/vocab/unit/CentiL")
    SUSCEPTIBILITY_ELEC = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_ELEC")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    M5 = URIRef("http://qudt.org/vocab/unit/M5")
    M2_PER_K = URIRef("http://qudt.org/vocab/unit/M2-PER-K")
    MESH = URIRef("http://qudt.org/vocab/unit/MESH")
    DYN_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM2")
    PA_M0dot5 = URIRef("http://qudt.org/vocab/unit/PA-M0dot5")
    KiloA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    PDL = URIRef("http://qudt.org/vocab/unit/PDL")
    M_PER_HR = URIRef("http://qudt.org/vocab/unit/M-PER-HR")
    PER_K = URIRef("http://qudt.org/vocab/unit/PER-K")
    NUM_PER_HectoGM = URIRef("http://qudt.org/vocab/unit/NUM-PER-HectoGM")
    FemtoV = URIRef("http://qudt.org/vocab/unit/FemtoV")
    FT2 = URIRef("http://qudt.org/vocab/unit/FT2")
    MilliS = URIRef("http://qudt.org/vocab/unit/MilliS")
    PicoA_PER_HectoPA = URIRef("http://qudt.org/vocab/unit/PicoA-PER-HectoPA")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    N_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-PER-RAD")
    GM_PER_M3_CentiPOISE = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-CentiPOISE")
    PINT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-MIN")
    PER_J2 = URIRef("http://qudt.org/vocab/unit/PER-J2")
    MicroGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3")
    MicroMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2")
    OZ_F_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ_F-PER-IN3")
    K_DAY = URIRef("http://qudt.org/vocab/unit/K-DAY")
    BTU_IT_PER_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL-DEG_F")

    _NS = Namespace("https://qudt.org/vocab/unit/")