from rdflib.namespace import DefinedNamespace, Namespace
from rdflib.term import URIRef


class SCHEMA(DefinedNamespace):
    # Generated with namespacelib version 0.3.0
    _fail = True
    firstPerformance = URIRef("https://schema.org/firstPerformance")
    wordCount = URIRef("https://schema.org/wordCount")
    performer = URIRef("https://schema.org/performer")
    hasPart = URIRef("https://schema.org/hasPart")
    wordCount = URIRef("https://schema.org/wordCount")
    returnShippingFeesAmount = URIRef("https://schema.org/returnShippingFeesAmount")
    artworkSurface = URIRef("https://schema.org/artworkSurface")
    providesService = URIRef("https://schema.org/providesService")
    VisualArtsEvent = URIRef("https://schema.org/VisualArtsEvent")
    founders = URIRef("https://schema.org/founders")
    amount = URIRef("https://schema.org/amount")
    preOp = URIRef("https://schema.org/preOp")
    alternativeOf = URIRef("https://schema.org/alternativeOf")
    WearableSizeGroupEnumeration = URIRef("https://schema.org/WearableSizeGroupEnumeration")
    accessibilityControl = URIRef("https://schema.org/accessibilityControl")
    remainingAttendeeCapacity = URIRef("https://schema.org/remainingAttendeeCapacity")
    PaymentCard = URIRef("https://schema.org/PaymentCard")
    Abdomen = URIRef("https://schema.org/Abdomen")
    DamagedCondition = URIRef("https://schema.org/DamagedCondition")
    hasRepresentation = URIRef("https://schema.org/hasRepresentation")
    printSection = URIRef("https://schema.org/printSection")
    byDay = URIRef("https://schema.org/byDay")
    ProductGroup = URIRef("https://schema.org/ProductGroup")
    MedicalBusiness = URIRef("https://schema.org/MedicalBusiness")
    DoubleBlindedTrial = URIRef("https://schema.org/DoubleBlindedTrial")
    countryOfAssembly = URIRef("https://schema.org/countryOfAssembly")
    timeRequired = URIRef("https://schema.org/timeRequired")
    CertificationInactive = URIRef("https://schema.org/CertificationInactive")
    warning = URIRef("https://schema.org/warning")
    associatedAnatomy = URIRef("https://schema.org/associatedAnatomy")
    netWorth = URIRef("https://schema.org/netWorth")
    Waterfall = URIRef("https://schema.org/Waterfall")
    numberOfItems = URIRef("https://schema.org/numberOfItems")
    publicTransportClosuresInfo = URIRef("https://schema.org/publicTransportClosuresInfo")
    prescriptionStatus = URIRef("https://schema.org/prescriptionStatus")
    dropoffTime = URIRef("https://schema.org/dropoffTime")
    availableLanguage = URIRef("https://schema.org/availableLanguage")
    lender = URIRef("https://schema.org/lender")
    caption = URIRef("https://schema.org/caption")
    album = URIRef("https://schema.org/album")
    address = URIRef("https://schema.org/address")
    chemicalComposition = URIRef("https://schema.org/chemicalComposition")
    editEIDR = URIRef("https://schema.org/editEIDR")
    GolfCourse = URIRef("https://schema.org/GolfCourse")
    pattern = URIRef("https://schema.org/pattern")
    partySize = URIRef("https://schema.org/partySize")
    amount = URIRef("https://schema.org/amount")
    numTracks = URIRef("https://schema.org/numTracks")
    Friday = URIRef("https://schema.org/Friday")
    WebAPI = URIRef("https://schema.org/WebAPI")
    Number = URIRef("https://schema.org/Number")
    gameLocation = URIRef("https://schema.org/gameLocation")
    Time = URIRef("https://schema.org/Time")
    VideoObject = URIRef("https://schema.org/VideoObject")
    TouristTrip = URIRef("https://schema.org/TouristTrip")
    OccupationalExperienceRequirements = URIRef("https://schema.org/OccupationalExperienceRequirements")
    Brand = URIRef("https://schema.org/Brand")
    LikeAction = URIRef("https://schema.org/LikeAction")
    subReservation = URIRef("https://schema.org/subReservation")
    duringMedia = URIRef("https://schema.org/duringMedia")
    downvoteCount = URIRef("https://schema.org/downvoteCount")
    marginOfError = URIRef("https://schema.org/marginOfError")
    InvestmentFund = URIRef("https://schema.org/InvestmentFund")
    ShortStory = URIRef("https://schema.org/ShortStory")
    MixedEventAttendanceMode = URIRef("https://schema.org/MixedEventAttendanceMode")
    amountOfThisGood = URIRef("https://schema.org/amountOfThisGood")
    billingIncrement = URIRef("https://schema.org/billingIncrement")
    qualifications = URIRef("https://schema.org/qualifications")
    competitor = URIRef("https://schema.org/competitor")
    busNumber = URIRef("https://schema.org/busNumber")
    MedicalCause = URIRef("https://schema.org/MedicalCause")
    termsPerYear = URIRef("https://schema.org/termsPerYear")
    SubscribeAction = URIRef("https://schema.org/SubscribeAction")
    trailer = URIRef("https://schema.org/trailer")
    supply = URIRef("https://schema.org/supply")
    businessFunction = URIRef("https://schema.org/businessFunction")
    discountCode = URIRef("https://schema.org/discountCode")
    item = URIRef("https://schema.org/item")
    RecommendedDoseSchedule = URIRef("https://schema.org/RecommendedDoseSchedule")
    reviewBody = URIRef("https://schema.org/reviewBody")
    seasons = URIRef("https://schema.org/seasons")
    associatedPathophysiology = URIRef("https://schema.org/associatedPathophysiology")
    provider = URIRef("https://schema.org/provider")
    currenciesAccepted = URIRef("https://schema.org/currenciesAccepted")
    negativeNotes = URIRef("https://schema.org/negativeNotes")
    subTest = URIRef("https://schema.org/subTest")
    UserReview = URIRef("https://schema.org/UserReview")
    contactPoints = URIRef("https://schema.org/contactPoints")
    ReplaceAction = URIRef("https://schema.org/ReplaceAction")
    MSRP = URIRef("https://schema.org/MSRP")
    directApply = URIRef("https://schema.org/directApply")
    SkiResort = URIRef("https://schema.org/SkiResort")
    isbn = URIRef("https://schema.org/isbn")
    interactionType = URIRef("https://schema.org/interactionType")
    EnergyEfficiencyEnumeration = URIRef("https://schema.org/EnergyEfficiencyEnumeration")
    Recruiting = URIRef("https://schema.org/Recruiting")
    NonprofitANBI = URIRef("https://schema.org/NonprofitANBI")
    Paperback = URIRef("https://schema.org/Paperback")
    DrugCostCategory = URIRef("https://schema.org/DrugCostCategory")
    runsTo = URIRef("https://schema.org/runsTo")
    TrackAction = URIRef("https://schema.org/TrackAction")
    itemListOrder = URIRef("https://schema.org/itemListOrder")
    salaryUponCompletion = URIRef("https://schema.org/salaryUponCompletion")
    hoursAvailable = URIRef("https://schema.org/hoursAvailable")
    EmployeeRole = URIRef("https://schema.org/EmployeeRole")
    DrinkAction = URIRef("https://schema.org/DrinkAction")
    Schedule = URIRef("https://schema.org/Schedule")
    memoryRequirements = URIRef("https://schema.org/memoryRequirements")
    result = URIRef("https://schema.org/result")
    beneficiaryBank = URIRef("https://schema.org/beneficiaryBank")
    Country = URIRef("https://schema.org/Country")
    relatedDrug = URIRef("https://schema.org/relatedDrug")
    parentTaxon = URIRef("https://schema.org/parentTaxon")
    SpeakableSpecification = URIRef("https://schema.org/SpeakableSpecification")
    InternetCafe = URIRef("https://schema.org/InternetCafe")
    OutOfStock = URIRef("https://schema.org/OutOfStock")
    gender = URIRef("https://schema.org/gender")
    publishedOn = URIRef("https://schema.org/publishedOn")
    CriticReview = URIRef("https://schema.org/CriticReview")
    HealthPlanFormulary = URIRef("https://schema.org/HealthPlanFormulary")
    adverseOutcome = URIRef("https://schema.org/adverseOutcome")
    EnergyStarCertified = URIRef("https://schema.org/EnergyStarCertified")
    catalogNumber = URIRef("https://schema.org/catalogNumber")
    busName = URIRef("https://schema.org/busName")
    scheduledPaymentDate = URIRef("https://schema.org/scheduledPaymentDate")
    WearableSizeGroupInfants = URIRef("https://schema.org/WearableSizeGroupInfants")
    Class = URIRef("https://schema.org/Class")
    EUEnergyEfficiencyCategoryA = URIRef("https://schema.org/EUEnergyEfficiencyCategoryA")
    Demand = URIRef("https://schema.org/Demand")
    maximumIntake = URIRef("https://schema.org/maximumIntake")
    CoverArt = URIRef("https://schema.org/CoverArt")
    codeValue = URIRef("https://schema.org/codeValue")
    BefriendAction = URIRef("https://schema.org/BefriendAction")
    OfferShippingDetails = URIRef("https://schema.org/OfferShippingDetails")
    expressedIn = URIRef("https://schema.org/expressedIn")
    molecularWeight = URIRef("https://schema.org/molecularWeight")
    email = URIRef("https://schema.org/email")
    SoftwareApplication = URIRef("https://schema.org/SoftwareApplication")
    Collection = URIRef("https://schema.org/Collection")
    reviewAspect = URIRef("https://schema.org/reviewAspect")
    callSign = URIRef("https://schema.org/callSign")
    about = URIRef("https://schema.org/about")
    VideoGameClip = URIRef("https://schema.org/VideoGameClip")
    reviewedBy = URIRef("https://schema.org/reviewedBy")
    trialDesign = URIRef("https://schema.org/trialDesign")
    correctionsPolicy = URIRef("https://schema.org/correctionsPolicy")
    legislationLegalValue = URIRef("https://schema.org/legislationLegalValue")
    equal = URIRef("https://schema.org/equal")
    availabilityStarts = URIRef("https://schema.org/availabilityStarts")
    RecommendedDoseSchedule = URIRef("https://schema.org/RecommendedDoseSchedule")
    SizeSystemEnumeration = URIRef("https://schema.org/SizeSystemEnumeration")
    cvdCollectionDate = URIRef("https://schema.org/cvdCollectionDate")
    deliveryLeadTime = URIRef("https://schema.org/deliveryLeadTime")
    loanType = URIRef("https://schema.org/loanType")
    relatedCondition = URIRef("https://schema.org/relatedCondition")
    TouristAttraction = URIRef("https://schema.org/TouristAttraction")
    alignmentType = URIRef("https://schema.org/alignmentType")
    distinguishingSign = URIRef("https://schema.org/distinguishingSign")
    OnlineStore = URIRef("https://schema.org/OnlineStore")
    flightNumber = URIRef("https://schema.org/flightNumber")
    slogan = URIRef("https://schema.org/slogan")
    isConsumableFor = URIRef("https://schema.org/isConsumableFor")
    workExample = URIRef("https://schema.org/workExample")
    CleaningFee = URIRef("https://schema.org/CleaningFee")
    codeValue = URIRef("https://schema.org/codeValue")
    numChildren = URIRef("https://schema.org/numChildren")
    cutoffTime = URIRef("https://schema.org/cutoffTime")
    about = URIRef("https://schema.org/about")
    primaryImageOfPage = URIRef("https://schema.org/primaryImageOfPage")
    opponent = URIRef("https://schema.org/opponent")
    parentItem = URIRef("https://schema.org/parentItem")
    Discontinued = URIRef("https://schema.org/Discontinued")
    MobilePhoneStore = URIRef("https://schema.org/MobilePhoneStore")
    WeaponConsideration = URIRef("https://schema.org/WeaponConsideration")
    Cardiovascular = URIRef("https://schema.org/Cardiovascular")
    RadioBroadcastService = URIRef("https://schema.org/RadioBroadcastService")
    WearableSizeGroupExtraShort = URIRef("https://schema.org/WearableSizeGroupExtraShort")
    MusicRelease = URIRef("https://schema.org/MusicRelease")
    Nonprofit501n = URIRef("https://schema.org/Nonprofit501n")
    SportingGoodsStore = URIRef("https://schema.org/SportingGoodsStore")
    ComputerStore = URIRef("https://schema.org/ComputerStore")
    postalCodeBegin = URIRef("https://schema.org/postalCodeBegin")
    downvoteCount = URIRef("https://schema.org/downvoteCount")
    legislationLegalForce = URIRef("https://schema.org/legislationLegalForce")
    floorLimit = URIRef("https://schema.org/floorLimit")
    webFeed = URIRef("https://schema.org/webFeed")
    keywords = URIRef("https://schema.org/keywords")
    inker = URIRef("https://schema.org/inker")
    penciler = URIRef("https://schema.org/penciler")
    priceSpecification = URIRef("https://schema.org/priceSpecification")
    supportingData = URIRef("https://schema.org/supportingData")
    Action = URIRef("https://schema.org/Action")
    AnalysisNewsArticle = URIRef("https://schema.org/AnalysisNewsArticle")
    AdministrativeArea = URIRef("https://schema.org/AdministrativeArea")
    fileSize = URIRef("https://schema.org/fileSize")
    workExample = URIRef("https://schema.org/workExample")
    commentTime = URIRef("https://schema.org/commentTime")
    observationPeriod = URIRef("https://schema.org/observationPeriod")
    BroadcastRelease = URIRef("https://schema.org/BroadcastRelease")
    certificationIdentification = URIRef("https://schema.org/certificationIdentification")
    shippingSettingsLink = URIRef("https://schema.org/shippingSettingsLink")
    TouristAttraction = URIRef("https://schema.org/TouristAttraction")
    maxPrice = URIRef("https://schema.org/maxPrice")
    MusicRecording = URIRef("https://schema.org/MusicRecording")
    Nonprofit501c8 = URIRef("https://schema.org/Nonprofit501c8")
    ItemAvailability = URIRef("https://schema.org/ItemAvailability")
    hasMenuSection = URIRef("https://schema.org/hasMenuSection")
    EnrollingByInvitation = URIRef("https://schema.org/EnrollingByInvitation")
    Drug = URIRef("https://schema.org/Drug")
    observationDate = URIRef("https://schema.org/observationDate")
    volumeNumber = URIRef("https://schema.org/volumeNumber")
    reviewAspect = URIRef("https://schema.org/reviewAspect")
    geographicArea = URIRef("https://schema.org/geographicArea")
    contentRating = URIRef("https://schema.org/contentRating")
    BodyMeasurementHead = URIRef("https://schema.org/BodyMeasurementHead")
    arrivalAirport = URIRef("https://schema.org/arrivalAirport")
    educationalLevel = URIRef("https://schema.org/educationalLevel")
    Property = URIRef("https://schema.org/Property")
    branchOf = URIRef("https://schema.org/branchOf")
    RelatedTopicsHealthAspect = URIRef("https://schema.org/RelatedTopicsHealthAspect")
    availableIn = URIRef("https://schema.org/availableIn")
    accessibilityHazard = URIRef("https://schema.org/accessibilityHazard")
    DonateAction = URIRef("https://schema.org/DonateAction")
    SelfCareHealthAspect = URIRef("https://schema.org/SelfCareHealthAspect")
    InfectiousDisease = URIRef("https://schema.org/InfectiousDisease")
    WearableSizeSystemJP = URIRef("https://schema.org/WearableSizeSystemJP")
    causeOf = URIRef("https://schema.org/causeOf")
    dateVehicleFirstRegistered = URIRef("https://schema.org/dateVehicleFirstRegistered")
    MusicGroup = URIRef("https://schema.org/MusicGroup")
    mobileUrl = URIRef("https://schema.org/mobileUrl")
    DisagreeAction = URIRef("https://schema.org/DisagreeAction")
    postalCode = URIRef("https://schema.org/postalCode")
    seller = URIRef("https://schema.org/seller")
    BusinessFunction = URIRef("https://schema.org/BusinessFunction")
    discusses = URIRef("https://schema.org/discusses")
    CompositeSyntheticDigitalSource = URIRef("https://schema.org/CompositeSyntheticDigitalSource")
    question = URIRef("https://schema.org/question")
    includesObject = URIRef("https://schema.org/includesObject")
    shippingDestination = URIRef("https://schema.org/shippingDestination")
    recourseLoan = URIRef("https://schema.org/recourseLoan")
    Drawing = URIRef("https://schema.org/Drawing")
    MixedEventAttendanceMode = URIRef("https://schema.org/MixedEventAttendanceMode")
    episodeNumber = URIRef("https://schema.org/episodeNumber")
    EmergencyService = URIRef("https://schema.org/EmergencyService")
    transcript = URIRef("https://schema.org/transcript")
    sport = URIRef("https://schema.org/sport")
    transitTime = URIRef("https://schema.org/transitTime")
    cashBack = URIRef("https://schema.org/cashBack")
    industry = URIRef("https://schema.org/industry")
    functionalClass = URIRef("https://schema.org/functionalClass")
    manufacturer = URIRef("https://schema.org/manufacturer")
    gtin = URIRef("https://schema.org/gtin")
    availableAtOrFrom = URIRef("https://schema.org/availableAtOrFrom")
    MerchantReturnEnumeration = URIRef("https://schema.org/MerchantReturnEnumeration")
    VirtualRecordingDigitalSource = URIRef("https://schema.org/VirtualRecordingDigitalSource")
    ReturnLabelCustomerResponsibility = URIRef("https://schema.org/ReturnLabelCustomerResponsibility")
    isUnlabelledFallback = URIRef("https://schema.org/isUnlabelledFallback")
    titleEIDR = URIRef("https://schema.org/titleEIDR")
    itemLocation = URIRef("https://schema.org/itemLocation")
    TennisComplex = URIRef("https://schema.org/TennisComplex")
    inBroadcastLineup = URIRef("https://schema.org/inBroadcastLineup")
    award = URIRef("https://schema.org/award")
    LoanOrCredit = URIRef("https://schema.org/LoanOrCredit")
    backstory = URIRef("https://schema.org/backstory")
    healthPlanDrugTier = URIRef("https://schema.org/healthPlanDrugTier")
    honorificSuffix = URIRef("https://schema.org/honorificSuffix")
    uploadDate = URIRef("https://schema.org/uploadDate")
    MobileApplication = URIRef("https://schema.org/MobileApplication")
    termsOfService = URIRef("https://schema.org/termsOfService")
    seatingCapacity = URIRef("https://schema.org/seatingCapacity")
    WearAction = URIRef("https://schema.org/WearAction")
    PreventionHealthAspect = URIRef("https://schema.org/PreventionHealthAspect")
    MedicalContraindication = URIRef("https://schema.org/MedicalContraindication")
    AskPublicNewsArticle = URIRef("https://schema.org/AskPublicNewsArticle")
    House = URIRef("https://schema.org/House")
    ProfessionalService = URIRef("https://schema.org/ProfessionalService")
    ShortStory = URIRef("https://schema.org/ShortStory")
    albumReleaseType = URIRef("https://schema.org/albumReleaseType")
    legislationLegalValue = URIRef("https://schema.org/legislationLegalValue")
    tool = URIRef("https://schema.org/tool")
    fromLocation = URIRef("https://schema.org/fromLocation")
    EngineSpecification = URIRef("https://schema.org/EngineSpecification")
    BroadcastService = URIRef("https://schema.org/BroadcastService")
    educationRequirements = URIRef("https://schema.org/educationRequirements")
    typicalAgeRange = URIRef("https://schema.org/typicalAgeRange")
    checkoutPageURLTemplate = URIRef("https://schema.org/checkoutPageURLTemplate")
    seatingType = URIRef("https://schema.org/seatingType")
    Resort = URIRef("https://schema.org/Resort")
    category = URIRef("https://schema.org/category")
    sha256 = URIRef("https://schema.org/sha256")
    codeSampleType = URIRef("https://schema.org/codeSampleType")
    availableDeliveryMethod = URIRef("https://schema.org/availableDeliveryMethod")
    status = URIRef("https://schema.org/status")
    ActiveActionStatus = URIRef("https://schema.org/ActiveActionStatus")
    employmentUnit = URIRef("https://schema.org/employmentUnit")
    cvdNumC19MechVentPats = URIRef("https://schema.org/cvdNumC19MechVentPats")
    typicalTest = URIRef("https://schema.org/typicalTest")
    highPrice = URIRef("https://schema.org/highPrice")
    acrissCode = URIRef("https://schema.org/acrissCode")
    observationDate = URIRef("https://schema.org/observationDate")
    menu = URIRef("https://schema.org/menu")
    HealthInsurancePlan = URIRef("https://schema.org/HealthInsurancePlan")
    trainNumber = URIRef("https://schema.org/trainNumber")
    contraindication = URIRef("https://schema.org/contraindication")
    UserCheckins = URIRef("https://schema.org/UserCheckins")
    hasMenu = URIRef("https://schema.org/hasMenu")
    applicationCategory = URIRef("https://schema.org/applicationCategory")
    Dentist = URIRef("https://schema.org/Dentist")
    netWorth = URIRef("https://schema.org/netWorth")
    reviewedBy = URIRef("https://schema.org/reviewedBy")
    priceCurrency = URIRef("https://schema.org/priceCurrency")
    diseaseSpreadStatistics = URIRef("https://schema.org/diseaseSpreadStatistics")
    TheaterGroup = URIRef("https://schema.org/TheaterGroup")
    shippingLabel = URIRef("https://schema.org/shippingLabel")
    jobLocation = URIRef("https://schema.org/jobLocation")
    UserDownloads = URIRef("https://schema.org/UserDownloads")
    Courthouse = URIRef("https://schema.org/Courthouse")
    mediaItemAppearance = URIRef("https://schema.org/mediaItemAppearance")
    cvdNumVentUse = URIRef("https://schema.org/cvdNumVentUse")
    hasPart = URIRef("https://schema.org/hasPart")
    bookEdition = URIRef("https://schema.org/bookEdition")
    Recommendation = URIRef("https://schema.org/Recommendation")
    departureTime = URIRef("https://schema.org/departureTime")
    Podiatric = URIRef("https://schema.org/Podiatric")
    colorist = URIRef("https://schema.org/colorist")
    successorOf = URIRef("https://schema.org/successorOf")
    dosageForm = URIRef("https://schema.org/dosageForm")
    partOfTrip = URIRef("https://schema.org/partOfTrip")
    exampleOfWork = URIRef("https://schema.org/exampleOfWork")
    employmentType = URIRef("https://schema.org/employmentType")
    sourceOrganization = URIRef("https://schema.org/sourceOrganization")
    LeisureTimeActivity = URIRef("https://schema.org/LeisureTimeActivity")
    SearchRescueOrganization = URIRef("https://schema.org/SearchRescueOrganization")
    category = URIRef("https://schema.org/category")
    pagination = URIRef("https://schema.org/pagination")
    sport = URIRef("https://schema.org/sport")
    documentation = URIRef("https://schema.org/documentation")
    subEvents = URIRef("https://schema.org/subEvents")
    branchOf = URIRef("https://schema.org/branchOf")
    TieAction = URIRef("https://schema.org/TieAction")
    pattern = URIRef("https://schema.org/pattern")
    ExerciseAction = URIRef("https://schema.org/ExerciseAction")
    taxonomicRange = URIRef("https://schema.org/taxonomicRange")
    Embassy = URIRef("https://schema.org/Embassy")
    version = URIRef("https://schema.org/version")
    SeeDoctorHealthAspect = URIRef("https://schema.org/SeeDoctorHealthAspect")
    currentExchangeRate = URIRef("https://schema.org/currentExchangeRate")
    knowsAbout = URIRef("https://schema.org/knowsAbout")
    MixtapeAlbum = URIRef("https://schema.org/MixtapeAlbum")
    spokenByCharacter = URIRef("https://schema.org/spokenByCharacter")
    language = URIRef("https://schema.org/language")
    ItemPage = URIRef("https://schema.org/ItemPage")
    readonlyValue = URIRef("https://schema.org/readonlyValue")
    recipient = URIRef("https://schema.org/recipient")
    SatireOrParodyContent = URIRef("https://schema.org/SatireOrParodyContent")
    transFatContent = URIRef("https://schema.org/transFatContent")
    availableDeliveryMethod = URIRef("https://schema.org/availableDeliveryMethod")
    MedicalAudience = URIRef("https://schema.org/MedicalAudience")
    VideoObject = URIRef("https://schema.org/VideoObject")
    MedicalGuidelineRecommendation = URIRef("https://schema.org/MedicalGuidelineRecommendation")
    MusicVideoObject = URIRef("https://schema.org/MusicVideoObject")
    broadcastSignalModulation = URIRef("https://schema.org/broadcastSignalModulation")
    vatID = URIRef("https://schema.org/vatID")
    DDxElement = URIRef("https://schema.org/DDxElement")
    causeOf = URIRef("https://schema.org/causeOf")
    gettingTestedInfo = URIRef("https://schema.org/gettingTestedInfo")
    PhysicalActivityCategory = URIRef("https://schema.org/PhysicalActivityCategory")
    studyLocation = URIRef("https://schema.org/studyLocation")
    Recommendation = URIRef("https://schema.org/Recommendation")
    Report = URIRef("https://schema.org/Report")
    founder = URIRef("https://schema.org/founder")
    MedicalTrial = URIRef("https://schema.org/MedicalTrial")
    workPerformed = URIRef("https://schema.org/workPerformed")
    medicineSystem = URIRef("https://schema.org/medicineSystem")
    Observational = URIRef("https://schema.org/Observational")
    activityFrequency = URIRef("https://schema.org/activityFrequency")
    DigitalFormat = URIRef("https://schema.org/DigitalFormat")
    hasDefinedTerm = URIRef("https://schema.org/hasDefinedTerm")
    MedicalSignOrSymptom = URIRef("https://schema.org/MedicalSignOrSymptom")
    PregnancyHealthAspect = URIRef("https://schema.org/PregnancyHealthAspect")
    chemicalComposition = URIRef("https://schema.org/chemicalComposition")
    scheduleTimezone = URIRef("https://schema.org/scheduleTimezone")
    ReturnLabelCustomerResponsibility = URIRef("https://schema.org/ReturnLabelCustomerResponsibility")
    modelDate = URIRef("https://schema.org/modelDate")
    duration = URIRef("https://schema.org/duration")
    Action = URIRef("https://schema.org/Action")
    productSupported = URIRef("https://schema.org/productSupported")
    Nonprofit501a = URIRef("https://schema.org/Nonprofit501a")
    returnMethod = URIRef("https://schema.org/returnMethod")
    HealthPlanCostSharingSpecification = URIRef("https://schema.org/HealthPlanCostSharingSpecification")
    honorificPrefix = URIRef("https://schema.org/honorificPrefix")
    InStoreOnly = URIRef("https://schema.org/InStoreOnly")
    hasHealthAspect = URIRef("https://schema.org/hasHealthAspect")
    status = URIRef("https://schema.org/status")
    TextObject = URIRef("https://schema.org/TextObject")
    participant = URIRef("https://schema.org/participant")
    hasMenuSection = URIRef("https://schema.org/hasMenuSection")
    signOrSymptom = URIRef("https://schema.org/signOrSymptom")
    Recipe = URIRef("https://schema.org/Recipe")
    MedicalImagingTechnique = URIRef("https://schema.org/MedicalImagingTechnique")
    diversityStaffingReport = URIRef("https://schema.org/diversityStaffingReport")
    entertainmentBusiness = URIRef("https://schema.org/entertainmentBusiness")
    geoOverlaps = URIRef("https://schema.org/geoOverlaps")
    question = URIRef("https://schema.org/question")
    MedicalTrialDesign = URIRef("https://schema.org/MedicalTrialDesign")
    endOffset = URIRef("https://schema.org/endOffset")
    CheckAction = URIRef("https://schema.org/CheckAction")
    DepartmentStore = URIRef("https://schema.org/DepartmentStore")
    sender = URIRef("https://schema.org/sender")
    Dataset = URIRef("https://schema.org/Dataset")
    PropertyValueSpecification = URIRef("https://schema.org/PropertyValueSpecification")
    referencesOrder = URIRef("https://schema.org/referencesOrder")
    touristType = URIRef("https://schema.org/touristType")
    benefitsSummaryUrl = URIRef("https://schema.org/benefitsSummaryUrl")
    associatedPathophysiology = URIRef("https://schema.org/associatedPathophysiology")
    Nonprofit501d = URIRef("https://schema.org/Nonprofit501d")
    cvdNumTotBeds = URIRef("https://schema.org/cvdNumTotBeds")
    knowsLanguage = URIRef("https://schema.org/knowsLanguage")
    gamePlatform = URIRef("https://schema.org/gamePlatform")
    WearableSizeSystemAU = URIRef("https://schema.org/WearableSizeSystemAU")
    permissionType = URIRef("https://schema.org/permissionType")
    error = URIRef("https://schema.org/error")
    owns = URIRef("https://schema.org/owns")
    sharedContent = URIRef("https://schema.org/sharedContent")
    nerve = URIRef("https://schema.org/nerve")
    cvdNumBedsOcc = URIRef("https://schema.org/cvdNumBedsOcc")
    paymentAccepted = URIRef("https://schema.org/paymentAccepted")
    numberOfPreviousOwners = URIRef("https://schema.org/numberOfPreviousOwners")
    identifier = URIRef("https://schema.org/identifier")
    PaymentAutomaticallyApplied = URIRef("https://schema.org/PaymentAutomaticallyApplied")
    previousStartDate = URIRef("https://schema.org/previousStartDate")
    InternationalTrial = URIRef("https://schema.org/InternationalTrial")
    VirtualLocation = URIRef("https://schema.org/VirtualLocation")
    Conversation = URIRef("https://schema.org/Conversation")
    expectedPrognosis = URIRef("https://schema.org/expectedPrognosis")
    diversityStaffingReport = URIRef("https://schema.org/diversityStaffingReport")
    sku = URIRef("https://schema.org/sku")
    isLiveBroadcast = URIRef("https://schema.org/isLiveBroadcast")
    studySubject = URIRef("https://schema.org/studySubject")
    applicationSubCategory = URIRef("https://schema.org/applicationSubCategory")
    isResizable = URIRef("https://schema.org/isResizable")
    FoodService = URIRef("https://schema.org/FoodService")
    checkoutTime = URIRef("https://schema.org/checkoutTime")
    issueNumber = URIRef("https://schema.org/issueNumber")
    workPresented = URIRef("https://schema.org/workPresented")
    validIn = URIRef("https://schema.org/validIn")
    CreativeWorkSeries = URIRef("https://schema.org/CreativeWorkSeries")
    EducationalOrganization = URIRef("https://schema.org/EducationalOrganization")
    URL = URIRef("https://schema.org/URL")
    appearance = URIRef("https://schema.org/appearance")
    review = URIRef("https://schema.org/review")
    overdosage = URIRef("https://schema.org/overdosage")
    MerchantReturnNotPermitted = URIRef("https://schema.org/MerchantReturnNotPermitted")
    ratingCount = URIRef("https://schema.org/ratingCount")
    geoOverlaps = URIRef("https://schema.org/geoOverlaps")
    PrimaryCare = URIRef("https://schema.org/PrimaryCare")
    serviceSmsNumber = URIRef("https://schema.org/serviceSmsNumber")
    cvdNumC19Died = URIRef("https://schema.org/cvdNumC19Died")
    mediaItemAppearance = URIRef("https://schema.org/mediaItemAppearance")
    timeToComplete = URIRef("https://schema.org/timeToComplete")
    numberOfAccommodationUnits = URIRef("https://schema.org/numberOfAccommodationUnits")
    WearableMeasurementTypeEnumeration = URIRef("https://schema.org/WearableMeasurementTypeEnumeration")
    unsaturatedFatContent = URIRef("https://schema.org/unsaturatedFatContent")
    runtime = URIRef("https://schema.org/runtime")
    occupationalCategory = URIRef("https://schema.org/occupationalCategory")
    amount = URIRef("https://schema.org/amount")
    molecularFormula = URIRef("https://schema.org/molecularFormula")
    House = URIRef("https://schema.org/House")
    MonetaryAmountDistribution = URIRef("https://schema.org/MonetaryAmountDistribution")
    MusicRelease = URIRef("https://schema.org/MusicRelease")
    contentReferenceTime = URIRef("https://schema.org/contentReferenceTime")
    Patient = URIRef("https://schema.org/Patient")
    GolfCourse = URIRef("https://schema.org/GolfCourse")
    interpretedAsClaim = URIRef("https://schema.org/interpretedAsClaim")
    GovernmentBenefitsType = URIRef("https://schema.org/GovernmentBenefitsType")
    monthsOfExperience = URIRef("https://schema.org/monthsOfExperience")
    tocContinuation = URIRef("https://schema.org/tocContinuation")
    PathologyTest = URIRef("https://schema.org/PathologyTest")
    MedicalEvidenceLevel = URIRef("https://schema.org/MedicalEvidenceLevel")
    LymphaticVessel = URIRef("https://schema.org/LymphaticVessel")
    transmissionMethod = URIRef("https://schema.org/transmissionMethod")
    Dataset = URIRef("https://schema.org/Dataset")
    intensity = URIRef("https://schema.org/intensity")
    geoOverlaps = URIRef("https://schema.org/geoOverlaps")
    broadcastAffiliateOf = URIRef("https://schema.org/broadcastAffiliateOf")
    copyrightYear = URIRef("https://schema.org/copyrightYear")
    servesCuisine = URIRef("https://schema.org/servesCuisine")
    vendor = URIRef("https://schema.org/vendor")
    parents = URIRef("https://schema.org/parents")
    email = URIRef("https://schema.org/email")
    exercisePlan = URIRef("https://schema.org/exercisePlan")
    ContagiousnessHealthAspect = URIRef("https://schema.org/ContagiousnessHealthAspect")
    DemoGameAvailability = URIRef("https://schema.org/DemoGameAvailability")
    statType = URIRef("https://schema.org/statType")
    PartiallyInForce = URIRef("https://schema.org/PartiallyInForce")
    MedicalTherapy = URIRef("https://schema.org/MedicalTherapy")
    HomeGoodsStore = URIRef("https://schema.org/HomeGoodsStore")
    MedicalIntangible = URIRef("https://schema.org/MedicalIntangible")
    funder = URIRef("https://schema.org/funder")
    hasDriveThroughService = URIRef("https://schema.org/hasDriveThroughService")
    educationalProgramMode = URIRef("https://schema.org/educationalProgramMode")
    isVariantOf = URIRef("https://schema.org/isVariantOf")
    NonprofitSBBI = URIRef("https://schema.org/NonprofitSBBI")
    Organization = URIRef("https://schema.org/Organization")
    Nonprofit501c20 = URIRef("https://schema.org/Nonprofit501c20")
    CreativeWorkSeason = URIRef("https://schema.org/CreativeWorkSeason")
    greater = URIRef("https://schema.org/greater")
    repeatFrequency = URIRef("https://schema.org/repeatFrequency")
    HealthAndBeautyBusiness = URIRef("https://schema.org/HealthAndBeautyBusiness")
    GameAvailabilityEnumeration = URIRef("https://schema.org/GameAvailabilityEnumeration")
    legislationConsolidates = URIRef("https://schema.org/legislationConsolidates")
    merchantReturnDays = URIRef("https://schema.org/merchantReturnDays")
    RadioChannel = URIRef("https://schema.org/RadioChannel")
    seatNumber = URIRef("https://schema.org/seatNumber")
    RestrictedDiet = URIRef("https://schema.org/RestrictedDiet")
    CarUsageType = URIRef("https://schema.org/CarUsageType")
    endDate = URIRef("https://schema.org/endDate")
    byDay = URIRef("https://schema.org/byDay")
    relatedTherapy = URIRef("https://schema.org/relatedTherapy")
    EventStatusType = URIRef("https://schema.org/EventStatusType")
    containsPlace = URIRef("https://schema.org/containsPlace")
    SideEffectsHealthAspect = URIRef("https://schema.org/SideEffectsHealthAspect")
    duns = URIRef("https://schema.org/duns")
    sha256 = URIRef("https://schema.org/sha256")
    thumbnail = URIRef("https://schema.org/thumbnail")
    hasPOS = URIRef("https://schema.org/hasPOS")
    Movie = URIRef("https://schema.org/Movie")
    Monday = URIRef("https://schema.org/Monday")
    dateModified = URIRef("https://schema.org/dateModified")
    vatID = URIRef("https://schema.org/vatID")
    RefundTypeEnumeration = URIRef("https://schema.org/RefundTypeEnumeration")
    accessMode = URIRef("https://schema.org/accessMode")
    subTrip = URIRef("https://schema.org/subTrip")
    TaxiService = URIRef("https://schema.org/TaxiService")
    prescriptionStatus = URIRef("https://schema.org/prescriptionStatus")
    measurementTechnique = URIRef("https://schema.org/measurementTechnique")
    servicePostalAddress = URIRef("https://schema.org/servicePostalAddress")
    Bakery = URIRef("https://schema.org/Bakery")
    Dentistry = URIRef("https://schema.org/Dentistry")
    scheduleTimezone = URIRef("https://schema.org/scheduleTimezone")
    archiveHeld = URIRef("https://schema.org/archiveHeld")
    ImageGallery = URIRef("https://schema.org/ImageGallery")
    referencesOrder = URIRef("https://schema.org/referencesOrder")
    KosherDiet = URIRef("https://schema.org/KosherDiet")
    ReturnLabelDownloadAndPrint = URIRef("https://schema.org/ReturnLabelDownloadAndPrint")
    MRI = URIRef("https://schema.org/MRI")
    AutoWash = URIRef("https://schema.org/AutoWash")
    diversityStaffingReport = URIRef("https://schema.org/diversityStaffingReport")
    boardingPolicy = URIRef("https://schema.org/boardingPolicy")
    BankAccount = URIRef("https://schema.org/BankAccount")
    track = URIRef("https://schema.org/track")
    Genitourinary = URIRef("https://schema.org/Genitourinary")
    programPrerequisites = URIRef("https://schema.org/programPrerequisites")
    occupationLocation = URIRef("https://schema.org/occupationLocation")
    healthPlanCopay = URIRef("https://schema.org/healthPlanCopay")
    validFrom = URIRef("https://schema.org/validFrom")
    creator = URIRef("https://schema.org/creator")
    Zoo = URIRef("https://schema.org/Zoo")
    Dermatology = URIRef("https://schema.org/Dermatology")
    archiveHeld = URIRef("https://schema.org/archiveHeld")
    Recipe = URIRef("https://schema.org/Recipe")
    producer = URIRef("https://schema.org/producer")
    applicantLocationRequirements = URIRef("https://schema.org/applicantLocationRequirements")
    WantAction = URIRef("https://schema.org/WantAction")
    containsSeason = URIRef("https://schema.org/containsSeason")
    error = URIRef("https://schema.org/error")
    caption = URIRef("https://schema.org/caption")
    numberOfAccommodationUnits = URIRef("https://schema.org/numberOfAccommodationUnits")
    volumeNumber = URIRef("https://schema.org/volumeNumber")
    bookingAgent = URIRef("https://schema.org/bookingAgent")
    letterer = URIRef("https://schema.org/letterer")
    amount = URIRef("https://schema.org/amount")
    UnclassifiedAdultConsideration = URIRef("https://schema.org/UnclassifiedAdultConsideration")
    knownVehicleDamages = URIRef("https://schema.org/knownVehicleDamages")
    pregnancyWarning = URIRef("https://schema.org/pregnancyWarning")
    Hostel = URIRef("https://schema.org/Hostel")
    diet = URIRef("https://schema.org/diet")
    yearsInOperation = URIRef("https://schema.org/yearsInOperation")
    isPartOf = URIRef("https://schema.org/isPartOf")
    depth = URIRef("https://schema.org/depth")
    HyperToc = URIRef("https://schema.org/HyperToc")
    pageEnd = URIRef("https://schema.org/pageEnd")
    menuAddOn = URIRef("https://schema.org/menuAddOn")
    LaserDiscFormat = URIRef("https://schema.org/LaserDiscFormat")
    PharmacySpecialty = URIRef("https://schema.org/PharmacySpecialty")
    Completed = URIRef("https://schema.org/Completed")
    MediaReviewItem = URIRef("https://schema.org/MediaReviewItem")
    deliveryLeadTime = URIRef("https://schema.org/deliveryLeadTime")
    honorificPrefix = URIRef("https://schema.org/honorificPrefix")
    postOfficeBoxNumber = URIRef("https://schema.org/postOfficeBoxNumber")
    Electrician = URIRef("https://schema.org/Electrician")
    PhysiciansOffice = URIRef("https://schema.org/PhysiciansOffice")
    numberOfRooms = URIRef("https://schema.org/numberOfRooms")
    genre = URIRef("https://schema.org/genre")
    administrationRoute = URIRef("https://schema.org/administrationRoute")
    BikeStore = URIRef("https://schema.org/BikeStore")
    availabilityStarts = URIRef("https://schema.org/availabilityStarts")
    paymentDue = URIRef("https://schema.org/paymentDue")
    trainingSalary = URIRef("https://schema.org/trainingSalary")
    CertificationActive = URIRef("https://schema.org/CertificationActive")
    eligibleQuantity = URIRef("https://schema.org/eligibleQuantity")
    replacer = URIRef("https://schema.org/replacer")
    Joint = URIRef("https://schema.org/Joint")
    OfficeEquipmentStore = URIRef("https://schema.org/OfficeEquipmentStore")
    RightHandDriving = URIRef("https://schema.org/RightHandDriving")
    aggregateRating = URIRef("https://schema.org/aggregateRating")
    AllWheelDriveConfiguration = URIRef("https://schema.org/AllWheelDriveConfiguration")
    sameAs = URIRef("https://schema.org/sameAs")
    DrugLegalStatus = URIRef("https://schema.org/DrugLegalStatus")
    downloadUrl = URIRef("https://schema.org/downloadUrl")
    endOffset = URIRef("https://schema.org/endOffset")
    iswcCode = URIRef("https://schema.org/iswcCode")
    FDAcategoryA = URIRef("https://schema.org/FDAcategoryA")
    numberOfPages = URIRef("https://schema.org/numberOfPages")
    stageAsNumber = URIRef("https://schema.org/stageAsNumber")
    healthPlanPharmacyCategory = URIRef("https://schema.org/healthPlanPharmacyCategory")
    Muscle = URIRef("https://schema.org/Muscle")
    City = URIRef("https://schema.org/City")
    inLanguage = URIRef("https://schema.org/inLanguage")
    OrderPaymentDue = URIRef("https://schema.org/OrderPaymentDue")
    upvoteCount = URIRef("https://schema.org/upvoteCount")
    LimitedByGuaranteeCharity = URIRef("https://schema.org/LimitedByGuaranteeCharity")
    asin = URIRef("https://schema.org/asin")
    greaterOrEqual = URIRef("https://schema.org/greaterOrEqual")
    xpath = URIRef("https://schema.org/xpath")
    creativeWorkStatus = URIRef("https://schema.org/creativeWorkStatus")
    healthPlanDrugOption = URIRef("https://schema.org/healthPlanDrugOption")
    Observational = URIRef("https://schema.org/Observational")
    WebContent = URIRef("https://schema.org/WebContent")
    spokenByCharacter = URIRef("https://schema.org/spokenByCharacter")
    BodyMeasurementHand = URIRef("https://schema.org/BodyMeasurementHand")
    version = URIRef("https://schema.org/version")
    billingStart = URIRef("https://schema.org/billingStart")
    Synagogue = URIRef("https://schema.org/Synagogue")
    MusicStore = URIRef("https://schema.org/MusicStore")
    query = URIRef("https://schema.org/query")
    hasMenuItem = URIRef("https://schema.org/hasMenuItem")
    BusStation = URIRef("https://schema.org/BusStation")
    scheduledTime = URIRef("https://schema.org/scheduledTime")
    paymentStatus = URIRef("https://schema.org/paymentStatus")
    RealEstateAgent = URIRef("https://schema.org/RealEstateAgent")
    musicCompositionForm = URIRef("https://schema.org/musicCompositionForm")
    menu = URIRef("https://schema.org/menu")
    requiredCollateral = URIRef("https://schema.org/requiredCollateral")
    isBasedOnUrl = URIRef("https://schema.org/isBasedOnUrl")
    encodesCreativeWork = URIRef("https://schema.org/encodesCreativeWork")
    Wholesale = URIRef("https://schema.org/Wholesale")
    enginePower = URIRef("https://schema.org/enginePower")
    prescriptionStatus = URIRef("https://schema.org/prescriptionStatus")
    teaches = URIRef("https://schema.org/teaches")
    renegotiableLoan = URIRef("https://schema.org/renegotiableLoan")
    rxcui = URIRef("https://schema.org/rxcui")
    Church = URIRef("https://schema.org/Church")
    width = URIRef("https://schema.org/width")
    conditionsOfAccess = URIRef("https://schema.org/conditionsOfAccess")
    TieAction = URIRef("https://schema.org/TieAction")
    assemblyVersion = URIRef("https://schema.org/assemblyVersion")
    distinguishingSign = URIRef("https://schema.org/distinguishingSign")
    isEncodedByBioChemEntity = URIRef("https://schema.org/isEncodedByBioChemEntity")
    FDAcategoryB = URIRef("https://schema.org/FDAcategoryB")
    gameAvailabilityType = URIRef("https://schema.org/gameAvailabilityType")
    MusicEvent = URIRef("https://schema.org/MusicEvent")
    CDFormat = URIRef("https://schema.org/CDFormat")
    Car = URIRef("https://schema.org/Car")
    foundingDate = URIRef("https://schema.org/foundingDate")
    IPTCDigitalSourceEnumeration = URIRef("https://schema.org/IPTCDigitalSourceEnumeration")
    LinkRole = URIRef("https://schema.org/LinkRole")
    Flight = URIRef("https://schema.org/Flight")
    releaseNotes = URIRef("https://schema.org/releaseNotes")
    AuthorizeAction = URIRef("https://schema.org/AuthorizeAction")
    suggestedGender = URIRef("https://schema.org/suggestedGender")
    eligibilityToWorkRequirement = URIRef("https://schema.org/eligibilityToWorkRequirement")
    hostingOrganization = URIRef("https://schema.org/hostingOrganization")
    availableOnDevice = URIRef("https://schema.org/availableOnDevice")
    measurementDenominator = URIRef("https://schema.org/measurementDenominator")
    healthPlanCopay = URIRef("https://schema.org/healthPlanCopay")
    availableChannel = URIRef("https://schema.org/availableChannel")
    letterer = URIRef("https://schema.org/letterer")
    readonlyValue = URIRef("https://schema.org/readonlyValue")
    OrderPickupAvailable = URIRef("https://schema.org/OrderPickupAvailable")
    bodyLocation = URIRef("https://schema.org/bodyLocation")
    MusicAlbumProductionType = URIRef("https://schema.org/MusicAlbumProductionType")
    overdosage = URIRef("https://schema.org/overdosage")
    commentTime = URIRef("https://schema.org/commentTime")
    maxValue = URIRef("https://schema.org/maxValue")
    SportsEvent = URIRef("https://schema.org/SportsEvent")
    cvdNumICUBedsOcc = URIRef("https://schema.org/cvdNumICUBedsOcc")
    CrossSectional = URIRef("https://schema.org/CrossSectional")
    thumbnail = URIRef("https://schema.org/thumbnail")
    timeRequired = URIRef("https://schema.org/timeRequired")
    healthCondition = URIRef("https://schema.org/healthCondition")
    Float = URIRef("https://schema.org/Float")
    priceComponentType = URIRef("https://schema.org/priceComponentType")
    RefundTypeEnumeration = URIRef("https://schema.org/RefundTypeEnumeration")
    Retail = URIRef("https://schema.org/Retail")
    seatingType = URIRef("https://schema.org/seatingType")
    VinylFormat = URIRef("https://schema.org/VinylFormat")
    Therapeutic = URIRef("https://schema.org/Therapeutic")
    activeIngredient = URIRef("https://schema.org/activeIngredient")
    distribution = URIRef("https://schema.org/distribution")
    commentTime = URIRef("https://schema.org/commentTime")
    postOfficeBoxNumber = URIRef("https://schema.org/postOfficeBoxNumber")
    nationality = URIRef("https://schema.org/nationality")
    returnMethod = URIRef("https://schema.org/returnMethod")
    IndividualProduct = URIRef("https://schema.org/IndividualProduct")
    dayOfWeek = URIRef("https://schema.org/dayOfWeek")
    TVSeries = URIRef("https://schema.org/TVSeries")
    CompilationAlbum = URIRef("https://schema.org/CompilationAlbum")
    athlete = URIRef("https://schema.org/athlete")
    Protozoa = URIRef("https://schema.org/Protozoa")
    OrganizeAction = URIRef("https://schema.org/OrganizeAction")
    VideoGame = URIRef("https://schema.org/VideoGame")
    OfflinePermanently = URIRef("https://schema.org/OfflinePermanently")
    birthPlace = URIRef("https://schema.org/birthPlace")
    arrivalBoatTerminal = URIRef("https://schema.org/arrivalBoatTerminal")
    tongueWeight = URIRef("https://schema.org/tongueWeight")
    expressedIn = URIRef("https://schema.org/expressedIn")
    member = URIRef("https://schema.org/member")
    drugClass = URIRef("https://schema.org/drugClass")
    publicAccess = URIRef("https://schema.org/publicAccess")
    parentTaxon = URIRef("https://schema.org/parentTaxon")
    Dermatologic = URIRef("https://schema.org/Dermatologic")
    assembly = URIRef("https://schema.org/assembly")
    specialOpeningHoursSpecification = URIRef("https://schema.org/specialOpeningHoursSpecification")
    gameServer = URIRef("https://schema.org/gameServer")
    RentAction = URIRef("https://schema.org/RentAction")
    isAccessibleForFree = URIRef("https://schema.org/isAccessibleForFree")
    instructor = URIRef("https://schema.org/instructor")
    partOfSystem = URIRef("https://schema.org/partOfSystem")
    correctionsPolicy = URIRef("https://schema.org/correctionsPolicy")
    MonetaryAmount = URIRef("https://schema.org/MonetaryAmount")
    LocalBusiness = URIRef("https://schema.org/LocalBusiness")
    HardwareStore = URIRef("https://schema.org/HardwareStore")
    clincalPharmacology = URIRef("https://schema.org/clincalPharmacology")
    ParkingMap = URIRef("https://schema.org/ParkingMap")
    Hostel = URIRef("https://schema.org/Hostel")
    fundedItem = URIRef("https://schema.org/fundedItem")
    byMonth = URIRef("https://schema.org/byMonth")
    AllocateAction = URIRef("https://schema.org/AllocateAction")
    MedicalAudienceType = URIRef("https://schema.org/MedicalAudienceType")
    agent = URIRef("https://schema.org/agent")
    supply = URIRef("https://schema.org/supply")
    ItemListOrderDescending = URIRef("https://schema.org/ItemListOrderDescending")
    shippingSettingsLink = URIRef("https://schema.org/shippingSettingsLink")
    isUnlabelledFallback = URIRef("https://schema.org/isUnlabelledFallback")
    ComicSeries = URIRef("https://schema.org/ComicSeries")
    normalRange = URIRef("https://schema.org/normalRange")
    timeOfDay = URIRef("https://schema.org/timeOfDay")
    OnlineEventAttendanceMode = URIRef("https://schema.org/OnlineEventAttendanceMode")
    PriceComponentTypeEnumeration = URIRef("https://schema.org/PriceComponentTypeEnumeration")
    VeganDiet = URIRef("https://schema.org/VeganDiet")
    Nonprofit501q = URIRef("https://schema.org/Nonprofit501q")
    BedAndBreakfast = URIRef("https://schema.org/BedAndBreakfast")
    Legislation = URIRef("https://schema.org/Legislation")
    issn = URIRef("https://schema.org/issn")
    EducationalOccupationalCredential = URIRef("https://schema.org/EducationalOccupationalCredential")
    FoodEstablishmentReservation = URIRef("https://schema.org/FoodEstablishmentReservation")
    Optometric = URIRef("https://schema.org/Optometric")
    isicV4 = URIRef("https://schema.org/isicV4")
    employmentUnit = URIRef("https://schema.org/employmentUnit")
    softwareHelp = URIRef("https://schema.org/softwareHelp")
    subtitleLanguage = URIRef("https://schema.org/subtitleLanguage")
    costPerUnit = URIRef("https://schema.org/costPerUnit")
    SizeSystemEnumeration = URIRef("https://schema.org/SizeSystemEnumeration")
    PalliativeProcedure = URIRef("https://schema.org/PalliativeProcedure")
    Diet = URIRef("https://schema.org/Diet")
    significantLink = URIRef("https://schema.org/significantLink")
    recordingOf = URIRef("https://schema.org/recordingOf")
    CertificationActive = URIRef("https://schema.org/CertificationActive")
    colleagues = URIRef("https://schema.org/colleagues")
    BusinessSupport = URIRef("https://schema.org/BusinessSupport")
    events = URIRef("https://schema.org/events")
    subStageSuffix = URIRef("https://schema.org/subStageSuffix")
    Accommodation = URIRef("https://schema.org/Accommodation")
    BookmarkAction = URIRef("https://schema.org/BookmarkAction")
    Oncologic = URIRef("https://schema.org/Oncologic")
    dayOfWeek = URIRef("https://schema.org/dayOfWeek")
    TVClip = URIRef("https://schema.org/TVClip")
    colorist = URIRef("https://schema.org/colorist")
    domainIncludes = URIRef("https://schema.org/domainIncludes")
    encodings = URIRef("https://schema.org/encodings")
    maintainer = URIRef("https://schema.org/maintainer")
    partOfTVSeries = URIRef("https://schema.org/partOfTVSeries")
    seatRow = URIRef("https://schema.org/seatRow")
    ResumeAction = URIRef("https://schema.org/ResumeAction")
    orderItemStatus = URIRef("https://schema.org/orderItemStatus")
    SoundtrackAlbum = URIRef("https://schema.org/SoundtrackAlbum")
    MonetaryAmount = URIRef("https://schema.org/MonetaryAmount")
    recipient = URIRef("https://schema.org/recipient")
    ratingValue = URIRef("https://schema.org/ratingValue")
    connectedTo = URIRef("https://schema.org/connectedTo")
    numberOfPreviousOwners = URIRef("https://schema.org/numberOfPreviousOwners")
    Offer = URIRef("https://schema.org/Offer")
    tool = URIRef("https://schema.org/tool")
    interpretedAsClaim = URIRef("https://schema.org/interpretedAsClaim")
    memberOf = URIRef("https://schema.org/memberOf")
    about = URIRef("https://schema.org/about")
    observationAbout = URIRef("https://schema.org/observationAbout")
    supersededBy = URIRef("https://schema.org/supersededBy")
    domiciledMortgage = URIRef("https://schema.org/domiciledMortgage")
    connectedTo = URIRef("https://schema.org/connectedTo")
    restockingFee = URIRef("https://schema.org/restockingFee")
    MeasurementMethodEnum = URIRef("https://schema.org/MeasurementMethodEnum")
    physicalRequirement = URIRef("https://schema.org/physicalRequirement")
    siblings = URIRef("https://schema.org/siblings")
    announcementLocation = URIRef("https://schema.org/announcementLocation")
    branchOf = URIRef("https://schema.org/branchOf")
    ReserveAction = URIRef("https://schema.org/ReserveAction")
    trailer = URIRef("https://schema.org/trailer")
    NightClub = URIRef("https://schema.org/NightClub")
    interpretedAsClaim = URIRef("https://schema.org/interpretedAsClaim")
    currency = URIRef("https://schema.org/currency")
    postalCodeBegin = URIRef("https://schema.org/postalCodeBegin")
    validFrom = URIRef("https://schema.org/validFrom")
    costCategory = URIRef("https://schema.org/costCategory")
    WorkBasedProgram = URIRef("https://schema.org/WorkBasedProgram")
    SellAction = URIRef("https://schema.org/SellAction")
    itemCondition = URIRef("https://schema.org/itemCondition")
    educationalAlignment = URIRef("https://schema.org/educationalAlignment")
    Float = URIRef("https://schema.org/Float")
    tocEntry = URIRef("https://schema.org/tocEntry")
    validThrough = URIRef("https://schema.org/validThrough")
    provider = URIRef("https://schema.org/provider")
    contentType = URIRef("https://schema.org/contentType")
    Distillery = URIRef("https://schema.org/Distillery")
    guideline = URIRef("https://schema.org/guideline")
    musicReleaseFormat = URIRef("https://schema.org/musicReleaseFormat")
    BasicIncome = URIRef("https://schema.org/BasicIncome")
    recognizedBy = URIRef("https://schema.org/recognizedBy")
    benefitsSummaryUrl = URIRef("https://schema.org/benefitsSummaryUrl")
    logo = URIRef("https://schema.org/logo")
    study = URIRef("https://schema.org/study")
    potentialAction = URIRef("https://schema.org/potentialAction")
    Nonprofit501q = URIRef("https://schema.org/Nonprofit501q")
    isAcceptingNewPatients = URIRef("https://schema.org/isAcceptingNewPatients")
    clinicalPharmacology = URIRef("https://schema.org/clinicalPharmacology")
    sibling = URIRef("https://schema.org/sibling")
    HowToTool = URIRef("https://schema.org/HowToTool")
    loanMortgageMandateAmount = URIRef("https://schema.org/loanMortgageMandateAmount")
    issuedBy = URIRef("https://schema.org/issuedBy")
    dateDeleted = URIRef("https://schema.org/dateDeleted")
    engineDisplacement = URIRef("https://schema.org/engineDisplacement")
    totalTime = URIRef("https://schema.org/totalTime")
    RadioBroadcastService = URIRef("https://schema.org/RadioBroadcastService")
    FAQPage = URIRef("https://schema.org/FAQPage")
    ScreeningHealthAspect = URIRef("https://schema.org/ScreeningHealthAspect")
    netWorth = URIRef("https://schema.org/netWorth")
    dissolutionDate = URIRef("https://schema.org/dissolutionDate")
    afterMedia = URIRef("https://schema.org/afterMedia")
    CohortStudy = URIRef("https://schema.org/CohortStudy")
    preparation = URIRef("https://schema.org/preparation")
    DDxElement = URIRef("https://schema.org/DDxElement")
    DrugCost = URIRef("https://schema.org/DrugCost")
    targetCollection = URIRef("https://schema.org/targetCollection")
    guidelineSubject = URIRef("https://schema.org/guidelineSubject")
    recordingOf = URIRef("https://schema.org/recordingOf")
    RandomizedTrial = URIRef("https://schema.org/RandomizedTrial")
    quarantineGuidelines = URIRef("https://schema.org/quarantineGuidelines")
    BankAccount = URIRef("https://schema.org/BankAccount")
    includedComposition = URIRef("https://schema.org/includedComposition")
    price = URIRef("https://schema.org/price")
    tocContinuation = URIRef("https://schema.org/tocContinuation")
    eligibleQuantity = URIRef("https://schema.org/eligibleQuantity")
    positiveNotes = URIRef("https://schema.org/positiveNotes")
    reviewedBy = URIRef("https://schema.org/reviewedBy")
    eventAttendanceMode = URIRef("https://schema.org/eventAttendanceMode")
    MoveAction = URIRef("https://schema.org/MoveAction")
    option = URIRef("https://schema.org/option")
    DownloadAction = URIRef("https://schema.org/DownloadAction")
    cvdCollectionDate = URIRef("https://schema.org/cvdCollectionDate")
    bed = URIRef("https://schema.org/bed")
    BeautySalon = URIRef("https://schema.org/BeautySalon")
    size = URIRef("https://schema.org/size")
    Airline = URIRef("https://schema.org/Airline")
    Nonprofit501k = URIRef("https://schema.org/Nonprofit501k")
    actionAccessibilityRequirement = URIRef("https://schema.org/actionAccessibilityRequirement")
    DateTime = URIRef("https://schema.org/DateTime")
    benefits = URIRef("https://schema.org/benefits")
    geoCovers = URIRef("https://schema.org/geoCovers")
    lyrics = URIRef("https://schema.org/lyrics")
    Nonprofit501q = URIRef("https://schema.org/Nonprofit501q")
    endDate = URIRef("https://schema.org/endDate")
    countryOfAssembly = URIRef("https://schema.org/countryOfAssembly")
    dependencies = URIRef("https://schema.org/dependencies")
    BedType = URIRef("https://schema.org/BedType")
    observationPeriod = URIRef("https://schema.org/observationPeriod")
    AnatomicalSystem = URIRef("https://schema.org/AnatomicalSystem")
    SomeProducts = URIRef("https://schema.org/SomeProducts")
    makesOffer = URIRef("https://schema.org/makesOffer")
    DanceGroup = URIRef("https://schema.org/DanceGroup")
    Nonprofit501c9 = URIRef("https://schema.org/Nonprofit501c9")
    Bakery = URIRef("https://schema.org/Bakery")
    countryOfOrigin = URIRef("https://schema.org/countryOfOrigin")
    BloodTest = URIRef("https://schema.org/BloodTest")
    grantee = URIRef("https://schema.org/grantee")
    nationality = URIRef("https://schema.org/nationality")
    legislationConsolidates = URIRef("https://schema.org/legislationConsolidates")
    Syllabus = URIRef("https://schema.org/Syllabus")
    EnergyConsumptionDetails = URIRef("https://schema.org/EnergyConsumptionDetails")
    DeliveryEvent = URIRef("https://schema.org/DeliveryEvent")
    Mass = URIRef("https://schema.org/Mass")
    HealthTopicContent = URIRef("https://schema.org/HealthTopicContent")
    drug = URIRef("https://schema.org/drug")
    WearableMeasurementSleeve = URIRef("https://schema.org/WearableMeasurementSleeve")
    deliveryStatus = URIRef("https://schema.org/deliveryStatus")
    MeasurementTypeEnumeration = URIRef("https://schema.org/MeasurementTypeEnumeration")
    accountMinimumInflow = URIRef("https://schema.org/accountMinimumInflow")
    workTranslation = URIRef("https://schema.org/workTranslation")
    UserCheckins = URIRef("https://schema.org/UserCheckins")
    observationAbout = URIRef("https://schema.org/observationAbout")
    parentOrganization = URIRef("https://schema.org/parentOrganization")
    passengerPriorityStatus = URIRef("https://schema.org/passengerPriorityStatus")
    vehicleConfiguration = URIRef("https://schema.org/vehicleConfiguration")
    validFrom = URIRef("https://schema.org/validFrom")
    RVPark = URIRef("https://schema.org/RVPark")
    gameAvailabilityType = URIRef("https://schema.org/gameAvailabilityType")
    subTrip = URIRef("https://schema.org/subTrip")
    dateCreated = URIRef("https://schema.org/dateCreated")
    WearableSizeGroupJuniors = URIRef("https://schema.org/WearableSizeGroupJuniors")
    encodesBioChemEntity = URIRef("https://schema.org/encodesBioChemEntity")
    maps = URIRef("https://schema.org/maps")
    CrossSectional = URIRef("https://schema.org/CrossSectional")
    acceptedPaymentMethod = URIRef("https://schema.org/acceptedPaymentMethod")
    syllabusSections = URIRef("https://schema.org/syllabusSections")
    discussionUrl = URIRef("https://schema.org/discussionUrl")
    OnlineEventAttendanceMode = URIRef("https://schema.org/OnlineEventAttendanceMode")
    eligibleDuration = URIRef("https://schema.org/eligibleDuration")
    partOfSeries = URIRef("https://schema.org/partOfSeries")
    contentReferenceTime = URIRef("https://schema.org/contentReferenceTime")
    yearsInOperation = URIRef("https://schema.org/yearsInOperation")
    healthPlanMarketingUrl = URIRef("https://schema.org/healthPlanMarketingUrl")
    foundingLocation = URIRef("https://schema.org/foundingLocation")
    PrescriptionOnly = URIRef("https://schema.org/PrescriptionOnly")
    Chapter = URIRef("https://schema.org/Chapter")
    legislationChanges = URIRef("https://schema.org/legislationChanges")
    Date = URIRef("https://schema.org/Date")
    arterialBranch = URIRef("https://schema.org/arterialBranch")
    inPlaylist = URIRef("https://schema.org/inPlaylist")
    fileFormat = URIRef("https://schema.org/fileFormat")
    variableMeasured = URIRef("https://schema.org/variableMeasured")
    HalalDiet = URIRef("https://schema.org/HalalDiet")
    DemoAlbum = URIRef("https://schema.org/DemoAlbum")
    Atlas = URIRef("https://schema.org/Atlas")
    RegisterAction = URIRef("https://schema.org/RegisterAction")
    publishedOn = URIRef("https://schema.org/publishedOn")
    processorRequirements = URIRef("https://schema.org/processorRequirements")
    sku = URIRef("https://schema.org/sku")
    restPeriods = URIRef("https://schema.org/restPeriods")
    alumniOf = URIRef("https://schema.org/alumniOf")
    legislationJurisdiction = URIRef("https://schema.org/legislationJurisdiction")
    StrengthTraining = URIRef("https://schema.org/StrengthTraining")
    newsUpdatesAndGuidelines = URIRef("https://schema.org/newsUpdatesAndGuidelines")
    Person = URIRef("https://schema.org/Person")
    KeepProduct = URIRef("https://schema.org/KeepProduct")
    RentalCarReservation = URIRef("https://schema.org/RentalCarReservation")
    WinAction = URIRef("https://schema.org/WinAction")
    targetPlatform = URIRef("https://schema.org/targetPlatform")
    PerformingGroup = URIRef("https://schema.org/PerformingGroup")
    DataDrivenMediaDigitalSource = URIRef("https://schema.org/DataDrivenMediaDigitalSource")
    associatedClaimReview = URIRef("https://schema.org/associatedClaimReview")
    Collection = URIRef("https://schema.org/Collection")
    healthPlanCopay = URIRef("https://schema.org/healthPlanCopay")
    netWorth = URIRef("https://schema.org/netWorth")
    printEdition = URIRef("https://schema.org/printEdition")
    GasStation = URIRef("https://schema.org/GasStation")
    size = URIRef("https://schema.org/size")
    purchaseDate = URIRef("https://schema.org/purchaseDate")
    Motorcycle = URIRef("https://schema.org/Motorcycle")
    globalLocationNumber = URIRef("https://schema.org/globalLocationNumber")
    isProprietary = URIRef("https://schema.org/isProprietary")
    Nonprofit501c6 = URIRef("https://schema.org/Nonprofit501c6")
    typeOfGood = URIRef("https://schema.org/typeOfGood")
    opens = URIRef("https://schema.org/opens")
    partySize = URIRef("https://schema.org/partySize")
    byMonthDay = URIRef("https://schema.org/byMonthDay")
    measurementDenominator = URIRef("https://schema.org/measurementDenominator")
    observationAbout = URIRef("https://schema.org/observationAbout")
    transitTime = URIRef("https://schema.org/transitTime")
    webCheckinTime = URIRef("https://schema.org/webCheckinTime")
    ReactAction = URIRef("https://schema.org/ReactAction")
    actor = URIRef("https://schema.org/actor")
    logo = URIRef("https://schema.org/logo")
    engineDisplacement = URIRef("https://schema.org/engineDisplacement")
    amenityFeature = URIRef("https://schema.org/amenityFeature")
    preparation = URIRef("https://schema.org/preparation")
    associatedDisease = URIRef("https://schema.org/associatedDisease")
    AuthoritativeLegalValue = URIRef("https://schema.org/AuthoritativeLegalValue")
    Nonprofit501c17 = URIRef("https://schema.org/Nonprofit501c17")
    acceptedAnswer = URIRef("https://schema.org/acceptedAnswer")
    composer = URIRef("https://schema.org/composer")
    availableLanguage = URIRef("https://schema.org/availableLanguage")
    ethicsPolicy = URIRef("https://schema.org/ethicsPolicy")
    MedicalSpecialty = URIRef("https://schema.org/MedicalSpecialty")
    smokingAllowed = URIRef("https://schema.org/smokingAllowed")
    tripOrigin = URIRef("https://schema.org/tripOrigin")
    titleEIDR = URIRef("https://schema.org/titleEIDR")
    eduQuestionType = URIRef("https://schema.org/eduQuestionType")
    trackingNumber = URIRef("https://schema.org/trackingNumber")
    contentUrl = URIRef("https://schema.org/contentUrl")
    gameTip = URIRef("https://schema.org/gameTip")
    WearableSizeSystemMX = URIRef("https://schema.org/WearableSizeSystemMX")
    APIReference = URIRef("https://schema.org/APIReference")
    DatedMoneySpecification = URIRef("https://schema.org/DatedMoneySpecification")
    accessibilityAPI = URIRef("https://schema.org/accessibilityAPI")
    UserBlocks = URIRef("https://schema.org/UserBlocks")
    CssSelectorType = URIRef("https://schema.org/CssSelectorType")
    legislationType = URIRef("https://schema.org/legislationType")
    DeactivateAction = URIRef("https://schema.org/DeactivateAction")
    VisualArtsEvent = URIRef("https://schema.org/VisualArtsEvent")
    discountCurrency = URIRef("https://schema.org/discountCurrency")
    AlbumRelease = URIRef("https://schema.org/AlbumRelease")
    calories = URIRef("https://schema.org/calories")
    penciler = URIRef("https://schema.org/penciler")
    benefitsSummaryUrl = URIRef("https://schema.org/benefitsSummaryUrl")
    orderStatus = URIRef("https://schema.org/orderStatus")
    HowItWorksHealthAspect = URIRef("https://schema.org/HowItWorksHealthAspect")
    inverseOf = URIRef("https://schema.org/inverseOf")
    photos = URIRef("https://schema.org/photos")
    representativeOfPage = URIRef("https://schema.org/representativeOfPage")
    Substance = URIRef("https://schema.org/Substance")
    follows = URIRef("https://schema.org/follows")
    Female = URIRef("https://schema.org/Female")
    totalPrice = URIRef("https://schema.org/totalPrice")
    foodWarning = URIRef("https://schema.org/foodWarning")
    season = URIRef("https://schema.org/season")
    MonetaryGrant = URIRef("https://schema.org/MonetaryGrant")
    subEvent = URIRef("https://schema.org/subEvent")
    BusStation = URIRef("https://schema.org/BusStation")
    Wholesale = URIRef("https://schema.org/Wholesale")
    missionCoveragePrioritiesPolicy = URIRef("https://schema.org/missionCoveragePrioritiesPolicy")
    IndividualPhysician = URIRef("https://schema.org/IndividualPhysician")
    postalCode = URIRef("https://schema.org/postalCode")
    serviceLocation = URIRef("https://schema.org/serviceLocation")
    travelBans = URIRef("https://schema.org/travelBans")
    albums = URIRef("https://schema.org/albums")
    Ultrasound = URIRef("https://schema.org/Ultrasound")
    totalHistoricalEnrollment = URIRef("https://schema.org/totalHistoricalEnrollment")
    ComicCoverArt = URIRef("https://schema.org/ComicCoverArt")
    childMaxAge = URIRef("https://schema.org/childMaxAge")
    breastfeedingWarning = URIRef("https://schema.org/breastfeedingWarning")
    legalStatus = URIRef("https://schema.org/legalStatus")
    Periodical = URIRef("https://schema.org/Periodical")
    QuantitativeValue = URIRef("https://schema.org/QuantitativeValue")
    reservationStatus = URIRef("https://schema.org/reservationStatus")
    contactPoints = URIRef("https://schema.org/contactPoints")
    DateTime = URIRef("https://schema.org/DateTime")
    seasons = URIRef("https://schema.org/seasons")
    legislationLegalValue = URIRef("https://schema.org/legislationLegalValue")
    successorOf = URIRef("https://schema.org/successorOf")
    faxNumber = URIRef("https://schema.org/faxNumber")
    Nonprofit501c15 = URIRef("https://schema.org/Nonprofit501c15")
    Ear = URIRef("https://schema.org/Ear")
    driveWheelConfiguration = URIRef("https://schema.org/driveWheelConfiguration")
    customerRemorseReturnShippingFeesAmount = URIRef("https://schema.org/customerRemorseReturnShippingFeesAmount")
    legislationJurisdiction = URIRef("https://schema.org/legislationJurisdiction")
    VideoGameClip = URIRef("https://schema.org/VideoGameClip")
    DefinedTermSet = URIRef("https://schema.org/DefinedTermSet")
    maps = URIRef("https://schema.org/maps")
    WearableSizeSystemEN13402 = URIRef("https://schema.org/WearableSizeSystemEN13402")
    MerchantReturnPolicy = URIRef("https://schema.org/MerchantReturnPolicy")
    SendAction = URIRef("https://schema.org/SendAction")
    measurementMethod = URIRef("https://schema.org/measurementMethod")
    OriginalShippingFees = URIRef("https://schema.org/OriginalShippingFees")
    brand = URIRef("https://schema.org/brand")
    addOn = URIRef("https://schema.org/addOn")
    Enumeration = URIRef("https://schema.org/Enumeration")
    BusinessEvent = URIRef("https://schema.org/BusinessEvent")
    Article = URIRef("https://schema.org/Article")
    Vehicle = URIRef("https://schema.org/Vehicle")
    unnamedSourcesPolicy = URIRef("https://schema.org/unnamedSourcesPolicy")
    identifyingTest = URIRef("https://schema.org/identifyingTest")
    BodyOfWater = URIRef("https://schema.org/BodyOfWater")
    LoanOrCredit = URIRef("https://schema.org/LoanOrCredit")
    termsPerYear = URIRef("https://schema.org/termsPerYear")
    ticketedSeat = URIRef("https://schema.org/ticketedSeat")
    broadcastOfEvent = URIRef("https://schema.org/broadcastOfEvent")
    EnergyStarCertified = URIRef("https://schema.org/EnergyStarCertified")
    FundingAgency = URIRef("https://schema.org/FundingAgency")
    funding = URIRef("https://schema.org/funding")
    accessibilityAPI = URIRef("https://schema.org/accessibilityAPI")
    boardingGroup = URIRef("https://schema.org/boardingGroup")
    merchantReturnDays = URIRef("https://schema.org/merchantReturnDays")
    DeliveryTimeSettings = URIRef("https://schema.org/DeliveryTimeSettings")
    PetStore = URIRef("https://schema.org/PetStore")
    legalName = URIRef("https://schema.org/legalName")
    signDetected = URIRef("https://schema.org/signDetected")
    dateCreated = URIRef("https://schema.org/dateCreated")
    MortgageLoan = URIRef("https://schema.org/MortgageLoan")
    backstory = URIRef("https://schema.org/backstory")
    RadioBroadcastService = URIRef("https://schema.org/RadioBroadcastService")
    provider = URIRef("https://schema.org/provider")
    availableService = URIRef("https://schema.org/availableService")
    PaidLeave = URIRef("https://schema.org/PaidLeave")
    possibleComplication = URIRef("https://schema.org/possibleComplication")
    sdDatePublished = URIRef("https://schema.org/sdDatePublished")
    offers = URIRef("https://schema.org/offers")
    Date = URIRef("https://schema.org/Date")
    LoanOrCredit = URIRef("https://schema.org/LoanOrCredit")
    dateIssued = URIRef("https://schema.org/dateIssued")
    LiteraryEvent = URIRef("https://schema.org/LiteraryEvent")
    LimitedAvailability = URIRef("https://schema.org/LimitedAvailability")
    menu = URIRef("https://schema.org/menu")
    DigitalDocument = URIRef("https://schema.org/DigitalDocument")
    participant = URIRef("https://schema.org/participant")
    EducationalOccupationalCredential = URIRef("https://schema.org/EducationalOccupationalCredential")
    question = URIRef("https://schema.org/question")
    servingSize = URIRef("https://schema.org/servingSize")
    inventoryLevel = URIRef("https://schema.org/inventoryLevel")
    Syllabus = URIRef("https://schema.org/Syllabus")
    alumniOf = URIRef("https://schema.org/alumniOf")
    eligibilityToWorkRequirement = URIRef("https://schema.org/eligibilityToWorkRequirement")
    EUEnergyEfficiencyCategoryA1Plus = URIRef("https://schema.org/EUEnergyEfficiencyCategoryA1Plus")
    artMedium = URIRef("https://schema.org/artMedium")
    calories = URIRef("https://schema.org/calories")
    WearableMeasurementChestOrBust = URIRef("https://schema.org/WearableMeasurementChestOrBust")
    WebAPI = URIRef("https://schema.org/WebAPI")
    shippingDestination = URIRef("https://schema.org/shippingDestination")
    MedicalSpecialty = URIRef("https://schema.org/MedicalSpecialty")
    hasBioPolymerSequence = URIRef("https://schema.org/hasBioPolymerSequence")
    target = URIRef("https://schema.org/target")
    FinancialProduct = URIRef("https://schema.org/FinancialProduct")
    evidenceLevel = URIRef("https://schema.org/evidenceLevel")
    payload = URIRef("https://schema.org/payload")
    musicBy = URIRef("https://schema.org/musicBy")
    measurementMethod = URIRef("https://schema.org/measurementMethod")
    Accommodation = URIRef("https://schema.org/Accommodation")
    instrument = URIRef("https://schema.org/instrument")
    replacee = URIRef("https://schema.org/replacee")
    frequency = URIRef("https://schema.org/frequency")
    Registry = URIRef("https://schema.org/Registry")
    ComedyClub = URIRef("https://schema.org/ComedyClub")
    dateline = URIRef("https://schema.org/dateline")
    LiquorStore = URIRef("https://schema.org/LiquorStore")
    incentives = URIRef("https://schema.org/incentives")
    MedicalRiskEstimator = URIRef("https://schema.org/MedicalRiskEstimator")
    DataDownload = URIRef("https://schema.org/DataDownload")
    DamagedCondition = URIRef("https://schema.org/DamagedCondition")
    Physiotherapy = URIRef("https://schema.org/Physiotherapy")
    containsPlace = URIRef("https://schema.org/containsPlace")
    ImageObject = URIRef("https://schema.org/ImageObject")
    course = URIRef("https://schema.org/course")
    Prion = URIRef("https://schema.org/Prion")
    hasVariant = URIRef("https://schema.org/hasVariant")
    EntertainmentBusiness = URIRef("https://schema.org/EntertainmentBusiness")
    MoneyTransfer = URIRef("https://schema.org/MoneyTransfer")
    OrderDelivered = URIRef("https://schema.org/OrderDelivered")
    partySize = URIRef("https://schema.org/partySize")
    hiringOrganization = URIRef("https://schema.org/hiringOrganization")
    validFrom = URIRef("https://schema.org/validFrom")
    totalJobOpenings = URIRef("https://schema.org/totalJobOpenings")
    areaServed = URIRef("https://schema.org/areaServed")
    RestockingFees = URIRef("https://schema.org/RestockingFees")
    Nonprofit501c4 = URIRef("https://schema.org/Nonprofit501c4")
    Corporation = URIRef("https://schema.org/Corporation")
    Diagnostic = URIRef("https://schema.org/Diagnostic")
    hostingOrganization = URIRef("https://schema.org/hostingOrganization")
    SinglePlayer = URIRef("https://schema.org/SinglePlayer")
    publisher = URIRef("https://schema.org/publisher")
    audio = URIRef("https://schema.org/audio")
    step = URIRef("https://schema.org/step")
    inProductGroupWithID = URIRef("https://schema.org/inProductGroupWithID")
    associatedArticle = URIRef("https://schema.org/associatedArticle")
    ListPrice = URIRef("https://schema.org/ListPrice")
    lyricist = URIRef("https://schema.org/lyricist")
    cvdNumVentUse = URIRef("https://schema.org/cvdNumVentUse")
    departureGate = URIRef("https://schema.org/departureGate")
    screenCount = URIRef("https://schema.org/screenCount")
    iso6523Code = URIRef("https://schema.org/iso6523Code")
    associatedReview = URIRef("https://schema.org/associatedReview")
    ActivationFee = URIRef("https://schema.org/ActivationFee")
    UseAction = URIRef("https://schema.org/UseAction")
    confirmationNumber = URIRef("https://schema.org/confirmationNumber")
    credentialCategory = URIRef("https://schema.org/credentialCategory")
    issuedBy = URIRef("https://schema.org/issuedBy")
    suggestedAge = URIRef("https://schema.org/suggestedAge")
    Endocrine = URIRef("https://schema.org/Endocrine")
    RsvpResponseNo = URIRef("https://schema.org/RsvpResponseNo")
    pageEnd = URIRef("https://schema.org/pageEnd")
    TVEpisode = URIRef("https://schema.org/TVEpisode")
    cvdNumC19OverflowPats = URIRef("https://schema.org/cvdNumC19OverflowPats")
    termDuration = URIRef("https://schema.org/termDuration")
    Nonprofit501e = URIRef("https://schema.org/Nonprofit501e")
    PlaceOfWorship = URIRef("https://schema.org/PlaceOfWorship")
    HowToStep = URIRef("https://schema.org/HowToStep")
    inBroadcastLineup = URIRef("https://schema.org/inBroadcastLineup")
    variableMeasured = URIRef("https://schema.org/variableMeasured")
    reviews = URIRef("https://schema.org/reviews")
    returnPolicyCategory = URIRef("https://schema.org/returnPolicyCategory")
    inChIKey = URIRef("https://schema.org/inChIKey")
    percentile90 = URIRef("https://schema.org/percentile90")
    educationalAlignment = URIRef("https://schema.org/educationalAlignment")
    addressCountry = URIRef("https://schema.org/addressCountry")
    endTime = URIRef("https://schema.org/endTime")
    dateSent = URIRef("https://schema.org/dateSent")
    Patient = URIRef("https://schema.org/Patient")
    greater = URIRef("https://schema.org/greater")
    sizeSystem = URIRef("https://schema.org/sizeSystem")
    IndividualProduct = URIRef("https://schema.org/IndividualProduct")
    BeautySalon = URIRef("https://schema.org/BeautySalon")
    coverageStartTime = URIRef("https://schema.org/coverageStartTime")
    hasBioChemEntityPart = URIRef("https://schema.org/hasBioChemEntityPart")
    OfferForLease = URIRef("https://schema.org/OfferForLease")
    OccupationalActivity = URIRef("https://schema.org/OccupationalActivity")
    Volcano = URIRef("https://schema.org/Volcano")
    coursePrerequisites = URIRef("https://schema.org/coursePrerequisites")
    guidelineSubject = URIRef("https://schema.org/guidelineSubject")
    recipeYield = URIRef("https://schema.org/recipeYield")
    price = URIRef("https://schema.org/price")
    fileFormat = URIRef("https://schema.org/fileFormat")
    Nonprofit501c18 = URIRef("https://schema.org/Nonprofit501c18")
    diseasePreventionInfo = URIRef("https://schema.org/diseasePreventionInfo")
    givenName = URIRef("https://schema.org/givenName")
    merchantReturnLink = URIRef("https://schema.org/merchantReturnLink")
    UserDownloads = URIRef("https://schema.org/UserDownloads")
    sampleType = URIRef("https://schema.org/sampleType")
    inCodeSet = URIRef("https://schema.org/inCodeSet")
    CancelAction = URIRef("https://schema.org/CancelAction")
    timeToComplete = URIRef("https://schema.org/timeToComplete")
    aggregateRating = URIRef("https://schema.org/aggregateRating")
    hasCourse = URIRef("https://schema.org/hasCourse")
    usesDevice = URIRef("https://schema.org/usesDevice")
    serviceUrl = URIRef("https://schema.org/serviceUrl")
    ethicsPolicy = URIRef("https://schema.org/ethicsPolicy")
    titleEIDR = URIRef("https://schema.org/titleEIDR")
    MotorizedBicycle = URIRef("https://schema.org/MotorizedBicycle")
    GolfCourse = URIRef("https://schema.org/GolfCourse")
    DamagedCondition = URIRef("https://schema.org/DamagedCondition")
    elevation = URIRef("https://schema.org/elevation")
    workPresented = URIRef("https://schema.org/workPresented")
    candidate = URIRef("https://schema.org/candidate")
    mediaItemAppearance = URIRef("https://schema.org/mediaItemAppearance")
    businessDays = URIRef("https://schema.org/businessDays")
    AcceptAction = URIRef("https://schema.org/AcceptAction")
    CourseInstance = URIRef("https://schema.org/CourseInstance")
    WinAction = URIRef("https://schema.org/WinAction")
    AboutPage = URIRef("https://schema.org/AboutPage")
    CarUsageType = URIRef("https://schema.org/CarUsageType")
    MotorcycleRepair = URIRef("https://schema.org/MotorcycleRepair")
    MedicalTherapy = URIRef("https://schema.org/MedicalTherapy")
    numAdults = URIRef("https://schema.org/numAdults")
    ImageObject = URIRef("https://schema.org/ImageObject")
    DefenceEstablishment = URIRef("https://schema.org/DefenceEstablishment")
    catalog = URIRef("https://schema.org/catalog")
    videoFormat = URIRef("https://schema.org/videoFormat")
    Nonprofit501c13 = URIRef("https://schema.org/Nonprofit501c13")
    ratingExplanation = URIRef("https://schema.org/ratingExplanation")
    QuantitativeValueDistribution = URIRef("https://schema.org/QuantitativeValueDistribution")
    distance = URIRef("https://schema.org/distance")
    OriginalMediaContent = URIRef("https://schema.org/OriginalMediaContent")
    validFrom = URIRef("https://schema.org/validFrom")
    OfflineTemporarily = URIRef("https://schema.org/OfflineTemporarily")
    availableDeliveryMethod = URIRef("https://schema.org/availableDeliveryMethod")
    Boolean = URIRef("https://schema.org/Boolean")
    underName = URIRef("https://schema.org/underName")
    areaServed = URIRef("https://schema.org/areaServed")
    Boolean = URIRef("https://schema.org/Boolean")
    softwareVersion = URIRef("https://schema.org/softwareVersion")
    SportsActivityLocation = URIRef("https://schema.org/SportsActivityLocation")
    productGroupID = URIRef("https://schema.org/productGroupID")
    EUEnergyEfficiencyCategoryA1Plus = URIRef("https://schema.org/EUEnergyEfficiencyCategoryA1Plus")
    HealthTopicContent = URIRef("https://schema.org/HealthTopicContent")
    medicalSpecialty = URIRef("https://schema.org/medicalSpecialty")
    TrainReservation = URIRef("https://schema.org/TrainReservation")
    tissueSample = URIRef("https://schema.org/tissueSample")
    ReviewNewsArticle = URIRef("https://schema.org/ReviewNewsArticle")
    claimInterpreter = URIRef("https://schema.org/claimInterpreter")
    LockerDelivery = URIRef("https://schema.org/LockerDelivery")
    VideoGallery = URIRef("https://schema.org/VideoGallery")
    TVSeason = URIRef("https://schema.org/TVSeason")
    missionCoveragePrioritiesPolicy = URIRef("https://schema.org/missionCoveragePrioritiesPolicy")
    location = URIRef("https://schema.org/location")
    TVClip = URIRef("https://schema.org/TVClip")
    seatSection = URIRef("https://schema.org/seatSection")
    BusOrCoach = URIRef("https://schema.org/BusOrCoach")
    MedicalScholarlyArticle = URIRef("https://schema.org/MedicalScholarlyArticle")
    eligibleRegion = URIRef("https://schema.org/eligibleRegion")
    physicalRequirement = URIRef("https://schema.org/physicalRequirement")
    additionalType = URIRef("https://schema.org/additionalType")
    TreatmentIndication = URIRef("https://schema.org/TreatmentIndication")
    MovieSeries = URIRef("https://schema.org/MovieSeries")
    publicationType = URIRef("https://schema.org/publicationType")
    funder = URIRef("https://schema.org/funder")
    pageEnd = URIRef("https://schema.org/pageEnd")
    verificationFactCheckingPolicy = URIRef("https://schema.org/verificationFactCheckingPolicy")
    acrissCode = URIRef("https://schema.org/acrissCode")
    procedureType = URIRef("https://schema.org/procedureType")
    RsvpResponseYes = URIRef("https://schema.org/RsvpResponseYes")
    EnergyStarCertified = URIRef("https://schema.org/EnergyStarCertified")
    AddAction = URIRef("https://schema.org/AddAction")
    description = URIRef("https://schema.org/description")
    Episode = URIRef("https://schema.org/Episode")
    exchangeRateSpread = URIRef("https://schema.org/exchangeRateSpread")
    URL = URIRef("https://schema.org/URL")
    eligibleQuantity = URIRef("https://schema.org/eligibleQuantity")
    qualifications = URIRef("https://schema.org/qualifications")
    shippingDestination = URIRef("https://schema.org/shippingDestination")
    performTime = URIRef("https://schema.org/performTime")
    assesses = URIRef("https://schema.org/assesses")
    broadcastAffiliateOf = URIRef("https://schema.org/broadcastAffiliateOf")
    OverviewHealthAspect = URIRef("https://schema.org/OverviewHealthAspect")
    servesCuisine = URIRef("https://schema.org/servesCuisine")
    programmingModel = URIRef("https://schema.org/programmingModel")
    collectionSize = URIRef("https://schema.org/collectionSize")
    usageInfo = URIRef("https://schema.org/usageInfo")
    stage = URIRef("https://schema.org/stage")
    jobTitle = URIRef("https://schema.org/jobTitle")
    EUEnergyEfficiencyCategoryE = URIRef("https://schema.org/EUEnergyEfficiencyCategoryE")
    occupancy = URIRef("https://schema.org/occupancy")
    UserTweets = URIRef("https://schema.org/UserTweets")
    VirtualRecordingDigitalSource = URIRef("https://schema.org/VirtualRecordingDigitalSource")
    keywords = URIRef("https://schema.org/keywords")
    GeoCircle = URIRef("https://schema.org/GeoCircle")
    EngineSpecification = URIRef("https://schema.org/EngineSpecification")
    Sculpture = URIRef("https://schema.org/Sculpture")
    DigitalDocumentPermissionType = URIRef("https://schema.org/DigitalDocumentPermissionType")
    OccupationalTherapy = URIRef("https://schema.org/OccupationalTherapy")
    EventRescheduled = URIRef("https://schema.org/EventRescheduled")
    softwareAddOn = URIRef("https://schema.org/softwareAddOn")
    WearableSizeGroupMens = URIRef("https://schema.org/WearableSizeGroupMens")
    secondaryPrevention = URIRef("https://schema.org/secondaryPrevention")
    nerve = URIRef("https://schema.org/nerve")
    WearableSizeGroupMens = URIRef("https://schema.org/WearableSizeGroupMens")
    followee = URIRef("https://schema.org/followee")
    Nonprofit501c18 = URIRef("https://schema.org/Nonprofit501c18")
    jobImmediateStart = URIRef("https://schema.org/jobImmediateStart")
    modifiedTime = URIRef("https://schema.org/modifiedTime")
    author = URIRef("https://schema.org/author")
    legislationIdentifier = URIRef("https://schema.org/legislationIdentifier")
    relatedTherapy = URIRef("https://schema.org/relatedTherapy")
    PreOrderAction = URIRef("https://schema.org/PreOrderAction")
    endOffset = URIRef("https://schema.org/endOffset")
    seeks = URIRef("https://schema.org/seeks")
    MedicineSystem = URIRef("https://schema.org/MedicineSystem")
    RentalCarReservation = URIRef("https://schema.org/RentalCarReservation")
    device = URIRef("https://schema.org/device")
    clipNumber = URIRef("https://schema.org/clipNumber")
    drugClass = URIRef("https://schema.org/drugClass")
    schemaVersion = URIRef("https://schema.org/schemaVersion")
    termsOfService = URIRef("https://schema.org/termsOfService")
    closes = URIRef("https://schema.org/closes")
    driveWheelConfiguration = URIRef("https://schema.org/driveWheelConfiguration")
    CompositeCaptureDigitalSource = URIRef("https://schema.org/CompositeCaptureDigitalSource")
    MapCategoryType = URIRef("https://schema.org/MapCategoryType")
    followee = URIRef("https://schema.org/followee")
    datePosted = URIRef("https://schema.org/datePosted")
    Table = URIRef("https://schema.org/Table")
    EventStatusType = URIRef("https://schema.org/EventStatusType")
    termCode = URIRef("https://schema.org/termCode")
    VinylFormat = URIRef("https://schema.org/VinylFormat")
    GraphicNovel = URIRef("https://schema.org/GraphicNovel")
    minValue = URIRef("https://schema.org/minValue")
    returnPolicyCategory = URIRef("https://schema.org/returnPolicyCategory")
    PrognosisHealthAspect = URIRef("https://schema.org/PrognosisHealthAspect")
    playerType = URIRef("https://schema.org/playerType")
    contributor = URIRef("https://schema.org/contributor")
    healthPlanNetworkId = URIRef("https://schema.org/healthPlanNetworkId")
    PreOrderAction = URIRef("https://schema.org/PreOrderAction")
    applicationStartDate = URIRef("https://schema.org/applicationStartDate")
    correction = URIRef("https://schema.org/correction")
    floorSize = URIRef("https://schema.org/floorSize")
    businessFunction = URIRef("https://schema.org/businessFunction")
    relatedLink = URIRef("https://schema.org/relatedLink")
    programmingLanguage = URIRef("https://schema.org/programmingLanguage")
    MortgageLoan = URIRef("https://schema.org/MortgageLoan")
    FurnitureStore = URIRef("https://schema.org/FurnitureStore")
    seatNumber = URIRef("https://schema.org/seatNumber")
    object = URIRef("https://schema.org/object")
    FDAcategoryA = URIRef("https://schema.org/FDAcategoryA")
    WearableMeasurementHips = URIRef("https://schema.org/WearableMeasurementHips")
    securityClearanceRequirement = URIRef("https://schema.org/securityClearanceRequirement")
    isAccessibleForFree = URIRef("https://schema.org/isAccessibleForFree")
    IPTCDigitalSourceEnumeration = URIRef("https://schema.org/IPTCDigitalSourceEnumeration")
    SolveMathAction = URIRef("https://schema.org/SolveMathAction")
    nationality = URIRef("https://schema.org/nationality")
    sku = URIRef("https://schema.org/sku")
    AudiobookFormat = URIRef("https://schema.org/AudiobookFormat")
    CaseSeries = URIRef("https://schema.org/CaseSeries")
    TouristTrip = URIRef("https://schema.org/TouristTrip")
    providesBroadcastService = URIRef("https://schema.org/providesBroadcastService")
    EventPostponed = URIRef("https://schema.org/EventPostponed")
    dayOfWeek = URIRef("https://schema.org/dayOfWeek")
    entertainmentBusiness = URIRef("https://schema.org/entertainmentBusiness")
    BowlingAlley = URIRef("https://schema.org/BowlingAlley")
    OrganizationRole = URIRef("https://schema.org/OrganizationRole")
    IPTCDigitalSourceEnumeration = URIRef("https://schema.org/IPTCDigitalSourceEnumeration")
    duplicateTherapy = URIRef("https://schema.org/duplicateTherapy")
    Consortium = URIRef("https://schema.org/Consortium")
    hasMenuSection = URIRef("https://schema.org/hasMenuSection")
    duplicateTherapy = URIRef("https://schema.org/duplicateTherapy")
    StatisticalPopulation = URIRef("https://schema.org/StatisticalPopulation")
    OrderProcessing = URIRef("https://schema.org/OrderProcessing")
    RadioBroadcastService = URIRef("https://schema.org/RadioBroadcastService")
    EndorsementRating = URIRef("https://schema.org/EndorsementRating")
    referenceQuantity = URIRef("https://schema.org/referenceQuantity")
    enginePower = URIRef("https://schema.org/enginePower")
    DietNutrition = URIRef("https://schema.org/DietNutrition")
    uploadDate = URIRef("https://schema.org/uploadDate")
    StoreCreditRefund = URIRef("https://schema.org/StoreCreditRefund")
    musicArrangement = URIRef("https://schema.org/musicArrangement")
    artform = URIRef("https://schema.org/artform")
    TelevisionStation = URIRef("https://schema.org/TelevisionStation")
    financialAidEligible = URIRef("https://schema.org/financialAidEligible")
    GenericWebPlatform = URIRef("https://schema.org/GenericWebPlatform")
    distribution = URIRef("https://schema.org/distribution")
    businessDays = URIRef("https://schema.org/businessDays")
    returnShippingFeesAmount = URIRef("https://schema.org/returnShippingFeesAmount")
    includedInHealthInsurancePlan = URIRef("https://schema.org/includedInHealthInsurancePlan")
    recognizingAuthority = URIRef("https://schema.org/recognizingAuthority")
    Festival = URIRef("https://schema.org/Festival")
    floorLevel = URIRef("https://schema.org/floorLevel")
    digitalSourceType = URIRef("https://schema.org/digitalSourceType")
    CriticReview = URIRef("https://schema.org/CriticReview")
    ImageObject = URIRef("https://schema.org/ImageObject")
    episodes = URIRef("https://schema.org/episodes")
    tocContinuation = URIRef("https://schema.org/tocContinuation")
    AMRadioChannel = URIRef("https://schema.org/AMRadioChannel")
    installUrl = URIRef("https://schema.org/installUrl")
    customer = URIRef("https://schema.org/customer")
    billingStart = URIRef("https://schema.org/billingStart")
    ShoeStore = URIRef("https://schema.org/ShoeStore")
    box = URIRef("https://schema.org/box")
    bodyType = URIRef("https://schema.org/bodyType")
    additionalNumberOfGuests = URIRef("https://schema.org/additionalNumberOfGuests")
    QuantitativeValueDistribution = URIRef("https://schema.org/QuantitativeValueDistribution")
    TouristTrip = URIRef("https://schema.org/TouristTrip")
    LegislationObject = URIRef("https://schema.org/LegislationObject")
    validUntil = URIRef("https://schema.org/validUntil")
    inker = URIRef("https://schema.org/inker")
    MapCategoryType = URIRef("https://schema.org/MapCategoryType")
    seatingCapacity = URIRef("https://schema.org/seatingCapacity")
    legislationDateVersion = URIRef("https://schema.org/legislationDateVersion")
    Course = URIRef("https://schema.org/Course")
    ViolenceConsideration = URIRef("https://schema.org/ViolenceConsideration")
    shippingSettingsLink = URIRef("https://schema.org/shippingSettingsLink")
    PerformAction = URIRef("https://schema.org/PerformAction")
    UsageOrScheduleHealthAspect = URIRef("https://schema.org/UsageOrScheduleHealthAspect")
    EnergyStarEnergyEfficiencyEnumeration = URIRef("https://schema.org/EnergyStarEnergyEfficiencyEnumeration")
    publicTransportClosuresInfo = URIRef("https://schema.org/publicTransportClosuresInfo")
    isPartOf = URIRef("https://schema.org/isPartOf")
    elevation = URIRef("https://schema.org/elevation")
    startDate = URIRef("https://schema.org/startDate")
    priceSpecification = URIRef("https://schema.org/priceSpecification")
    Balance = URIRef("https://schema.org/Balance")
    experienceRequirements = URIRef("https://schema.org/experienceRequirements")
    encoding = URIRef("https://schema.org/encoding")
    WebSite = URIRef("https://schema.org/WebSite")
    subStructure = URIRef("https://schema.org/subStructure")
    associatedMediaReview = URIRef("https://schema.org/associatedMediaReview")
    recipeCategory = URIRef("https://schema.org/recipeCategory")
    inSupportOf = URIRef("https://schema.org/inSupportOf")
    SizeSystemMetric = URIRef("https://schema.org/SizeSystemMetric")
    diseasePreventionInfo = URIRef("https://schema.org/diseasePreventionInfo")
    customerRemorseReturnLabelSource = URIRef("https://schema.org/customerRemorseReturnLabelSource")
    RepaymentSpecification = URIRef("https://schema.org/RepaymentSpecification")
    identifyingTest = URIRef("https://schema.org/identifyingTest")
    additionalNumberOfGuests = URIRef("https://schema.org/additionalNumberOfGuests")
    accountOverdraftLimit = URIRef("https://schema.org/accountOverdraftLimit")
    telephone = URIRef("https://schema.org/telephone")
    countryOfAssembly = URIRef("https://schema.org/countryOfAssembly")
    emissionsCO2 = URIRef("https://schema.org/emissionsCO2")
    duration = URIRef("https://schema.org/duration")
    Withdrawn = URIRef("https://schema.org/Withdrawn")
    jobTitle = URIRef("https://schema.org/jobTitle")
    Event = URIRef("https://schema.org/Event")
    Thesis = URIRef("https://schema.org/Thesis")
    MotorcycleRepair = URIRef("https://schema.org/MotorcycleRepair")
    SalePrice = URIRef("https://schema.org/SalePrice")
    geoDisjoint = URIRef("https://schema.org/geoDisjoint")
    offers = URIRef("https://schema.org/offers")
    MediaGallery = URIRef("https://schema.org/MediaGallery")
    scheduledPaymentDate = URIRef("https://schema.org/scheduledPaymentDate")
    Dentist = URIRef("https://schema.org/Dentist")
    boardingGroup = URIRef("https://schema.org/boardingGroup")
    legislationConsolidates = URIRef("https://schema.org/legislationConsolidates")
    BodyMeasurementWaist = URIRef("https://schema.org/BodyMeasurementWaist")
    familyName = URIRef("https://schema.org/familyName")
    AgreeAction = URIRef("https://schema.org/AgreeAction")
    accommodationCategory = URIRef("https://schema.org/accommodationCategory")
    OfferForPurchase = URIRef("https://schema.org/OfferForPurchase")
    legislationDateVersion = URIRef("https://schema.org/legislationDateVersion")
    Registry = URIRef("https://schema.org/Registry")
    caption = URIRef("https://schema.org/caption")
    MedicalAudienceType = URIRef("https://schema.org/MedicalAudienceType")
    customerRemorseReturnLabelSource = URIRef("https://schema.org/customerRemorseReturnLabelSource")
    hasDigitalDocumentPermission = URIRef("https://schema.org/hasDigitalDocumentPermission")
    XRay = URIRef("https://schema.org/XRay")
    hasMenu = URIRef("https://schema.org/hasMenu")
    positiveNotes = URIRef("https://schema.org/positiveNotes")
    drugUnit = URIRef("https://schema.org/drugUnit")
    checkinTime = URIRef("https://schema.org/checkinTime")
    CategoryCodeSet = URIRef("https://schema.org/CategoryCodeSet")
    exerciseRelatedDiet = URIRef("https://schema.org/exerciseRelatedDiet")
    downPayment = URIRef("https://schema.org/downPayment")
    pathophysiology = URIRef("https://schema.org/pathophysiology")
    course = URIRef("https://schema.org/course")
    HealthClub = URIRef("https://schema.org/HealthClub")
    inStoreReturnsOffered = URIRef("https://schema.org/inStoreReturnsOffered")
    UseAction = URIRef("https://schema.org/UseAction")
    AssignAction = URIRef("https://schema.org/AssignAction")
    MedicalGuidelineContraindication = URIRef("https://schema.org/MedicalGuidelineContraindication")
    School = URIRef("https://schema.org/School")
    DanceEvent = URIRef("https://schema.org/DanceEvent")
    prescribingInfo = URIRef("https://schema.org/prescribingInfo")
    previousItem = URIRef("https://schema.org/previousItem")
    typicalAgeRange = URIRef("https://schema.org/typicalAgeRange")
    DataType = URIRef("https://schema.org/DataType")
    MedicalProcedure = URIRef("https://schema.org/MedicalProcedure")
    Ear = URIRef("https://schema.org/Ear")
    OutletStore = URIRef("https://schema.org/OutletStore")
    mainEntity = URIRef("https://schema.org/mainEntity")
    interactingDrug = URIRef("https://schema.org/interactingDrug")
    director = URIRef("https://schema.org/director")
    expectedPrognosis = URIRef("https://schema.org/expectedPrognosis")
    TreatmentIndication = URIRef("https://schema.org/TreatmentIndication")
    educationRequirements = URIRef("https://schema.org/educationRequirements")
    postalCodeEnd = URIRef("https://schema.org/postalCodeEnd")
    RefurbishedCondition = URIRef("https://schema.org/RefurbishedCondition")
    Casino = URIRef("https://schema.org/Casino")
    HobbyShop = URIRef("https://schema.org/HobbyShop")
    UseAction = URIRef("https://schema.org/UseAction")
    FundingAgency = URIRef("https://schema.org/FundingAgency")
    possibleComplication = URIRef("https://schema.org/possibleComplication")
    Nonprofit501c22 = URIRef("https://schema.org/Nonprofit501c22")
    HealthAndBeautyBusiness = URIRef("https://schema.org/HealthAndBeautyBusiness")
    WearableSizeGroupHusky = URIRef("https://schema.org/WearableSizeGroupHusky")
    ItemList = URIRef("https://schema.org/ItemList")
    Neck = URIRef("https://schema.org/Neck")
    operatingSystem = URIRef("https://schema.org/operatingSystem")
    OrderProcessing = URIRef("https://schema.org/OrderProcessing")
    Motorcycle = URIRef("https://schema.org/Motorcycle")
    bankAccountType = URIRef("https://schema.org/bankAccountType")
    seeks = URIRef("https://schema.org/seeks")
    toLocation = URIRef("https://schema.org/toLocation")
    SideEffectsHealthAspect = URIRef("https://schema.org/SideEffectsHealthAspect")
    numberOfPages = URIRef("https://schema.org/numberOfPages")
    shippingLabel = URIRef("https://schema.org/shippingLabel")
    spatial = URIRef("https://schema.org/spatial")
    interactionType = URIRef("https://schema.org/interactionType")
    educationalLevel = URIRef("https://schema.org/educationalLevel")
    byMonthWeek = URIRef("https://schema.org/byMonthWeek")
    cvdNumC19OFMechVentPats = URIRef("https://schema.org/cvdNumC19OFMechVentPats")
    practicesAt = URIRef("https://schema.org/practicesAt")
    jobImmediateStart = URIRef("https://schema.org/jobImmediateStart")
    returnPolicyCategory = URIRef("https://schema.org/returnPolicyCategory")
    targetPopulation = URIRef("https://schema.org/targetPopulation")
    Nonprofit501c7 = URIRef("https://schema.org/Nonprofit501c7")
    DefinitiveLegalValue = URIRef("https://schema.org/DefinitiveLegalValue")
    license = URIRef("https://schema.org/license")
    hasBioChemEntityPart = URIRef("https://schema.org/hasBioChemEntityPart")
    tracks = URIRef("https://schema.org/tracks")
    areaServed = URIRef("https://schema.org/areaServed")
    NGO = URIRef("https://schema.org/NGO")
    mediaItemAppearance = URIRef("https://schema.org/mediaItemAppearance")
    Distance = URIRef("https://schema.org/Distance")
    WearableMeasurementInseam = URIRef("https://schema.org/WearableMeasurementInseam")
    step = URIRef("https://schema.org/step")
    CurrencyConversionService = URIRef("https://schema.org/CurrencyConversionService")
    credentialCategory = URIRef("https://schema.org/credentialCategory")
    itemCondition = URIRef("https://schema.org/itemCondition")
    CommentPermission = URIRef("https://schema.org/CommentPermission")
    catalogNumber = URIRef("https://schema.org/catalogNumber")
    dateIssued = URIRef("https://schema.org/dateIssued")
    hoursAvailable = URIRef("https://schema.org/hoursAvailable")
    acceptsReservations = URIRef("https://schema.org/acceptsReservations")
    Continent = URIRef("https://schema.org/Continent")
    Waterfall = URIRef("https://schema.org/Waterfall")
    WearableSizeGroupExtraShort = URIRef("https://schema.org/WearableSizeGroupExtraShort")
    OnlineFull = URIRef("https://schema.org/OnlineFull")
    digitalSourceType = URIRef("https://schema.org/digitalSourceType")
    PlaceOfWorship = URIRef("https://schema.org/PlaceOfWorship")
    MonetaryAmount = URIRef("https://schema.org/MonetaryAmount")
    hasOfferCatalog = URIRef("https://schema.org/hasOfferCatalog")
    seatRow = URIRef("https://schema.org/seatRow")
    GardenStore = URIRef("https://schema.org/GardenStore")
    QuantitativeValue = URIRef("https://schema.org/QuantitativeValue")
    legislationTransposes = URIRef("https://schema.org/legislationTransposes")
    MenuSection = URIRef("https://schema.org/MenuSection")
    affectedBy = URIRef("https://schema.org/affectedBy")
    subStageSuffix = URIRef("https://schema.org/subStageSuffix")
    workFeatured = URIRef("https://schema.org/workFeatured")
    AllocateAction = URIRef("https://schema.org/AllocateAction")
    WearableMeasurementCollar = URIRef("https://schema.org/WearableMeasurementCollar")
    partOfTrip = URIRef("https://schema.org/partOfTrip")
    increasesRiskOf = URIRef("https://schema.org/increasesRiskOf")
    recordedAt = URIRef("https://schema.org/recordedAt")
    availableService = URIRef("https://schema.org/availableService")
    OrderInTransit = URIRef("https://schema.org/OrderInTransit")
    SchoolDistrict = URIRef("https://schema.org/SchoolDistrict")
    productionCompany = URIRef("https://schema.org/productionCompany")
    programPrerequisites = URIRef("https://schema.org/programPrerequisites")
    subStageSuffix = URIRef("https://schema.org/subStageSuffix")
    learningResourceType = URIRef("https://schema.org/learningResourceType")
    usedToDiagnose = URIRef("https://schema.org/usedToDiagnose")
    FrontWheelDriveConfiguration = URIRef("https://schema.org/FrontWheelDriveConfiguration")
    orderDelivery = URIRef("https://schema.org/orderDelivery")
    contactType = URIRef("https://schema.org/contactType")
    knowsLanguage = URIRef("https://schema.org/knowsLanguage")
    AskPublicNewsArticle = URIRef("https://schema.org/AskPublicNewsArticle")
    acceptedPaymentMethod = URIRef("https://schema.org/acceptedPaymentMethod")
    PerformingArtsTheater = URIRef("https://schema.org/PerformingArtsTheater")
    MedicalBusiness = URIRef("https://schema.org/MedicalBusiness")
    MerchantReturnUnspecified = URIRef("https://schema.org/MerchantReturnUnspecified")
    Beach = URIRef("https://schema.org/Beach")
    unitCode = URIRef("https://schema.org/unitCode")
    checkinTime = URIRef("https://schema.org/checkinTime")
    nonProprietaryName = URIRef("https://schema.org/nonProprietaryName")
    supply = URIRef("https://schema.org/supply")
    isSimilarTo = URIRef("https://schema.org/isSimilarTo")
    WearableSizeSystemFR = URIRef("https://schema.org/WearableSizeSystemFR")
    CDCPMDRecord = URIRef("https://schema.org/CDCPMDRecord")
    workPerformed = URIRef("https://schema.org/workPerformed")
    VideoObject = URIRef("https://schema.org/VideoObject")
    constraintProperty = URIRef("https://schema.org/constraintProperty")
    loanRepaymentForm = URIRef("https://schema.org/loanRepaymentForm")
    Virus = URIRef("https://schema.org/Virus")
    PaymentService = URIRef("https://schema.org/PaymentService")
    recognizedBy = URIRef("https://schema.org/recognizedBy")
    Report = URIRef("https://schema.org/Report")
    Library = URIRef("https://schema.org/Library")
    medicalAudience = URIRef("https://schema.org/medicalAudience")
    Skin = URIRef("https://schema.org/Skin")
    WeaponConsideration = URIRef("https://schema.org/WeaponConsideration")
    translationOfWork = URIRef("https://schema.org/translationOfWork")
    Musculoskeletal = URIRef("https://schema.org/Musculoskeletal")
    ClaimReview = URIRef("https://schema.org/ClaimReview")
    produces = URIRef("https://schema.org/produces")
    taxonomicRange = URIRef("https://schema.org/taxonomicRange")
    Certification = URIRef("https://schema.org/Certification")
    courseWorkload = URIRef("https://schema.org/courseWorkload")
    sdLicense = URIRef("https://schema.org/sdLicense")
    returnFees = URIRef("https://schema.org/returnFees")
    Course = URIRef("https://schema.org/Course")
    MonetaryGrant = URIRef("https://schema.org/MonetaryGrant")
    ReturnByMail = URIRef("https://schema.org/ReturnByMail")
    HairSalon = URIRef("https://schema.org/HairSalon")
    physicalRequirement = URIRef("https://schema.org/physicalRequirement")
    credentialCategory = URIRef("https://schema.org/credentialCategory")
    isRelatedTo = URIRef("https://schema.org/isRelatedTo")
    legislationPassedBy = URIRef("https://schema.org/legislationPassedBy")
    dayOfWeek = URIRef("https://schema.org/dayOfWeek")
    Nonprofit501c16 = URIRef("https://schema.org/Nonprofit501c16")
    itemShipped = URIRef("https://schema.org/itemShipped")
    MerchantReturnNotPermitted = URIRef("https://schema.org/MerchantReturnNotPermitted")
    foundingDate = URIRef("https://schema.org/foundingDate")
    legislationChanges = URIRef("https://schema.org/legislationChanges")
    ChildrensEvent = URIRef("https://schema.org/ChildrensEvent")
    byMonth = URIRef("https://schema.org/byMonth")
    acquiredFrom = URIRef("https://schema.org/acquiredFrom")
    variesBy = URIRef("https://schema.org/variesBy")
    cargoVolume = URIRef("https://schema.org/cargoVolume")
    softwareRequirements = URIRef("https://schema.org/softwareRequirements")
    OfferShippingDetails = URIRef("https://schema.org/OfferShippingDetails")
    numberOfEmployees = URIRef("https://schema.org/numberOfEmployees")
    dateReceived = URIRef("https://schema.org/dateReceived")
    dateDeleted = URIRef("https://schema.org/dateDeleted")
    LiteraryEvent = URIRef("https://schema.org/LiteraryEvent")
    DaySpa = URIRef("https://schema.org/DaySpa")
    familyName = URIRef("https://schema.org/familyName")
    accessibilityFeature = URIRef("https://schema.org/accessibilityFeature")
    touristType = URIRef("https://schema.org/touristType")
    hasVariant = URIRef("https://schema.org/hasVariant")
    acquireLicensePage = URIRef("https://schema.org/acquireLicensePage")
    ReservationHold = URIRef("https://schema.org/ReservationHold")
    PrependAction = URIRef("https://schema.org/PrependAction")
    healthPlanNetworkId = URIRef("https://schema.org/healthPlanNetworkId")
    track = URIRef("https://schema.org/track")
    PerformingGroup = URIRef("https://schema.org/PerformingGroup")
    WorkBasedProgram = URIRef("https://schema.org/WorkBasedProgram")
    productionDate = URIRef("https://schema.org/productionDate")
    additionalName = URIRef("https://schema.org/additionalName")
    requiredGender = URIRef("https://schema.org/requiredGender")
    replacee = URIRef("https://schema.org/replacee")
    Neurologic = URIRef("https://schema.org/Neurologic")
    modelDate = URIRef("https://schema.org/modelDate")
    Nonprofit501c15 = URIRef("https://schema.org/Nonprofit501c15")
    AmusementPark = URIRef("https://schema.org/AmusementPark")
    steps = URIRef("https://schema.org/steps")
    seller = URIRef("https://schema.org/seller")
    geoRadius = URIRef("https://schema.org/geoRadius")
    BarOrPub = URIRef("https://schema.org/BarOrPub")
    line = URIRef("https://schema.org/line")
    HealthAspectEnumeration = URIRef("https://schema.org/HealthAspectEnumeration")
    expectedArrivalFrom = URIRef("https://schema.org/expectedArrivalFrom")
    isGift = URIRef("https://schema.org/isGift")
    recognizedBy = URIRef("https://schema.org/recognizedBy")
    sizeGroup = URIRef("https://schema.org/sizeGroup")
    MeetingRoom = URIRef("https://schema.org/MeetingRoom")
    itemListOrder = URIRef("https://schema.org/itemListOrder")
    fuelCapacity = URIRef("https://schema.org/fuelCapacity")
    size = URIRef("https://schema.org/size")
    FindAction = URIRef("https://schema.org/FindAction")
    Ligament = URIRef("https://schema.org/Ligament")
    season = URIRef("https://schema.org/season")
    busNumber = URIRef("https://schema.org/busNumber")
    Emergency = URIRef("https://schema.org/Emergency")
    fromLocation = URIRef("https://schema.org/fromLocation")
    shippingOrigin = URIRef("https://schema.org/shippingOrigin")
    ItemList = URIRef("https://schema.org/ItemList")
    grantee = URIRef("https://schema.org/grantee")
    legislationLegalForce = URIRef("https://schema.org/legislationLegalForce")
    Photograph = URIRef("https://schema.org/Photograph")
    MedicalCode = URIRef("https://schema.org/MedicalCode")
    CivicStructure = URIRef("https://schema.org/CivicStructure")
    InStock = URIRef("https://schema.org/InStock")
    labelDetails = URIRef("https://schema.org/labelDetails")
    UnclassifiedAdultConsideration = URIRef("https://schema.org/UnclassifiedAdultConsideration")
    GovernmentBenefitsType = URIRef("https://schema.org/GovernmentBenefitsType")
    enginePower = URIRef("https://schema.org/enginePower")
    Nonprofit501c16 = URIRef("https://schema.org/Nonprofit501c16")
    ReturnShippingFees = URIRef("https://schema.org/ReturnShippingFees")
    gender = URIRef("https://schema.org/gender")
    EnrollingByInvitation = URIRef("https://schema.org/EnrollingByInvitation")
    termsPerYear = URIRef("https://schema.org/termsPerYear")
    parentItem = URIRef("https://schema.org/parentItem")
    acceptedOffer = URIRef("https://schema.org/acceptedOffer")
    PreOrder = URIRef("https://schema.org/PreOrder")
    addOn = URIRef("https://schema.org/addOn")
    mealService = URIRef("https://schema.org/mealService")
    image = URIRef("https://schema.org/image")
    ReducedRelevanceForChildrenConsideration = URIRef("https://schema.org/ReducedRelevanceForChildrenConsideration")
    FullGameAvailability = URIRef("https://schema.org/FullGameAvailability")
    Atlas = URIRef("https://schema.org/Atlas")
    readBy = URIRef("https://schema.org/readBy")
    Infectious = URIRef("https://schema.org/Infectious")
    WearableSizeSystemEurope = URIRef("https://schema.org/WearableSizeSystemEurope")
    Audiobook = URIRef("https://schema.org/Audiobook")
    hasDriveThroughService = URIRef("https://schema.org/hasDriveThroughService")
    requiredMaxAge = URIRef("https://schema.org/requiredMaxAge")
    AMRadioChannel = URIRef("https://schema.org/AMRadioChannel")
    DryCleaningOrLaundry = URIRef("https://schema.org/DryCleaningOrLaundry")
    legalStatus = URIRef("https://schema.org/legalStatus")
    Sunday = URIRef("https://schema.org/Sunday")
    OneTimePayments = URIRef("https://schema.org/OneTimePayments")
    editEIDR = URIRef("https://schema.org/editEIDR")
    legislationChanges = URIRef("https://schema.org/legislationChanges")
    WearableSizeSystemIT = URIRef("https://schema.org/WearableSizeSystemIT")
    Gynecologic = URIRef("https://schema.org/Gynecologic")
    exceptDate = URIRef("https://schema.org/exceptDate")
    Periodical = URIRef("https://schema.org/Periodical")
    parentService = URIRef("https://schema.org/parentService")
    HighSchool = URIRef("https://schema.org/HighSchool")
    LivingWithHealthAspect = URIRef("https://schema.org/LivingWithHealthAspect")
    RestrictedDiet = URIRef("https://schema.org/RestrictedDiet")
    surface = URIRef("https://schema.org/surface")
    Periodical = URIRef("https://schema.org/Periodical")
    occupancy = URIRef("https://schema.org/occupancy")
    WritePermission = URIRef("https://schema.org/WritePermission")
    MedicalCondition = URIRef("https://schema.org/MedicalCondition")
    holdingArchive = URIRef("https://schema.org/holdingArchive")
    numberOfPlayers = URIRef("https://schema.org/numberOfPlayers")
    trialDesign = URIRef("https://schema.org/trialDesign")
    jobLocation = URIRef("https://schema.org/jobLocation")
    ChemicalSubstance = URIRef("https://schema.org/ChemicalSubstance")
    height = URIRef("https://schema.org/height")
    suggestedMinAge = URIRef("https://schema.org/suggestedMinAge")
    comprisedOf = URIRef("https://schema.org/comprisedOf")
    smokingAllowed = URIRef("https://schema.org/smokingAllowed")
    endorsers = URIRef("https://schema.org/endorsers")
    requiredGender = URIRef("https://schema.org/requiredGender")
    breastfeedingWarning = URIRef("https://schema.org/breastfeedingWarning")
    citation = URIRef("https://schema.org/citation")
    coverageStartTime = URIRef("https://schema.org/coverageStartTime")
    cvdNumC19Died = URIRef("https://schema.org/cvdNumC19Died")
    QuantitativeValueDistribution = URIRef("https://schema.org/QuantitativeValueDistribution")
    quarantineGuidelines = URIRef("https://schema.org/quarantineGuidelines")
    PeopleAudience = URIRef("https://schema.org/PeopleAudience")
    applicantLocationRequirements = URIRef("https://schema.org/applicantLocationRequirements")
    taxonRank = URIRef("https://schema.org/taxonRank")
    StatusEnumeration = URIRef("https://schema.org/StatusEnumeration")
    HealthPlanCostSharingSpecification = URIRef("https://schema.org/HealthPlanCostSharingSpecification")
    AnatomicalSystem = URIRef("https://schema.org/AnatomicalSystem")
    TaxiService = URIRef("https://schema.org/TaxiService")
    gtin8 = URIRef("https://schema.org/gtin8")
    DecontextualizedContent = URIRef("https://schema.org/DecontextualizedContent")
    Vehicle = URIRef("https://schema.org/Vehicle")
    DataDownload = URIRef("https://schema.org/DataDownload")
    pageStart = URIRef("https://schema.org/pageStart")
    nonprofitStatus = URIRef("https://schema.org/nonprofitStatus")
    checkinTime = URIRef("https://schema.org/checkinTime")
    tributary = URIRef("https://schema.org/tributary")
    ParkingMap = URIRef("https://schema.org/ParkingMap")
    honorificPrefix = URIRef("https://schema.org/honorificPrefix")
    LearningResource = URIRef("https://schema.org/LearningResource")
    valueReference = URIRef("https://schema.org/valueReference")
    Dataset = URIRef("https://schema.org/Dataset")
    lastReviewed = URIRef("https://schema.org/lastReviewed")
    funding = URIRef("https://schema.org/funding")
    SportsOrganization = URIRef("https://schema.org/SportsOrganization")
    KeepProduct = URIRef("https://schema.org/KeepProduct")
    numberOfForwardGears = URIRef("https://schema.org/numberOfForwardGears")
    answerCount = URIRef("https://schema.org/answerCount")
    NightClub = URIRef("https://schema.org/NightClub")
    tongueWeight = URIRef("https://schema.org/tongueWeight")
    issn = URIRef("https://schema.org/issn")
    sdLicense = URIRef("https://schema.org/sdLicense")
    departureBusStop = URIRef("https://schema.org/departureBusStop")
    mealService = URIRef("https://schema.org/mealService")
    BusReservation = URIRef("https://schema.org/BusReservation")
    TextDigitalDocument = URIRef("https://schema.org/TextDigitalDocument")
    Muscle = URIRef("https://schema.org/Muscle")
    InsuranceAgency = URIRef("https://schema.org/InsuranceAgency")
    Newspaper = URIRef("https://schema.org/Newspaper")
    AlcoholConsideration = URIRef("https://schema.org/AlcoholConsideration")
    healthPlanCostSharing = URIRef("https://schema.org/healthPlanCostSharing")
    bodyType = URIRef("https://schema.org/bodyType")
    includesHealthPlanFormulary = URIRef("https://schema.org/includesHealthPlanFormulary")
    ConstraintNode = URIRef("https://schema.org/ConstraintNode")
    OriginalShippingFees = URIRef("https://schema.org/OriginalShippingFees")
    LowFatDiet = URIRef("https://schema.org/LowFatDiet")
    mentions = URIRef("https://schema.org/mentions")
    AndroidPlatform = URIRef("https://schema.org/AndroidPlatform")
    ownedThrough = URIRef("https://schema.org/ownedThrough")
    iupacName = URIRef("https://schema.org/iupacName")
    CorrectionComment = URIRef("https://schema.org/CorrectionComment")
    relatedCondition = URIRef("https://schema.org/relatedCondition")
    UnofficialLegalValue = URIRef("https://schema.org/UnofficialLegalValue")
    InvestmentOrDeposit = URIRef("https://schema.org/InvestmentOrDeposit")
    BenefitsHealthAspect = URIRef("https://schema.org/BenefitsHealthAspect")
    legislationConsolidates = URIRef("https://schema.org/legislationConsolidates")
    seatSection = URIRef("https://schema.org/seatSection")
    hasOccupation = URIRef("https://schema.org/hasOccupation")
    ConstraintNode = URIRef("https://schema.org/ConstraintNode")
    PlayAction = URIRef("https://schema.org/PlayAction")
    DatedMoneySpecification = URIRef("https://schema.org/DatedMoneySpecification")
    termDuration = URIRef("https://schema.org/termDuration")
    PublicSwimmingPool = URIRef("https://schema.org/PublicSwimmingPool")
    recognizingAuthority = URIRef("https://schema.org/recognizingAuthority")
    associatedClaimReview = URIRef("https://schema.org/associatedClaimReview")
    RsvpResponseNo = URIRef("https://schema.org/RsvpResponseNo")
    healthPlanDrugOption = URIRef("https://schema.org/healthPlanDrugOption")
    spokenByCharacter = URIRef("https://schema.org/spokenByCharacter")
    LakeBodyOfWater = URIRef("https://schema.org/LakeBodyOfWater")
    PrognosisHealthAspect = URIRef("https://schema.org/PrognosisHealthAspect")
    alumni = URIRef("https://schema.org/alumni")
    MedicalRiskScore = URIRef("https://schema.org/MedicalRiskScore")
    contactPoint = URIRef("https://schema.org/contactPoint")
    availabilityEnds = URIRef("https://schema.org/availabilityEnds")
    relatedLink = URIRef("https://schema.org/relatedLink")
    WearableSizeSystemFR = URIRef("https://schema.org/WearableSizeSystemFR")
    gtin13 = URIRef("https://schema.org/gtin13")
    grantee = URIRef("https://schema.org/grantee")
    numberOfCredits = URIRef("https://schema.org/numberOfCredits")
    MobileWebPlatform = URIRef("https://schema.org/MobileWebPlatform")
    TVSeries = URIRef("https://schema.org/TVSeries")
    suggestedGender = URIRef("https://schema.org/suggestedGender")
    ShippingRateSettings = URIRef("https://schema.org/ShippingRateSettings")
    freeShippingThreshold = URIRef("https://schema.org/freeShippingThreshold")
    surface = URIRef("https://schema.org/surface")
    valueReference = URIRef("https://schema.org/valueReference")
    associatedAnatomy = URIRef("https://schema.org/associatedAnatomy")
    containedInPlace = URIRef("https://schema.org/containedInPlace")
    WearableSizeGroupEnumeration = URIRef("https://schema.org/WearableSizeGroupEnumeration")
    CreateAction = URIRef("https://schema.org/CreateAction")
    Menu = URIRef("https://schema.org/Menu")
    composer = URIRef("https://schema.org/composer")
    educationalCredentialAwarded = URIRef("https://schema.org/educationalCredentialAwarded")
    codeValue = URIRef("https://schema.org/codeValue")
    legislationResponsible = URIRef("https://schema.org/legislationResponsible")
    jobLocationType = URIRef("https://schema.org/jobLocationType")
    leaseLength = URIRef("https://schema.org/leaseLength")
    OrderPaymentDue = URIRef("https://schema.org/OrderPaymentDue")
    thumbnailUrl = URIRef("https://schema.org/thumbnailUrl")
    PostOffice = URIRef("https://schema.org/PostOffice")
    location = URIRef("https://schema.org/location")
    billingPeriod = URIRef("https://schema.org/billingPeriod")
    vendor = URIRef("https://schema.org/vendor")
    hasBioChemEntityPart = URIRef("https://schema.org/hasBioChemEntityPart")
    childMaxAge = URIRef("https://schema.org/childMaxAge")
    HealthcareConsideration = URIRef("https://schema.org/HealthcareConsideration")
    Crematorium = URIRef("https://schema.org/Crematorium")
    Residence = URIRef("https://schema.org/Residence")
    numberOfCredits = URIRef("https://schema.org/numberOfCredits")
    reservationId = URIRef("https://schema.org/reservationId")
    DayOfWeek = URIRef("https://schema.org/DayOfWeek")
    MedicalCause = URIRef("https://schema.org/MedicalCause")
    members = URIRef("https://schema.org/members")
    xpath = URIRef("https://schema.org/xpath")
    duration = URIRef("https://schema.org/duration")
    availableIn = URIRef("https://schema.org/availableIn")
    DrugCostCategory = URIRef("https://schema.org/DrugCostCategory")
    securityClearanceRequirement = URIRef("https://schema.org/securityClearanceRequirement")
    Nonprofit501c26 = URIRef("https://schema.org/Nonprofit501c26")
    genre = URIRef("https://schema.org/genre")
    rsvpResponse = URIRef("https://schema.org/rsvpResponse")
    CompoundPriceSpecification = URIRef("https://schema.org/CompoundPriceSpecification")
    ChildrensEvent = URIRef("https://schema.org/ChildrensEvent")
    lowPrice = URIRef("https://schema.org/lowPrice")
    geoDisjoint = URIRef("https://schema.org/geoDisjoint")
    upvoteCount = URIRef("https://schema.org/upvoteCount")
    Manuscript = URIRef("https://schema.org/Manuscript")
    accessibilitySummary = URIRef("https://schema.org/accessibilitySummary")
    eduQuestionType = URIRef("https://schema.org/eduQuestionType")
    mobileUrl = URIRef("https://schema.org/mobileUrl")
    AccountingService = URIRef("https://schema.org/AccountingService")
    legislationTransposes = URIRef("https://schema.org/legislationTransposes")
    legislationPassedBy = URIRef("https://schema.org/legislationPassedBy")
    currency = URIRef("https://schema.org/currency")
    earlyPrepaymentPenalty = URIRef("https://schema.org/earlyPrepaymentPenalty")
    WebAPI = URIRef("https://schema.org/WebAPI")
    SteeringPositionValue = URIRef("https://schema.org/SteeringPositionValue")
    collectionSize = URIRef("https://schema.org/collectionSize")
    discountCode = URIRef("https://schema.org/discountCode")
    isInvolvedInBiologicalProcess = URIRef("https://schema.org/isInvolvedInBiologicalProcess")
    subTest = URIRef("https://schema.org/subTest")
    providerMobility = URIRef("https://schema.org/providerMobility")
    TrainedAlgorithmicMediaDigitalSource = URIRef("https://schema.org/TrainedAlgorithmicMediaDigitalSource")
    AskPublicNewsArticle = URIRef("https://schema.org/AskPublicNewsArticle")
    SizeGroupEnumeration = URIRef("https://schema.org/SizeGroupEnumeration")
    Midwifery = URIRef("https://schema.org/Midwifery")
    roofLoad = URIRef("https://schema.org/roofLoad")
    postalCodeEnd = URIRef("https://schema.org/postalCodeEnd")
    ViewAction = URIRef("https://schema.org/ViewAction")
    proprietaryName = URIRef("https://schema.org/proprietaryName")
    InteractAction = URIRef("https://schema.org/InteractAction")
    PaymentDue = URIRef("https://schema.org/PaymentDue")
    Energy = URIRef("https://schema.org/Energy")
    acceptsReservations = URIRef("https://schema.org/acceptsReservations")
    cvdFacilityId = URIRef("https://schema.org/cvdFacilityId")
    MedicalTest = URIRef("https://schema.org/MedicalTest")
    availableDeliveryMethod = URIRef("https://schema.org/availableDeliveryMethod")
    UnofficialLegalValue = URIRef("https://schema.org/UnofficialLegalValue")
    permissionType = URIRef("https://schema.org/permissionType")
    ShoeStore = URIRef("https://schema.org/ShoeStore")
    WearableSizeGroupShort = URIRef("https://schema.org/WearableSizeGroupShort")
    touristType = URIRef("https://schema.org/touristType")
    ConfirmAction = URIRef("https://schema.org/ConfirmAction")
    QuoteAction = URIRef("https://schema.org/QuoteAction")
    GameServer = URIRef("https://schema.org/GameServer")
    urlTemplate = URIRef("https://schema.org/urlTemplate")
    educationalFramework = URIRef("https://schema.org/educationalFramework")
    performerIn = URIRef("https://schema.org/performerIn")
    accountablePerson = URIRef("https://schema.org/accountablePerson")
    subjectOf = URIRef("https://schema.org/subjectOf")
    TouristAttraction = URIRef("https://schema.org/TouristAttraction")
    permitAudience = URIRef("https://schema.org/permitAudience")
    reservationStatus = URIRef("https://schema.org/reservationStatus")
    steeringPosition = URIRef("https://schema.org/steeringPosition")
    dateRead = URIRef("https://schema.org/dateRead")
    dataFeedElement = URIRef("https://schema.org/dataFeedElement")
    Ticket = URIRef("https://schema.org/Ticket")
    currentExchangeRate = URIRef("https://schema.org/currentExchangeRate")
    IngredientsHealthAspect = URIRef("https://schema.org/IngredientsHealthAspect")
    size = URIRef("https://schema.org/size")
    aggregateRating = URIRef("https://schema.org/aggregateRating")
    Nonprofit501e = URIRef("https://schema.org/Nonprofit501e")
    Bacteria = URIRef("https://schema.org/Bacteria")
    EducationalOccupationalProgram = URIRef("https://schema.org/EducationalOccupationalProgram")
    HousePainter = URIRef("https://schema.org/HousePainter")
    departureBoatTerminal = URIRef("https://schema.org/departureBoatTerminal")
    Psychiatric = URIRef("https://schema.org/Psychiatric")
    billingStart = URIRef("https://schema.org/billingStart")
    makesOffer = URIRef("https://schema.org/makesOffer")
    Seat = URIRef("https://schema.org/Seat")
    rsvpResponse = URIRef("https://schema.org/rsvpResponse")
    Winery = URIRef("https://schema.org/Winery")
    DigitalCaptureDigitalSource = URIRef("https://schema.org/DigitalCaptureDigitalSource")
    seatingCapacity = URIRef("https://schema.org/seatingCapacity")
    hasCourseInstance = URIRef("https://schema.org/hasCourseInstance")
    subStructure = URIRef("https://schema.org/subStructure")
    ArriveAction = URIRef("https://schema.org/ArriveAction")
    copyrightNotice = URIRef("https://schema.org/copyrightNotice")
    MedicalImagingTechnique = URIRef("https://schema.org/MedicalImagingTechnique")
    issueNumber = URIRef("https://schema.org/issueNumber")
    BoatTrip = URIRef("https://schema.org/BoatTrip")
    item = URIRef("https://schema.org/item")
    offersPrescriptionByMail = URIRef("https://schema.org/offersPrescriptionByMail")
    yearBuilt = URIRef("https://schema.org/yearBuilt")
    downPayment = URIRef("https://schema.org/downPayment")
    byDay = URIRef("https://schema.org/byDay")
    ReplaceAction = URIRef("https://schema.org/ReplaceAction")
    serviceSmsNumber = URIRef("https://schema.org/serviceSmsNumber")
    EBook = URIRef("https://schema.org/EBook")
    sponsor = URIRef("https://schema.org/sponsor")
    returnPolicyCountry = URIRef("https://schema.org/returnPolicyCountry")
    significantLinks = URIRef("https://schema.org/significantLinks")
    containsPlace = URIRef("https://schema.org/containsPlace")
    sizeGroup = URIRef("https://schema.org/sizeGroup")
    associatedDisease = URIRef("https://schema.org/associatedDisease")
    resultReview = URIRef("https://schema.org/resultReview")
    requirements = URIRef("https://schema.org/requirements")
    Suite = URIRef("https://schema.org/Suite")
    engineDisplacement = URIRef("https://schema.org/engineDisplacement")
    Recommendation = URIRef("https://schema.org/Recommendation")
    Resort = URIRef("https://schema.org/Resort")
    Nonprofit501c25 = URIRef("https://schema.org/Nonprofit501c25")
    AutoDealer = URIRef("https://schema.org/AutoDealer")
    itemListElement = URIRef("https://schema.org/itemListElement")
    Plumber = URIRef("https://schema.org/Plumber")
    CompositeSyntheticDigitalSource = URIRef("https://schema.org/CompositeSyntheticDigitalSource")
    RVPark = URIRef("https://schema.org/RVPark")
    encodingType = URIRef("https://schema.org/encodingType")
    PreOrder = URIRef("https://schema.org/PreOrder")
    softwareVersion = URIRef("https://schema.org/softwareVersion")
    ComputerLanguage = URIRef("https://schema.org/ComputerLanguage")
    credentialCategory = URIRef("https://schema.org/credentialCategory")
    legislationDateVersion = URIRef("https://schema.org/legislationDateVersion")
    addressCountry = URIRef("https://schema.org/addressCountry")
    editor = URIRef("https://schema.org/editor")
    itemOffered = URIRef("https://schema.org/itemOffered")
    applicationSubCategory = URIRef("https://schema.org/applicationSubCategory")
    CreativeWorkSeries = URIRef("https://schema.org/CreativeWorkSeries")
    colorSwatch = URIRef("https://schema.org/colorSwatch")
    seeks = URIRef("https://schema.org/seeks")
    legislationApplies = URIRef("https://schema.org/legislationApplies")
    contactlessPayment = URIRef("https://schema.org/contactlessPayment")
    administrationRoute = URIRef("https://schema.org/administrationRoute")
    CheckInAction = URIRef("https://schema.org/CheckInAction")
    loanTerm = URIRef("https://schema.org/loanTerm")
    FireStation = URIRef("https://schema.org/FireStation")
    tissueSample = URIRef("https://schema.org/tissueSample")
    encodingType = URIRef("https://schema.org/encodingType")
    BusinessEvent = URIRef("https://schema.org/BusinessEvent")
    vendor = URIRef("https://schema.org/vendor")
    serialNumber = URIRef("https://schema.org/serialNumber")
    minPrice = URIRef("https://schema.org/minPrice")
    RsvpAction = URIRef("https://schema.org/RsvpAction")
    alignmentType = URIRef("https://schema.org/alignmentType")
    LaboratoryScience = URIRef("https://schema.org/LaboratoryScience")
    actionAccessibilityRequirement = URIRef("https://schema.org/actionAccessibilityRequirement")
    CreativeWork = URIRef("https://schema.org/CreativeWork")
    tool = URIRef("https://schema.org/tool")
    icaoCode = URIRef("https://schema.org/icaoCode")
    speakable = URIRef("https://schema.org/speakable")
    iupacName = URIRef("https://schema.org/iupacName")
    BoatTrip = URIRef("https://schema.org/BoatTrip")
    AudioObjectSnapshot = URIRef("https://schema.org/AudioObjectSnapshot")
    fileSize = URIRef("https://schema.org/fileSize")
    alternateName = URIRef("https://schema.org/alternateName")
    TradeAction = URIRef("https://schema.org/TradeAction")
    tripOrigin = URIRef("https://schema.org/tripOrigin")
    MediaEnumeration = URIRef("https://schema.org/MediaEnumeration")
    numberOfAvailableAccommodationUnits = URIRef("https://schema.org/numberOfAvailableAccommodationUnits")
    businessDays = URIRef("https://schema.org/businessDays")
    productionCompany = URIRef("https://schema.org/productionCompany")
    lender = URIRef("https://schema.org/lender")
    jobBenefits = URIRef("https://schema.org/jobBenefits")
    numberOfAvailableAccommodationUnits = URIRef("https://schema.org/numberOfAvailableAccommodationUnits")
    distance = URIRef("https://schema.org/distance")
    providesService = URIRef("https://schema.org/providesService")
    pickupLocation = URIRef("https://schema.org/pickupLocation")
    availableAtOrFrom = URIRef("https://schema.org/availableAtOrFrom")
    overdosage = URIRef("https://schema.org/overdosage")
    targetCollection = URIRef("https://schema.org/targetCollection")
    certificationStatus = URIRef("https://schema.org/certificationStatus")
    MisconceptionsHealthAspect = URIRef("https://schema.org/MisconceptionsHealthAspect")
    interactionService = URIRef("https://schema.org/interactionService")
    partOfSeason = URIRef("https://schema.org/partOfSeason")
    associatedClaimReview = URIRef("https://schema.org/associatedClaimReview")
    actionPlatform = URIRef("https://schema.org/actionPlatform")
    duplicateTherapy = URIRef("https://schema.org/duplicateTherapy")
    game = URIRef("https://schema.org/game")
    WearableSizeGroupJuniors = URIRef("https://schema.org/WearableSizeGroupJuniors")
    TraditionalChinese = URIRef("https://schema.org/TraditionalChinese")
    branchCode = URIRef("https://schema.org/branchCode")
    Observational = URIRef("https://schema.org/Observational")
    fromLocation = URIRef("https://schema.org/fromLocation")
    HealthPlanFormulary = URIRef("https://schema.org/HealthPlanFormulary")
    QAPage = URIRef("https://schema.org/QAPage")
    potentialAction = URIRef("https://schema.org/potentialAction")
    recipeInstructions = URIRef("https://schema.org/recipeInstructions")
    publicAccess = URIRef("https://schema.org/publicAccess")
    hasMolecularFunction = URIRef("https://schema.org/hasMolecularFunction")
    review = URIRef("https://schema.org/review")
    hasMap = URIRef("https://schema.org/hasMap")
    customerRemorseReturnShippingFeesAmount = URIRef("https://schema.org/customerRemorseReturnShippingFeesAmount")
    firstPerformance = URIRef("https://schema.org/firstPerformance")
    newsUpdatesAndGuidelines = URIRef("https://schema.org/newsUpdatesAndGuidelines")
    DeliveryChargeSpecification = URIRef("https://schema.org/DeliveryChargeSpecification")
    LeftHandDriving = URIRef("https://schema.org/LeftHandDriving")
    paymentAccepted = URIRef("https://schema.org/paymentAccepted")
    skills = URIRef("https://schema.org/skills")
    coursePrerequisites = URIRef("https://schema.org/coursePrerequisites")
    screenCount = URIRef("https://schema.org/screenCount")
    legislationIdentifier = URIRef("https://schema.org/legislationIdentifier")
    ImageObjectSnapshot = URIRef("https://schema.org/ImageObjectSnapshot")
    NailSalon = URIRef("https://schema.org/NailSalon")
    acceptsReservations = URIRef("https://schema.org/acceptsReservations")
    Manuscript = URIRef("https://schema.org/Manuscript")
    employmentUnit = URIRef("https://schema.org/employmentUnit")
    fiberContent = URIRef("https://schema.org/fiberContent")
    lodgingUnitDescription = URIRef("https://schema.org/lodgingUnitDescription")
    HealthPlanCostSharingSpecification = URIRef("https://schema.org/HealthPlanCostSharingSpecification")
    ComedyEvent = URIRef("https://schema.org/ComedyEvent")
    speed = URIRef("https://schema.org/speed")
    duration = URIRef("https://schema.org/duration")
    BusinessSupport = URIRef("https://schema.org/BusinessSupport")
    UsageOrScheduleHealthAspect = URIRef("https://schema.org/UsageOrScheduleHealthAspect")
    aggregateRating = URIRef("https://schema.org/aggregateRating")
    FMRadioChannel = URIRef("https://schema.org/FMRadioChannel")
    xpath = URIRef("https://schema.org/xpath")
    PaymentStatusType = URIRef("https://schema.org/PaymentStatusType")
    itemOffered = URIRef("https://schema.org/itemOffered")
    instructor = URIRef("https://schema.org/instructor")
    LeisureTimeActivity = URIRef("https://schema.org/LeisureTimeActivity")
    observationPeriod = URIRef("https://schema.org/observationPeriod")
    Nonprofit501c7 = URIRef("https://schema.org/Nonprofit501c7")
    suggestedMinAge = URIRef("https://schema.org/suggestedMinAge")
    hasCredential = URIRef("https://schema.org/hasCredential")
    UserDownloads = URIRef("https://schema.org/UserDownloads")
    Oncologic = URIRef("https://schema.org/Oncologic")
    tocContinuation = URIRef("https://schema.org/tocContinuation")
    departureTerminal = URIRef("https://schema.org/departureTerminal")
    activeIngredient = URIRef("https://schema.org/activeIngredient")
    mathExpression = URIRef("https://schema.org/mathExpression")
    AutomotiveBusiness = URIRef("https://schema.org/AutomotiveBusiness")
    bookingAgent = URIRef("https://schema.org/bookingAgent")
    MedicalCause = URIRef("https://schema.org/MedicalCause")
    OutOfStock = URIRef("https://schema.org/OutOfStock")
    returnFees = URIRef("https://schema.org/returnFees")
    AutoWash = URIRef("https://schema.org/AutoWash")
    starRating = URIRef("https://schema.org/starRating")
    expectedPrognosis = URIRef("https://schema.org/expectedPrognosis")
    episodeNumber = URIRef("https://schema.org/episodeNumber")
    alternativeHeadline = URIRef("https://schema.org/alternativeHeadline")
    event = URIRef("https://schema.org/event")
    WearableSizeGroupGirls = URIRef("https://schema.org/WearableSizeGroupGirls")
    Movie = URIRef("https://schema.org/Movie")
    creativeWorkStatus = URIRef("https://schema.org/creativeWorkStatus")
    MedicalSign = URIRef("https://schema.org/MedicalSign")
    qualifications = URIRef("https://schema.org/qualifications")
    aggregateRating = URIRef("https://schema.org/aggregateRating")
    abstract = URIRef("https://schema.org/abstract")
    WearableSizeGroupBoys = URIRef("https://schema.org/WearableSizeGroupBoys")
    governmentBenefitsInfo = URIRef("https://schema.org/governmentBenefitsInfo")
    legislationIdentifier = URIRef("https://schema.org/legislationIdentifier")
    lesser = URIRef("https://schema.org/lesser")
    measurementTechnique = URIRef("https://schema.org/measurementTechnique")
    artist = URIRef("https://schema.org/artist")
    PoliticalParty = URIRef("https://schema.org/PoliticalParty")
    founders = URIRef("https://schema.org/founders")
    legislationConsolidates = URIRef("https://schema.org/legislationConsolidates")
    MovieClip = URIRef("https://schema.org/MovieClip")
    translator = URIRef("https://schema.org/translator")
    FDAcategoryX = URIRef("https://schema.org/FDAcategoryX")
    employee = URIRef("https://schema.org/employee")
    employmentType = URIRef("https://schema.org/employmentType")
    ItemListOrderAscending = URIRef("https://schema.org/ItemListOrderAscending")
    UserLikes = URIRef("https://schema.org/UserLikes")
    FundingScheme = URIRef("https://schema.org/FundingScheme")
    documentation = URIRef("https://schema.org/documentation")
    icaoCode = URIRef("https://schema.org/icaoCode")
    cookingMethod = URIRef("https://schema.org/cookingMethod")
    APIReference = URIRef("https://schema.org/APIReference")
    evidenceOrigin = URIRef("https://schema.org/evidenceOrigin")
    RegisterAction = URIRef("https://schema.org/RegisterAction")
    OccupationalTherapy = URIRef("https://schema.org/OccupationalTherapy")
    HowItWorksHealthAspect = URIRef("https://schema.org/HowItWorksHealthAspect")
    sizeSystem = URIRef("https://schema.org/sizeSystem")
    box = URIRef("https://schema.org/box")
    tourBookingPage = URIRef("https://schema.org/tourBookingPage")
    boardingPolicy = URIRef("https://schema.org/boardingPolicy")
    height = URIRef("https://schema.org/height")
    FindAction = URIRef("https://schema.org/FindAction")
    WearableMeasurementWaist = URIRef("https://schema.org/WearableMeasurementWaist")
    urlTemplate = URIRef("https://schema.org/urlTemplate")
    NewsMediaOrganization = URIRef("https://schema.org/NewsMediaOrganization")
    broadcastSignalModulation = URIRef("https://schema.org/broadcastSignalModulation")
    category = URIRef("https://schema.org/category")
    billingDuration = URIRef("https://schema.org/billingDuration")
    associatedClaimReview = URIRef("https://schema.org/associatedClaimReview")
    genre = URIRef("https://schema.org/genre")
    exchangeRateSpread = URIRef("https://schema.org/exchangeRateSpread")
    PrimaryCare = URIRef("https://schema.org/PrimaryCare")
    originalMediaContextDescription = URIRef("https://schema.org/originalMediaContextDescription")
    coverageStartTime = URIRef("https://schema.org/coverageStartTime")
    episodes = URIRef("https://schema.org/episodes")
    containedIn = URIRef("https://schema.org/containedIn")
    processorRequirements = URIRef("https://schema.org/processorRequirements")
    molecularWeight = URIRef("https://schema.org/molecularWeight")
    performer = URIRef("https://schema.org/performer")
    RealEstateAgent = URIRef("https://schema.org/RealEstateAgent")
    embedUrl = URIRef("https://schema.org/embedUrl")
    itemListElement = URIRef("https://schema.org/itemListElement")
    observationAbout = URIRef("https://schema.org/observationAbout")
    healthPlanNetworkId = URIRef("https://schema.org/healthPlanNetworkId")
    isFamilyFriendly = URIRef("https://schema.org/isFamilyFriendly")
    Casino = URIRef("https://schema.org/Casino")
    directApply = URIRef("https://schema.org/directApply")
    checkoutTime = URIRef("https://schema.org/checkoutTime")
    schoolClosuresInfo = URIRef("https://schema.org/schoolClosuresInfo")
    drugUnit = URIRef("https://schema.org/drugUnit")
    TrackAction = URIRef("https://schema.org/TrackAction")
    MedicalSignOrSymptom = URIRef("https://schema.org/MedicalSignOrSymptom")
    EducationalOccupationalCredential = URIRef("https://schema.org/EducationalOccupationalCredential")
    SRP = URIRef("https://schema.org/SRP")
    HowToSection = URIRef("https://schema.org/HowToSection")
    geoRadius = URIRef("https://schema.org/geoRadius")
    numberOfAxles = URIRef("https://schema.org/numberOfAxles")
    includesAttraction = URIRef("https://schema.org/includesAttraction")
    MotorizedBicycle = URIRef("https://schema.org/MotorizedBicycle")
    contentSize = URIRef("https://schema.org/contentSize")
    Nonprofit501c2 = URIRef("https://schema.org/Nonprofit501c2")
    floorLimit = URIRef("https://schema.org/floorLimit")
    duringMedia = URIRef("https://schema.org/duringMedia")
    MedicalIndication = URIRef("https://schema.org/MedicalIndication")
    DataFeed = URIRef("https://schema.org/DataFeed")
    toLocation = URIRef("https://schema.org/toLocation")
    SportsEvent = URIRef("https://schema.org/SportsEvent")
    reviewAspect = URIRef("https://schema.org/reviewAspect")
    startTime = URIRef("https://schema.org/startTime")
    itemListElement = URIRef("https://schema.org/itemListElement")
    Cemetery = URIRef("https://schema.org/Cemetery")
    targetPlatform = URIRef("https://schema.org/targetPlatform")
    color = URIRef("https://schema.org/color")
    Clip = URIRef("https://schema.org/Clip")
    healthPlanMarketingUrl = URIRef("https://schema.org/healthPlanMarketingUrl")
    CompilationAlbum = URIRef("https://schema.org/CompilationAlbum")
    Text = URIRef("https://schema.org/Text")
    codeSampleType = URIRef("https://schema.org/codeSampleType")
    UnincorporatedAssociationCharity = URIRef("https://schema.org/UnincorporatedAssociationCharity")
    deliveryAddress = URIRef("https://schema.org/deliveryAddress")
    dayOfWeek = URIRef("https://schema.org/dayOfWeek")
    CreativeWork = URIRef("https://schema.org/CreativeWork")
    healthPlanCopayOption = URIRef("https://schema.org/healthPlanCopayOption")
    ScholarlyArticle = URIRef("https://schema.org/ScholarlyArticle")
    departureBusStop = URIRef("https://schema.org/departureBusStop")
    SportsClub = URIRef("https://schema.org/SportsClub")
    SatireOrParodyContent = URIRef("https://schema.org/SatireOrParodyContent")
    possibleTreatment = URIRef("https://schema.org/possibleTreatment")
    occupationalCategory = URIRef("https://schema.org/occupationalCategory")
    physiologicalBenefits = URIRef("https://schema.org/physiologicalBenefits")
    AskAction = URIRef("https://schema.org/AskAction")
    Fungus = URIRef("https://schema.org/Fungus")
    PronounceableText = URIRef("https://schema.org/PronounceableText")
    screenshot = URIRef("https://schema.org/screenshot")
    PoliticalParty = URIRef("https://schema.org/PoliticalParty")
    knownVehicleDamages = URIRef("https://schema.org/knownVehicleDamages")
    colorist = URIRef("https://schema.org/colorist")
    PET = URIRef("https://schema.org/PET")
    attendee = URIRef("https://schema.org/attendee")
    occupationLocation = URIRef("https://schema.org/occupationLocation")
    publicAccess = URIRef("https://schema.org/publicAccess")
    includesAttraction = URIRef("https://schema.org/includesAttraction")
    polygon = URIRef("https://schema.org/polygon")
    MusicEvent = URIRef("https://schema.org/MusicEvent")
    serviceOperator = URIRef("https://schema.org/serviceOperator")
    endorsee = URIRef("https://schema.org/endorsee")
    missionCoveragePrioritiesPolicy = URIRef("https://schema.org/missionCoveragePrioritiesPolicy")
    ReservationCancelled = URIRef("https://schema.org/ReservationCancelled")
    mpn = URIRef("https://schema.org/mpn")
    returnShippingFeesAmount = URIRef("https://schema.org/returnShippingFeesAmount")
    NotInForce = URIRef("https://schema.org/NotInForce")
    bioChemInteraction = URIRef("https://schema.org/bioChemInteraction")
    RentalVehicleUsage = URIRef("https://schema.org/RentalVehicleUsage")
    applicationDeadline = URIRef("https://schema.org/applicationDeadline")
    error = URIRef("https://schema.org/error")
    MedicalObservationalStudyDesign = URIRef("https://schema.org/MedicalObservationalStudyDesign")
    LymphaticVessel = URIRef("https://schema.org/LymphaticVessel")
    firstAppearance = URIRef("https://schema.org/firstAppearance")
    jurisdiction = URIRef("https://schema.org/jurisdiction")
    publishedOn = URIRef("https://schema.org/publishedOn")
    cvdCollectionDate = URIRef("https://schema.org/cvdCollectionDate")
    SpreadsheetDigitalDocument = URIRef("https://schema.org/SpreadsheetDigitalDocument")
    ConfirmAction = URIRef("https://schema.org/ConfirmAction")
    funding = URIRef("https://schema.org/funding")
    healthPlanDrugTier = URIRef("https://schema.org/healthPlanDrugTier")
    broadcastFrequency = URIRef("https://schema.org/broadcastFrequency")
    inPlaylist = URIRef("https://schema.org/inPlaylist")
    Installment = URIRef("https://schema.org/Installment")
    layoutImage = URIRef("https://schema.org/layoutImage")
    WearableSizeGroupHusky = URIRef("https://schema.org/WearableSizeGroupHusky")
    isAcceptingNewPatients = URIRef("https://schema.org/isAcceptingNewPatients")
    Throat = URIRef("https://schema.org/Throat")
    bodyType = URIRef("https://schema.org/bodyType")
    colleagues = URIRef("https://schema.org/colleagues")
    ticketNumber = URIRef("https://schema.org/ticketNumber")
    positiveNotes = URIRef("https://schema.org/positiveNotes")
    EvidenceLevelA = URIRef("https://schema.org/EvidenceLevelA")
    breastfeedingWarning = URIRef("https://schema.org/breastfeedingWarning")
    worksFor = URIRef("https://schema.org/worksFor")
    area = URIRef("https://schema.org/area")
    offersPrescriptionByMail = URIRef("https://schema.org/offersPrescriptionByMail")
    branch = URIRef("https://schema.org/branch")
    Nonprofit501c2 = URIRef("https://schema.org/Nonprofit501c2")
    WebPageElement = URIRef("https://schema.org/WebPageElement")
    OpenTrial = URIRef("https://schema.org/OpenTrial")
    Nonprofit501c5 = URIRef("https://schema.org/Nonprofit501c5")
    spokenByCharacter = URIRef("https://schema.org/spokenByCharacter")
    events = URIRef("https://schema.org/events")
    significance = URIRef("https://schema.org/significance")
    VeterinaryCare = URIRef("https://schema.org/VeterinaryCare")
    WearableMeasurementHeight = URIRef("https://schema.org/WearableMeasurementHeight")
    Obstetric = URIRef("https://schema.org/Obstetric")
    clincalPharmacology = URIRef("https://schema.org/clincalPharmacology")
    exifData = URIRef("https://schema.org/exifData")
    AudiobookFormat = URIRef("https://schema.org/AudiobookFormat")
    occupationalCategory = URIRef("https://schema.org/occupationalCategory")
    geoCoveredBy = URIRef("https://schema.org/geoCoveredBy")
    AdvertiserContentArticle = URIRef("https://schema.org/AdvertiserContentArticle")
    handlingTime = URIRef("https://schema.org/handlingTime")
    TransitMap = URIRef("https://schema.org/TransitMap")
    resultComment = URIRef("https://schema.org/resultComment")
    infectiousAgentClass = URIRef("https://schema.org/infectiousAgentClass")
    requiredQuantity = URIRef("https://schema.org/requiredQuantity")
    returnPolicySeasonalOverride = URIRef("https://schema.org/returnPolicySeasonalOverride")
    paymentDueDate = URIRef("https://schema.org/paymentDueDate")
    steeringPosition = URIRef("https://schema.org/steeringPosition")
    confirmationNumber = URIRef("https://schema.org/confirmationNumber")
    EUEnergyEfficiencyCategoryC = URIRef("https://schema.org/EUEnergyEfficiencyCategoryC")
    afterMedia = URIRef("https://schema.org/afterMedia")
    roleName = URIRef("https://schema.org/roleName")
    syllabusSections = URIRef("https://schema.org/syllabusSections")
    hiringOrganization = URIRef("https://schema.org/hiringOrganization")
    supply = URIRef("https://schema.org/supply")
    returnPolicySeasonalOverride = URIRef("https://schema.org/returnPolicySeasonalOverride")
    parentOrganization = URIRef("https://schema.org/parentOrganization")
    PublicationIssue = URIRef("https://schema.org/PublicationIssue")
    titleEIDR = URIRef("https://schema.org/titleEIDR")
    Enumeration = URIRef("https://schema.org/Enumeration")
    availability = URIRef("https://schema.org/availability")
    DigitalDocument = URIRef("https://schema.org/DigitalDocument")
    loanTerm = URIRef("https://schema.org/loanTerm")
    PresentationDigitalDocument = URIRef("https://schema.org/PresentationDigitalDocument")
    merchantReturnDays = URIRef("https://schema.org/merchantReturnDays")
    BankOrCreditUnion = URIRef("https://schema.org/BankOrCreditUnion")
    HyperTocEntry = URIRef("https://schema.org/HyperTocEntry")
    BookFormatType = URIRef("https://schema.org/BookFormatType")
    exercisePlan = URIRef("https://schema.org/exercisePlan")
    HowTo = URIRef("https://schema.org/HowTo")
    isRelatedTo = URIRef("https://schema.org/isRelatedTo")
    partOfSeason = URIRef("https://schema.org/partOfSeason")
    associatedMedia = URIRef("https://schema.org/associatedMedia")
    Abdomen = URIRef("https://schema.org/Abdomen")
    dayOfWeek = URIRef("https://schema.org/dayOfWeek")
    encodesBioChemEntity = URIRef("https://schema.org/encodesBioChemEntity")
    embedUrl = URIRef("https://schema.org/embedUrl")
    video = URIRef("https://schema.org/video")
    material = URIRef("https://schema.org/material")
    MedicalRiskCalculator = URIRef("https://schema.org/MedicalRiskCalculator")
    sourcedFrom = URIRef("https://schema.org/sourcedFrom")
    TherapeuticProcedure = URIRef("https://schema.org/TherapeuticProcedure")
    Pharmacy = URIRef("https://schema.org/Pharmacy")
    associatedDisease = URIRef("https://schema.org/associatedDisease")
    byDay = URIRef("https://schema.org/byDay")
    MovingCompany = URIRef("https://schema.org/MovingCompany")
    isUnlabelledFallback = URIRef("https://schema.org/isUnlabelledFallback")
    HealthClub = URIRef("https://schema.org/HealthClub")
    archiveHeld = URIRef("https://schema.org/archiveHeld")
    parentItem = URIRef("https://schema.org/parentItem")
    Recommendation = URIRef("https://schema.org/Recommendation")
    CategoryCodeSet = URIRef("https://schema.org/CategoryCodeSet")
    nonprofitStatus = URIRef("https://schema.org/nonprofitStatus")
    partOfSystem = URIRef("https://schema.org/partOfSystem")
    genre = URIRef("https://schema.org/genre")
    numberOfPages = URIRef("https://schema.org/numberOfPages")
    returnMethod = URIRef("https://schema.org/returnMethod")
    courseMode = URIRef("https://schema.org/courseMode")
    IOSPlatform = URIRef("https://schema.org/IOSPlatform")
    ItemListUnordered = URIRef("https://schema.org/ItemListUnordered")
    Taxi = URIRef("https://schema.org/Taxi")
    subtitleLanguage = URIRef("https://schema.org/subtitleLanguage")
    Eye = URIRef("https://schema.org/Eye")
    actionableFeedbackPolicy = URIRef("https://schema.org/actionableFeedbackPolicy")
    Occupation = URIRef("https://schema.org/Occupation")
    logo = URIRef("https://schema.org/logo")
    BroadcastService = URIRef("https://schema.org/BroadcastService")
    expectsAcceptanceOf = URIRef("https://schema.org/expectsAcceptanceOf")
    Claim = URIRef("https://schema.org/Claim")
    OfferShippingDetails = URIRef("https://schema.org/OfferShippingDetails")
    learningResourceType = URIRef("https://schema.org/learningResourceType")
    encodings = URIRef("https://schema.org/encodings")
    Game = URIRef("https://schema.org/Game")
    MedicalOrganization = URIRef("https://schema.org/MedicalOrganization")
    UKTrust = URIRef("https://schema.org/UKTrust")
    equal = URIRef("https://schema.org/equal")
    numberOfSeasons = URIRef("https://schema.org/numberOfSeasons")
    SizeSpecification = URIRef("https://schema.org/SizeSpecification")
    BusinessSupport = URIRef("https://schema.org/BusinessSupport")
    SingleFamilyResidence = URIRef("https://schema.org/SingleFamilyResidence")
    blogPosts = URIRef("https://schema.org/blogPosts")
    isProprietary = URIRef("https://schema.org/isProprietary")
    fatContent = URIRef("https://schema.org/fatContent")
    AppendAction = URIRef("https://schema.org/AppendAction")
    secondaryPrevention = URIRef("https://schema.org/secondaryPrevention")
    Anesthesia = URIRef("https://schema.org/Anesthesia")
    SeeDoctorHealthAspect = URIRef("https://schema.org/SeeDoctorHealthAspect")
    Hematologic = URIRef("https://schema.org/Hematologic")
    Preschool = URIRef("https://schema.org/Preschool")
    SeeDoctorHealthAspect = URIRef("https://schema.org/SeeDoctorHealthAspect")
    toRecipient = URIRef("https://schema.org/toRecipient")
    breadcrumb = URIRef("https://schema.org/breadcrumb")
    serviceOperator = URIRef("https://schema.org/serviceOperator")
    legislationResponsible = URIRef("https://schema.org/legislationResponsible")
    Pharmacy = URIRef("https://schema.org/Pharmacy")
    numberOfAirbags = URIRef("https://schema.org/numberOfAirbags")
    WeaponConsideration = URIRef("https://schema.org/WeaponConsideration")
    nerveMotor = URIRef("https://schema.org/nerveMotor")
    publishingPrinciples = URIRef("https://schema.org/publishingPrinciples")
    creditedTo = URIRef("https://schema.org/creditedTo")
    domiciledMortgage = URIRef("https://schema.org/domiciledMortgage")
    specialty = URIRef("https://schema.org/specialty")
    billingAddress = URIRef("https://schema.org/billingAddress")
    returnMethod = URIRef("https://schema.org/returnMethod")
    WearableSizeGroupMaternity = URIRef("https://schema.org/WearableSizeGroupMaternity")
    associatedDisease = URIRef("https://schema.org/associatedDisease")
    maximumEnrollment = URIRef("https://schema.org/maximumEnrollment")
    byMonth = URIRef("https://schema.org/byMonth")
    BlogPosting = URIRef("https://schema.org/BlogPosting")
    AMRadioChannel = URIRef("https://schema.org/AMRadioChannel")
    returnMethod = URIRef("https://schema.org/returnMethod")
    salaryCurrency = URIRef("https://schema.org/salaryCurrency")
    Newspaper = URIRef("https://schema.org/Newspaper")
    BenefitsHealthAspect = URIRef("https://schema.org/BenefitsHealthAspect")
    serviceArea = URIRef("https://schema.org/serviceArea")
    SalePrice = URIRef("https://schema.org/SalePrice")
    sourcedFrom = URIRef("https://schema.org/sourcedFrom")
    responsibilities = URIRef("https://schema.org/responsibilities")
    totalTime = URIRef("https://schema.org/totalTime")
    monoisotopicMolecularWeight = URIRef("https://schema.org/monoisotopicMolecularWeight")
    album = URIRef("https://schema.org/album")
    EUEnergyEfficiencyCategoryA2Plus = URIRef("https://schema.org/EUEnergyEfficiencyCategoryA2Plus")
    exchangeRateSpread = URIRef("https://schema.org/exchangeRateSpread")
    longitude = URIRef("https://schema.org/longitude")
    FireStation = URIRef("https://schema.org/FireStation")
    educationalLevel = URIRef("https://schema.org/educationalLevel")
    musicCompositionForm = URIRef("https://schema.org/musicCompositionForm")
    recipient = URIRef("https://schema.org/recipient")
    SteeringPositionValue = URIRef("https://schema.org/SteeringPositionValue")
    InfectiousDisease = URIRef("https://schema.org/InfectiousDisease")
    termsOfService = URIRef("https://schema.org/termsOfService")
    gtin = URIRef("https://schema.org/gtin")
    ExchangeRefund = URIRef("https://schema.org/ExchangeRefund")
    iataCode = URIRef("https://schema.org/iataCode")
    recognizedBy = URIRef("https://schema.org/recognizedBy")
    Motel = URIRef("https://schema.org/Motel")
    attendee = URIRef("https://schema.org/attendee")
    temporal = URIRef("https://schema.org/temporal")
    MusicGroup = URIRef("https://schema.org/MusicGroup")
    experienceInPlaceOfEducation = URIRef("https://schema.org/experienceInPlaceOfEducation")
    Nose = URIRef("https://schema.org/Nose")
    fatContent = URIRef("https://schema.org/fatContent")
    missionCoveragePrioritiesPolicy = URIRef("https://schema.org/missionCoveragePrioritiesPolicy")
    healthPlanId = URIRef("https://schema.org/healthPlanId")
    statType = URIRef("https://schema.org/statType")
    mentions = URIRef("https://schema.org/mentions")
    Nonprofit501c24 = URIRef("https://schema.org/Nonprofit501c24")
    EducationEvent = URIRef("https://schema.org/EducationEvent")
    shippingOrigin = URIRef("https://schema.org/shippingOrigin")
    rxcui = URIRef("https://schema.org/rxcui")
    XRay = URIRef("https://schema.org/XRay")
    PrintDigitalSource = URIRef("https://schema.org/PrintDigitalSource")
    itemShipped = URIRef("https://schema.org/itemShipped")
    numberOfRooms = URIRef("https://schema.org/numberOfRooms")
    actionAccessibilityRequirement = URIRef("https://schema.org/actionAccessibilityRequirement")
    paymentStatus = URIRef("https://schema.org/paymentStatus")
    comprisedOf = URIRef("https://schema.org/comprisedOf")
    EUEnergyEfficiencyCategoryG = URIRef("https://schema.org/EUEnergyEfficiencyCategoryG")
    feesAndCommissionsSpecification = URIRef("https://schema.org/feesAndCommissionsSpecification")
    DefinedTermSet = URIRef("https://schema.org/DefinedTermSet")
    bloodSupply = URIRef("https://schema.org/bloodSupply")
    workLocation = URIRef("https://schema.org/workLocation")
    accelerationTime = URIRef("https://schema.org/accelerationTime")
    PriceComponentTypeEnumeration = URIRef("https://schema.org/PriceComponentTypeEnumeration")
    healthPlanCoinsuranceRate = URIRef("https://schema.org/healthPlanCoinsuranceRate")
    responsibilities = URIRef("https://schema.org/responsibilities")
    CreditCard = URIRef("https://schema.org/CreditCard")
    requirements = URIRef("https://schema.org/requirements")
    orderedItem = URIRef("https://schema.org/orderedItem")
    GiveAction = URIRef("https://schema.org/GiveAction")
    nonEqual = URIRef("https://schema.org/nonEqual")
    preOp = URIRef("https://schema.org/preOp")
    totalPrice = URIRef("https://schema.org/totalPrice")
    musicalKey = URIRef("https://schema.org/musicalKey")
    worksFor = URIRef("https://schema.org/worksFor")
    departureBusStop = URIRef("https://schema.org/departureBusStop")
    torque = URIRef("https://schema.org/torque")
    MedicalScholarlyArticle = URIRef("https://schema.org/MedicalScholarlyArticle")
    serialNumber = URIRef("https://schema.org/serialNumber")
    LendAction = URIRef("https://schema.org/LendAction")
    Tuesday = URIRef("https://schema.org/Tuesday")
    Quiz = URIRef("https://schema.org/Quiz")
    EUEnergyEfficiencyCategoryB = URIRef("https://schema.org/EUEnergyEfficiencyCategoryB")
    legislationResponsible = URIRef("https://schema.org/legislationResponsible")
    DiscoverAction = URIRef("https://schema.org/DiscoverAction")
    currenciesAccepted = URIRef("https://schema.org/currenciesAccepted")
    Flexibility = URIRef("https://schema.org/Flexibility")
    VenueMap = URIRef("https://schema.org/VenueMap")
    regionDrained = URIRef("https://schema.org/regionDrained")
    occupationalCredentialAwarded = URIRef("https://schema.org/occupationalCredentialAwarded")
    itemShipped = URIRef("https://schema.org/itemShipped")
    estimatesRiskOf = URIRef("https://schema.org/estimatesRiskOf")
    courseWorkload = URIRef("https://schema.org/courseWorkload")
    OnDemandEvent = URIRef("https://schema.org/OnDemandEvent")
    SeatingMap = URIRef("https://schema.org/SeatingMap")
    monthsOfExperience = URIRef("https://schema.org/monthsOfExperience")
    RentalVehicleUsage = URIRef("https://schema.org/RentalVehicleUsage")
    strengthUnit = URIRef("https://schema.org/strengthUnit")
    SocialMediaPosting = URIRef("https://schema.org/SocialMediaPosting")
    administrationRoute = URIRef("https://schema.org/administrationRoute")
    molecularWeight = URIRef("https://schema.org/molecularWeight")
    actionableFeedbackPolicy = URIRef("https://schema.org/actionableFeedbackPolicy")
    globalLocationNumber = URIRef("https://schema.org/globalLocationNumber")
    naics = URIRef("https://schema.org/naics")
    BodyMeasurementWaist = URIRef("https://schema.org/BodyMeasurementWaist")
    checkoutTime = URIRef("https://schema.org/checkoutTime")
    HowToTip = URIRef("https://schema.org/HowToTip")
    actor = URIRef("https://schema.org/actor")
    diseaseSpreadStatistics = URIRef("https://schema.org/diseaseSpreadStatistics")
    resultReview = URIRef("https://schema.org/resultReview")
    BloodTest = URIRef("https://schema.org/BloodTest")
    lodgingUnitDescription = URIRef("https://schema.org/lodgingUnitDescription")
    MedicalProcedure = URIRef("https://schema.org/MedicalProcedure")
    creator = URIRef("https://schema.org/creator")
    TreatmentsHealthAspect = URIRef("https://schema.org/TreatmentsHealthAspect")
    AllWheelDriveConfiguration = URIRef("https://schema.org/AllWheelDriveConfiguration")
    model = URIRef("https://schema.org/model")
    ReturnAction = URIRef("https://schema.org/ReturnAction")
    EUEnergyEfficiencyCategoryF = URIRef("https://schema.org/EUEnergyEfficiencyCategoryF")
    DesktopWebPlatform = URIRef("https://schema.org/DesktopWebPlatform")
    employees = URIRef("https://schema.org/employees")
    Room = URIRef("https://schema.org/Room")
    isConsumableFor = URIRef("https://schema.org/isConsumableFor")
    ExchangeRefund = URIRef("https://schema.org/ExchangeRefund")
    WPFooter = URIRef("https://schema.org/WPFooter")
    BusStation = URIRef("https://schema.org/BusStation")
    dosageForm = URIRef("https://schema.org/dosageForm")
    gtin12 = URIRef("https://schema.org/gtin12")
    Organization = URIRef("https://schema.org/Organization")
    MedicalStudyStatus = URIRef("https://schema.org/MedicalStudyStatus")
    ControlAction = URIRef("https://schema.org/ControlAction")
    ExchangeRateSpecification = URIRef("https://schema.org/ExchangeRateSpecification")
    positiveNotes = URIRef("https://schema.org/positiveNotes")
    doesNotShip = URIRef("https://schema.org/doesNotShip")
    follows = URIRef("https://schema.org/follows")
    saturatedFatContent = URIRef("https://schema.org/saturatedFatContent")
    SoldOut = URIRef("https://schema.org/SoldOut")
    Drug = URIRef("https://schema.org/Drug")
    startTime = URIRef("https://schema.org/startTime")
    awards = URIRef("https://schema.org/awards")
    InForce = URIRef("https://schema.org/InForce")
    greaterOrEqual = URIRef("https://schema.org/greaterOrEqual")
    WearableSizeGroupEnumeration = URIRef("https://schema.org/WearableSizeGroupEnumeration")
    member = URIRef("https://schema.org/member")
    installUrl = URIRef("https://schema.org/installUrl")
    hasVariant = URIRef("https://schema.org/hasVariant")
    numberOfRooms = URIRef("https://schema.org/numberOfRooms")
    TouristInformationCenter = URIRef("https://schema.org/TouristInformationCenter")
    ReturnLabelCustomerResponsibility = URIRef("https://schema.org/ReturnLabelCustomerResponsibility")
    Otolaryngologic = URIRef("https://schema.org/Otolaryngologic")
    measurementTechnique = URIRef("https://schema.org/measurementTechnique")
    diversityStaffingReport = URIRef("https://schema.org/diversityStaffingReport")
    FrontWheelDriveConfiguration = URIRef("https://schema.org/FrontWheelDriveConfiguration")
    relevantSpecialty = URIRef("https://schema.org/relevantSpecialty")
    text = URIRef("https://schema.org/text")
    albumReleaseType = URIRef("https://schema.org/albumReleaseType")
    MediaReview = URIRef("https://schema.org/MediaReview")
    containedIn = URIRef("https://schema.org/containedIn")
    nsn = URIRef("https://schema.org/nsn")
    numberOfAxles = URIRef("https://schema.org/numberOfAxles")
    ItemPage = URIRef("https://schema.org/ItemPage")
    diet = URIRef("https://schema.org/diet")
    cvdNumTotBeds = URIRef("https://schema.org/cvdNumTotBeds")
    claimReviewed = URIRef("https://schema.org/claimReviewed")
    geoEquals = URIRef("https://schema.org/geoEquals")
    about = URIRef("https://schema.org/about")
    PreOrderAction = URIRef("https://schema.org/PreOrderAction")
    ReplyAction = URIRef("https://schema.org/ReplyAction")
    currency = URIRef("https://schema.org/currency")
    MedicalSymptom = URIRef("https://schema.org/MedicalSymptom")
    UserBlocks = URIRef("https://schema.org/UserBlocks")
    HowToItem = URIRef("https://schema.org/HowToItem")
    healthPlanId = URIRef("https://schema.org/healthPlanId")
    performers = URIRef("https://schema.org/performers")
    partOfSeries = URIRef("https://schema.org/partOfSeries")
    WearAction = URIRef("https://schema.org/WearAction")
    fileSize = URIRef("https://schema.org/fileSize")
    publishingPrinciples = URIRef("https://schema.org/publishingPrinciples")
    byArtist = URIRef("https://schema.org/byArtist")
    asin = URIRef("https://schema.org/asin")
    biologicalRole = URIRef("https://schema.org/biologicalRole")
    accessModeSufficient = URIRef("https://schema.org/accessModeSufficient")
    colorSwatch = URIRef("https://schema.org/colorSwatch")
    cvdNumC19HospPats = URIRef("https://schema.org/cvdNumC19HospPats")
    InStock = URIRef("https://schema.org/InStock")
    paymentMethodId = URIRef("https://schema.org/paymentMethodId")
    WebPage = URIRef("https://schema.org/WebPage")
    ShippingDeliveryTime = URIRef("https://schema.org/ShippingDeliveryTime")
    taxonRank = URIRef("https://schema.org/taxonRank")
    asin = URIRef("https://schema.org/asin")
    Order = URIRef("https://schema.org/Order")
    SingleCenterTrial = URIRef("https://schema.org/SingleCenterTrial")
    IngredientsHealthAspect = URIRef("https://schema.org/IngredientsHealthAspect")
    DrugStrength = URIRef("https://schema.org/DrugStrength")
    ShoppingCenter = URIRef("https://schema.org/ShoppingCenter")
    Psychiatric = URIRef("https://schema.org/Psychiatric")
    provider = URIRef("https://schema.org/provider")
    responsibilities = URIRef("https://schema.org/responsibilities")
    modifiedTime = URIRef("https://schema.org/modifiedTime")
    hasPOS = URIRef("https://schema.org/hasPOS")
    customer = URIRef("https://schema.org/customer")
    rangeIncludes = URIRef("https://schema.org/rangeIncludes")
    childMaxAge = URIRef("https://schema.org/childMaxAge")
    children = URIRef("https://schema.org/children")
    RadioStation = URIRef("https://schema.org/RadioStation")
    relatedCondition = URIRef("https://schema.org/relatedCondition")
    measurementTechnique = URIRef("https://schema.org/measurementTechnique")
    hasOfferCatalog = URIRef("https://schema.org/hasOfferCatalog")
    nsn = URIRef("https://schema.org/nsn")
    UserPlusOnes = URIRef("https://schema.org/UserPlusOnes")
    parent = URIRef("https://schema.org/parent")
    smokingAllowed = URIRef("https://schema.org/smokingAllowed")
    faxNumber = URIRef("https://schema.org/faxNumber")
    calories = URIRef("https://schema.org/calories")
    VitalSign = URIRef("https://schema.org/VitalSign")
    variableMeasured = URIRef("https://schema.org/variableMeasured")
    ItemListOrderType = URIRef("https://schema.org/ItemListOrderType")
    tongueWeight = URIRef("https://schema.org/tongueWeight")
    evidenceLevel = URIRef("https://schema.org/evidenceLevel")
    occupationLocation = URIRef("https://schema.org/occupationLocation")
    UserPlusOnes = URIRef("https://schema.org/UserPlusOnes")
    InternationalTrial = URIRef("https://schema.org/InternationalTrial")
    ReservationStatusType = URIRef("https://schema.org/ReservationStatusType")
    HyperToc = URIRef("https://schema.org/HyperToc")
    BackOrder = URIRef("https://schema.org/BackOrder")
    SeekToAction = URIRef("https://schema.org/SeekToAction")
    permitAudience = URIRef("https://schema.org/permitAudience")
    photos = URIRef("https://schema.org/photos")
    actionApplication = URIRef("https://schema.org/actionApplication")
    actionableFeedbackPolicy = URIRef("https://schema.org/actionableFeedbackPolicy")
    Cemetery = URIRef("https://schema.org/Cemetery")
    associatedAnatomy = URIRef("https://schema.org/associatedAnatomy")
    competitor = URIRef("https://schema.org/competitor")
    cheatCode = URIRef("https://schema.org/cheatCode")
    ElectronicsStore = URIRef("https://schema.org/ElectronicsStore")
    seasonNumber = URIRef("https://schema.org/seasonNumber")
    gettingTestedInfo = URIRef("https://schema.org/gettingTestedInfo")
    geoWithin = URIRef("https://schema.org/geoWithin")
    position = URIRef("https://schema.org/position")
    unnamedSourcesPolicy = URIRef("https://schema.org/unnamedSourcesPolicy")
    EndorsementRating = URIRef("https://schema.org/EndorsementRating")
    pregnancyCategory = URIRef("https://schema.org/pregnancyCategory")
    PriceComponentTypeEnumeration = URIRef("https://schema.org/PriceComponentTypeEnumeration")
    serialNumber = URIRef("https://schema.org/serialNumber")
    ownershipFundingInfo = URIRef("https://schema.org/ownershipFundingInfo")
    ArchiveOrganization = URIRef("https://schema.org/ArchiveOrganization")
    Corporation = URIRef("https://schema.org/Corporation")
    EUEnergyEfficiencyCategoryA1Plus = URIRef("https://schema.org/EUEnergyEfficiencyCategoryA1Plus")
    expectedArrivalFrom = URIRef("https://schema.org/expectedArrivalFrom")
    RepaymentSpecification = URIRef("https://schema.org/RepaymentSpecification")
    percentile75 = URIRef("https://schema.org/percentile75")
    eligibleDuration = URIRef("https://schema.org/eligibleDuration")
    RadioStation = URIRef("https://schema.org/RadioStation")
    gtin8 = URIRef("https://schema.org/gtin8")
    gracePeriod = URIRef("https://schema.org/gracePeriod")
    measurementMethod = URIRef("https://schema.org/measurementMethod")
    vehicleConfiguration = URIRef("https://schema.org/vehicleConfiguration")
    speechToTextMarkup = URIRef("https://schema.org/speechToTextMarkup")
    OceanBodyOfWater = URIRef("https://schema.org/OceanBodyOfWater")
    appearance = URIRef("https://schema.org/appearance")
    EventReservation = URIRef("https://schema.org/EventReservation")
    MisconceptionsHealthAspect = URIRef("https://schema.org/MisconceptionsHealthAspect")
    BackgroundNewsArticle = URIRef("https://schema.org/BackgroundNewsArticle")
    VirtualRecordingDigitalSource = URIRef("https://schema.org/VirtualRecordingDigitalSource")
    colorist = URIRef("https://schema.org/colorist")
    Ligament = URIRef("https://schema.org/Ligament")
    membershipPointsEarned = URIRef("https://schema.org/membershipPointsEarned")
    LibrarySystem = URIRef("https://schema.org/LibrarySystem")
    pathophysiology = URIRef("https://schema.org/pathophysiology")
    OfficeEquipmentStore = URIRef("https://schema.org/OfficeEquipmentStore")
    paymentUrl = URIRef("https://schema.org/paymentUrl")
    BoatTrip = URIRef("https://schema.org/BoatTrip")
    proficiencyLevel = URIRef("https://schema.org/proficiencyLevel")
    RsvpAction = URIRef("https://schema.org/RsvpAction")
    PaymentPastDue = URIRef("https://schema.org/PaymentPastDue")
    Nonprofit501c9 = URIRef("https://schema.org/Nonprofit501c9")
    typeOfBed = URIRef("https://schema.org/typeOfBed")
    RsvpResponseType = URIRef("https://schema.org/RsvpResponseType")
    Crematorium = URIRef("https://schema.org/Crematorium")
    processingTime = URIRef("https://schema.org/processingTime")
    value = URIRef("https://schema.org/value")
    MedicalRiskCalculator = URIRef("https://schema.org/MedicalRiskCalculator")
    productGroupID = URIRef("https://schema.org/productGroupID")
    archiveHeld = URIRef("https://schema.org/archiveHeld")
    LibrarySystem = URIRef("https://schema.org/LibrarySystem")
    sha256 = URIRef("https://schema.org/sha256")
    StagedContent = URIRef("https://schema.org/StagedContent")
    birthDate = URIRef("https://schema.org/birthDate")
    CollectionPage = URIRef("https://schema.org/CollectionPage")
    MedicalRiskScore = URIRef("https://schema.org/MedicalRiskScore")
    actor = URIRef("https://schema.org/actor")
    buyer = URIRef("https://schema.org/buyer")
    CassetteFormat = URIRef("https://schema.org/CassetteFormat")
    additionalVariable = URIRef("https://schema.org/additionalVariable")
    amenityFeature = URIRef("https://schema.org/amenityFeature")
    Pulmonary = URIRef("https://schema.org/Pulmonary")
    orderDelivery = URIRef("https://schema.org/orderDelivery")
    areaServed = URIRef("https://schema.org/areaServed")
    inLanguage = URIRef("https://schema.org/inLanguage")
    ratingCount = URIRef("https://schema.org/ratingCount")
    Guide = URIRef("https://schema.org/Guide")
    dateVehicleFirstRegistered = URIRef("https://schema.org/dateVehicleFirstRegistered")
    PaymentService = URIRef("https://schema.org/PaymentService")
    geoDisjoint = URIRef("https://schema.org/geoDisjoint")
    deliveryStatus = URIRef("https://schema.org/deliveryStatus")
    GovernmentBuilding = URIRef("https://schema.org/GovernmentBuilding")
    OfferItemCondition = URIRef("https://schema.org/OfferItemCondition")
    EBook = URIRef("https://schema.org/EBook")
    lowPrice = URIRef("https://schema.org/lowPrice")
    AutoWash = URIRef("https://schema.org/AutoWash")
    floorLevel = URIRef("https://schema.org/floorLevel")
    SizeSystemMetric = URIRef("https://schema.org/SizeSystemMetric")
    temporalCoverage = URIRef("https://schema.org/temporalCoverage")
    educationalAlignment = URIRef("https://schema.org/educationalAlignment")
    broadcaster = URIRef("https://schema.org/broadcaster")
    orderedItem = URIRef("https://schema.org/orderedItem")
    EUEnergyEfficiencyCategoryA2Plus = URIRef("https://schema.org/EUEnergyEfficiencyCategoryA2Plus")
    Map = URIRef("https://schema.org/Map")
    ownershipFundingInfo = URIRef("https://schema.org/ownershipFundingInfo")
    season = URIRef("https://schema.org/season")
    carrierRequirements = URIRef("https://schema.org/carrierRequirements")
    orderItemNumber = URIRef("https://schema.org/orderItemNumber")
    PodcastSeason = URIRef("https://schema.org/PodcastSeason")
    Brand = URIRef("https://schema.org/Brand")
    requiresSubscription = URIRef("https://schema.org/requiresSubscription")
    result = URIRef("https://schema.org/result")
    negativeNotes = URIRef("https://schema.org/negativeNotes")
    AutoRepair = URIRef("https://schema.org/AutoRepair")
    line = URIRef("https://schema.org/line")
    constraintProperty = URIRef("https://schema.org/constraintProperty")
    wheelbase = URIRef("https://schema.org/wheelbase")
    Legislation = URIRef("https://schema.org/Legislation")
    TypeAndQuantityNode = URIRef("https://schema.org/TypeAndQuantityNode")
    baseSalary = URIRef("https://schema.org/baseSalary")
    reservedTicket = URIRef("https://schema.org/reservedTicket")
    usesHealthPlanIdStandard = URIRef("https://schema.org/usesHealthPlanIdStandard")
    postalCode = URIRef("https://schema.org/postalCode")
    publishingPrinciples = URIRef("https://schema.org/publishingPrinciples")
    byArtist = URIRef("https://schema.org/byArtist")
    flightDistance = URIRef("https://schema.org/flightDistance")
    ticketedSeat = URIRef("https://schema.org/ticketedSeat")
    MerchantReturnEnumeration = URIRef("https://schema.org/MerchantReturnEnumeration")
    numberOfPartialBathrooms = URIRef("https://schema.org/numberOfPartialBathrooms")
    videoQuality = URIRef("https://schema.org/videoQuality")
    SearchRescueOrganization = URIRef("https://schema.org/SearchRescueOrganization")
    ProductGroup = URIRef("https://schema.org/ProductGroup")
    sibling = URIRef("https://schema.org/sibling")
    targetDescription = URIRef("https://schema.org/targetDescription")
    legislationLegalForce = URIRef("https://schema.org/legislationLegalForce")
    vendor = URIRef("https://schema.org/vendor")
    BodyMeasurementHeight = URIRef("https://schema.org/BodyMeasurementHeight")
    ReserveAction = URIRef("https://schema.org/ReserveAction")
    transitTimeLabel = URIRef("https://schema.org/transitTimeLabel")
    mobileUrl = URIRef("https://schema.org/mobileUrl")
    PublicSwimmingPool = URIRef("https://schema.org/PublicSwimmingPool")
    numAdults = URIRef("https://schema.org/numAdults")
    includesHealthPlanNetwork = URIRef("https://schema.org/includesHealthPlanNetwork")
    Order = URIRef("https://schema.org/Order")
    Offer = URIRef("https://schema.org/Offer")
    InformAction = URIRef("https://schema.org/InformAction")
    mainEntity = URIRef("https://schema.org/mainEntity")
    pregnancyCategory = URIRef("https://schema.org/pregnancyCategory")
    letterer = URIRef("https://schema.org/letterer")
    expectedPrognosis = URIRef("https://schema.org/expectedPrognosis")
    hiringOrganization = URIRef("https://schema.org/hiringOrganization")
    recipeInstructions = URIRef("https://schema.org/recipeInstructions")
    archivedAt = URIRef("https://schema.org/archivedAt")
    jobLocation = URIRef("https://schema.org/jobLocation")
    usNPI = URIRef("https://schema.org/usNPI")
    OrderAction = URIRef("https://schema.org/OrderAction")
    containsSeason = URIRef("https://schema.org/containsSeason")
    studyDesign = URIRef("https://schema.org/studyDesign")
    RightHandDriving = URIRef("https://schema.org/RightHandDriving")
    legislationResponsible = URIRef("https://schema.org/legislationResponsible")
    returnPolicyCountry = URIRef("https://schema.org/returnPolicyCountry")
    inStoreReturnsOffered = URIRef("https://schema.org/inStoreReturnsOffered")
    SizeSpecification = URIRef("https://schema.org/SizeSpecification")
    hasBioChemEntityPart = URIRef("https://schema.org/hasBioChemEntityPart")
    baseSalary = URIRef("https://schema.org/baseSalary")
    hasCertification = URIRef("https://schema.org/hasCertification")
    sampleType = URIRef("https://schema.org/sampleType")
    OpinionNewsArticle = URIRef("https://schema.org/OpinionNewsArticle")
    trackingUrl = URIRef("https://schema.org/trackingUrl")
    Virus = URIRef("https://schema.org/Virus")
    measurementMethod = URIRef("https://schema.org/measurementMethod")
    warrantyPromise = URIRef("https://schema.org/warrantyPromise")
    alumniOf = URIRef("https://schema.org/alumniOf")
    Male = URIRef("https://schema.org/Male")
    publisherImprint = URIRef("https://schema.org/publisherImprint")
    broadcastServiceTier = URIRef("https://schema.org/broadcastServiceTier")
    repetitions = URIRef("https://schema.org/repetitions")
    VideoGallery = URIRef("https://schema.org/VideoGallery")
    lodgingUnitType = URIRef("https://schema.org/lodgingUnitType")
    shippingOrigin = URIRef("https://schema.org/shippingOrigin")
    PetStore = URIRef("https://schema.org/PetStore")
    menuAddOn = URIRef("https://schema.org/menuAddOn")
    USNonprofitType = URIRef("https://schema.org/USNonprofitType")
    DiabeticDiet = URIRef("https://schema.org/DiabeticDiet")
    countryOfOrigin = URIRef("https://schema.org/countryOfOrigin")
    starRating = URIRef("https://schema.org/starRating")
    typeOfGood = URIRef("https://schema.org/typeOfGood")
    sensoryUnit = URIRef("https://schema.org/sensoryUnit")
    NoteDigitalDocument = URIRef("https://schema.org/NoteDigitalDocument")
    interactionService = URIRef("https://schema.org/interactionService")
    logo = URIRef("https://schema.org/logo")
    speakable = URIRef("https://schema.org/speakable")
    trailerWeight = URIRef("https://schema.org/trailerWeight")
    availabilityStarts = URIRef("https://schema.org/availabilityStarts")
    sdPublisher = URIRef("https://schema.org/sdPublisher")
    EnergyEfficiencyEnumeration = URIRef("https://schema.org/EnergyEfficiencyEnumeration")
    membershipPointsEarned = URIRef("https://schema.org/membershipPointsEarned")
    rangeIncludes = URIRef("https://schema.org/rangeIncludes")
    menuAddOn = URIRef("https://schema.org/menuAddOn")
    CheckAction = URIRef("https://schema.org/CheckAction")
    schoolClosuresInfo = URIRef("https://schema.org/schoolClosuresInfo")
    MediaObject = URIRef("https://schema.org/MediaObject")
    loser = URIRef("https://schema.org/loser")
    monthlyMinimumRepaymentAmount = URIRef("https://schema.org/monthlyMinimumRepaymentAmount")
    hasMeasurement = URIRef("https://schema.org/hasMeasurement")
    foodEstablishment = URIRef("https://schema.org/foodEstablishment")
    SRP = URIRef("https://schema.org/SRP")
    mathExpression = URIRef("https://schema.org/mathExpression")
    recommendedIntake = URIRef("https://schema.org/recommendedIntake")
    practicesAt = URIRef("https://schema.org/practicesAt")
    EUEnergyEfficiencyCategoryF = URIRef("https://schema.org/EUEnergyEfficiencyCategoryF")
    PublicationVolume = URIRef("https://schema.org/PublicationVolume")
    subReservation = URIRef("https://schema.org/subReservation")
    geoIntersects = URIRef("https://schema.org/geoIntersects")
    partOfInvoice = URIRef("https://schema.org/partOfInvoice")
    targetProduct = URIRef("https://schema.org/targetProduct")
    isLocatedInSubcellularLocation = URIRef("https://schema.org/isLocatedInSubcellularLocation")
    LandmarksOrHistoricalBuildings = URIRef("https://schema.org/LandmarksOrHistoricalBuildings")
    ResearchOrganization = URIRef("https://schema.org/ResearchOrganization")
    checkoutPageURLTemplate = URIRef("https://schema.org/checkoutPageURLTemplate")
    TypesHealthAspect = URIRef("https://schema.org/TypesHealthAspect")
    PaymentChargeSpecification = URIRef("https://schema.org/PaymentChargeSpecification")
    WearableMeasurementLength = URIRef("https://schema.org/WearableMeasurementLength")
    geoCrosses = URIRef("https://schema.org/geoCrosses")
    postalCodeBegin = URIRef("https://schema.org/postalCodeBegin")
    identifyingExam = URIRef("https://schema.org/identifyingExam")
    ExercisePlan = URIRef("https://schema.org/ExercisePlan")
    temporalCoverage = URIRef("https://schema.org/temporalCoverage")
    disambiguatingDescription = URIRef("https://schema.org/disambiguatingDescription")
    GameServer = URIRef("https://schema.org/GameServer")
    Downpayment = URIRef("https://schema.org/Downpayment")
    providesBroadcastService = URIRef("https://schema.org/providesBroadcastService")
    FinancialService = URIRef("https://schema.org/FinancialService")
    status = URIRef("https://schema.org/status")
    SpecialAnnouncement = URIRef("https://schema.org/SpecialAnnouncement")
    petsAllowed = URIRef("https://schema.org/petsAllowed")
    termDuration = URIRef("https://schema.org/termDuration")
    DistanceFee = URIRef("https://schema.org/DistanceFee")
    bioChemSimilarity = URIRef("https://schema.org/bioChemSimilarity")
    Painting = URIRef("https://schema.org/Painting")
    underName = URIRef("https://schema.org/underName")
    safetyConsideration = URIRef("https://schema.org/safetyConsideration")
    language = URIRef("https://schema.org/language")
    opponent = URIRef("https://schema.org/opponent")
    url = URIRef("https://schema.org/url")
    ZoneBoardingPolicy = URIRef("https://schema.org/ZoneBoardingPolicy")
    serviceType = URIRef("https://schema.org/serviceType")
    hasDeliveryMethod = URIRef("https://schema.org/hasDeliveryMethod")
    yearsInOperation = URIRef("https://schema.org/yearsInOperation")
    MedicalWebPage = URIRef("https://schema.org/MedicalWebPage")
    Audience = URIRef("https://schema.org/Audience")
    geoRadius = URIRef("https://schema.org/geoRadius")
    Radiography = URIRef("https://schema.org/Radiography")
    observationDate = URIRef("https://schema.org/observationDate")
    medicalAudience = URIRef("https://schema.org/medicalAudience")
    billingAddress = URIRef("https://schema.org/billingAddress")
    dropoffTime = URIRef("https://schema.org/dropoffTime")
    option = URIRef("https://schema.org/option")
    inDefinedTermSet = URIRef("https://schema.org/inDefinedTermSet")
    CampingPitch = URIRef("https://schema.org/CampingPitch")
    entertainmentBusiness = URIRef("https://schema.org/entertainmentBusiness")
    printSection = URIRef("https://schema.org/printSection")
    SpokenWordAlbum = URIRef("https://schema.org/SpokenWordAlbum")
    upvoteCount = URIRef("https://schema.org/upvoteCount")
    knowsAbout = URIRef("https://schema.org/knowsAbout")
    educationalCredentialAwarded = URIRef("https://schema.org/educationalCredentialAwarded")
    phoneticText = URIRef("https://schema.org/phoneticText")
    SeekToAction = URIRef("https://schema.org/SeekToAction")
    workload = URIRef("https://schema.org/workload")
    accommodationCategory = URIRef("https://schema.org/accommodationCategory")
    orderedItem = URIRef("https://schema.org/orderedItem")
    Nursing = URIRef("https://schema.org/Nursing")
    acceptedOffer = URIRef("https://schema.org/acceptedOffer")
    TherapeuticProcedure = URIRef("https://schema.org/TherapeuticProcedure")
    userInteractionCount = URIRef("https://schema.org/userInteractionCount")
    referencesOrder = URIRef("https://schema.org/referencesOrder")
    HowToSection = URIRef("https://schema.org/HowToSection")
    EducationalOccupationalCredential = URIRef("https://schema.org/EducationalOccupationalCredential")
    isBasedOn = URIRef("https://schema.org/isBasedOn")
    Comment = URIRef("https://schema.org/Comment")
    deathDate = URIRef("https://schema.org/deathDate")
    accessMode = URIRef("https://schema.org/accessMode")
    SheetMusic = URIRef("https://schema.org/SheetMusic")
    salaryCurrency = URIRef("https://schema.org/salaryCurrency")
    countryOfOrigin = URIRef("https://schema.org/countryOfOrigin")
    suggestedAnswer = URIRef("https://schema.org/suggestedAnswer")
    PaymentMethod = URIRef("https://schema.org/PaymentMethod")
    BodyMeasurementChest = URIRef("https://schema.org/BodyMeasurementChest")
    supersededBy = URIRef("https://schema.org/supersededBy")
    PoliticalParty = URIRef("https://schema.org/PoliticalParty")
    customer = URIRef("https://schema.org/customer")
    Claim = URIRef("https://schema.org/Claim")
    bestRating = URIRef("https://schema.org/bestRating")
    variesBy = URIRef("https://schema.org/variesBy")
    courseWorkload = URIRef("https://schema.org/courseWorkload")
    Motorcycle = URIRef("https://schema.org/Motorcycle")
    BusinessFunction = URIRef("https://schema.org/BusinessFunction")
    RadioEpisode = URIRef("https://schema.org/RadioEpisode")
    speed = URIRef("https://schema.org/speed")
    Throat = URIRef("https://schema.org/Throat")
    title = URIRef("https://schema.org/title")
    naturalProgression = URIRef("https://schema.org/naturalProgression")
    AlgorithmicallyEnhancedDigitalSource = URIRef("https://schema.org/AlgorithmicallyEnhancedDigitalSource")
    sender = URIRef("https://schema.org/sender")
    steps = URIRef("https://schema.org/steps")
    educationalUse = URIRef("https://schema.org/educationalUse")
    relevantOccupation = URIRef("https://schema.org/relevantOccupation")
    hasRepresentation = URIRef("https://schema.org/hasRepresentation")
    epidemiology = URIRef("https://schema.org/epidemiology")
    IceCreamShop = URIRef("https://schema.org/IceCreamShop")
    taxID = URIRef("https://schema.org/taxID")
    serviceArea = URIRef("https://schema.org/serviceArea")
    AnalysisNewsArticle = URIRef("https://schema.org/AnalysisNewsArticle")
    measurementDenominator = URIRef("https://schema.org/measurementDenominator")
    comment = URIRef("https://schema.org/comment")
    associatedMedia = URIRef("https://schema.org/associatedMedia")
    interactingDrug = URIRef("https://schema.org/interactingDrug")
    functionalClass = URIRef("https://schema.org/functionalClass")
    layoutImage = URIRef("https://schema.org/layoutImage")
    AutomotiveBusiness = URIRef("https://schema.org/AutomotiveBusiness")
    logo = URIRef("https://schema.org/logo")
    MusicAlbum = URIRef("https://schema.org/MusicAlbum")
    providerMobility = URIRef("https://schema.org/providerMobility")
    legislationIdentifier = URIRef("https://schema.org/legislationIdentifier")
    superEvent = URIRef("https://schema.org/superEvent")
    variesBy = URIRef("https://schema.org/variesBy")
    geo = URIRef("https://schema.org/geo")
    guidelineSubject = URIRef("https://schema.org/guidelineSubject")
    MortgageLoan = URIRef("https://schema.org/MortgageLoan")
    WorkBasedProgram = URIRef("https://schema.org/WorkBasedProgram")
    fuelEfficiency = URIRef("https://schema.org/fuelEfficiency")
    followee = URIRef("https://schema.org/followee")
    DangerousGoodConsideration = URIRef("https://schema.org/DangerousGoodConsideration")
    shippingDetails = URIRef("https://schema.org/shippingDetails")
    studyDesign = URIRef("https://schema.org/studyDesign")
    Campground = URIRef("https://schema.org/Campground")
    targetPlatform = URIRef("https://schema.org/targetPlatform")
    embeddedTextCaption = URIRef("https://schema.org/embeddedTextCaption")
    MedicalObservationalStudyDesign = URIRef("https://schema.org/MedicalObservationalStudyDesign")
    experienceRequirements = URIRef("https://schema.org/experienceRequirements")
    ethicsPolicy = URIRef("https://schema.org/ethicsPolicy")
    Legislation = URIRef("https://schema.org/Legislation")
    Withdrawn = URIRef("https://schema.org/Withdrawn")
    EnergyStarEnergyEfficiencyEnumeration = URIRef("https://schema.org/EnergyStarEnergyEfficiencyEnumeration")
    numberOfPages = URIRef("https://schema.org/numberOfPages")
    accelerationTime = URIRef("https://schema.org/accelerationTime")
    duns = URIRef("https://schema.org/duns")
    Pulmonary = URIRef("https://schema.org/Pulmonary")
    benefits = URIRef("https://schema.org/benefits")
    usageInfo = URIRef("https://schema.org/usageInfo")
    MerchantReturnEnumeration = URIRef("https://schema.org/MerchantReturnEnumeration")
    exercisePlan = URIRef("https://schema.org/exercisePlan")
    cholesterolContent = URIRef("https://schema.org/cholesterolContent")
    liveBlogUpdate = URIRef("https://schema.org/liveBlogUpdate")
    valueAddedTaxIncluded = URIRef("https://schema.org/valueAddedTaxIncluded")
    arrivalGate = URIRef("https://schema.org/arrivalGate")
    photos = URIRef("https://schema.org/photos")
    ImageObjectSnapshot = URIRef("https://schema.org/ImageObjectSnapshot")
    ownershipFundingInfo = URIRef("https://schema.org/ownershipFundingInfo")
    DataCatalog = URIRef("https://schema.org/DataCatalog")
    DigitalDocumentPermission = URIRef("https://schema.org/DigitalDocumentPermission")
    Reservoir = URIRef("https://schema.org/Reservoir")
    industry = URIRef("https://schema.org/industry")
    cutoffTime = URIRef("https://schema.org/cutoffTime")
    expressedIn = URIRef("https://schema.org/expressedIn")
    ComicStory = URIRef("https://schema.org/ComicStory")
    competencyRequired = URIRef("https://schema.org/competencyRequired")
    endDate = URIRef("https://schema.org/endDate")
    WearableSizeGroupHusky = URIRef("https://schema.org/WearableSizeGroupHusky")
    FreeReturn = URIRef("https://schema.org/FreeReturn")
    ShippingDeliveryTime = URIRef("https://schema.org/ShippingDeliveryTime")
    DigitalPlatformEnumeration = URIRef("https://schema.org/DigitalPlatformEnumeration")
    DeliveryEvent = URIRef("https://schema.org/DeliveryEvent")
    departureAirport = URIRef("https://schema.org/departureAirport")
    ownershipFundingInfo = URIRef("https://schema.org/ownershipFundingInfo")
    LeaveAction = URIRef("https://schema.org/LeaveAction")
    hasCredential = URIRef("https://schema.org/hasCredential")
    PartiallyInForce = URIRef("https://schema.org/PartiallyInForce")
    ParentAudience = URIRef("https://schema.org/ParentAudience")
    menuAddOn = URIRef("https://schema.org/menuAddOn")
    safetyConsideration = URIRef("https://schema.org/safetyConsideration")
    billingPeriod = URIRef("https://schema.org/billingPeriod")
    toRecipient = URIRef("https://schema.org/toRecipient")
    modelDate = URIRef("https://schema.org/modelDate")
    startDate = URIRef("https://schema.org/startDate")
    priceRange = URIRef("https://schema.org/priceRange")
    programmingLanguage = URIRef("https://schema.org/programmingLanguage")
    Pediatric = URIRef("https://schema.org/Pediatric")
    earlyPrepaymentPenalty = URIRef("https://schema.org/earlyPrepaymentPenalty")
    inStoreReturnsOffered = URIRef("https://schema.org/inStoreReturnsOffered")
    query = URIRef("https://schema.org/query")
    diversityStaffingReport = URIRef("https://schema.org/diversityStaffingReport")
    cholesterolContent = URIRef("https://schema.org/cholesterolContent")
    measurementQualifier = URIRef("https://schema.org/measurementQualifier")
    AskPublicNewsArticle = URIRef("https://schema.org/AskPublicNewsArticle")
    tissueSample = URIRef("https://schema.org/tissueSample")
    ClaimReview = URIRef("https://schema.org/ClaimReview")
    suggestedMeasurement = URIRef("https://schema.org/suggestedMeasurement")
    propertyID = URIRef("https://schema.org/propertyID")
    Reservation = URIRef("https://schema.org/Reservation")
    procedure = URIRef("https://schema.org/procedure")
    legislationJurisdiction = URIRef("https://schema.org/legislationJurisdiction")
    alcoholWarning = URIRef("https://schema.org/alcoholWarning")
    editor = URIRef("https://schema.org/editor")
    vehicleInteriorColor = URIRef("https://schema.org/vehicleInteriorColor")
    Downpayment = URIRef("https://schema.org/Downpayment")
    BoatReservation = URIRef("https://schema.org/BoatReservation")
    significantLink = URIRef("https://schema.org/significantLink")
    mobileUrl = URIRef("https://schema.org/mobileUrl")
    musicArrangement = URIRef("https://schema.org/musicArrangement")
    AdultOrientedEnumeration = URIRef("https://schema.org/AdultOrientedEnumeration")
    DigitalCaptureDigitalSource = URIRef("https://schema.org/DigitalCaptureDigitalSource")
    AlignmentObject = URIRef("https://schema.org/AlignmentObject")
    Trip = URIRef("https://schema.org/Trip")
    phoneticText = URIRef("https://schema.org/phoneticText")
    sportsActivityLocation = URIRef("https://schema.org/sportsActivityLocation")
    OrganizeAction = URIRef("https://schema.org/OrganizeAction")
    relevantOccupation = URIRef("https://schema.org/relevantOccupation")
    targetDescription = URIRef("https://schema.org/targetDescription")
    Statement = URIRef("https://schema.org/Statement")
    productID = URIRef("https://schema.org/productID")
    affectedBy = URIRef("https://schema.org/affectedBy")
    softwareAddOn = URIRef("https://schema.org/softwareAddOn")
    Nonprofit501c5 = URIRef("https://schema.org/Nonprofit501c5")
    toRecipient = URIRef("https://schema.org/toRecipient")
    ParcelService = URIRef("https://schema.org/ParcelService")
    subOrganization = URIRef("https://schema.org/subOrganization")
    iso6523Code = URIRef("https://schema.org/iso6523Code")
    AggregateOffer = URIRef("https://schema.org/AggregateOffer")
    healthPlanNetworkTier = URIRef("https://schema.org/healthPlanNetworkTier")
    makesOffer = URIRef("https://schema.org/makesOffer")
    usesHealthPlanIdStandard = URIRef("https://schema.org/usesHealthPlanIdStandard")
    qualifications = URIRef("https://schema.org/qualifications")
    ResearchProject = URIRef("https://schema.org/ResearchProject")
    toRecipient = URIRef("https://schema.org/toRecipient")
    predecessorOf = URIRef("https://schema.org/predecessorOf")
    MusicEvent = URIRef("https://schema.org/MusicEvent")
    seatNumber = URIRef("https://schema.org/seatNumber")
    StrengthTraining = URIRef("https://schema.org/StrengthTraining")
    childMinAge = URIRef("https://schema.org/childMinAge")
    gameItem = URIRef("https://schema.org/gameItem")
    LifestyleModification = URIRef("https://schema.org/LifestyleModification")
    MenuItem = URIRef("https://schema.org/MenuItem")
    linkRelationship = URIRef("https://schema.org/linkRelationship")
    Question = URIRef("https://schema.org/Question")
    claimInterpreter = URIRef("https://schema.org/claimInterpreter")
    ControlAction = URIRef("https://schema.org/ControlAction")
    PodcastSeason = URIRef("https://schema.org/PodcastSeason")
    Preschool = URIRef("https://schema.org/Preschool")
    containsSeason = URIRef("https://schema.org/containsSeason")
    WearableSizeSystemUK = URIRef("https://schema.org/WearableSizeSystemUK")
    endTime = URIRef("https://schema.org/endTime")
    articleSection = URIRef("https://schema.org/articleSection")
    Grant = URIRef("https://schema.org/Grant")
    WearableSizeGroupMaternity = URIRef("https://schema.org/WearableSizeGroupMaternity")
    relatedTo = URIRef("https://schema.org/relatedTo")
    deliveryTime = URIRef("https://schema.org/deliveryTime")
    chemicalRole = URIRef("https://schema.org/chemicalRole")
    originalMediaContextDescription = URIRef("https://schema.org/originalMediaContextDescription")
    GeospatialGeometry = URIRef("https://schema.org/GeospatialGeometry")
    merchant = URIRef("https://schema.org/merchant")
    landlord = URIRef("https://schema.org/landlord")
    gtin13 = URIRef("https://schema.org/gtin13")
    PatientExperienceHealthAspect = URIRef("https://schema.org/PatientExperienceHealthAspect")
    utterances = URIRef("https://schema.org/utterances")
    MediaEnumeration = URIRef("https://schema.org/MediaEnumeration")
    AutomatedTeller = URIRef("https://schema.org/AutomatedTeller")
    numTracks = URIRef("https://schema.org/numTracks")
    AuthoritativeLegalValue = URIRef("https://schema.org/AuthoritativeLegalValue")
    aspect = URIRef("https://schema.org/aspect")
    healthPlanNetworkTier = URIRef("https://schema.org/healthPlanNetworkTier")
    DriveWheelConfigurationValue = URIRef("https://schema.org/DriveWheelConfigurationValue")
    MedicalScholarlyArticle = URIRef("https://schema.org/MedicalScholarlyArticle")
    valueMinLength = URIRef("https://schema.org/valueMinLength")
    PartiallyInForce = URIRef("https://schema.org/PartiallyInForce")
    sourceOrganization = URIRef("https://schema.org/sourceOrganization")
    Diet = URIRef("https://schema.org/Diet")
    DefinedTerm = URIRef("https://schema.org/DefinedTerm")
    baseSalary = URIRef("https://schema.org/baseSalary")
    isEncodedByBioChemEntity = URIRef("https://schema.org/isEncodedByBioChemEntity")
    acceptsReservations = URIRef("https://schema.org/acceptsReservations")
    followee = URIRef("https://schema.org/followee")
    webFeed = URIRef("https://schema.org/webFeed")
    MerchantReturnUnlimitedWindow = URIRef("https://schema.org/MerchantReturnUnlimitedWindow")
    includedComposition = URIRef("https://schema.org/includedComposition")
    study = URIRef("https://schema.org/study")
    nonProprietaryName = URIRef("https://schema.org/nonProprietaryName")
    returnLabelSource = URIRef("https://schema.org/returnLabelSource")
    composer = URIRef("https://schema.org/composer")
    Bacteria = URIRef("https://schema.org/Bacteria")
    interactionService = URIRef("https://schema.org/interactionService")
    DemoAlbum = URIRef("https://schema.org/DemoAlbum")
    contentSize = URIRef("https://schema.org/contentSize")
    healthPlanId = URIRef("https://schema.org/healthPlanId")
    arterialBranch = URIRef("https://schema.org/arterialBranch")
    VideoObjectSnapshot = URIRef("https://schema.org/VideoObjectSnapshot")
    CertificationInactive = URIRef("https://schema.org/CertificationInactive")
    procedureType = URIRef("https://schema.org/procedureType")
    financialAidEligible = URIRef("https://schema.org/financialAidEligible")
    NotYetRecruiting = URIRef("https://schema.org/NotYetRecruiting")
    fuelCapacity = URIRef("https://schema.org/fuelCapacity")
    PhysicalTherapy = URIRef("https://schema.org/PhysicalTherapy")
    recordedAt = URIRef("https://schema.org/recordedAt")
    naics = URIRef("https://schema.org/naics")
    FastFoodRestaurant = URIRef("https://schema.org/FastFoodRestaurant")
    Neurologic = URIRef("https://schema.org/Neurologic")
    announcementLocation = URIRef("https://schema.org/announcementLocation")
    audience = URIRef("https://schema.org/audience")
    NegativeFilmDigitalSource = URIRef("https://schema.org/NegativeFilmDigitalSource")
    normalRange = URIRef("https://schema.org/normalRange")
    courseMode = URIRef("https://schema.org/courseMode")
    ScreeningEvent = URIRef("https://schema.org/ScreeningEvent")
    numAdults = URIRef("https://schema.org/numAdults")
    stepValue = URIRef("https://schema.org/stepValue")
    includesObject = URIRef("https://schema.org/includesObject")
    clipNumber = URIRef("https://schema.org/clipNumber")
    assemblyVersion = URIRef("https://schema.org/assemblyVersion")
    interactionType = URIRef("https://schema.org/interactionType")
    description = URIRef("https://schema.org/description")
    NailSalon = URIRef("https://schema.org/NailSalon")
    parentTaxon = URIRef("https://schema.org/parentTaxon")
    xpath = URIRef("https://schema.org/xpath")
    InternetCafe = URIRef("https://schema.org/InternetCafe")
    legislationTransposes = URIRef("https://schema.org/legislationTransposes")
    broker = URIRef("https://schema.org/broker")
    title = URIRef("https://schema.org/title")
    Infectious = URIRef("https://schema.org/Infectious")
    CertificationActive = URIRef("https://schema.org/CertificationActive")
    supersededBy = URIRef("https://schema.org/supersededBy")
    diversityStaffingReport = URIRef("https://schema.org/diversityStaffingReport")
    occupationalCredentialAwarded = URIRef("https://schema.org/occupationalCredentialAwarded")
    interestRate = URIRef("https://schema.org/interestRate")
    elevation = URIRef("https://schema.org/elevation")
    aggregateRating = URIRef("https://schema.org/aggregateRating")
    availability = URIRef("https://schema.org/availability")
    legislationApplies = URIRef("https://schema.org/legislationApplies")
    Newspaper = URIRef("https://schema.org/Newspaper")
    homeTeam = URIRef("https://schema.org/homeTeam")
    Embassy = URIRef("https://schema.org/Embassy")
    diversityStaffingReport = URIRef("https://schema.org/diversityStaffingReport")
    ApplyAction = URIRef("https://schema.org/ApplyAction")
    LowSaltDiet = URIRef("https://schema.org/LowSaltDiet")
    taxonomicRange = URIRef("https://schema.org/taxonomicRange")
    TreatmentIndication = URIRef("https://schema.org/TreatmentIndication")
    model = URIRef("https://schema.org/model")
    hasEnergyConsumptionDetails = URIRef("https://schema.org/hasEnergyConsumptionDetails")
    partOfTrip = URIRef("https://schema.org/partOfTrip")
    lastReviewed = URIRef("https://schema.org/lastReviewed")
    ratingCount = URIRef("https://schema.org/ratingCount")
    MobileApplication = URIRef("https://schema.org/MobileApplication")
    Action = URIRef("https://schema.org/Action")
    codeValue = URIRef("https://schema.org/codeValue")
    musicArrangement = URIRef("https://schema.org/musicArrangement")
    touristType = URIRef("https://schema.org/touristType")
    actors = URIRef("https://schema.org/actors")
    ReservationPending = URIRef("https://schema.org/ReservationPending")
    fundedItem = URIRef("https://schema.org/fundedItem")
    legislationApplies = URIRef("https://schema.org/legislationApplies")
    drug = URIRef("https://schema.org/drug")
    risks = URIRef("https://schema.org/risks")
    episode = URIRef("https://schema.org/episode")
    legislationConsolidates = URIRef("https://schema.org/legislationConsolidates")
    AutoPartsStore = URIRef("https://schema.org/AutoPartsStore")
    accountId = URIRef("https://schema.org/accountId")
    interactingDrug = URIRef("https://schema.org/interactingDrug")
    superEvent = URIRef("https://schema.org/superEvent")
    SendAction = URIRef("https://schema.org/SendAction")
    DrugStrength = URIRef("https://schema.org/DrugStrength")
    WearableSizeGroupWomens = URIRef("https://schema.org/WearableSizeGroupWomens")
    conditionsOfAccess = URIRef("https://schema.org/conditionsOfAccess")
    accessMode = URIRef("https://schema.org/accessMode")
    expectsAcceptanceOf = URIRef("https://schema.org/expectsAcceptanceOf")
    value = URIRef("https://schema.org/value")
    MedicalScholarlyArticle = URIRef("https://schema.org/MedicalScholarlyArticle")
    numberOfEpisodes = URIRef("https://schema.org/numberOfEpisodes")
    percentile90 = URIRef("https://schema.org/percentile90")
    EnergyStarEnergyEfficiencyEnumeration = URIRef("https://schema.org/EnergyStarEnergyEfficiencyEnumeration")
    energyEfficiencyScaleMin = URIRef("https://schema.org/energyEfficiencyScaleMin")
    experienceRequirements = URIRef("https://schema.org/experienceRequirements")
    relevantOccupation = URIRef("https://schema.org/relevantOccupation")
    hasDefinedTerm = URIRef("https://schema.org/hasDefinedTerm")
    Bridge = URIRef("https://schema.org/Bridge")
    educationalRole = URIRef("https://schema.org/educationalRole")
    funder = URIRef("https://schema.org/funder")
    jobImmediateStart = URIRef("https://schema.org/jobImmediateStart")
    line = URIRef("https://schema.org/line")
    advanceBookingRequirement = URIRef("https://schema.org/advanceBookingRequirement")
    DeliveryChargeSpecification = URIRef("https://schema.org/DeliveryChargeSpecification")
    DietarySupplement = URIRef("https://schema.org/DietarySupplement")
    employees = URIRef("https://schema.org/employees")
    commentTime = URIRef("https://schema.org/commentTime")
    CheckoutPage = URIRef("https://schema.org/CheckoutPage")
    strengthValue = URIRef("https://schema.org/strengthValue")
    MoneyTransfer = URIRef("https://schema.org/MoneyTransfer")
    imagingTechnique = URIRef("https://schema.org/imagingTechnique")
    postOp = URIRef("https://schema.org/postOp")
    WearableSizeSystemGS1 = URIRef("https://schema.org/WearableSizeSystemGS1")
    inLanguage = URIRef("https://schema.org/inLanguage")
    educationalUse = URIRef("https://schema.org/educationalUse")
    jobBenefits = URIRef("https://schema.org/jobBenefits")
    LoseAction = URIRef("https://schema.org/LoseAction")
    bestRating = URIRef("https://schema.org/bestRating")
    announcementLocation = URIRef("https://schema.org/announcementLocation")
    percentile90 = URIRef("https://schema.org/percentile90")
    touristType = URIRef("https://schema.org/touristType")
    currentExchangeRate = URIRef("https://schema.org/currentExchangeRate")
    MedicalGuideline = URIRef("https://schema.org/MedicalGuideline")
    tool = URIRef("https://schema.org/tool")
    ItemListOrderAscending = URIRef("https://schema.org/ItemListOrderAscending")
    TennisComplex = URIRef("https://schema.org/TennisComplex")
    AuthorizeAction = URIRef("https://schema.org/AuthorizeAction")
    isrcCode = URIRef("https://schema.org/isrcCode")
    copyrightHolder = URIRef("https://schema.org/copyrightHolder")
    WesternConventional = URIRef("https://schema.org/WesternConventional")
    occupationalCredentialAwarded = URIRef("https://schema.org/occupationalCredentialAwarded")
    LibrarySystem = URIRef("https://schema.org/LibrarySystem")
    EventSeries = URIRef("https://schema.org/EventSeries")
    accommodationFloorPlan = URIRef("https://schema.org/accommodationFloorPlan")
    Renal = URIRef("https://schema.org/Renal")
    MedicalClinic = URIRef("https://schema.org/MedicalClinic")
    ActiveNotRecruiting = URIRef("https://schema.org/ActiveNotRecruiting")
    episodeNumber = URIRef("https://schema.org/episodeNumber")
    EPRelease = URIRef("https://schema.org/EPRelease")
    ReportageNewsArticle = URIRef("https://schema.org/ReportageNewsArticle")
    numberOfForwardGears = URIRef("https://schema.org/numberOfForwardGears")
    newsUpdatesAndGuidelines = URIRef("https://schema.org/newsUpdatesAndGuidelines")
    Artery = URIRef("https://schema.org/Artery")
    NewsArticle = URIRef("https://schema.org/NewsArticle")
    ReducedRelevanceForChildrenConsideration = URIRef("https://schema.org/ReducedRelevanceForChildrenConsideration")
    email = URIRef("https://schema.org/email")
    globalLocationNumber = URIRef("https://schema.org/globalLocationNumber")
    acceptedAnswer = URIRef("https://schema.org/acceptedAnswer")
    MedicalTrialDesign = URIRef("https://schema.org/MedicalTrialDesign")
    additionalName = URIRef("https://schema.org/additionalName")
    NotInForce = URIRef("https://schema.org/NotInForce")
    isInvolvedInBiologicalProcess = URIRef("https://schema.org/isInvolvedInBiologicalProcess")
    Bacteria = URIRef("https://schema.org/Bacteria")
    EventSeries = URIRef("https://schema.org/EventSeries")
    Neuro = URIRef("https://schema.org/Neuro")
    billingStart = URIRef("https://schema.org/billingStart")
    possibleTreatment = URIRef("https://schema.org/possibleTreatment")
    albumRelease = URIRef("https://schema.org/albumRelease")
    engineType = URIRef("https://schema.org/engineType")
    signDetected = URIRef("https://schema.org/signDetected")
    messageAttachment = URIRef("https://schema.org/messageAttachment")
    risks = URIRef("https://schema.org/risks")
    TradeAction = URIRef("https://schema.org/TradeAction")
    Country = URIRef("https://schema.org/Country")
    lowPrice = URIRef("https://schema.org/lowPrice")
    BroadcastFrequencySpecification = URIRef("https://schema.org/BroadcastFrequencySpecification")
    awards = URIRef("https://schema.org/awards")
    datePublished = URIRef("https://schema.org/datePublished")
    numberOfForwardGears = URIRef("https://schema.org/numberOfForwardGears")
    postOp = URIRef("https://schema.org/postOp")
    honorificPrefix = URIRef("https://schema.org/honorificPrefix")
    ArchiveComponent = URIRef("https://schema.org/ArchiveComponent")
    isInvolvedInBiologicalProcess = URIRef("https://schema.org/isInvolvedInBiologicalProcess")
    OutletStore = URIRef("https://schema.org/OutletStore")
    issn = URIRef("https://schema.org/issn")
    breastfeedingWarning = URIRef("https://schema.org/breastfeedingWarning")
    namedPosition = URIRef("https://schema.org/namedPosition")
    WearableSizeSystemMX = URIRef("https://schema.org/WearableSizeSystemMX")
    MedicalCode = URIRef("https://schema.org/MedicalCode")
    itemListElement = URIRef("https://schema.org/itemListElement")
    FMRadioChannel = URIRef("https://schema.org/FMRadioChannel")
    availability = URIRef("https://schema.org/availability")
    VirtualRecordingDigitalSource = URIRef("https://schema.org/VirtualRecordingDigitalSource")
    supersededBy = URIRef("https://schema.org/supersededBy")
    bccRecipient = URIRef("https://schema.org/bccRecipient")
    RemixAlbum = URIRef("https://schema.org/RemixAlbum")
    Season = URIRef("https://schema.org/Season")
    PodcastSeason = URIRef("https://schema.org/PodcastSeason")
    DiagnosticLab = URIRef("https://schema.org/DiagnosticLab")
    partOfEpisode = URIRef("https://schema.org/partOfEpisode")
    video = URIRef("https://schema.org/video")
    IgnoreAction = URIRef("https://schema.org/IgnoreAction")
    PhysicalActivity = URIRef("https://schema.org/PhysicalActivity")
    item = URIRef("https://schema.org/item")
    PayAction = URIRef("https://schema.org/PayAction")
    EventSeries = URIRef("https://schema.org/EventSeries")
    Grant = URIRef("https://schema.org/Grant")
    TouristTrip = URIRef("https://schema.org/TouristTrip")
    SubscribeAction = URIRef("https://schema.org/SubscribeAction")
    collection = URIRef("https://schema.org/collection")
    employerOverview = URIRef("https://schema.org/employerOverview")
    AlignmentObject = URIRef("https://schema.org/AlignmentObject")
    documentation = URIRef("https://schema.org/documentation")
    landlord = URIRef("https://schema.org/landlord")
    priceRange = URIRef("https://schema.org/priceRange")
    dateReceived = URIRef("https://schema.org/dateReceived")
    UserLikes = URIRef("https://schema.org/UserLikes")
    valuePattern = URIRef("https://schema.org/valuePattern")
    antagonist = URIRef("https://schema.org/antagonist")
    partOfInvoice = URIRef("https://schema.org/partOfInvoice")
    CovidTestingFacility = URIRef("https://schema.org/CovidTestingFacility")
    priceValidUntil = URIRef("https://schema.org/priceValidUntil")
    LocalBusiness = URIRef("https://schema.org/LocalBusiness")
    educationalProgramMode = URIRef("https://schema.org/educationalProgramMode")
    hasMolecularFunction = URIRef("https://schema.org/hasMolecularFunction")
    servingSize = URIRef("https://schema.org/servingSize")
    Dentistry = URIRef("https://schema.org/Dentistry")
    broadcastFrequencyValue = URIRef("https://schema.org/broadcastFrequencyValue")
    numberOfAirbags = URIRef("https://schema.org/numberOfAirbags")
    originalMediaLink = URIRef("https://schema.org/originalMediaLink")
    LocationFeatureSpecification = URIRef("https://schema.org/LocationFeatureSpecification")
    LegalForceStatus = URIRef("https://schema.org/LegalForceStatus")
    answerExplanation = URIRef("https://schema.org/answerExplanation")
    MixedEventAttendanceMode = URIRef("https://schema.org/MixedEventAttendanceMode")
    servingSize = URIRef("https://schema.org/servingSize")
    partySize = URIRef("https://schema.org/partySize")
    MobileApplication = URIRef("https://schema.org/MobileApplication")
    TrainTrip = URIRef("https://schema.org/TrainTrip")
    audio = URIRef("https://schema.org/audio")
    priceRange = URIRef("https://schema.org/priceRange")
    targetCollection = URIRef("https://schema.org/targetCollection")
    sender = URIRef("https://schema.org/sender")
    alternativeOf = URIRef("https://schema.org/alternativeOf")
    roleName = URIRef("https://schema.org/roleName")
    WearableSizeGroupEnumeration = URIRef("https://schema.org/WearableSizeGroupEnumeration")
    PaymentCard = URIRef("https://schema.org/PaymentCard")
    hasPOS = URIRef("https://schema.org/hasPOS")
    printColumn = URIRef("https://schema.org/printColumn")
    FDAcategoryX = URIRef("https://schema.org/FDAcategoryX")
    season = URIRef("https://schema.org/season")
    customerRemorseReturnLabelSource = URIRef("https://schema.org/customerRemorseReturnLabelSource")
    unnamedSourcesPolicy = URIRef("https://schema.org/unnamedSourcesPolicy")
    LegalValueLevel = URIRef("https://schema.org/LegalValueLevel")
    releaseOf = URIRef("https://schema.org/releaseOf")
    customerRemorseReturnLabelSource = URIRef("https://schema.org/customerRemorseReturnLabelSource")
    median = URIRef("https://schema.org/median")
    restPeriods = URIRef("https://schema.org/restPeriods")
    DiabeticDiet = URIRef("https://schema.org/DiabeticDiet")
    paymentMethod = URIRef("https://schema.org/paymentMethod")
    NegativeFilmDigitalSource = URIRef("https://schema.org/NegativeFilmDigitalSource")
    employee = URIRef("https://schema.org/employee")
    prescriptionStatus = URIRef("https://schema.org/prescriptionStatus")
    FreeReturn = URIRef("https://schema.org/FreeReturn")
    fuelEfficiency = URIRef("https://schema.org/fuelEfficiency")
    Nonprofit501c19 = URIRef("https://schema.org/Nonprofit501c19")
    lender = URIRef("https://schema.org/lender")
    Artery = URIRef("https://schema.org/Artery")
    category = URIRef("https://schema.org/category")
    renegotiableLoan = URIRef("https://schema.org/renegotiableLoan")
    logo = URIRef("https://schema.org/logo")
    acceptedPaymentMethod = URIRef("https://schema.org/acceptedPaymentMethod")
    ScheduleAction = URIRef("https://schema.org/ScheduleAction")
    Game = URIRef("https://schema.org/Game")
    industry = URIRef("https://schema.org/industry")
    claimReviewed = URIRef("https://schema.org/claimReviewed")
    runsTo = URIRef("https://schema.org/runsTo")
    BeautySalon = URIRef("https://schema.org/BeautySalon")
    TaxiVehicleUsage = URIRef("https://schema.org/TaxiVehicleUsage")
    speakable = URIRef("https://schema.org/speakable")
    InvestmentFund = URIRef("https://schema.org/InvestmentFund")
    floorSize = URIRef("https://schema.org/floorSize")
    CharitableIncorporatedOrganization = URIRef("https://schema.org/CharitableIncorporatedOrganization")
    AggregateOffer = URIRef("https://schema.org/AggregateOffer")
    maximumPhysicalAttendeeCapacity = URIRef("https://schema.org/maximumPhysicalAttendeeCapacity")
    studySubject = URIRef("https://schema.org/studySubject")
    vehicleEngine = URIRef("https://schema.org/vehicleEngine")
    Taxi = URIRef("https://schema.org/Taxi")
    itemCondition = URIRef("https://schema.org/itemCondition")
    loanType = URIRef("https://schema.org/loanType")
    aggregateRating = URIRef("https://schema.org/aggregateRating")
    CertificationStatusEnumeration = URIRef("https://schema.org/CertificationStatusEnumeration")
    legalStatus = URIRef("https://schema.org/legalStatus")
    MedicalRiskCalculator = URIRef("https://schema.org/MedicalRiskCalculator")
    priceValidUntil = URIRef("https://schema.org/priceValidUntil")
    Dataset = URIRef("https://schema.org/Dataset")
    track = URIRef("https://schema.org/track")
    SaleEvent = URIRef("https://schema.org/SaleEvent")
    familyName = URIRef("https://schema.org/familyName")
    EntertainmentBusiness = URIRef("https://schema.org/EntertainmentBusiness")
    educationalUse = URIRef("https://schema.org/educationalUse")
    gender = URIRef("https://schema.org/gender")
    startOffset = URIRef("https://schema.org/startOffset")
    catalogNumber = URIRef("https://schema.org/catalogNumber")
    SkiResort = URIRef("https://schema.org/SkiResort")
    musicBy = URIRef("https://schema.org/musicBy")
    GameAvailabilityEnumeration = URIRef("https://schema.org/GameAvailabilityEnumeration")
    Flexibility = URIRef("https://schema.org/Flexibility")
    parentOrganization = URIRef("https://schema.org/parentOrganization")
    applicationDeadline = URIRef("https://schema.org/applicationDeadline")
    ProductCollection = URIRef("https://schema.org/ProductCollection")
    winner = URIRef("https://schema.org/winner")
    numberOfSeasons = URIRef("https://schema.org/numberOfSeasons")
    digitalSourceType = URIRef("https://schema.org/digitalSourceType")
    ingredients = URIRef("https://schema.org/ingredients")
    loanMortgageMandateAmount = URIRef("https://schema.org/loanMortgageMandateAmount")
    performTime = URIRef("https://schema.org/performTime")
    ReservationPackage = URIRef("https://schema.org/ReservationPackage")
    occupationalCategory = URIRef("https://schema.org/occupationalCategory")
    cashBack = URIRef("https://schema.org/cashBack")
    valueMaxLength = URIRef("https://schema.org/valueMaxLength")
    certificationIdentification = URIRef("https://schema.org/certificationIdentification")
    Clip = URIRef("https://schema.org/Clip")
    Role = URIRef("https://schema.org/Role")
    BusinessAudience = URIRef("https://schema.org/BusinessAudience")
    expressedIn = URIRef("https://schema.org/expressedIn")
    MoveAction = URIRef("https://schema.org/MoveAction")
    Demand = URIRef("https://schema.org/Demand")
    FundingAgency = URIRef("https://schema.org/FundingAgency")
    AccountingService = URIRef("https://schema.org/AccountingService")
    aircraft = URIRef("https://schema.org/aircraft")
    InForce = URIRef("https://schema.org/InForce")
    datePublished = URIRef("https://schema.org/datePublished")
    fuelConsumption = URIRef("https://schema.org/fuelConsumption")
    significance = URIRef("https://schema.org/significance")
    inDefinedTermSet = URIRef("https://schema.org/inDefinedTermSet")
    occupancy = URIRef("https://schema.org/occupancy")
    accommodationFloorPlan = URIRef("https://schema.org/accommodationFloorPlan")
    mechanismOfAction = URIRef("https://schema.org/mechanismOfAction")
    DefinitiveLegalValue = URIRef("https://schema.org/DefinitiveLegalValue")
    hasMolecularFunction = URIRef("https://schema.org/hasMolecularFunction")
    PhysicalExam = URIRef("https://schema.org/PhysicalExam")
    proteinContent = URIRef("https://schema.org/proteinContent")
    ReturnAtKiosk = URIRef("https://schema.org/ReturnAtKiosk")
    priceComponentType = URIRef("https://schema.org/priceComponentType")
    mainEntityOfPage = URIRef("https://schema.org/mainEntityOfPage")
    cvdNumICUBeds = URIRef("https://schema.org/cvdNumICUBeds")
    Ligament = URIRef("https://schema.org/Ligament")
    Recipe = URIRef("https://schema.org/Recipe")
    Psychiatric = URIRef("https://schema.org/Psychiatric")
    EventSeries = URIRef("https://schema.org/EventSeries")
    OpenTrial = URIRef("https://schema.org/OpenTrial")
    FAQPage = URIRef("https://schema.org/FAQPage")
    fuelConsumption = URIRef("https://schema.org/fuelConsumption")
    seeks = URIRef("https://schema.org/seeks")
    sponsor = URIRef("https://schema.org/sponsor")
    Longitudinal = URIRef("https://schema.org/Longitudinal")
    arrivalPlatform = URIRef("https://schema.org/arrivalPlatform")
    StudioAlbum = URIRef("https://schema.org/StudioAlbum")
    spatialCoverage = URIRef("https://schema.org/spatialCoverage")
    width = URIRef("https://schema.org/width")
    homeLocation = URIRef("https://schema.org/homeLocation")
    industry = URIRef("https://schema.org/industry")
    artworkSurface = URIRef("https://schema.org/artworkSurface")
    missionCoveragePrioritiesPolicy = URIRef("https://schema.org/missionCoveragePrioritiesPolicy")
    device = URIRef("https://schema.org/device")
    spokenByCharacter = URIRef("https://schema.org/spokenByCharacter")
    StagedContent = URIRef("https://schema.org/StagedContent")
    SpreadsheetDigitalDocument = URIRef("https://schema.org/SpreadsheetDigitalDocument")
    messageAttachment = URIRef("https://schema.org/messageAttachment")
    DrugCost = URIRef("https://schema.org/DrugCost")
    molecularWeight = URIRef("https://schema.org/molecularWeight")
    numConstraints = URIRef("https://schema.org/numConstraints")
    firstAppearance = URIRef("https://schema.org/firstAppearance")
    doseSchedule = URIRef("https://schema.org/doseSchedule")
    State = URIRef("https://schema.org/State")
    Service = URIRef("https://schema.org/Service")
    UserInteraction = URIRef("https://schema.org/UserInteraction")
    Vein = URIRef("https://schema.org/Vein")
    BuddhistTemple = URIRef("https://schema.org/BuddhistTemple")
    streetAddress = URIRef("https://schema.org/streetAddress")
    Review = URIRef("https://schema.org/Review")
    endorsee = URIRef("https://schema.org/endorsee")
    knowsAbout = URIRef("https://schema.org/knowsAbout")
    Intangible = URIRef("https://schema.org/Intangible")
    Property = URIRef("https://schema.org/Property")
    RepaymentSpecification = URIRef("https://schema.org/RepaymentSpecification")
    VeganDiet = URIRef("https://schema.org/VeganDiet")
    latitude = URIRef("https://schema.org/latitude")
    ControlAction = URIRef("https://schema.org/ControlAction")
    backstory = URIRef("https://schema.org/backstory")
    actors = URIRef("https://schema.org/actors")
    WebApplication = URIRef("https://schema.org/WebApplication")
    MedicalObservationalStudy = URIRef("https://schema.org/MedicalObservationalStudy")
    alumni = URIRef("https://schema.org/alumni")
    offersPrescriptionByMail = URIRef("https://schema.org/offersPrescriptionByMail")
    UnRegisterAction = URIRef("https://schema.org/UnRegisterAction")
    maximumAttendeeCapacity = URIRef("https://schema.org/maximumAttendeeCapacity")
    interactionService = URIRef("https://schema.org/interactionService")
    videoFormat = URIRef("https://schema.org/videoFormat")
    orderItemStatus = URIRef("https://schema.org/orderItemStatus")
    iataCode = URIRef("https://schema.org/iataCode")
    typeOfBed = URIRef("https://schema.org/typeOfBed")
    typeOfGood = URIRef("https://schema.org/typeOfGood")
    UKTrust = URIRef("https://schema.org/UKTrust")
    seller = URIRef("https://schema.org/seller")
    MediaSubscription = URIRef("https://schema.org/MediaSubscription")
    httpMethod = URIRef("https://schema.org/httpMethod")
    postalCodePrefix = URIRef("https://schema.org/postalCodePrefix")
    EUEnergyEfficiencyCategoryD = URIRef("https://schema.org/EUEnergyEfficiencyCategoryD")
    BankOrCreditUnion = URIRef("https://schema.org/BankOrCreditUnion")
    leiCode = URIRef("https://schema.org/leiCode")
    realEstateAgent = URIRef("https://schema.org/realEstateAgent")
    episode = URIRef("https://schema.org/episode")
    connectedTo = URIRef("https://schema.org/connectedTo")
    numberOfSeasons = URIRef("https://schema.org/numberOfSeasons")
    DisagreeAction = URIRef("https://schema.org/DisagreeAction")
    runsTo = URIRef("https://schema.org/runsTo")
    TireShop = URIRef("https://schema.org/TireShop")
    Friday = URIRef("https://schema.org/Friday")
    TheaterEvent = URIRef("https://schema.org/TheaterEvent")
    MedicalCode = URIRef("https://schema.org/MedicalCode")
    shippingDestination = URIRef("https://schema.org/shippingDestination")
    byMonth = URIRef("https://schema.org/byMonth")
    vehicleTransmission = URIRef("https://schema.org/vehicleTransmission")
    includedDataCatalog = URIRef("https://schema.org/includedDataCatalog")
    percentile90 = URIRef("https://schema.org/percentile90")
    DangerousGoodConsideration = URIRef("https://schema.org/DangerousGoodConsideration")
    musicBy = URIRef("https://schema.org/musicBy")
    WholesaleStore = URIRef("https://schema.org/WholesaleStore")
    announcementLocation = URIRef("https://schema.org/announcementLocation")
    biomechnicalClass = URIRef("https://schema.org/biomechnicalClass")
    courseMode = URIRef("https://schema.org/courseMode")
    childMinAge = URIRef("https://schema.org/childMinAge")
    performTime = URIRef("https://schema.org/performTime")
    negativeNotes = URIRef("https://schema.org/negativeNotes")
    tripOrigin = URIRef("https://schema.org/tripOrigin")
    AutoDealer = URIRef("https://schema.org/AutoDealer")
    petsAllowed = URIRef("https://schema.org/petsAllowed")
    RadioSeason = URIRef("https://schema.org/RadioSeason")
    Chiropractic = URIRef("https://schema.org/Chiropractic")
    gameLocation = URIRef("https://schema.org/gameLocation")
    itinerary = URIRef("https://schema.org/itinerary")
    EntryPoint = URIRef("https://schema.org/EntryPoint")
    provider = URIRef("https://schema.org/provider")
    trainingSalary = URIRef("https://schema.org/trainingSalary")
    ViolenceConsideration = URIRef("https://schema.org/ViolenceConsideration")
    softwareVersion = URIRef("https://schema.org/softwareVersion")
    TransitMap = URIRef("https://schema.org/TransitMap")
    legislationDateVersion = URIRef("https://schema.org/legislationDateVersion")
    Podiatric = URIRef("https://schema.org/Podiatric")
    LegalForceStatus = URIRef("https://schema.org/LegalForceStatus")
    programMembershipUsed = URIRef("https://schema.org/programMembershipUsed")
    Notary = URIRef("https://schema.org/Notary")
    Play = URIRef("https://schema.org/Play")
    audio = URIRef("https://schema.org/audio")
    orderDate = URIRef("https://schema.org/orderDate")
    recordingOf = URIRef("https://schema.org/recordingOf")
    WearableSizeSystemCN = URIRef("https://schema.org/WearableSizeSystemCN")
    abstract = URIRef("https://schema.org/abstract")
    possibleComplication = URIRef("https://schema.org/possibleComplication")
    broadcastTimezone = URIRef("https://schema.org/broadcastTimezone")
    servingSize = URIRef("https://schema.org/servingSize")
    interactivityType = URIRef("https://schema.org/interactivityType")
    sodiumContent = URIRef("https://schema.org/sodiumContent")
    Review = URIRef("https://schema.org/Review")
    ComedyEvent = URIRef("https://schema.org/ComedyEvent")
    inker = URIRef("https://schema.org/inker")
    endTime = URIRef("https://schema.org/endTime")
    securityScreening = URIRef("https://schema.org/securityScreening")
    productID = URIRef("https://schema.org/productID")
    recommendationStrength = URIRef("https://schema.org/recommendationStrength")
    PlanAction = URIRef("https://schema.org/PlanAction")
    mapType = URIRef("https://schema.org/mapType")
    alcoholWarning = URIRef("https://schema.org/alcoholWarning")
    VideoGame = URIRef("https://schema.org/VideoGame")
    ConsumeAction = URIRef("https://schema.org/ConsumeAction")
    subReservation = URIRef("https://schema.org/subReservation")
    prescribingInfo = URIRef("https://schema.org/prescribingInfo")
    dateModified = URIRef("https://schema.org/dateModified")
    DefinitiveLegalValue = URIRef("https://schema.org/DefinitiveLegalValue")
    cashBack = URIRef("https://schema.org/cashBack")
    arrivalTime = URIRef("https://schema.org/arrivalTime")
    fileFormat = URIRef("https://schema.org/fileFormat")
    predecessorOf = URIRef("https://schema.org/predecessorOf")
    availabilityStarts = URIRef("https://schema.org/availabilityStarts")
    Withdrawn = URIRef("https://schema.org/Withdrawn")
    startDate = URIRef("https://schema.org/startDate")
    priceType = URIRef("https://schema.org/priceType")
    HealthPlanFormulary = URIRef("https://schema.org/HealthPlanFormulary")
    abridged = URIRef("https://schema.org/abridged")
    identifier = URIRef("https://schema.org/identifier")
    department = URIRef("https://schema.org/department")
    originalMediaContextDescription = URIRef("https://schema.org/originalMediaContextDescription")
    legislationPassedBy = URIRef("https://schema.org/legislationPassedBy")
    Taxi = URIRef("https://schema.org/Taxi")
    bitrate = URIRef("https://schema.org/bitrate")
    comment = URIRef("https://schema.org/comment")
    NewCondition = URIRef("https://schema.org/NewCondition")
    itemOffered = URIRef("https://schema.org/itemOffered")
    possibleComplication = URIRef("https://schema.org/possibleComplication")
    partOfSystem = URIRef("https://schema.org/partOfSystem")
    Seat = URIRef("https://schema.org/Seat")
    ReadAction = URIRef("https://schema.org/ReadAction")
    httpMethod = URIRef("https://schema.org/httpMethod")
    ReviewNewsArticle = URIRef("https://schema.org/ReviewNewsArticle")
    fuelCapacity = URIRef("https://schema.org/fuelCapacity")
    countryOfOrigin = URIRef("https://schema.org/countryOfOrigin")
    PawnShop = URIRef("https://schema.org/PawnShop")
    typicalCreditsPerTerm = URIRef("https://schema.org/typicalCreditsPerTerm")
    UnitPriceSpecification = URIRef("https://schema.org/UnitPriceSpecification")
    geoMidpoint = URIRef("https://schema.org/geoMidpoint")
    Taxon = URIRef("https://schema.org/Taxon")
    reviewAspect = URIRef("https://schema.org/reviewAspect")
    abridged = URIRef("https://schema.org/abridged")
    nutrition = URIRef("https://schema.org/nutrition")
    inStoreReturnsOffered = URIRef("https://schema.org/inStoreReturnsOffered")
    HVACBusiness = URIRef("https://schema.org/HVACBusiness")
    Hotel = URIRef("https://schema.org/Hotel")
    SeaBodyOfWater = URIRef("https://schema.org/SeaBodyOfWater")
    valuePattern = URIRef("https://schema.org/valuePattern")
    hasRepresentation = URIRef("https://schema.org/hasRepresentation")
    strengthUnit = URIRef("https://schema.org/strengthUnit")
    Mosque = URIRef("https://schema.org/Mosque")
    hasMeasurement = URIRef("https://schema.org/hasMeasurement")
    vehicleModelDate = URIRef("https://schema.org/vehicleModelDate")
    GameServerStatus = URIRef("https://schema.org/GameServerStatus")
    Collection = URIRef("https://schema.org/Collection")
    unitText = URIRef("https://schema.org/unitText")
    TypesHealthAspect = URIRef("https://schema.org/TypesHealthAspect")
    maintainer = URIRef("https://schema.org/maintainer")
    partOfInvoice = URIRef("https://schema.org/partOfInvoice")
    branchCode = URIRef("https://schema.org/branchCode")
    normalRange = URIRef("https://schema.org/normalRange")
    geoContains = URIRef("https://schema.org/geoContains")
    addressCountry = URIRef("https://schema.org/addressCountry")
    courseCode = URIRef("https://schema.org/courseCode")
    ReturnFeesEnumeration = URIRef("https://schema.org/ReturnFeesEnumeration")
    availableFrom = URIRef("https://schema.org/availableFrom")
    HealthPlanNetwork = URIRef("https://schema.org/HealthPlanNetwork")
    recipe = URIRef("https://schema.org/recipe")
    DVDFormat = URIRef("https://schema.org/DVDFormat")
    validIn = URIRef("https://schema.org/validIn")
    HealthPlanNetwork = URIRef("https://schema.org/HealthPlanNetwork")
    orderStatus = URIRef("https://schema.org/orderStatus")
    epidemiology = URIRef("https://schema.org/epidemiology")
    FurnitureStore = URIRef("https://schema.org/FurnitureStore")
    MRI = URIRef("https://schema.org/MRI")
    namedPosition = URIRef("https://schema.org/namedPosition")
    printColumn = URIRef("https://schema.org/printColumn")
    LimitedByGuaranteeCharity = URIRef("https://schema.org/LimitedByGuaranteeCharity")
    FundingAgency = URIRef("https://schema.org/FundingAgency")
    hasAdultConsideration = URIRef("https://schema.org/hasAdultConsideration")
    character = URIRef("https://schema.org/character")
    syllabusSections = URIRef("https://schema.org/syllabusSections")
    geoTouches = URIRef("https://schema.org/geoTouches")
    earlyPrepaymentPenalty = URIRef("https://schema.org/earlyPrepaymentPenalty")
    MedicalEvidenceLevel = URIRef("https://schema.org/MedicalEvidenceLevel")
    valueRequired = URIRef("https://schema.org/valueRequired")
    DownloadAction = URIRef("https://schema.org/DownloadAction")
    ActivationFee = URIRef("https://schema.org/ActivationFee")
    infectiousAgent = URIRef("https://schema.org/infectiousAgent")
    Surgical = URIRef("https://schema.org/Surgical")
    hasBioPolymerSequence = URIRef("https://schema.org/hasBioPolymerSequence")
    text = URIRef("https://schema.org/text")
    actionOption = URIRef("https://schema.org/actionOption")
    knows = URIRef("https://schema.org/knows")
    CertificationStatusEnumeration = URIRef("https://schema.org/CertificationStatusEnumeration")
    OrderInTransit = URIRef("https://schema.org/OrderInTransit")
    EvidenceLevelA = URIRef("https://schema.org/EvidenceLevelA")
    PriceComponentTypeEnumeration = URIRef("https://schema.org/PriceComponentTypeEnumeration")
    byDay = URIRef("https://schema.org/byDay")
    hasOfferCatalog = URIRef("https://schema.org/hasOfferCatalog")
    TaxiReservation = URIRef("https://schema.org/TaxiReservation")
    vatID = URIRef("https://schema.org/vatID")
    EducationalOccupationalProgram = URIRef("https://schema.org/EducationalOccupationalProgram")
    alternateName = URIRef("https://schema.org/alternateName")
    recognizedBy = URIRef("https://schema.org/recognizedBy")
    jobLocationType = URIRef("https://schema.org/jobLocationType")
    diagnosis = URIRef("https://schema.org/diagnosis")
    baseSalary = URIRef("https://schema.org/baseSalary")
    ownershipFundingInfo = URIRef("https://schema.org/ownershipFundingInfo")
    sender = URIRef("https://schema.org/sender")
    UnemploymentSupport = URIRef("https://schema.org/UnemploymentSupport")
    TrainedAlgorithmicMediaDigitalSource = URIRef("https://schema.org/TrainedAlgorithmicMediaDigitalSource")
    eduQuestionType = URIRef("https://schema.org/eduQuestionType")
    ViewAction = URIRef("https://schema.org/ViewAction")
    free = URIRef("https://schema.org/free")
    DrinkAction = URIRef("https://schema.org/DrinkAction")
    PreOrder = URIRef("https://schema.org/PreOrder")
    fileFormat = URIRef("https://schema.org/fileFormat")
    audienceType = URIRef("https://schema.org/audienceType")
    EndorseAction = URIRef("https://schema.org/EndorseAction")
    repeatFrequency = URIRef("https://schema.org/repeatFrequency")
    knowsAbout = URIRef("https://schema.org/knowsAbout")
    CT = URIRef("https://schema.org/CT")
    MonetaryAmountDistribution = URIRef("https://schema.org/MonetaryAmountDistribution")
    priceComponent = URIRef("https://schema.org/priceComponent")
    priceCurrency = URIRef("https://schema.org/priceCurrency")
    requiredCollateral = URIRef("https://schema.org/requiredCollateral")
    GardenStore = URIRef("https://schema.org/GardenStore")
    Audiobook = URIRef("https://schema.org/Audiobook")
    review = URIRef("https://schema.org/review")
    durationOfWarranty = URIRef("https://schema.org/durationOfWarranty")
    inCodeSet = URIRef("https://schema.org/inCodeSet")
    beforeMedia = URIRef("https://schema.org/beforeMedia")
    AndroidPlatform = URIRef("https://schema.org/AndroidPlatform")
    position = URIRef("https://schema.org/position")
    ItemAvailability = URIRef("https://schema.org/ItemAvailability")
    populationType = URIRef("https://schema.org/populationType")
    TVSeason = URIRef("https://schema.org/TVSeason")
    VacationRental = URIRef("https://schema.org/VacationRental")
    weightTotal = URIRef("https://schema.org/weightTotal")
    AlgorithmicMediaDigitalSource = URIRef("https://schema.org/AlgorithmicMediaDigitalSource")
    cssSelector = URIRef("https://schema.org/cssSelector")
    measuredProperty = URIRef("https://schema.org/measuredProperty")
    replacee = URIRef("https://schema.org/replacee")
    reservationId = URIRef("https://schema.org/reservationId")
    seatRow = URIRef("https://schema.org/seatRow")
    ReservationPackage = URIRef("https://schema.org/ReservationPackage")
    DepartmentStore = URIRef("https://schema.org/DepartmentStore")
    taxonomicRange = URIRef("https://schema.org/taxonomicRange")
    SearchAction = URIRef("https://schema.org/SearchAction")
    annualPercentageRate = URIRef("https://schema.org/annualPercentageRate")
    ineligibleRegion = URIRef("https://schema.org/ineligibleRegion")
    acrissCode = URIRef("https://schema.org/acrissCode")
    warrantyPromise = URIRef("https://schema.org/warrantyPromise")
    mentions = URIRef("https://schema.org/mentions")
    accountId = URIRef("https://schema.org/accountId")
    additionalNumberOfGuests = URIRef("https://schema.org/additionalNumberOfGuests")
    pagination = URIRef("https://schema.org/pagination")
    issuedBy = URIRef("https://schema.org/issuedBy")
    maximumPhysicalAttendeeCapacity = URIRef("https://schema.org/maximumPhysicalAttendeeCapacity")
    event = URIRef("https://schema.org/event")
    winner = URIRef("https://schema.org/winner")
    RoofingContractor = URIRef("https://schema.org/RoofingContractor")
    DataCatalog = URIRef("https://schema.org/DataCatalog")
    legislationIdentifier = URIRef("https://schema.org/legislationIdentifier")
    eligibleCustomerType = URIRef("https://schema.org/eligibleCustomerType")
    tourBookingPage = URIRef("https://schema.org/tourBookingPage")
    weightTotal = URIRef("https://schema.org/weightTotal")
    followup = URIRef("https://schema.org/followup")
    sha256 = URIRef("https://schema.org/sha256")
    IngredientsHealthAspect = URIRef("https://schema.org/IngredientsHealthAspect")
    LowCalorieDiet = URIRef("https://schema.org/LowCalorieDiet")
    photo = URIRef("https://schema.org/photo")
    energyEfficiencyScaleMax = URIRef("https://schema.org/energyEfficiencyScaleMax")
    AgreeAction = URIRef("https://schema.org/AgreeAction")
    NarcoticConsideration = URIRef("https://schema.org/NarcoticConsideration")
    HowOrWhereHealthAspect = URIRef("https://schema.org/HowOrWhereHealthAspect")
    Nonprofit501k = URIRef("https://schema.org/Nonprofit501k")
    doseValue = URIRef("https://schema.org/doseValue")
    availableLanguage = URIRef("https://schema.org/availableLanguage")
    numberOfDoors = URIRef("https://schema.org/numberOfDoors")
    broadcastFrequency = URIRef("https://schema.org/broadcastFrequency")
    earlyPrepaymentPenalty = URIRef("https://schema.org/earlyPrepaymentPenalty")
    LaboratoryScience = URIRef("https://schema.org/LaboratoryScience")
    variableMeasured = URIRef("https://schema.org/variableMeasured")
    PrependAction = URIRef("https://schema.org/PrependAction")
    contraindication = URIRef("https://schema.org/contraindication")
    howPerformed = URIRef("https://schema.org/howPerformed")
    PostalCodeRangeSpecification = URIRef("https://schema.org/PostalCodeRangeSpecification")
    ScreeningHealthAspect = URIRef("https://schema.org/ScreeningHealthAspect")
    shippingLabel = URIRef("https://schema.org/shippingLabel")
    mileageFromOdometer = URIRef("https://schema.org/mileageFromOdometer")
    Play = URIRef("https://schema.org/Play")
    MedicalTrialDesign = URIRef("https://schema.org/MedicalTrialDesign")
    value = URIRef("https://schema.org/value")
    AllergiesHealthAspect = URIRef("https://schema.org/AllergiesHealthAspect")
    accessibilityAPI = URIRef("https://schema.org/accessibilityAPI")
    loanPaymentFrequency = URIRef("https://schema.org/loanPaymentFrequency")
    NLNonprofitType = URIRef("https://schema.org/NLNonprofitType")
    ProfessionalService = URIRef("https://schema.org/ProfessionalService")
    interactivityType = URIRef("https://schema.org/interactivityType")
    educationalAlignment = URIRef("https://schema.org/educationalAlignment")
    BookStore = URIRef("https://schema.org/BookStore")
    meetsEmissionStandard = URIRef("https://schema.org/meetsEmissionStandard")
    openingHoursSpecification = URIRef("https://schema.org/openingHoursSpecification")
    merchant = URIRef("https://schema.org/merchant")
    ComedyEvent = URIRef("https://schema.org/ComedyEvent")
    DigitalFormat = URIRef("https://schema.org/DigitalFormat")
    JoinAction = URIRef("https://schema.org/JoinAction")
    trailerWeight = URIRef("https://schema.org/trailerWeight")
    Skin = URIRef("https://schema.org/Skin")
    UserReview = URIRef("https://schema.org/UserReview")
    verificationFactCheckingPolicy = URIRef("https://schema.org/verificationFactCheckingPolicy")
    storageRequirements = URIRef("https://schema.org/storageRequirements")
    SelfCareHealthAspect = URIRef("https://schema.org/SelfCareHealthAspect")
    ReplaceAction = URIRef("https://schema.org/ReplaceAction")
    Optometric = URIRef("https://schema.org/Optometric")
    targetPopulation = URIRef("https://schema.org/targetPopulation")
    director = URIRef("https://schema.org/director")
    ChildCare = URIRef("https://schema.org/ChildCare")
    HealthTopicContent = URIRef("https://schema.org/HealthTopicContent")
    Plumber = URIRef("https://schema.org/Plumber")
    NotInForce = URIRef("https://schema.org/NotInForce")
    HardwareStore = URIRef("https://schema.org/HardwareStore")
    AdultEntertainment = URIRef("https://schema.org/AdultEntertainment")
    confirmationNumber = URIRef("https://schema.org/confirmationNumber")
    hasAdultConsideration = URIRef("https://schema.org/hasAdultConsideration")
    position = URIRef("https://schema.org/position")
    cvdNumC19MechVentPats = URIRef("https://schema.org/cvdNumC19MechVentPats")
    installUrl = URIRef("https://schema.org/installUrl")
    Schedule = URIRef("https://schema.org/Schedule")
    transFatContent = URIRef("https://schema.org/transFatContent")
    LowLactoseDiet = URIRef("https://schema.org/LowLactoseDiet")
    transcript = URIRef("https://schema.org/transcript")
    permittedUsage = URIRef("https://schema.org/permittedUsage")
    accessibilityFeature = URIRef("https://schema.org/accessibilityFeature")
    parentTaxon = URIRef("https://schema.org/parentTaxon")
    GiveAction = URIRef("https://schema.org/GiveAction")
    preOp = URIRef("https://schema.org/preOp")
    PresentationDigitalDocument = URIRef("https://schema.org/PresentationDigitalDocument")
    pickupLocation = URIRef("https://schema.org/pickupLocation")
    gracePeriod = URIRef("https://schema.org/gracePeriod")
    Place = URIRef("https://schema.org/Place")
    WearableMeasurementInseam = URIRef("https://schema.org/WearableMeasurementInseam")
    rxcui = URIRef("https://schema.org/rxcui")
    datePosted = URIRef("https://schema.org/datePosted")
    QualitativeValue = URIRef("https://schema.org/QualitativeValue")
    softwareRequirements = URIRef("https://schema.org/softwareRequirements")
    userInteractionCount = URIRef("https://schema.org/userInteractionCount")
    backstory = URIRef("https://schema.org/backstory")
    availableChannel = URIRef("https://schema.org/availableChannel")
    PhysiciansOffice = URIRef("https://schema.org/PhysiciansOffice")
    coverageEndTime = URIRef("https://schema.org/coverageEndTime")
    endOffset = URIRef("https://schema.org/endOffset")
    numberOfAirbags = URIRef("https://schema.org/numberOfAirbags")
    distinguishingSign = URIRef("https://schema.org/distinguishingSign")
    ShippingDeliveryTime = URIRef("https://schema.org/ShippingDeliveryTime")
    Vehicle = URIRef("https://schema.org/Vehicle")
    frequency = URIRef("https://schema.org/frequency")
    availableAtOrFrom = URIRef("https://schema.org/availableAtOrFrom")
    legislationIdentifier = URIRef("https://schema.org/legislationIdentifier")
    replyToUrl = URIRef("https://schema.org/replyToUrl")
    shippingRate = URIRef("https://schema.org/shippingRate")
    ItemAvailability = URIRef("https://schema.org/ItemAvailability")
    about = URIRef("https://schema.org/about")
    measuredProperty = URIRef("https://schema.org/measuredProperty")
    SpecialAnnouncement = URIRef("https://schema.org/SpecialAnnouncement")
    measurementMethod = URIRef("https://schema.org/measurementMethod")
    broadcastSubChannel = URIRef("https://schema.org/broadcastSubChannel")
    PropertyValue = URIRef("https://schema.org/PropertyValue")
    email = URIRef("https://schema.org/email")
    PrimaryCare = URIRef("https://schema.org/PrimaryCare")
    StagedContent = URIRef("https://schema.org/StagedContent")
    isAvailableGenerically = URIRef("https://schema.org/isAvailableGenerically")
    keywords = URIRef("https://schema.org/keywords")
    HealthPlanCostSharingSpecification = URIRef("https://schema.org/HealthPlanCostSharingSpecification")
    DanceEvent = URIRef("https://schema.org/DanceEvent")
    workLocation = URIRef("https://schema.org/workLocation")
    occupationalCategory = URIRef("https://schema.org/occupationalCategory")
    educationalFramework = URIRef("https://schema.org/educationalFramework")
    PlayGameAction = URIRef("https://schema.org/PlayGameAction")
    associatedArticle = URIRef("https://schema.org/associatedArticle")
    Claim = URIRef("https://schema.org/Claim")
    LimitedAvailability = URIRef("https://schema.org/LimitedAvailability")
    PlasticSurgery = URIRef("https://schema.org/PlasticSurgery")
    Dermatologic = URIRef("https://schema.org/Dermatologic")
    Nonprofit501c12 = URIRef("https://schema.org/Nonprofit501c12")
    albumProductionType = URIRef("https://schema.org/albumProductionType")
    CancelAction = URIRef("https://schema.org/CancelAction")
    area = URIRef("https://schema.org/area")
    DefenceEstablishment = URIRef("https://schema.org/DefenceEstablishment")
    exerciseRelatedDiet = URIRef("https://schema.org/exerciseRelatedDiet")
    TheaterEvent = URIRef("https://schema.org/TheaterEvent")
    award = URIRef("https://schema.org/award")
    textValue = URIRef("https://schema.org/textValue")
    itemDefectReturnShippingFeesAmount = URIRef("https://schema.org/itemDefectReturnShippingFeesAmount")
    legalName = URIRef("https://schema.org/legalName")
    lyricist = URIRef("https://schema.org/lyricist")
    hasRepresentation = URIRef("https://schema.org/hasRepresentation")
    numberOfEpisodes = URIRef("https://schema.org/numberOfEpisodes")
    availableDeliveryMethod = URIRef("https://schema.org/availableDeliveryMethod")
    webFeed = URIRef("https://schema.org/webFeed")
    activeIngredient = URIRef("https://schema.org/activeIngredient")
    eligibleDuration = URIRef("https://schema.org/eligibleDuration")
    cvdNumC19HospPats = URIRef("https://schema.org/cvdNumC19HospPats")
    Physician = URIRef("https://schema.org/Physician")
    BodyMeasurementArm = URIRef("https://schema.org/BodyMeasurementArm")
    masthead = URIRef("https://schema.org/masthead")
    occupationalCategory = URIRef("https://schema.org/occupationalCategory")
    Tuesday = URIRef("https://schema.org/Tuesday")
    diseaseSpreadStatistics = URIRef("https://schema.org/diseaseSpreadStatistics")
    signOrSymptom = URIRef("https://schema.org/signOrSymptom")
    maximumIntake = URIRef("https://schema.org/maximumIntake")
    ReturnInStore = URIRef("https://schema.org/ReturnInStore")
    positiveNotes = URIRef("https://schema.org/positiveNotes")
    Attorney = URIRef("https://schema.org/Attorney")
    NewCondition = URIRef("https://schema.org/NewCondition")
    AccountingService = URIRef("https://schema.org/AccountingService")
    OriginalMediaContent = URIRef("https://schema.org/OriginalMediaContent")
    industry = URIRef("https://schema.org/industry")
    HinduDiet = URIRef("https://schema.org/HinduDiet")
    MinimumAdvertisedPrice = URIRef("https://schema.org/MinimumAdvertisedPrice")
    worksFor = URIRef("https://schema.org/worksFor")
    Nonprofit501n = URIRef("https://schema.org/Nonprofit501n")
    SurgicalProcedure = URIRef("https://schema.org/SurgicalProcedure")
    subStructure = URIRef("https://schema.org/subStructure")
    Flight = URIRef("https://schema.org/Flight")
    foodEstablishment = URIRef("https://schema.org/foodEstablishment")
    MobileWebPlatform = URIRef("https://schema.org/MobileWebPlatform")
    RentalVehicleUsage = URIRef("https://schema.org/RentalVehicleUsage")
    TreatmentsHealthAspect = URIRef("https://schema.org/TreatmentsHealthAspect")
    Invoice = URIRef("https://schema.org/Invoice")
    Toxicologic = URIRef("https://schema.org/Toxicologic")
    CassetteFormat = URIRef("https://schema.org/CassetteFormat")
    LegalValueLevel = URIRef("https://schema.org/LegalValueLevel")
    homeTeam = URIRef("https://schema.org/homeTeam")
    TypeAndQuantityNode = URIRef("https://schema.org/TypeAndQuantityNode")
    annualPercentageRate = URIRef("https://schema.org/annualPercentageRate")
    LegalForceStatus = URIRef("https://schema.org/LegalForceStatus")
    paymentStatus = URIRef("https://schema.org/paymentStatus")
    endOffset = URIRef("https://schema.org/endOffset")
    activeIngredient = URIRef("https://schema.org/activeIngredient")
    boardingGroup = URIRef("https://schema.org/boardingGroup")
    WearableMeasurementBack = URIRef("https://schema.org/WearableMeasurementBack")
    MedicalObservationalStudyDesign = URIRef("https://schema.org/MedicalObservationalStudyDesign")
    auditDate = URIRef("https://schema.org/auditDate")
    warranty = URIRef("https://schema.org/warranty")
    predecessorOf = URIRef("https://schema.org/predecessorOf")
    VegetarianDiet = URIRef("https://schema.org/VegetarianDiet")
    fuelEfficiency = URIRef("https://schema.org/fuelEfficiency")
    OfferForLease = URIRef("https://schema.org/OfferForLease")
    CityHall = URIRef("https://schema.org/CityHall")
    trackingUrl = URIRef("https://schema.org/trackingUrl")
    hasCategoryCode = URIRef("https://schema.org/hasCategoryCode")
    GatedResidenceCommunity = URIRef("https://schema.org/GatedResidenceCommunity")
    PoliceStation = URIRef("https://schema.org/PoliceStation")
    educationalCredentialAwarded = URIRef("https://schema.org/educationalCredentialAwarded")
    error = URIRef("https://schema.org/error")
    dataset = URIRef("https://schema.org/dataset")
    gtin14 = URIRef("https://schema.org/gtin14")
    aircraft = URIRef("https://schema.org/aircraft")
    PriceSpecification = URIRef("https://schema.org/PriceSpecification")
    availableLanguage = URIRef("https://schema.org/availableLanguage")
    muscleAction = URIRef("https://schema.org/muscleAction")
    DistanceFee = URIRef("https://schema.org/DistanceFee")
    isLocatedInSubcellularLocation = URIRef("https://schema.org/isLocatedInSubcellularLocation")
    MedicalGuidelineRecommendation = URIRef("https://schema.org/MedicalGuidelineRecommendation")
    acceptedOffer = URIRef("https://schema.org/acceptedOffer")
    pattern = URIRef("https://schema.org/pattern")
    jurisdiction = URIRef("https://schema.org/jurisdiction")
    CausesHealthAspect = URIRef("https://schema.org/CausesHealthAspect")
    PresentationDigitalDocument = URIRef("https://schema.org/PresentationDigitalDocument")
    playMode = URIRef("https://schema.org/playMode")
    Nonprofit501c12 = URIRef("https://schema.org/Nonprofit501c12")
    subStructure = URIRef("https://schema.org/subStructure")
    measuredProperty = URIRef("https://schema.org/measuredProperty")
    customer = URIRef("https://schema.org/customer")
    paymentDue = URIRef("https://schema.org/paymentDue")
    WebPageElement = URIRef("https://schema.org/WebPageElement")
    productionCompany = URIRef("https://schema.org/productionCompany")
    Integer = URIRef("https://schema.org/Integer")
    color = URIRef("https://schema.org/color")
    awards = URIRef("https://schema.org/awards")
    SoftwareSourceCode = URIRef("https://schema.org/SoftwareSourceCode")
    DigitalArtDigitalSource = URIRef("https://schema.org/DigitalArtDigitalSource")
    originatesFrom = URIRef("https://schema.org/originatesFrom")
    GeoShape = URIRef("https://schema.org/GeoShape")
    nerveMotor = URIRef("https://schema.org/nerveMotor")
    characterName = URIRef("https://schema.org/characterName")
    subEvents = URIRef("https://schema.org/subEvents")
    reservedTicket = URIRef("https://schema.org/reservedTicket")
    Bridge = URIRef("https://schema.org/Bridge")
    musicReleaseFormat = URIRef("https://schema.org/musicReleaseFormat")
    artEdition = URIRef("https://schema.org/artEdition")
    QuoteAction = URIRef("https://schema.org/QuoteAction")
    customerRemorseReturnShippingFeesAmount = URIRef("https://schema.org/customerRemorseReturnShippingFeesAmount")
    UserBlocks = URIRef("https://schema.org/UserBlocks")
    sdPublisher = URIRef("https://schema.org/sdPublisher")
    itemReviewed = URIRef("https://schema.org/itemReviewed")
    PostalCodeRangeSpecification = URIRef("https://schema.org/PostalCodeRangeSpecification")
    GovernmentPermit = URIRef("https://schema.org/GovernmentPermit")
    vehicleModelDate = URIRef("https://schema.org/vehicleModelDate")
    MedicalOrganization = URIRef("https://schema.org/MedicalOrganization")
    estimatedFlightDuration = URIRef("https://schema.org/estimatedFlightDuration")
    workTranslation = URIRef("https://schema.org/workTranslation")
    permissions = URIRef("https://schema.org/permissions")
    previousItem = URIRef("https://schema.org/previousItem")
    procedure = URIRef("https://schema.org/procedure")
    MusicAlbumReleaseType = URIRef("https://schema.org/MusicAlbumReleaseType")
    sharedContent = URIRef("https://schema.org/sharedContent")
    RepaymentSpecification = URIRef("https://schema.org/RepaymentSpecification")
    gtin = URIRef("https://schema.org/gtin")
    seller = URIRef("https://schema.org/seller")
    inChIKey = URIRef("https://schema.org/inChIKey")
    stage = URIRef("https://schema.org/stage")
    comment = URIRef("https://schema.org/comment")
    SingleCenterTrial = URIRef("https://schema.org/SingleCenterTrial")
    PublicationVolume = URIRef("https://schema.org/PublicationVolume")
    returnPolicySeasonalOverride = URIRef("https://schema.org/returnPolicySeasonalOverride")
    applicationContact = URIRef("https://schema.org/applicationContact")
    BlogPosting = URIRef("https://schema.org/BlogPosting")
    aggregateRating = URIRef("https://schema.org/aggregateRating")
    courseMode = URIRef("https://schema.org/courseMode")
    engineDisplacement = URIRef("https://schema.org/engineDisplacement")
    Audiobook = URIRef("https://schema.org/Audiobook")
    EndorsementRating = URIRef("https://schema.org/EndorsementRating")
    UserPlusOnes = URIRef("https://schema.org/UserPlusOnes")
    Sculpture = URIRef("https://schema.org/Sculpture")
    publisherImprint = URIRef("https://schema.org/publisherImprint")
    PawnShop = URIRef("https://schema.org/PawnShop")
    inChIKey = URIRef("https://schema.org/inChIKey")
    CausesHealthAspect = URIRef("https://schema.org/CausesHealthAspect")
    hasDriveThroughService = URIRef("https://schema.org/hasDriveThroughService")
    nutrition = URIRef("https://schema.org/nutrition")
    actionStatus = URIRef("https://schema.org/actionStatus")
    StadiumOrArena = URIRef("https://schema.org/StadiumOrArena")
    constraintProperty = URIRef("https://schema.org/constraintProperty")
    dosageForm = URIRef("https://schema.org/dosageForm")
    relevantOccupation = URIRef("https://schema.org/relevantOccupation")
    BenefitsHealthAspect = URIRef("https://schema.org/BenefitsHealthAspect")
    EnergyConsumptionDetails = URIRef("https://schema.org/EnergyConsumptionDetails")
    checkoutPageURLTemplate = URIRef("https://schema.org/checkoutPageURLTemplate")
    Physiotherapy = URIRef("https://schema.org/Physiotherapy")
    ExampleMeasurementMethodEnum = URIRef("https://schema.org/ExampleMeasurementMethodEnum")
    Prion = URIRef("https://schema.org/Prion")
    PercutaneousProcedure = URIRef("https://schema.org/PercutaneousProcedure")
    assemblyVersion = URIRef("https://schema.org/assemblyVersion")
    itemLocation = URIRef("https://schema.org/itemLocation")
    musicCompositionForm = URIRef("https://schema.org/musicCompositionForm")
    minPrice = URIRef("https://schema.org/minPrice")
    inLanguage = URIRef("https://schema.org/inLanguage")
    refundType = URIRef("https://schema.org/refundType")
    attendees = URIRef("https://schema.org/attendees")
    Nonprofit501c25 = URIRef("https://schema.org/Nonprofit501c25")
    datePosted = URIRef("https://schema.org/datePosted")
    directors = URIRef("https://schema.org/directors")
    worstRating = URIRef("https://schema.org/worstRating")
    DefinedTerm = URIRef("https://schema.org/DefinedTerm")
    performers = URIRef("https://schema.org/performers")
    unitCode = URIRef("https://schema.org/unitCode")
    GroceryStore = URIRef("https://schema.org/GroceryStore")
    FrontWheelDriveConfiguration = URIRef("https://schema.org/FrontWheelDriveConfiguration")
    category = URIRef("https://schema.org/category")
    Taxi = URIRef("https://schema.org/Taxi")
    Discontinued = URIRef("https://schema.org/Discontinued")
    smokingAllowed = URIRef("https://schema.org/smokingAllowed")
    TobaccoNicotineConsideration = URIRef("https://schema.org/TobaccoNicotineConsideration")
    prepTime = URIRef("https://schema.org/prepTime")
    datasetTimeInterval = URIRef("https://schema.org/datasetTimeInterval")
    SiteNavigationElement = URIRef("https://schema.org/SiteNavigationElement")
    EventAttendanceModeEnumeration = URIRef("https://schema.org/EventAttendanceModeEnumeration")
    SpecialAnnouncement = URIRef("https://schema.org/SpecialAnnouncement")
    VideoObject = URIRef("https://schema.org/VideoObject")
    FloorPlan = URIRef("https://schema.org/FloorPlan")
    serviceOperator = URIRef("https://schema.org/serviceOperator")
    conditionsOfAccess = URIRef("https://schema.org/conditionsOfAccess")
    Sculpture = URIRef("https://schema.org/Sculpture")
    mainContentOfPage = URIRef("https://schema.org/mainContentOfPage")
    ReviewNewsArticle = URIRef("https://schema.org/ReviewNewsArticle")
    isEncodedByBioChemEntity = URIRef("https://schema.org/isEncodedByBioChemEntity")
    procedureType = URIRef("https://schema.org/procedureType")
    FullGameAvailability = URIRef("https://schema.org/FullGameAvailability")
    isProprietary = URIRef("https://schema.org/isProprietary")
    gtin12 = URIRef("https://schema.org/gtin12")
    price = URIRef("https://schema.org/price")
    Joint = URIRef("https://schema.org/Joint")
    agent = URIRef("https://schema.org/agent")
    eligibleRegion = URIRef("https://schema.org/eligibleRegion")
    TravelAction = URIRef("https://schema.org/TravelAction")
    geoCrosses = URIRef("https://schema.org/geoCrosses")
    ReservationHold = URIRef("https://schema.org/ReservationHold")
    repetitions = URIRef("https://schema.org/repetitions")
    TextDigitalDocument = URIRef("https://schema.org/TextDigitalDocument")
    titleEIDR = URIRef("https://schema.org/titleEIDR")
    populationType = URIRef("https://schema.org/populationType")
    actors = URIRef("https://schema.org/actors")
    schoolClosuresInfo = URIRef("https://schema.org/schoolClosuresInfo")
    areaServed = URIRef("https://schema.org/areaServed")
    LiveAlbum = URIRef("https://schema.org/LiveAlbum")
    assesses = URIRef("https://schema.org/assesses")
    bed = URIRef("https://schema.org/bed")
    authenticator = URIRef("https://schema.org/authenticator")
    VirtualLocation = URIRef("https://schema.org/VirtualLocation")
    depth = URIRef("https://schema.org/depth")
    DigitalAudioTapeFormat = URIRef("https://schema.org/DigitalAudioTapeFormat")
    BoatTrip = URIRef("https://schema.org/BoatTrip")
    ReadPermission = URIRef("https://schema.org/ReadPermission")
    medicineSystem = URIRef("https://schema.org/medicineSystem")
    transFatContent = URIRef("https://schema.org/transFatContent")
    fuelCapacity = URIRef("https://schema.org/fuelCapacity")
    skills = URIRef("https://schema.org/skills")
    Apartment = URIRef("https://schema.org/Apartment")
    healthPlanNetworkId = URIRef("https://schema.org/healthPlanNetworkId")
    PatientExperienceHealthAspect = URIRef("https://schema.org/PatientExperienceHealthAspect")
    targetPopulation = URIRef("https://schema.org/targetPopulation")
    Certification = URIRef("https://schema.org/Certification")
    dateReceived = URIRef("https://schema.org/dateReceived")
    lesserOrEqual = URIRef("https://schema.org/lesserOrEqual")
    bioChemSimilarity = URIRef("https://schema.org/bioChemSimilarity")
    Airport = URIRef("https://schema.org/Airport")
    review = URIRef("https://schema.org/review")
    dayOfWeek = URIRef("https://schema.org/dayOfWeek")
    MoneyTransfer = URIRef("https://schema.org/MoneyTransfer")
    FullGameAvailability = URIRef("https://schema.org/FullGameAvailability")
    tracks = URIRef("https://schema.org/tracks")
    numberOfBathroomsTotal = URIRef("https://schema.org/numberOfBathroomsTotal")
    partOfEpisode = URIRef("https://schema.org/partOfEpisode")
    biologicalRole = URIRef("https://schema.org/biologicalRole")
    wheelbase = URIRef("https://schema.org/wheelbase")
    availableIn = URIRef("https://schema.org/availableIn")
    HowToItem = URIRef("https://schema.org/HowToItem")
    Duration = URIRef("https://schema.org/Duration")
    browserRequirements = URIRef("https://schema.org/browserRequirements")
    intensity = URIRef("https://schema.org/intensity")
    PerformingGroup = URIRef("https://schema.org/PerformingGroup")
    ChemicalSubstance = URIRef("https://schema.org/ChemicalSubstance")
    AnatomicalSystem = URIRef("https://schema.org/AnatomicalSystem")
    City = URIRef("https://schema.org/City")
    NonprofitType = URIRef("https://schema.org/NonprofitType")
    hasMerchantReturnPolicy = URIRef("https://schema.org/hasMerchantReturnPolicy")
    inventoryLevel = URIRef("https://schema.org/inventoryLevel")
    actionOption = URIRef("https://schema.org/actionOption")
    cashBack = URIRef("https://schema.org/cashBack")
    OrderCancelled = URIRef("https://schema.org/OrderCancelled")
    howPerformed = URIRef("https://schema.org/howPerformed")
    eduQuestionType = URIRef("https://schema.org/eduQuestionType")
    startOffset = URIRef("https://schema.org/startOffset")
    ClaimReview = URIRef("https://schema.org/ClaimReview")
    SeaBodyOfWater = URIRef("https://schema.org/SeaBodyOfWater")
    speakable = URIRef("https://schema.org/speakable")
    icaoCode = URIRef("https://schema.org/icaoCode")
    maximumVirtualAttendeeCapacity = URIRef("https://schema.org/maximumVirtualAttendeeCapacity")
    memberOf = URIRef("https://schema.org/memberOf")
    model = URIRef("https://schema.org/model")
    observationDate = URIRef("https://schema.org/observationDate")
    ReturnLabelSourceEnumeration = URIRef("https://schema.org/ReturnLabelSourceEnumeration")
    expires = URIRef("https://schema.org/expires")
    cookTime = URIRef("https://schema.org/cookTime")
    ReplyAction = URIRef("https://schema.org/ReplyAction")
    jurisdiction = URIRef("https://schema.org/jurisdiction")
    legalStatus = URIRef("https://schema.org/legalStatus")
    RealEstateAgent = URIRef("https://schema.org/RealEstateAgent")
    ReservationConfirmed = URIRef("https://schema.org/ReservationConfirmed")
    numberOfBedrooms = URIRef("https://schema.org/numberOfBedrooms")
    SuspendAction = URIRef("https://schema.org/SuspendAction")
    minimumPaymentDue = URIRef("https://schema.org/minimumPaymentDue")
    Plumber = URIRef("https://schema.org/Plumber")
    MinimumAdvertisedPrice = URIRef("https://schema.org/MinimumAdvertisedPrice")
    hasCertification = URIRef("https://schema.org/hasCertification")
    device = URIRef("https://schema.org/device")
    algorithm = URIRef("https://schema.org/algorithm")
    fileFormat = URIRef("https://schema.org/fileFormat")
    hasOccupation = URIRef("https://schema.org/hasOccupation")
    naturalProgression = URIRef("https://schema.org/naturalProgression")
    steps = URIRef("https://schema.org/steps")
    minValue = URIRef("https://schema.org/minValue")
    EducationalAudience = URIRef("https://schema.org/EducationalAudience")
    Playground = URIRef("https://schema.org/Playground")
    monoisotopicMolecularWeight = URIRef("https://schema.org/monoisotopicMolecularWeight")
    studyDesign = URIRef("https://schema.org/studyDesign")
    workload = URIRef("https://schema.org/workload")
    Campground = URIRef("https://schema.org/Campground")
    lodgingUnitType = URIRef("https://schema.org/lodgingUnitType")
    Series = URIRef("https://schema.org/Series")
    customerRemorseReturnShippingFeesAmount = URIRef("https://schema.org/customerRemorseReturnShippingFeesAmount")
    BioChemEntity = URIRef("https://schema.org/BioChemEntity")
    LibrarySystem = URIRef("https://schema.org/LibrarySystem")
    activityDuration = URIRef("https://schema.org/activityDuration")
    containsSeason = URIRef("https://schema.org/containsSeason")
    payload = URIRef("https://schema.org/payload")
    WarrantyPromise = URIRef("https://schema.org/WarrantyPromise")
    FundingScheme = URIRef("https://schema.org/FundingScheme")
    processingTime = URIRef("https://schema.org/processingTime")
    GenericWebPlatform = URIRef("https://schema.org/GenericWebPlatform")
    publicAccess = URIRef("https://schema.org/publicAccess")
    ResearchProject = URIRef("https://schema.org/ResearchProject")
    correctionsPolicy = URIRef("https://schema.org/correctionsPolicy")
    provider = URIRef("https://schema.org/provider")
    PublicationVolume = URIRef("https://schema.org/PublicationVolume")
    inDefinedTermSet = URIRef("https://schema.org/inDefinedTermSet")
    dateVehicleFirstRegistered = URIRef("https://schema.org/dateVehicleFirstRegistered")
    OnlineOnly = URIRef("https://schema.org/OnlineOnly")
    UserPlays = URIRef("https://schema.org/UserPlays")
    makesOffer = URIRef("https://schema.org/makesOffer")
    Dermatology = URIRef("https://schema.org/Dermatology")
    Installment = URIRef("https://schema.org/Installment")
    targetUrl = URIRef("https://schema.org/targetUrl")
    partOfTVSeries = URIRef("https://schema.org/partOfTVSeries")
    requiredMinAge = URIRef("https://schema.org/requiredMinAge")
    HealthcareConsideration = URIRef("https://schema.org/HealthcareConsideration")
    Vehicle = URIRef("https://schema.org/Vehicle")
    estimatedSalary = URIRef("https://schema.org/estimatedSalary")
    WearableSizeSystemUS = URIRef("https://schema.org/WearableSizeSystemUS")
    performers = URIRef("https://schema.org/performers")
    Nonprofit501d = URIRef("https://schema.org/Nonprofit501d")
    MedicalConditionStage = URIRef("https://schema.org/MedicalConditionStage")
    valueMaxLength = URIRef("https://schema.org/valueMaxLength")
    OriginalMediaContent = URIRef("https://schema.org/OriginalMediaContent")
    recipeIngredient = URIRef("https://schema.org/recipeIngredient")
    Festival = URIRef("https://schema.org/Festival")
    tocContinuation = URIRef("https://schema.org/tocContinuation")
    itemDefectReturnLabelSource = URIRef("https://schema.org/itemDefectReturnLabelSource")
    readonlyValue = URIRef("https://schema.org/readonlyValue")
    countryOfLastProcessing = URIRef("https://schema.org/countryOfLastProcessing")
    hasMolecularFunction = URIRef("https://schema.org/hasMolecularFunction")
    BreadcrumbList = URIRef("https://schema.org/BreadcrumbList")
    InstallAction = URIRef("https://schema.org/InstallAction")
    TakeAction = URIRef("https://schema.org/TakeAction")
    lesserOrEqual = URIRef("https://schema.org/lesserOrEqual")
    EndorseAction = URIRef("https://schema.org/EndorseAction")
    endTime = URIRef("https://schema.org/endTime")
    faxNumber = URIRef("https://schema.org/faxNumber")
    VideoGameSeries = URIRef("https://schema.org/VideoGameSeries")
    evidenceLevel = URIRef("https://schema.org/evidenceLevel")
    gameTip = URIRef("https://schema.org/gameTip")
    BusStop = URIRef("https://schema.org/BusStop")
    primaryImageOfPage = URIRef("https://schema.org/primaryImageOfPage")
    description = URIRef("https://schema.org/description")
    yearlyRevenue = URIRef("https://schema.org/yearlyRevenue")
    identifyingTest = URIRef("https://schema.org/identifyingTest")
    healthPlanCoinsuranceOption = URIRef("https://schema.org/healthPlanCoinsuranceOption")
    smokingAllowed = URIRef("https://schema.org/smokingAllowed")
    offers = URIRef("https://schema.org/offers")
    Clinician = URIRef("https://schema.org/Clinician")
    ShoppingCenter = URIRef("https://schema.org/ShoppingCenter")
    course = URIRef("https://schema.org/course")
    asin = URIRef("https://schema.org/asin")
    StagedContent = URIRef("https://schema.org/StagedContent")
    Chapter = URIRef("https://schema.org/Chapter")
    itemDefectReturnFees = URIRef("https://schema.org/itemDefectReturnFees")
    jobBenefits = URIRef("https://schema.org/jobBenefits")
    includedInHealthInsurancePlan = URIRef("https://schema.org/includedInHealthInsurancePlan")
    broadcastTimezone = URIRef("https://schema.org/broadcastTimezone")
    appliesToPaymentMethod = URIRef("https://schema.org/appliesToPaymentMethod")
    StatusEnumeration = URIRef("https://schema.org/StatusEnumeration")
    isFamilyFriendly = URIRef("https://schema.org/isFamilyFriendly")
    author = URIRef("https://schema.org/author")
    statType = URIRef("https://schema.org/statType")
    customerRemorseReturnShippingFeesAmount = URIRef("https://schema.org/customerRemorseReturnShippingFeesAmount")
    episodeNumber = URIRef("https://schema.org/episodeNumber")
    executableLibraryName = URIRef("https://schema.org/executableLibraryName")
    geoEquals = URIRef("https://schema.org/geoEquals")
    StatisticalPopulation = URIRef("https://schema.org/StatisticalPopulation")
    BodyMeasurementBust = URIRef("https://schema.org/BodyMeasurementBust")
    additionalType = URIRef("https://schema.org/additionalType")
    Nonprofit501q = URIRef("https://schema.org/Nonprofit501q")
    countryOfOrigin = URIRef("https://schema.org/countryOfOrigin")
    hasEnergyConsumptionDetails = URIRef("https://schema.org/hasEnergyConsumptionDetails")
    repeatCount = URIRef("https://schema.org/repeatCount")
    geoWithin = URIRef("https://schema.org/geoWithin")
    uploadDate = URIRef("https://schema.org/uploadDate")
    actors = URIRef("https://schema.org/actors")
    addressRegion = URIRef("https://schema.org/addressRegion")
    engineType = URIRef("https://schema.org/engineType")
    arrivalTerminal = URIRef("https://schema.org/arrivalTerminal")
    Podiatric = URIRef("https://schema.org/Podiatric")
    NLNonprofitType = URIRef("https://schema.org/NLNonprofitType")
    successorOf = URIRef("https://schema.org/successorOf")
    isResizable = URIRef("https://schema.org/isResizable")
    specialty = URIRef("https://schema.org/specialty")
    vehicleIdentificationNumber = URIRef("https://schema.org/vehicleIdentificationNumber")
    followup = URIRef("https://schema.org/followup")
    regionsAllowed = URIRef("https://schema.org/regionsAllowed")
    PreOrderAction = URIRef("https://schema.org/PreOrderAction")
    StatisticalVariable = URIRef("https://schema.org/StatisticalVariable")
    OceanBodyOfWater = URIRef("https://schema.org/OceanBodyOfWater")
    DefinedTerm = URIRef("https://schema.org/DefinedTerm")
    assesses = URIRef("https://schema.org/assesses")
    MedicalCondition = URIRef("https://schema.org/MedicalCondition")
    availableLanguage = URIRef("https://schema.org/availableLanguage")
    HVACBusiness = URIRef("https://schema.org/HVACBusiness")
    review = URIRef("https://schema.org/review")
    DaySpa = URIRef("https://schema.org/DaySpa")
    hasCourse = URIRef("https://schema.org/hasCourse")
    Nonprofit501q = URIRef("https://schema.org/Nonprofit501q")
    qualifications = URIRef("https://schema.org/qualifications")
    hasMenuSection = URIRef("https://schema.org/hasMenuSection")
    embeddedTextCaption = URIRef("https://schema.org/embeddedTextCaption")
    shippingDestination = URIRef("https://schema.org/shippingDestination")
    valuePattern = URIRef("https://schema.org/valuePattern")
    Drawing = URIRef("https://schema.org/Drawing")
    cvdNumC19HOPats = URIRef("https://schema.org/cvdNumC19HOPats")
    HowToDirection = URIRef("https://schema.org/HowToDirection")
    CommentAction = URIRef("https://schema.org/CommentAction")
    isAvailableGenerically = URIRef("https://schema.org/isAvailableGenerically")
    Permit = URIRef("https://schema.org/Permit")
    legislationPassedBy = URIRef("https://schema.org/legislationPassedBy")
    regionDrained = URIRef("https://schema.org/regionDrained")
    checkoutPageURLTemplate = URIRef("https://schema.org/checkoutPageURLTemplate")
    benefits = URIRef("https://schema.org/benefits")
    buyer = URIRef("https://schema.org/buyer")
    itemOffered = URIRef("https://schema.org/itemOffered")
    targetName = URIRef("https://schema.org/targetName")
    gtin8 = URIRef("https://schema.org/gtin8")
    Online = URIRef("https://schema.org/Online")
    digitalSourceType = URIRef("https://schema.org/digitalSourceType")
    ownedThrough = URIRef("https://schema.org/ownedThrough")
    passengerSequenceNumber = URIRef("https://schema.org/passengerSequenceNumber")
    Nonprofit501k = URIRef("https://schema.org/Nonprofit501k")
    availabilityStarts = URIRef("https://schema.org/availabilityStarts")
    legislationResponsible = URIRef("https://schema.org/legislationResponsible")
    byMonthDay = URIRef("https://schema.org/byMonthDay")
    Nonprofit501c3 = URIRef("https://schema.org/Nonprofit501c3")
    associatedClaimReview = URIRef("https://schema.org/associatedClaimReview")
    Researcher = URIRef("https://schema.org/Researcher")
    inLanguage = URIRef("https://schema.org/inLanguage")
    occupancy = URIRef("https://schema.org/occupancy")
    DisabilitySupport = URIRef("https://schema.org/DisabilitySupport")
    ZoneBoardingPolicy = URIRef("https://schema.org/ZoneBoardingPolicy")
    PublicHolidays = URIRef("https://schema.org/PublicHolidays")
    broadcastChannelId = URIRef("https://schema.org/broadcastChannelId")
    contraindication = URIRef("https://schema.org/contraindication")
    valueReference = URIRef("https://schema.org/valueReference")
    geoWithin = URIRef("https://schema.org/geoWithin")
    possibleTreatment = URIRef("https://schema.org/possibleTreatment")
    correction = URIRef("https://schema.org/correction")
    checkinTime = URIRef("https://schema.org/checkinTime")
    guideline = URIRef("https://schema.org/guideline")
    Nonprofit501c10 = URIRef("https://schema.org/Nonprofit501c10")
    noBylinesPolicy = URIRef("https://schema.org/noBylinesPolicy")
    Store = URIRef("https://schema.org/Store")
    recipeYield = URIRef("https://schema.org/recipeYield")
    pickupTime = URIRef("https://schema.org/pickupTime")
    recordedAs = URIRef("https://schema.org/recordedAs")
    servicePhone = URIRef("https://schema.org/servicePhone")
    affiliation = URIRef("https://schema.org/affiliation")
    dissolutionDate = URIRef("https://schema.org/dissolutionDate")
    breadcrumb = URIRef("https://schema.org/breadcrumb")
    DrugStrength = URIRef("https://schema.org/DrugStrength")
    accessibilitySummary = URIRef("https://schema.org/accessibilitySummary")
    cvdNumBeds = URIRef("https://schema.org/cvdNumBeds")
    InviteAction = URIRef("https://schema.org/InviteAction")
    activityFrequency = URIRef("https://schema.org/activityFrequency")
    orderedItem = URIRef("https://schema.org/orderedItem")
    beneficiaryBank = URIRef("https://schema.org/beneficiaryBank")
    maxPrice = URIRef("https://schema.org/maxPrice")
    MusicAlbum = URIRef("https://schema.org/MusicAlbum")
    LiveAlbum = URIRef("https://schema.org/LiveAlbum")
    broadcastSubChannel = URIRef("https://schema.org/broadcastSubChannel")
    loanTerm = URIRef("https://schema.org/loanTerm")
    quest = URIRef("https://schema.org/quest")
    chemicalRole = URIRef("https://schema.org/chemicalRole")
    drainsTo = URIRef("https://schema.org/drainsTo")
    GamePlayMode = URIRef("https://schema.org/GamePlayMode")
    possibleTreatment = URIRef("https://schema.org/possibleTreatment")
    suggestedMeasurement = URIRef("https://schema.org/suggestedMeasurement")
    lesser = URIRef("https://schema.org/lesser")
    sku = URIRef("https://schema.org/sku")
    Audience = URIRef("https://schema.org/Audience")
    BorrowAction = URIRef("https://schema.org/BorrowAction")
    accelerationTime = URIRef("https://schema.org/accelerationTime")
    Paperback = URIRef("https://schema.org/Paperback")
    seriousAdverseOutcome = URIRef("https://schema.org/seriousAdverseOutcome")
    alternativeOf = URIRef("https://schema.org/alternativeOf")
    ReturnMethodEnumeration = URIRef("https://schema.org/ReturnMethodEnumeration")
    CafeOrCoffeeShop = URIRef("https://schema.org/CafeOrCoffeeShop")
    estimatedSalary = URIRef("https://schema.org/estimatedSalary")
    availableService = URIRef("https://schema.org/availableService")
    hasBroadcastChannel = URIRef("https://schema.org/hasBroadcastChannel")
    Hackathon = URIRef("https://schema.org/Hackathon")
    relatedCondition = URIRef("https://schema.org/relatedCondition")
    Trip = URIRef("https://schema.org/Trip")
    track = URIRef("https://schema.org/track")
    healthPlanPharmacyCategory = URIRef("https://schema.org/healthPlanPharmacyCategory")
    responsibilities = URIRef("https://schema.org/responsibilities")
    carbohydrateContent = URIRef("https://schema.org/carbohydrateContent")
    repeatFrequency = URIRef("https://schema.org/repeatFrequency")
    HomeAndConstructionBusiness = URIRef("https://schema.org/HomeAndConstructionBusiness")
    lyrics = URIRef("https://schema.org/lyrics")
    restPeriods = URIRef("https://schema.org/restPeriods")
    Nonprofit501a = URIRef("https://schema.org/Nonprofit501a")
    UnitPriceSpecification = URIRef("https://schema.org/UnitPriceSpecification")
    broadcastDisplayName = URIRef("https://schema.org/broadcastDisplayName")
    healthPlanPharmacyCategory = URIRef("https://schema.org/healthPlanPharmacyCategory")
    SafetyHealthAspect = URIRef("https://schema.org/SafetyHealthAspect")
    answerExplanation = URIRef("https://schema.org/answerExplanation")
    Specialty = URIRef("https://schema.org/Specialty")
    SizeSystemImperial = URIRef("https://schema.org/SizeSystemImperial")
    City = URIRef("https://schema.org/City")
    DataDrivenMediaDigitalSource = URIRef("https://schema.org/DataDrivenMediaDigitalSource")
    sportsTeam = URIRef("https://schema.org/sportsTeam")
    TattooParlor = URIRef("https://schema.org/TattooParlor")
    vatID = URIRef("https://schema.org/vatID")
    legislationDate = URIRef("https://schema.org/legislationDate")
    CoverArt = URIRef("https://schema.org/CoverArt")
    broadcastSubChannel = URIRef("https://schema.org/broadcastSubChannel")
    legislationJurisdiction = URIRef("https://schema.org/legislationJurisdiction")
    Monday = URIRef("https://schema.org/Monday")
    sku = URIRef("https://schema.org/sku")
    sport = URIRef("https://schema.org/sport")
    RadioSeries = URIRef("https://schema.org/RadioSeries")
    duplicateTherapy = URIRef("https://schema.org/duplicateTherapy")
    MovieRentalStore = URIRef("https://schema.org/MovieRentalStore")
    MedicalTestPanel = URIRef("https://schema.org/MedicalTestPanel")
    serviceAudience = URIRef("https://schema.org/serviceAudience")
    hasBroadcastChannel = URIRef("https://schema.org/hasBroadcastChannel")
    touristType = URIRef("https://schema.org/touristType")
    priceComponent = URIRef("https://schema.org/priceComponent")
    purchaseDate = URIRef("https://schema.org/purchaseDate")
    copyrightNotice = URIRef("https://schema.org/copyrightNotice")
    Syllabus = URIRef("https://schema.org/Syllabus")
    monthsOfExperience = URIRef("https://schema.org/monthsOfExperience")
    readBy = URIRef("https://schema.org/readBy")
    ReceiveAction = URIRef("https://schema.org/ReceiveAction")
    hasEnergyEfficiencyCategory = URIRef("https://schema.org/hasEnergyEfficiencyCategory")
    tocEntry = URIRef("https://schema.org/tocEntry")
    LearningResource = URIRef("https://schema.org/LearningResource")
    geoCrosses = URIRef("https://schema.org/geoCrosses")
    copyrightHolder = URIRef("https://schema.org/copyrightHolder")
    correction = URIRef("https://schema.org/correction")
    fuelConsumption = URIRef("https://schema.org/fuelConsumption")
    weight = URIRef("https://schema.org/weight")
    DataCatalog = URIRef("https://schema.org/DataCatalog")
    causeOf = URIRef("https://schema.org/causeOf")
    abridged = URIRef("https://schema.org/abridged")
    MedicalTestPanel = URIRef("https://schema.org/MedicalTestPanel")
    PresentationDigitalDocument = URIRef("https://schema.org/PresentationDigitalDocument")
    AskPublicNewsArticle = URIRef("https://schema.org/AskPublicNewsArticle")
    evidenceLevel = URIRef("https://schema.org/evidenceLevel")
    hasCourse = URIRef("https://schema.org/hasCourse")
    Nonprofit501c23 = URIRef("https://schema.org/Nonprofit501c23")
    authenticator = URIRef("https://schema.org/authenticator")
    MedicalAudience = URIRef("https://schema.org/MedicalAudience")
    taxonomicRange = URIRef("https://schema.org/taxonomicRange")
    Pharmacy = URIRef("https://schema.org/Pharmacy")
    DrugClass = URIRef("https://schema.org/DrugClass")
    Ticket = URIRef("https://schema.org/Ticket")
    numberOfPartialBathrooms = URIRef("https://schema.org/numberOfPartialBathrooms")
    broker = URIRef("https://schema.org/broker")
    CompositeWithTrainedAlgorithmicMediaDigitalSource = URIRef("https://schema.org/CompositeWithTrainedAlgorithmicMediaDigitalSource")
    photo = URIRef("https://schema.org/photo")
    employerOverview = URIRef("https://schema.org/employerOverview")
    ReadAction = URIRef("https://schema.org/ReadAction")
    interactionCount = URIRef("https://schema.org/interactionCount")
    Chiropractic = URIRef("https://schema.org/Chiropractic")
    partOfEpisode = URIRef("https://schema.org/partOfEpisode")
    isGift = URIRef("https://schema.org/isGift")
    ConfirmAction = URIRef("https://schema.org/ConfirmAction")
    minimumPaymentDue = URIRef("https://schema.org/minimumPaymentDue")
    WatchAction = URIRef("https://schema.org/WatchAction")
    ExercisePlan = URIRef("https://schema.org/ExercisePlan")
    phoneticText = URIRef("https://schema.org/phoneticText")
    geoIntersects = URIRef("https://schema.org/geoIntersects")
    OnlineFull = URIRef("https://schema.org/OnlineFull")
    manufacturer = URIRef("https://schema.org/manufacturer")
    encodesCreativeWork = URIRef("https://schema.org/encodesCreativeWork")
    monthlyMinimumRepaymentAmount = URIRef("https://schema.org/monthlyMinimumRepaymentAmount")
    DownloadAction = URIRef("https://schema.org/DownloadAction")
    actionableFeedbackPolicy = URIRef("https://schema.org/actionableFeedbackPolicy")
    busNumber = URIRef("https://schema.org/busNumber")
    HalalDiet = URIRef("https://schema.org/HalalDiet")
    healthPlanCopay = URIRef("https://schema.org/healthPlanCopay")
    BodyMeasurementHand = URIRef("https://schema.org/BodyMeasurementHand")
    Nonprofit501c28 = URIRef("https://schema.org/Nonprofit501c28")
    WearableSizeGroupExtraShort = URIRef("https://schema.org/WearableSizeGroupExtraShort")
    partOfInvoice = URIRef("https://schema.org/partOfInvoice")
    noBylinesPolicy = URIRef("https://schema.org/noBylinesPolicy")
    EventAttendanceModeEnumeration = URIRef("https://schema.org/EventAttendanceModeEnumeration")
    hasMap = URIRef("https://schema.org/hasMap")
    StatisticalVariable = URIRef("https://schema.org/StatisticalVariable")
    recipeCuisine = URIRef("https://schema.org/recipeCuisine")
    accessModeSufficient = URIRef("https://schema.org/accessModeSufficient")
    numberOfDoors = URIRef("https://schema.org/numberOfDoors")
    customerRemorseReturnLabelSource = URIRef("https://schema.org/customerRemorseReturnLabelSource")
    geoCrosses = URIRef("https://schema.org/geoCrosses")
    gameTip = URIRef("https://schema.org/gameTip")
    digitalSourceType = URIRef("https://schema.org/digitalSourceType")
    ArchiveOrganization = URIRef("https://schema.org/ArchiveOrganization")
    pageEnd = URIRef("https://schema.org/pageEnd")
    biologicalRole = URIRef("https://schema.org/biologicalRole")
    Infectious = URIRef("https://schema.org/Infectious")
    foodWarning = URIRef("https://schema.org/foodWarning")
    includedRiskFactor = URIRef("https://schema.org/includedRiskFactor")
    currentExchangeRate = URIRef("https://schema.org/currentExchangeRate")
    maximumAttendeeCapacity = URIRef("https://schema.org/maximumAttendeeCapacity")
    WearableSizeGroupExtraTall = URIRef("https://schema.org/WearableSizeGroupExtraTall")
    PaymentDue = URIRef("https://schema.org/PaymentDue")
    CompositeCaptureDigitalSource = URIRef("https://schema.org/CompositeCaptureDigitalSource")
    BoatTrip = URIRef("https://schema.org/BoatTrip")
    possibleTreatment = URIRef("https://schema.org/possibleTreatment")
    EventSeries = URIRef("https://schema.org/EventSeries")
    WearableSizeSystemEurope = URIRef("https://schema.org/WearableSizeSystemEurope")
    numberOfDoors = URIRef("https://schema.org/numberOfDoors")
    sibling = URIRef("https://schema.org/sibling")
    FundingScheme = URIRef("https://schema.org/FundingScheme")
    orderItemNumber = URIRef("https://schema.org/orderItemNumber")
    postOfficeBoxNumber = URIRef("https://schema.org/postOfficeBoxNumber")
    temporalCoverage = URIRef("https://schema.org/temporalCoverage")
    nsn = URIRef("https://schema.org/nsn")
    currenciesAccepted = URIRef("https://schema.org/currenciesAccepted")
    BroadcastService = URIRef("https://schema.org/BroadcastService")
    City = URIRef("https://schema.org/City")
    PrintDigitalSource = URIRef("https://schema.org/PrintDigitalSource")
    geoMidpoint = URIRef("https://schema.org/geoMidpoint")
    Person = URIRef("https://schema.org/Person")
    rsvpResponse = URIRef("https://schema.org/rsvpResponse")
    deliveryStatus = URIRef("https://schema.org/deliveryStatus")
    Hospital = URIRef("https://schema.org/Hospital")
    Artery = URIRef("https://schema.org/Artery")
    speed = URIRef("https://schema.org/speed")
    imagingTechnique = URIRef("https://schema.org/imagingTechnique")
    EffectivenessHealthAspect = URIRef("https://schema.org/EffectivenessHealthAspect")
    inDefinedTermSet = URIRef("https://schema.org/inDefinedTermSet")
    publisher = URIRef("https://schema.org/publisher")
    logo = URIRef("https://schema.org/logo")
    Resort = URIRef("https://schema.org/Resort")
    ratingValue = URIRef("https://schema.org/ratingValue")
    RealEstateListing = URIRef("https://schema.org/RealEstateListing")
    Property = URIRef("https://schema.org/Property")
    RiverBodyOfWater = URIRef("https://schema.org/RiverBodyOfWater")
    FloorPlan = URIRef("https://schema.org/FloorPlan")
    Property = URIRef("https://schema.org/Property")
    valueMaxLength = URIRef("https://schema.org/valueMaxLength")
    DataDownload = URIRef("https://schema.org/DataDownload")
    UpdateAction = URIRef("https://schema.org/UpdateAction")
    WearableSizeGroupExtraShort = URIRef("https://schema.org/WearableSizeGroupExtraShort")
    Physiotherapy = URIRef("https://schema.org/Physiotherapy")
    drug = URIRef("https://schema.org/drug")
    answerExplanation = URIRef("https://schema.org/answerExplanation")
    WearableMeasurementSleeve = URIRef("https://schema.org/WearableMeasurementSleeve")
    MedicalGuidelineRecommendation = URIRef("https://schema.org/MedicalGuidelineRecommendation")
    WearableMeasurementCup = URIRef("https://schema.org/WearableMeasurementCup")
    creativeWorkStatus = URIRef("https://schema.org/creativeWorkStatus")
    memoryRequirements = URIRef("https://schema.org/memoryRequirements")
    bestRating = URIRef("https://schema.org/bestRating")
    partOfOrder = URIRef("https://schema.org/partOfOrder")
    menuAddOn = URIRef("https://schema.org/menuAddOn")
    GovernmentOffice = URIRef("https://schema.org/GovernmentOffice")
    Occupation = URIRef("https://schema.org/Occupation")
    gettingTestedInfo = URIRef("https://schema.org/gettingTestedInfo")
    geoCovers = URIRef("https://schema.org/geoCovers")
    actors = URIRef("https://schema.org/actors")
    jobBenefits = URIRef("https://schema.org/jobBenefits")
    callSign = URIRef("https://schema.org/callSign")
    TrackAction = URIRef("https://schema.org/TrackAction")
    WearableMeasurementOutsideLeg = URIRef("https://schema.org/WearableMeasurementOutsideLeg")
    sensoryRequirement = URIRef("https://schema.org/sensoryRequirement")
    Withdrawn = URIRef("https://schema.org/Withdrawn")
    Answer = URIRef("https://schema.org/Answer")
    WorkBasedProgram = URIRef("https://schema.org/WorkBasedProgram")
    step = URIRef("https://schema.org/step")
    riskFactor = URIRef("https://schema.org/riskFactor")
    legislationPassedBy = URIRef("https://schema.org/legislationPassedBy")
    Library = URIRef("https://schema.org/Library")
    Ayurvedic = URIRef("https://schema.org/Ayurvedic")
    Physiotherapy = URIRef("https://schema.org/Physiotherapy")
    CollectionPage = URIRef("https://schema.org/CollectionPage")
    dropoffTime = URIRef("https://schema.org/dropoffTime")
    preparation = URIRef("https://schema.org/preparation")
    typicalCreditsPerTerm = URIRef("https://schema.org/typicalCreditsPerTerm")
    BodyMeasurementWeight = URIRef("https://schema.org/BodyMeasurementWeight")
    pattern = URIRef("https://schema.org/pattern")
    discountCode = URIRef("https://schema.org/discountCode")
    creditText = URIRef("https://schema.org/creditText")
    typicalTest = URIRef("https://schema.org/typicalTest")
    borrower = URIRef("https://schema.org/borrower")
    penciler = URIRef("https://schema.org/penciler")
    modifiedTime = URIRef("https://schema.org/modifiedTime")
    isAcceptingNewPatients = URIRef("https://schema.org/isAcceptingNewPatients")
    occupancy = URIRef("https://schema.org/occupancy")
    timeRequired = URIRef("https://schema.org/timeRequired")
    creditedTo = URIRef("https://schema.org/creditedTo")
    releaseNotes = URIRef("https://schema.org/releaseNotes")
    OnlineBusiness = URIRef("https://schema.org/OnlineBusiness")
    tributary = URIRef("https://schema.org/tributary")
    measurementTechnique = URIRef("https://schema.org/measurementTechnique")
    Genitourinary = URIRef("https://schema.org/Genitourinary")
    verificationFactCheckingPolicy = URIRef("https://schema.org/verificationFactCheckingPolicy")
    EventCancelled = URIRef("https://schema.org/EventCancelled")
    OfferCatalog = URIRef("https://schema.org/OfferCatalog")
    vehicleEngine = URIRef("https://schema.org/vehicleEngine")
    OnlineBusiness = URIRef("https://schema.org/OnlineBusiness")
    ReturnAtKiosk = URIRef("https://schema.org/ReturnAtKiosk")
    BoardingPolicyType = URIRef("https://schema.org/BoardingPolicyType")
    boardingPolicy = URIRef("https://schema.org/boardingPolicy")
    estimatesRiskOf = URIRef("https://schema.org/estimatesRiskOf")
    BodyMeasurementBust = URIRef("https://schema.org/BodyMeasurementBust")
    RearWheelDriveConfiguration = URIRef("https://schema.org/RearWheelDriveConfiguration")
    relevantOccupation = URIRef("https://schema.org/relevantOccupation")
    gtin12 = URIRef("https://schema.org/gtin12")
    valueAddedTaxIncluded = URIRef("https://schema.org/valueAddedTaxIncluded")
    awayTeam = URIRef("https://schema.org/awayTeam")
    vehicleInteriorType = URIRef("https://schema.org/vehicleInteriorType")
    maximumIntake = URIRef("https://schema.org/maximumIntake")
    shippingDestination = URIRef("https://schema.org/shippingDestination")
    exerciseCourse = URIRef("https://schema.org/exerciseCourse")
    occupationalCategory = URIRef("https://schema.org/occupationalCategory")
    BodyMeasurementHeight = URIRef("https://schema.org/BodyMeasurementHeight")
    StatisticalVariable = URIRef("https://schema.org/StatisticalVariable")
    IceCreamShop = URIRef("https://schema.org/IceCreamShop")
    SingleCenterTrial = URIRef("https://schema.org/SingleCenterTrial")
    ReactAction = URIRef("https://schema.org/ReactAction")
    mathExpression = URIRef("https://schema.org/mathExpression")
    departureTerminal = URIRef("https://schema.org/departureTerminal")
    Code = URIRef("https://schema.org/Code")
    inverseOf = URIRef("https://schema.org/inverseOf")
    funder = URIRef("https://schema.org/funder")
    Researcher = URIRef("https://schema.org/Researcher")
    countryOfOrigin = URIRef("https://schema.org/countryOfOrigin")
    minValue = URIRef("https://schema.org/minValue")
    trialDesign = URIRef("https://schema.org/trialDesign")
    WearableMeasurementHips = URIRef("https://schema.org/WearableMeasurementHips")
    itemReviewed = URIRef("https://schema.org/itemReviewed")
    SuperficialAnatomy = URIRef("https://schema.org/SuperficialAnatomy")
    embeddedTextCaption = URIRef("https://schema.org/embeddedTextCaption")
    supplyTo = URIRef("https://schema.org/supplyTo")
    startTime = URIRef("https://schema.org/startTime")
    dateDeleted = URIRef("https://schema.org/dateDeleted")
    ReturnFeesCustomerResponsibility = URIRef("https://schema.org/ReturnFeesCustomerResponsibility")
    applicationDeadline = URIRef("https://schema.org/applicationDeadline")
    letterer = URIRef("https://schema.org/letterer")
    CityHall = URIRef("https://schema.org/CityHall")
    Optometric = URIRef("https://schema.org/Optometric")
    safetyConsideration = URIRef("https://schema.org/safetyConsideration")
    HVACBusiness = URIRef("https://schema.org/HVACBusiness")
    orderedItem = URIRef("https://schema.org/orderedItem")
    VegetarianDiet = URIRef("https://schema.org/VegetarianDiet")
    WearableSizeGroupInfants = URIRef("https://schema.org/WearableSizeGroupInfants")
    highPrice = URIRef("https://schema.org/highPrice")
    HinduTemple = URIRef("https://schema.org/HinduTemple")
    exerciseType = URIRef("https://schema.org/exerciseType")
    Park = URIRef("https://schema.org/Park")
    dropoffLocation = URIRef("https://schema.org/dropoffLocation")
    LifestyleModification = URIRef("https://schema.org/LifestyleModification")
    WearableSizeGroupBig = URIRef("https://schema.org/WearableSizeGroupBig")
    hasPart = URIRef("https://schema.org/hasPart")
    inStoreReturnsOffered = URIRef("https://schema.org/inStoreReturnsOffered")
    healthcareReportingData = URIRef("https://schema.org/healthcareReportingData")
    broadcastChannelId = URIRef("https://schema.org/broadcastChannelId")
    publication = URIRef("https://schema.org/publication")
    Church = URIRef("https://schema.org/Church")
    Ultrasound = URIRef("https://schema.org/Ultrasound")
    loanType = URIRef("https://schema.org/loanType")
    PharmacySpecialty = URIRef("https://schema.org/PharmacySpecialty")
    acquiredFrom = URIRef("https://schema.org/acquiredFrom")
    BorrowAction = URIRef("https://schema.org/BorrowAction")
    Retail = URIRef("https://schema.org/Retail")
    LaserDiscFormat = URIRef("https://schema.org/LaserDiscFormat")
    duration = URIRef("https://schema.org/duration")
    Midwifery = URIRef("https://schema.org/Midwifery")
    Head = URIRef("https://schema.org/Head")
    PaymentCard = URIRef("https://schema.org/PaymentCard")
    stepValue = URIRef("https://schema.org/stepValue")
    additionalVariable = URIRef("https://schema.org/additionalVariable")
    HealthPlanFormulary = URIRef("https://schema.org/HealthPlanFormulary")
    tickerSymbol = URIRef("https://schema.org/tickerSymbol")
    directors = URIRef("https://schema.org/directors")
    WearableSizeGroupMaternity = URIRef("https://schema.org/WearableSizeGroupMaternity")
    activeIngredient = URIRef("https://schema.org/activeIngredient")
    resultReview = URIRef("https://schema.org/resultReview")
    availableStrength = URIRef("https://schema.org/availableStrength")
    Airport = URIRef("https://schema.org/Airport")
    VeterinaryCare = URIRef("https://schema.org/VeterinaryCare")
    measurementTechnique = URIRef("https://schema.org/measurementTechnique")
    MediaSubscription = URIRef("https://schema.org/MediaSubscription")
    Ticket = URIRef("https://schema.org/Ticket")
    workTranslation = URIRef("https://schema.org/workTranslation")
    BroadcastEvent = URIRef("https://schema.org/BroadcastEvent")
    inventoryLevel = URIRef("https://schema.org/inventoryLevel")
    permittedUsage = URIRef("https://schema.org/permittedUsage")
    engineType = URIRef("https://schema.org/engineType")
    skills = URIRef("https://schema.org/skills")
    ListItem = URIRef("https://schema.org/ListItem")
    DigitalFormat = URIRef("https://schema.org/DigitalFormat")
    iupacName = URIRef("https://schema.org/iupacName")
    attendees = URIRef("https://schema.org/attendees")
    typicalAgeRange = URIRef("https://schema.org/typicalAgeRange")
    brand = URIRef("https://schema.org/brand")
    workHours = URIRef("https://schema.org/workHours")
    legislationChanges = URIRef("https://schema.org/legislationChanges")
    materialExtent = URIRef("https://schema.org/materialExtent")
    layoutImage = URIRef("https://schema.org/layoutImage")
    Ligament = URIRef("https://schema.org/Ligament")
    usesHealthPlanIdStandard = URIRef("https://schema.org/usesHealthPlanIdStandard")
    PregnancyHealthAspect = URIRef("https://schema.org/PregnancyHealthAspect")
    numberOfCredits = URIRef("https://schema.org/numberOfCredits")
    AllWheelDriveConfiguration = URIRef("https://schema.org/AllWheelDriveConfiguration")
    Nonprofit501c14 = URIRef("https://schema.org/Nonprofit501c14")
    attendees = URIRef("https://schema.org/attendees")
    bookFormat = URIRef("https://schema.org/bookFormat")
    seasons = URIRef("https://schema.org/seasons")
    isbn = URIRef("https://schema.org/isbn")
    iswcCode = URIRef("https://schema.org/iswcCode")
    permitAudience = URIRef("https://schema.org/permitAudience")
    pickupTime = URIRef("https://schema.org/pickupTime")
    inProductGroupWithID = URIRef("https://schema.org/inProductGroupWithID")
    mechanismOfAction = URIRef("https://schema.org/mechanismOfAction")
    paymentDue = URIRef("https://schema.org/paymentDue")
    physicalRequirement = URIRef("https://schema.org/physicalRequirement")
    itinerary = URIRef("https://schema.org/itinerary")
    contactlessPayment = URIRef("https://schema.org/contactlessPayment")
    broker = URIRef("https://schema.org/broker")
    QuantitativeValueDistribution = URIRef("https://schema.org/QuantitativeValueDistribution")
    MusicReleaseFormatType = URIRef("https://schema.org/MusicReleaseFormatType")
    statType = URIRef("https://schema.org/statType")
    numberOfPartialBathrooms = URIRef("https://schema.org/numberOfPartialBathrooms")
    numberOfItems = URIRef("https://schema.org/numberOfItems")
    NoteDigitalDocument = URIRef("https://schema.org/NoteDigitalDocument")
    applicantLocationRequirements = URIRef("https://schema.org/applicantLocationRequirements")
    significance = URIRef("https://schema.org/significance")
    status = URIRef("https://schema.org/status")
    healthPlanNetworkTier = URIRef("https://schema.org/healthPlanNetworkTier")
    workTranslation = URIRef("https://schema.org/workTranslation")
    PaymentComplete = URIRef("https://schema.org/PaymentComplete")
    area = URIRef("https://schema.org/area")
    paymentDueDate = URIRef("https://schema.org/paymentDueDate")
    softwareRequirements = URIRef("https://schema.org/softwareRequirements")
    LeaveAction = URIRef("https://schema.org/LeaveAction")
    CssSelectorType = URIRef("https://schema.org/CssSelectorType")
    RsvpAction = URIRef("https://schema.org/RsvpAction")
    SymptomsHealthAspect = URIRef("https://schema.org/SymptomsHealthAspect")
    Geriatric = URIRef("https://schema.org/Geriatric")
    deliveryMethod = URIRef("https://schema.org/deliveryMethod")
    AlignmentObject = URIRef("https://schema.org/AlignmentObject")
    itemDefectReturnLabelSource = URIRef("https://schema.org/itemDefectReturnLabelSource")
    drugUnit = URIRef("https://schema.org/drugUnit")
    size = URIRef("https://schema.org/size")
    PreSale = URIRef("https://schema.org/PreSale")
    MedicalConditionStage = URIRef("https://schema.org/MedicalConditionStage")
    width = URIRef("https://schema.org/width")
    workHours = URIRef("https://schema.org/workHours")
    amenityFeature = URIRef("https://schema.org/amenityFeature")
    ClothingStore = URIRef("https://schema.org/ClothingStore")
    applicationCategory = URIRef("https://schema.org/applicationCategory")
    inChI = URIRef("https://schema.org/inChI")
    AutoRepair = URIRef("https://schema.org/AutoRepair")
    StatusEnumeration = URIRef("https://schema.org/StatusEnumeration")
    actionApplication = URIRef("https://schema.org/actionApplication")
    Dentistry = URIRef("https://schema.org/Dentistry")
    MedicalConditionStage = URIRef("https://schema.org/MedicalConditionStage")
    contentType = URIRef("https://schema.org/contentType")
    exchangeRateSpread = URIRef("https://schema.org/exchangeRateSpread")
    numberOfPlayers = URIRef("https://schema.org/numberOfPlayers")
    MapCategoryType = URIRef("https://schema.org/MapCategoryType")
    expectedArrivalUntil = URIRef("https://schema.org/expectedArrivalUntil")
    passengerSequenceNumber = URIRef("https://schema.org/passengerSequenceNumber")
    jurisdiction = URIRef("https://schema.org/jurisdiction")
    arrivalStation = URIRef("https://schema.org/arrivalStation")
    insertion = URIRef("https://schema.org/insertion")
    StudioAlbum = URIRef("https://schema.org/StudioAlbum")
    wheelbase = URIRef("https://schema.org/wheelbase")
    acceptedPaymentMethod = URIRef("https://schema.org/acceptedPaymentMethod")
    statType = URIRef("https://schema.org/statType")
    identifyingTest = URIRef("https://schema.org/identifyingTest")
    DigitalDocument = URIRef("https://schema.org/DigitalDocument")
    fundedItem = URIRef("https://schema.org/fundedItem")
    Lung = URIRef("https://schema.org/Lung")
    FlightReservation = URIRef("https://schema.org/FlightReservation")
    feesAndCommissionsSpecification = URIRef("https://schema.org/feesAndCommissionsSpecification")
    relatedTo = URIRef("https://schema.org/relatedTo")
    ProgramMembership = URIRef("https://schema.org/ProgramMembership")
    sugarContent = URIRef("https://schema.org/sugarContent")
    MobileWebPlatform = URIRef("https://schema.org/MobileWebPlatform")
    RadioSeason = URIRef("https://schema.org/RadioSeason")
    inAlbum = URIRef("https://schema.org/inAlbum")
    Hospital = URIRef("https://schema.org/Hospital")
    DataType = URIRef("https://schema.org/DataType")
    scheduledTime = URIRef("https://schema.org/scheduledTime")
    associatedReview = URIRef("https://schema.org/associatedReview")
    PriceSpecification = URIRef("https://schema.org/PriceSpecification")
    occupationLocation = URIRef("https://schema.org/occupationLocation")
    BodyMeasurementInsideLeg = URIRef("https://schema.org/BodyMeasurementInsideLeg")
    FullRefund = URIRef("https://schema.org/FullRefund")
    Dermatology = URIRef("https://schema.org/Dermatology")
    contraindication = URIRef("https://schema.org/contraindication")
    ContactPointOption = URIRef("https://schema.org/ContactPointOption")
    MinimumAdvertisedPrice = URIRef("https://schema.org/MinimumAdvertisedPrice")
    contentType = URIRef("https://schema.org/contentType")
    size = URIRef("https://schema.org/size")
    vehicleTransmission = URIRef("https://schema.org/vehicleTransmission")
    recordedIn = URIRef("https://schema.org/recordedIn")
    broker = URIRef("https://schema.org/broker")
    expertConsiderations = URIRef("https://schema.org/expertConsiderations")
    teaches = URIRef("https://schema.org/teaches")
    physiologicalBenefits = URIRef("https://schema.org/physiologicalBenefits")
    EventVenue = URIRef("https://schema.org/EventVenue")
    MediaReview = URIRef("https://schema.org/MediaReview")
    jobImmediateStart = URIRef("https://schema.org/jobImmediateStart")
    CreditCard = URIRef("https://schema.org/CreditCard")
    Nonprofit501c13 = URIRef("https://schema.org/Nonprofit501c13")
    eligibilityToWorkRequirement = URIRef("https://schema.org/eligibilityToWorkRequirement")
    legislationPassedBy = URIRef("https://schema.org/legislationPassedBy")
    SatiricalArticle = URIRef("https://schema.org/SatiricalArticle")
    Nonprofit501c2 = URIRef("https://schema.org/Nonprofit501c2")
    postOfficeBoxNumber = URIRef("https://schema.org/postOfficeBoxNumber")
    WearableMeasurementCup = URIRef("https://schema.org/WearableMeasurementCup")
    actionPlatform = URIRef("https://schema.org/actionPlatform")
    ReturnFeesCustomerResponsibility = URIRef("https://schema.org/ReturnFeesCustomerResponsibility")
    ResultsNotAvailable = URIRef("https://schema.org/ResultsNotAvailable")
    ratingValue = URIRef("https://schema.org/ratingValue")
    valueMinLength = URIRef("https://schema.org/valueMinLength")
    biologicalRole = URIRef("https://schema.org/biologicalRole")
    PaymentDeclined = URIRef("https://schema.org/PaymentDeclined")
    AppendAction = URIRef("https://schema.org/AppendAction")
    vehicleInteriorColor = URIRef("https://schema.org/vehicleInteriorColor")
    OrderProblem = URIRef("https://schema.org/OrderProblem")
    surface = URIRef("https://schema.org/surface")
    Place = URIRef("https://schema.org/Place")
    coach = URIRef("https://schema.org/coach")
    valueName = URIRef("https://schema.org/valueName")
    SocialMediaPosting = URIRef("https://schema.org/SocialMediaPosting")
    hasRepresentation = URIRef("https://schema.org/hasRepresentation")
    AndroidPlatform = URIRef("https://schema.org/AndroidPlatform")
    PeopleAudience = URIRef("https://schema.org/PeopleAudience")
    HVACBusiness = URIRef("https://schema.org/HVACBusiness")
    Pharmacy = URIRef("https://schema.org/Pharmacy")
    weight = URIRef("https://schema.org/weight")
    numberOfEmployees = URIRef("https://schema.org/numberOfEmployees")
    WearableSizeGroupExtraTall = URIRef("https://schema.org/WearableSizeGroupExtraTall")
    MSRP = URIRef("https://schema.org/MSRP")
    directors = URIRef("https://schema.org/directors")
    cvdNumVent = URIRef("https://schema.org/cvdNumVent")
    cvdNumC19MechVentPats = URIRef("https://schema.org/cvdNumC19MechVentPats")
    RejectAction = URIRef("https://schema.org/RejectAction")
    DrugLegalStatus = URIRef("https://schema.org/DrugLegalStatus")
    opponent = URIRef("https://schema.org/opponent")
    MedicalGuideline = URIRef("https://schema.org/MedicalGuideline")
    UserPageVisits = URIRef("https://schema.org/UserPageVisits")
    hasDefinedTerm = URIRef("https://schema.org/hasDefinedTerm")
    EmployerAggregateRating = URIRef("https://schema.org/EmployerAggregateRating")
    jobTitle = URIRef("https://schema.org/jobTitle")
    isRelatedTo = URIRef("https://schema.org/isRelatedTo")
    realEstateAgent = URIRef("https://schema.org/realEstateAgent")
    bed = URIRef("https://schema.org/bed")
    UserTweets = URIRef("https://schema.org/UserTweets")
    recordedAt = URIRef("https://schema.org/recordedAt")
    gameEdition = URIRef("https://schema.org/gameEdition")
    ReadAction = URIRef("https://schema.org/ReadAction")
    deliveryMethod = URIRef("https://schema.org/deliveryMethod")
    floorLevel = URIRef("https://schema.org/floorLevel")
    modelDate = URIRef("https://schema.org/modelDate")
    priceCurrency = URIRef("https://schema.org/priceCurrency")
    medicalSpecialty = URIRef("https://schema.org/medicalSpecialty")
    BodyMeasurementHeight = URIRef("https://schema.org/BodyMeasurementHeight")
    code = URIRef("https://schema.org/code")
    utterances = URIRef("https://schema.org/utterances")
    MedicalProcedure = URIRef("https://schema.org/MedicalProcedure")
    ApartmentComplex = URIRef("https://schema.org/ApartmentComplex")
    scheduleTimezone = URIRef("https://schema.org/scheduleTimezone")
    organizer = URIRef("https://schema.org/organizer")
    additionalProperty = URIRef("https://schema.org/additionalProperty")
    providesService = URIRef("https://schema.org/providesService")
    penciler = URIRef("https://schema.org/penciler")
    checkoutTime = URIRef("https://schema.org/checkoutTime")
    masthead = URIRef("https://schema.org/masthead")
    schoolClosuresInfo = URIRef("https://schema.org/schoolClosuresInfo")
    NewsMediaOrganization = URIRef("https://schema.org/NewsMediaOrganization")
    loanTerm = URIRef("https://schema.org/loanTerm")
    MedicalImagingTechnique = URIRef("https://schema.org/MedicalImagingTechnique")
    PlayGameAction = URIRef("https://schema.org/PlayGameAction")
    applicationSubCategory = URIRef("https://schema.org/applicationSubCategory")
    healthPlanDrugOption = URIRef("https://schema.org/healthPlanDrugOption")
    termDuration = URIRef("https://schema.org/termDuration")
    EnergyStarEnergyEfficiencyEnumeration = URIRef("https://schema.org/EnergyStarEnergyEfficiencyEnumeration")
    knowsLanguage = URIRef("https://schema.org/knowsLanguage")
    softwareHelp = URIRef("https://schema.org/softwareHelp")
    byMonthDay = URIRef("https://schema.org/byMonthDay")
    pickupTime = URIRef("https://schema.org/pickupTime")
    MedicalClinic = URIRef("https://schema.org/MedicalClinic")
    LiveAlbum = URIRef("https://schema.org/LiveAlbum")
    DeliveryTimeSettings = URIRef("https://schema.org/DeliveryTimeSettings")
    BusOrCoach = URIRef("https://schema.org/BusOrCoach")
    postOp = URIRef("https://schema.org/postOp")
    HealthClub = URIRef("https://schema.org/HealthClub")
    flightNumber = URIRef("https://schema.org/flightNumber")
    DisabilitySupport = URIRef("https://schema.org/DisabilitySupport")
    areaServed = URIRef("https://schema.org/areaServed")
    encodesBioChemEntity = URIRef("https://schema.org/encodesBioChemEntity")
    currency = URIRef("https://schema.org/currency")
    performerIn = URIRef("https://schema.org/performerIn")
    makesOffer = URIRef("https://schema.org/makesOffer")
    opens = URIRef("https://schema.org/opens")
    collectionSize = URIRef("https://schema.org/collectionSize")
    MayTreatHealthAspect = URIRef("https://schema.org/MayTreatHealthAspect")
    Friday = URIRef("https://schema.org/Friday")
    ResumeAction = URIRef("https://schema.org/ResumeAction")
    AuthoritativeLegalValue = URIRef("https://schema.org/AuthoritativeLegalValue")
    RentalVehicleUsage = URIRef("https://schema.org/RentalVehicleUsage")
    Store = URIRef("https://schema.org/Store")
    HobbyShop = URIRef("https://schema.org/HobbyShop")
    MerchantReturnNotPermitted = URIRef("https://schema.org/MerchantReturnNotPermitted")
    ResearchProject = URIRef("https://schema.org/ResearchProject")
    Corporation = URIRef("https://schema.org/Corporation")
    endDate = URIRef("https://schema.org/endDate")
    includedInHealthInsurancePlan = URIRef("https://schema.org/includedInHealthInsurancePlan")
    linkRelationship = URIRef("https://schema.org/linkRelationship")
    BodyMeasurementTypeEnumeration = URIRef("https://schema.org/BodyMeasurementTypeEnumeration")
    BodyMeasurementWeight = URIRef("https://schema.org/BodyMeasurementWeight")
    hospitalAffiliation = URIRef("https://schema.org/hospitalAffiliation")
    isSimilarTo = URIRef("https://schema.org/isSimilarTo")
    guidelineSubject = URIRef("https://schema.org/guidelineSubject")
    articleBody = URIRef("https://schema.org/articleBody")
    inAlbum = URIRef("https://schema.org/inAlbum")
    RentAction = URIRef("https://schema.org/RentAction")
    makesOffer = URIRef("https://schema.org/makesOffer")
    SizeSystemImperial = URIRef("https://schema.org/SizeSystemImperial")
    costOrigin = URIRef("https://schema.org/costOrigin")
    relatedLink = URIRef("https://schema.org/relatedLink")
    OutletStore = URIRef("https://schema.org/OutletStore")
    FoodService = URIRef("https://schema.org/FoodService")
    diseaseSpreadStatistics = URIRef("https://schema.org/diseaseSpreadStatistics")
    shippingSettingsLink = URIRef("https://schema.org/shippingSettingsLink")
    totalPrice = URIRef("https://schema.org/totalPrice")
    cvdFacilityCounty = URIRef("https://schema.org/cvdFacilityCounty")
    availableService = URIRef("https://schema.org/availableService")
    PaidLeave = URIRef("https://schema.org/PaidLeave")
    BookStore = URIRef("https://schema.org/BookStore")
    InfectiousDisease = URIRef("https://schema.org/InfectiousDisease")
    RiverBodyOfWater = URIRef("https://schema.org/RiverBodyOfWater")
    TravelAgency = URIRef("https://schema.org/TravelAgency")
    possibleComplication = URIRef("https://schema.org/possibleComplication")
    artist = URIRef("https://schema.org/artist")
    DiabeticDiet = URIRef("https://schema.org/DiabeticDiet")
    replacee = URIRef("https://schema.org/replacee")
    drainsTo = URIRef("https://schema.org/drainsTo")
    accountId = URIRef("https://schema.org/accountId")
    GatedResidenceCommunity = URIRef("https://schema.org/GatedResidenceCommunity")
    Wholesale = URIRef("https://schema.org/Wholesale")
    Playground = URIRef("https://schema.org/Playground")
    HowToDirection = URIRef("https://schema.org/HowToDirection")
    trainName = URIRef("https://schema.org/trainName")
    isBasedOnUrl = URIRef("https://schema.org/isBasedOnUrl")
    interactionStatistic = URIRef("https://schema.org/interactionStatistic")
    cvdNumBedsOcc = URIRef("https://schema.org/cvdNumBedsOcc")
    suggestedAge = URIRef("https://schema.org/suggestedAge")
    productionCompany = URIRef("https://schema.org/productionCompany")
    byMonthDay = URIRef("https://schema.org/byMonthDay")
    medicalAudience = URIRef("https://schema.org/medicalAudience")
    remainingAttendeeCapacity = URIRef("https://schema.org/remainingAttendeeCapacity")
    businessDays = URIRef("https://schema.org/businessDays")
    CausesHealthAspect = URIRef("https://schema.org/CausesHealthAspect")
    eligibleTransactionVolume = URIRef("https://schema.org/eligibleTransactionVolume")
    SocialMediaPosting = URIRef("https://schema.org/SocialMediaPosting")
    MovieClip = URIRef("https://schema.org/MovieClip")
    CertificationStatusEnumeration = URIRef("https://schema.org/CertificationStatusEnumeration")
    Terminated = URIRef("https://schema.org/Terminated")
    programPrerequisites = URIRef("https://schema.org/programPrerequisites")
    HomeAndConstructionBusiness = URIRef("https://schema.org/HomeAndConstructionBusiness")
    ContactPointOption = URIRef("https://schema.org/ContactPointOption")
    GeoCircle = URIRef("https://schema.org/GeoCircle")
    acquireLicensePage = URIRef("https://schema.org/acquireLicensePage")
    ReservationHold = URIRef("https://schema.org/ReservationHold")
    subEvent = URIRef("https://schema.org/subEvent")
    CriticReview = URIRef("https://schema.org/CriticReview")
    molecularFormula = URIRef("https://schema.org/molecularFormula")
    superEvent = URIRef("https://schema.org/superEvent")
    SuperficialAnatomy = URIRef("https://schema.org/SuperficialAnatomy")
    founder = URIRef("https://schema.org/founder")
    totalPrice = URIRef("https://schema.org/totalPrice")
    hasHealthAspect = URIRef("https://schema.org/hasHealthAspect")
    ClothingStore = URIRef("https://schema.org/ClothingStore")
    collection = URIRef("https://schema.org/collection")
    proficiencyLevel = URIRef("https://schema.org/proficiencyLevel")
    inBroadcastLineup = URIRef("https://schema.org/inBroadcastLineup")
    cvdNumC19Died = URIRef("https://schema.org/cvdNumC19Died")
    leiCode = URIRef("https://schema.org/leiCode")
    HowToStep = URIRef("https://schema.org/HowToStep")
    BasicIncome = URIRef("https://schema.org/BasicIncome")
    significantLink = URIRef("https://schema.org/significantLink")
    molecularWeight = URIRef("https://schema.org/molecularWeight")
    BusinessAudience = URIRef("https://schema.org/BusinessAudience")
    WearableMeasurementTypeEnumeration = URIRef("https://schema.org/WearableMeasurementTypeEnumeration")
    HomeGoodsStore = URIRef("https://schema.org/HomeGoodsStore")
    BusOrCoach = URIRef("https://schema.org/BusOrCoach")
    dropoffLocation = URIRef("https://schema.org/dropoffLocation")
    paymentUrl = URIRef("https://schema.org/paymentUrl")
    workExample = URIRef("https://schema.org/workExample")
    processorRequirements = URIRef("https://schema.org/processorRequirements")
    orderNumber = URIRef("https://schema.org/orderNumber")
    warranty = URIRef("https://schema.org/warranty")
    Invoice = URIRef("https://schema.org/Invoice")
    MediaReview = URIRef("https://schema.org/MediaReview")
    serviceAudience = URIRef("https://schema.org/serviceAudience")
    MolecularEntity = URIRef("https://schema.org/MolecularEntity")
    monthlyMinimumRepaymentAmount = URIRef("https://schema.org/monthlyMinimumRepaymentAmount")
    studyLocation = URIRef("https://schema.org/studyLocation")
    fundedItem = URIRef("https://schema.org/fundedItem")
    StatusEnumeration = URIRef("https://schema.org/StatusEnumeration")
    BusTrip = URIRef("https://schema.org/BusTrip")
    AssignAction = URIRef("https://schema.org/AssignAction")
    AnatomicalStructure = URIRef("https://schema.org/AnatomicalStructure")
    additionalName = URIRef("https://schema.org/additionalName")
    validIn = URIRef("https://schema.org/validIn")
    CreativeWorkSeason = URIRef("https://schema.org/CreativeWorkSeason")
    Bridge = URIRef("https://schema.org/Bridge")
    birthPlace = URIRef("https://schema.org/birthPlace")
    incentiveCompensation = URIRef("https://schema.org/incentiveCompensation")
    Series = URIRef("https://schema.org/Series")
    includesHealthPlanNetwork = URIRef("https://schema.org/includesHealthPlanNetwork")
    tongueWeight = URIRef("https://schema.org/tongueWeight")
    LendAction = URIRef("https://schema.org/LendAction")
    Park = URIRef("https://schema.org/Park")
    openingHours = URIRef("https://schema.org/openingHours")
    fundedItem = URIRef("https://schema.org/fundedItem")
    percentile10 = URIRef("https://schema.org/percentile10")
    usedToDiagnose = URIRef("https://schema.org/usedToDiagnose")
    issueNumber = URIRef("https://schema.org/issueNumber")
    EUEnergyEfficiencyCategoryE = URIRef("https://schema.org/EUEnergyEfficiencyCategoryE")
    alternativeHeadline = URIRef("https://schema.org/alternativeHeadline")
    currentExchangeRate = URIRef("https://schema.org/currentExchangeRate")
    purchaseDate = URIRef("https://schema.org/purchaseDate")
    video = URIRef("https://schema.org/video")
    readBy = URIRef("https://schema.org/readBy")
    RecommendedDoseSchedule = URIRef("https://schema.org/RecommendedDoseSchedule")
    includesHealthPlanNetwork = URIRef("https://schema.org/includesHealthPlanNetwork")
    byMonth = URIRef("https://schema.org/byMonth")
    greaterOrEqual = URIRef("https://schema.org/greaterOrEqual")
    unitText = URIRef("https://schema.org/unitText")
    geoWithin = URIRef("https://schema.org/geoWithin")
    downloadUrl = URIRef("https://schema.org/downloadUrl")
    cvdNumC19HospPats = URIRef("https://schema.org/cvdNumC19HospPats")
    arrivalPlatform = URIRef("https://schema.org/arrivalPlatform")
    WearableSizeGroupBoys = URIRef("https://schema.org/WearableSizeGroupBoys")
    jobTitle = URIRef("https://schema.org/jobTitle")
    permissions = URIRef("https://schema.org/permissions")
    businessDays = URIRef("https://schema.org/businessDays")
    additionalProperty = URIRef("https://schema.org/additionalProperty")
    exceptDate = URIRef("https://schema.org/exceptDate")
    deliveryMethod = URIRef("https://schema.org/deliveryMethod")
    language = URIRef("https://schema.org/language")
    performer = URIRef("https://schema.org/performer")
    PsychologicalTreatment = URIRef("https://schema.org/PsychologicalTreatment")
    hasCredential = URIRef("https://schema.org/hasCredential")
    ParentAudience = URIRef("https://schema.org/ParentAudience")
    bookingTime = URIRef("https://schema.org/bookingTime")
    departureGate = URIRef("https://schema.org/departureGate")
    regionDrained = URIRef("https://schema.org/regionDrained")
    maps = URIRef("https://schema.org/maps")
    gamePlatform = URIRef("https://schema.org/gamePlatform")
    EventAttendanceModeEnumeration = URIRef("https://schema.org/EventAttendanceModeEnumeration")
    MedicalTrialDesign = URIRef("https://schema.org/MedicalTrialDesign")
    isrcCode = URIRef("https://schema.org/isrcCode")
    BroadcastFrequencySpecification = URIRef("https://schema.org/BroadcastFrequencySpecification")
    Nose = URIRef("https://schema.org/Nose")
    printPage = URIRef("https://schema.org/printPage")
    gracePeriod = URIRef("https://schema.org/gracePeriod")
    legislationApplies = URIRef("https://schema.org/legislationApplies")
    Class = URIRef("https://schema.org/Class")
    QAPage = URIRef("https://schema.org/QAPage")
    requiredCollateral = URIRef("https://schema.org/requiredCollateral")
    valueAddedTaxIncluded = URIRef("https://schema.org/valueAddedTaxIncluded")
    SportsActivityLocation = URIRef("https://schema.org/SportsActivityLocation")
    TransferAction = URIRef("https://schema.org/TransferAction")
    RestockingFees = URIRef("https://schema.org/RestockingFees")
    colleague = URIRef("https://schema.org/colleague")
    ShortStory = URIRef("https://schema.org/ShortStory")
    Podiatric = URIRef("https://schema.org/Podiatric")
    startTime = URIRef("https://schema.org/startTime")
    programName = URIRef("https://schema.org/programName")
    engineDisplacement = URIRef("https://schema.org/engineDisplacement")
    dateCreated = URIRef("https://schema.org/dateCreated")
    MusicAlbumProductionType = URIRef("https://schema.org/MusicAlbumProductionType")
    availableChannel = URIRef("https://schema.org/availableChannel")
    missionCoveragePrioritiesPolicy = URIRef("https://schema.org/missionCoveragePrioritiesPolicy")
    AdultEntertainment = URIRef("https://schema.org/AdultEntertainment")
    expires = URIRef("https://schema.org/expires")
    activityFrequency = URIRef("https://schema.org/activityFrequency")
    albumProductionType = URIRef("https://schema.org/albumProductionType")
    commentCount = URIRef("https://schema.org/commentCount")
    VeterinaryCare = URIRef("https://schema.org/VeterinaryCare")
    releaseNotes = URIRef("https://schema.org/releaseNotes")
    expertConsiderations = URIRef("https://schema.org/expertConsiderations")
    DanceGroup = URIRef("https://schema.org/DanceGroup")
    isPartOfBioChemEntity = URIRef("https://schema.org/isPartOfBioChemEntity")
    tributary = URIRef("https://schema.org/tributary")
    newsUpdatesAndGuidelines = URIRef("https://schema.org/newsUpdatesAndGuidelines")
    pregnancyWarning = URIRef("https://schema.org/pregnancyWarning")
    totalHistoricalEnrollment = URIRef("https://schema.org/totalHistoricalEnrollment")
    Female = URIRef("https://schema.org/Female")
    encoding = URIRef("https://schema.org/encoding")
    Nonprofit501c15 = URIRef("https://schema.org/Nonprofit501c15")
    SeekToAction = URIRef("https://schema.org/SeekToAction")
    UserInteraction = URIRef("https://schema.org/UserInteraction")
    codeRepository = URIRef("https://schema.org/codeRepository")
    BodyMeasurementWeight = URIRef("https://schema.org/BodyMeasurementWeight")
    WearableSizeGroupEnumeration = URIRef("https://schema.org/WearableSizeGroupEnumeration")
    Nonprofit501c23 = URIRef("https://schema.org/Nonprofit501c23")
    playersOnline = URIRef("https://schema.org/playersOnline")
    abridged = URIRef("https://schema.org/abridged")
    Project = URIRef("https://schema.org/Project")
    gameItem = URIRef("https://schema.org/gameItem")
    valueReference = URIRef("https://schema.org/valueReference")
    wheelbase = URIRef("https://schema.org/wheelbase")
    Park = URIRef("https://schema.org/Park")
    WearableSizeGroupExtraTall = URIRef("https://schema.org/WearableSizeGroupExtraTall")
    WearableMeasurementLength = URIRef("https://schema.org/WearableMeasurementLength")
    awayTeam = URIRef("https://schema.org/awayTeam")
    expires = URIRef("https://schema.org/expires")
    doseValue = URIRef("https://schema.org/doseValue")
    funding = URIRef("https://schema.org/funding")
    ownedFrom = URIRef("https://schema.org/ownedFrom")
    MayTreatHealthAspect = URIRef("https://schema.org/MayTreatHealthAspect")
    RemixAlbum = URIRef("https://schema.org/RemixAlbum")
    iataCode = URIRef("https://schema.org/iataCode")
    gracePeriod = URIRef("https://schema.org/gracePeriod")
    actor = URIRef("https://schema.org/actor")
    proteinContent = URIRef("https://schema.org/proteinContent")
    productionCompany = URIRef("https://schema.org/productionCompany")
    MonetaryGrant = URIRef("https://schema.org/MonetaryGrant")
    engineType = URIRef("https://schema.org/engineType")
    correction = URIRef("https://schema.org/correction")
    ProductCollection = URIRef("https://schema.org/ProductCollection")
    subTrip = URIRef("https://schema.org/subTrip")
    ReturnLabelSourceEnumeration = URIRef("https://schema.org/ReturnLabelSourceEnumeration")
    targetCollection = URIRef("https://schema.org/targetCollection")
    hasRepresentation = URIRef("https://schema.org/hasRepresentation")
    subtitleLanguage = URIRef("https://schema.org/subtitleLanguage")
    flightDistance = URIRef("https://schema.org/flightDistance")
    trailerWeight = URIRef("https://schema.org/trailerWeight")
    availableService = URIRef("https://schema.org/availableService")
    Brewery = URIRef("https://schema.org/Brewery")
    ReviewAction = URIRef("https://schema.org/ReviewAction")
    OceanBodyOfWater = URIRef("https://schema.org/OceanBodyOfWater")
    nerveMotor = URIRef("https://schema.org/nerveMotor")
    ListenAction = URIRef("https://schema.org/ListenAction")
    width = URIRef("https://schema.org/width")
    PlayGameAction = URIRef("https://schema.org/PlayGameAction")
    BodyMeasurementTypeEnumeration = URIRef("https://schema.org/BodyMeasurementTypeEnumeration")
    sizeSystem = URIRef("https://schema.org/sizeSystem")
    Psychiatric = URIRef("https://schema.org/Psychiatric")
    EvidenceLevelA = URIRef("https://schema.org/EvidenceLevelA")
    CompletedActionStatus = URIRef("https://schema.org/CompletedActionStatus")
    maximumAttendeeCapacity = URIRef("https://schema.org/maximumAttendeeCapacity")
    NLNonprofitType = URIRef("https://schema.org/NLNonprofitType")
    SatiricalArticle = URIRef("https://schema.org/SatiricalArticle")
    ReturnInStore = URIRef("https://schema.org/ReturnInStore")
    BusinessEntityType = URIRef("https://schema.org/BusinessEntityType")
    sameAs = URIRef("https://schema.org/sameAs")
    playMode = URIRef("https://schema.org/playMode")
    Neck = URIRef("https://schema.org/Neck")
    Campground = URIRef("https://schema.org/Campground")
    DiscoverAction = URIRef("https://schema.org/DiscoverAction")
    serialNumber = URIRef("https://schema.org/serialNumber")
    proteinContent = URIRef("https://schema.org/proteinContent")
    differentialDiagnosis = URIRef("https://schema.org/differentialDiagnosis")
    OnlineBusiness = URIRef("https://schema.org/OnlineBusiness")
    legislationDate = URIRef("https://schema.org/legislationDate")
    Project = URIRef("https://schema.org/Project")
    enginePower = URIRef("https://schema.org/enginePower")
    JoinAction = URIRef("https://schema.org/JoinAction")
    isEncodedByBioChemEntity = URIRef("https://schema.org/isEncodedByBioChemEntity")
    orderDelivery = URIRef("https://schema.org/orderDelivery")
    trailerWeight = URIRef("https://schema.org/trailerWeight")
    OnDemandEvent = URIRef("https://schema.org/OnDemandEvent")
    confirmationNumber = URIRef("https://schema.org/confirmationNumber")
    accessCode = URIRef("https://schema.org/accessCode")
    runtime = URIRef("https://schema.org/runtime")
    requiredQuantity = URIRef("https://schema.org/requiredQuantity")
    Installment = URIRef("https://schema.org/Installment")
    MusicRelease = URIRef("https://schema.org/MusicRelease")
    smiles = URIRef("https://schema.org/smiles")
    taxonRank = URIRef("https://schema.org/taxonRank")
    competitor = URIRef("https://schema.org/competitor")
    MinorHumanEditsDigitalSource = URIRef("https://schema.org/MinorHumanEditsDigitalSource")
    percentile25 = URIRef("https://schema.org/percentile25")
    PostalCodeRangeSpecification = URIRef("https://schema.org/PostalCodeRangeSpecification")
    WearableSizeSystemEnumeration = URIRef("https://schema.org/WearableSizeSystemEnumeration")
    Nonprofit501c16 = URIRef("https://schema.org/Nonprofit501c16")
    lastReviewed = URIRef("https://schema.org/lastReviewed")
    bitrate = URIRef("https://schema.org/bitrate")
    cvdNumC19OFMechVentPats = URIRef("https://schema.org/cvdNumC19OFMechVentPats")
    associatedMediaReview = URIRef("https://schema.org/associatedMediaReview")
    JewelryStore = URIRef("https://schema.org/JewelryStore")
    offers = URIRef("https://schema.org/offers")
    credentialCategory = URIRef("https://schema.org/credentialCategory")
    DigitalArtDigitalSource = URIRef("https://schema.org/DigitalArtDigitalSource")
    Chapter = URIRef("https://schema.org/Chapter")
    WearableMeasurementHeight = URIRef("https://schema.org/WearableMeasurementHeight")
    pathophysiology = URIRef("https://schema.org/pathophysiology")
    validUntil = URIRef("https://schema.org/validUntil")
    paymentDue = URIRef("https://schema.org/paymentDue")
    broadcastFrequencyValue = URIRef("https://schema.org/broadcastFrequencyValue")
    schoolClosuresInfo = URIRef("https://schema.org/schoolClosuresInfo")
    endorsers = URIRef("https://schema.org/endorsers")
    incentiveCompensation = URIRef("https://schema.org/incentiveCompensation")
    Drug = URIRef("https://schema.org/Drug")
    AutoBodyShop = URIRef("https://schema.org/AutoBodyShop")
    TouristInformationCenter = URIRef("https://schema.org/TouristInformationCenter")
    mobileUrl = URIRef("https://schema.org/mobileUrl")
    equal = URIRef("https://schema.org/equal")
    SportsTeam = URIRef("https://schema.org/SportsTeam")
    browserRequirements = URIRef("https://schema.org/browserRequirements")
    producer = URIRef("https://schema.org/producer")
    recipeInstructions = URIRef("https://schema.org/recipeInstructions")
    PlanAction = URIRef("https://schema.org/PlanAction")
    CarUsageType = URIRef("https://schema.org/CarUsageType")
    pattern = URIRef("https://schema.org/pattern")
    acrissCode = URIRef("https://schema.org/acrissCode")
    observationPeriod = URIRef("https://schema.org/observationPeriod")
    monthlyMinimumRepaymentAmount = URIRef("https://schema.org/monthlyMinimumRepaymentAmount")
    ImagingTest = URIRef("https://schema.org/ImagingTest")
    WearableMeasurementWidth = URIRef("https://schema.org/WearableMeasurementWidth")
    baseSalary = URIRef("https://schema.org/baseSalary")
    ReturnInStore = URIRef("https://schema.org/ReturnInStore")
    breadcrumb = URIRef("https://schema.org/breadcrumb")
    RadioSeason = URIRef("https://schema.org/RadioSeason")
    directors = URIRef("https://schema.org/directors")
    Order = URIRef("https://schema.org/Order")
    VisualArtwork = URIRef("https://schema.org/VisualArtwork")
    utterances = URIRef("https://schema.org/utterances")
    contactPoint = URIRef("https://schema.org/contactPoint")
    doorTime = URIRef("https://schema.org/doorTime")
    Suite = URIRef("https://schema.org/Suite")
    reviews = URIRef("https://schema.org/reviews")
    ineligibleRegion = URIRef("https://schema.org/ineligibleRegion")
    InStock = URIRef("https://schema.org/InStock")
    Nonprofit501c14 = URIRef("https://schema.org/Nonprofit501c14")
    containedIn = URIRef("https://schema.org/containedIn")
    audience = URIRef("https://schema.org/audience")
    Legislation = URIRef("https://schema.org/Legislation")
    DoseSchedule = URIRef("https://schema.org/DoseSchedule")
    ReceiveAction = URIRef("https://schema.org/ReceiveAction")
    PatientExperienceHealthAspect = URIRef("https://schema.org/PatientExperienceHealthAspect")
    DislikeAction = URIRef("https://schema.org/DislikeAction")
    aspect = URIRef("https://schema.org/aspect")
    publicationType = URIRef("https://schema.org/publicationType")
    verificationFactCheckingPolicy = URIRef("https://schema.org/verificationFactCheckingPolicy")
    tributary = URIRef("https://schema.org/tributary")
    RsvpResponseType = URIRef("https://schema.org/RsvpResponseType")
    PathologyTest = URIRef("https://schema.org/PathologyTest")
    InsertAction = URIRef("https://schema.org/InsertAction")
    membershipPointsEarned = URIRef("https://schema.org/membershipPointsEarned")
    interactionCount = URIRef("https://schema.org/interactionCount")
    startTime = URIRef("https://schema.org/startTime")
    Event = URIRef("https://schema.org/Event")
    OrderAction = URIRef("https://schema.org/OrderAction")
    creator = URIRef("https://schema.org/creator")
    MaximumDoseSchedule = URIRef("https://schema.org/MaximumDoseSchedule")
    inDefinedTermSet = URIRef("https://schema.org/inDefinedTermSet")
    WearableSizeGroupInfants = URIRef("https://schema.org/WearableSizeGroupInfants")
    sdLicense = URIRef("https://schema.org/sdLicense")
    Motorcycle = URIRef("https://schema.org/Motorcycle")
    award = URIRef("https://schema.org/award")
    PaidLeave = URIRef("https://schema.org/PaidLeave")
    drugUnit = URIRef("https://schema.org/drugUnit")
    CaseSeries = URIRef("https://schema.org/CaseSeries")
    Accommodation = URIRef("https://schema.org/Accommodation")
    HealthCare = URIRef("https://schema.org/HealthCare")
    vehicleSpecialUsage = URIRef("https://schema.org/vehicleSpecialUsage")
    instructor = URIRef("https://schema.org/instructor")
    loanMortgageMandateAmount = URIRef("https://schema.org/loanMortgageMandateAmount")
    isGift = URIRef("https://schema.org/isGift")
    surface = URIRef("https://schema.org/surface")
    audio = URIRef("https://schema.org/audio")
    securityClearanceRequirement = URIRef("https://schema.org/securityClearanceRequirement")
    SelfStorage = URIRef("https://schema.org/SelfStorage")
    actionAccessibilityRequirement = URIRef("https://schema.org/actionAccessibilityRequirement")
    provider = URIRef("https://schema.org/provider")
    associatedPathophysiology = URIRef("https://schema.org/associatedPathophysiology")
    educationalFramework = URIRef("https://schema.org/educationalFramework")
    prescriptionStatus = URIRef("https://schema.org/prescriptionStatus")
    drainsTo = URIRef("https://schema.org/drainsTo")
    doseUnit = URIRef("https://schema.org/doseUnit")
    Nonprofit501c15 = URIRef("https://schema.org/Nonprofit501c15")
    Car = URIRef("https://schema.org/Car")
    CriticReview = URIRef("https://schema.org/CriticReview")
    serviceSmsNumber = URIRef("https://schema.org/serviceSmsNumber")
    MixedEventAttendanceMode = URIRef("https://schema.org/MixedEventAttendanceMode")
    Flexibility = URIRef("https://schema.org/Flexibility")
    Physician = URIRef("https://schema.org/Physician")
    StoreCreditRefund = URIRef("https://schema.org/StoreCreditRefund")
    vehicleSeatingCapacity = URIRef("https://schema.org/vehicleSeatingCapacity")
    DigitalFormat = URIRef("https://schema.org/DigitalFormat")
    LaserDiscFormat = URIRef("https://schema.org/LaserDiscFormat")
    OrderStatus = URIRef("https://schema.org/OrderStatus")
    geoTouches = URIRef("https://schema.org/geoTouches")
    taxonRank = URIRef("https://schema.org/taxonRank")
    playersOnline = URIRef("https://schema.org/playersOnline")
    RealEstateListing = URIRef("https://schema.org/RealEstateListing")
    encodesBioChemEntity = URIRef("https://schema.org/encodesBioChemEntity")
    encodesCreativeWork = URIRef("https://schema.org/encodesCreativeWork")
    Registry = URIRef("https://schema.org/Registry")
    ElectronicsStore = URIRef("https://schema.org/ElectronicsStore")
    exercisePlan = URIRef("https://schema.org/exercisePlan")
    Nonprofit501c1 = URIRef("https://schema.org/Nonprofit501c1")
    gracePeriod = URIRef("https://schema.org/gracePeriod")
    DigitalAudioTapeFormat = URIRef("https://schema.org/DigitalAudioTapeFormat")
    claimReviewed = URIRef("https://schema.org/claimReviewed")
    broadcastFrequency = URIRef("https://schema.org/broadcastFrequency")
    sdPublisher = URIRef("https://schema.org/sdPublisher")
    includedComposition = URIRef("https://schema.org/includedComposition")
    healthPlanNetworkId = URIRef("https://schema.org/healthPlanNetworkId")
    occupancy = URIRef("https://schema.org/occupancy")
    termDuration = URIRef("https://schema.org/termDuration")
    supply = URIRef("https://schema.org/supply")
    additionalProperty = URIRef("https://schema.org/additionalProperty")
    event = URIRef("https://schema.org/event")
    orderedItem = URIRef("https://schema.org/orderedItem")
    ReducedRelevanceForChildrenConsideration = URIRef("https://schema.org/ReducedRelevanceForChildrenConsideration")
    FMRadioChannel = URIRef("https://schema.org/FMRadioChannel")
    DietNutrition = URIRef("https://schema.org/DietNutrition")
    advanceBookingRequirement = URIRef("https://schema.org/advanceBookingRequirement")
    RadioChannel = URIRef("https://schema.org/RadioChannel")
    tourBookingPage = URIRef("https://schema.org/tourBookingPage")
    floorLimit = URIRef("https://schema.org/floorLimit")
    incentiveCompensation = URIRef("https://schema.org/incentiveCompensation")
    AchieveAction = URIRef("https://schema.org/AchieveAction")
    arrivalTime = URIRef("https://schema.org/arrivalTime")
    NewsArticle = URIRef("https://schema.org/NewsArticle")
    OriginalShippingFees = URIRef("https://schema.org/OriginalShippingFees")
    NewsMediaOrganization = URIRef("https://schema.org/NewsMediaOrganization")
    serialNumber = URIRef("https://schema.org/serialNumber")
    encodesCreativeWork = URIRef("https://schema.org/encodesCreativeWork")
    stage = URIRef("https://schema.org/stage")
    eventAttendanceMode = URIRef("https://schema.org/eventAttendanceMode")
    Permit = URIRef("https://schema.org/Permit")
    Downpayment = URIRef("https://schema.org/Downpayment")
    applicationSuite = URIRef("https://schema.org/applicationSuite")
    contactPoints = URIRef("https://schema.org/contactPoints")
    guideline = URIRef("https://schema.org/guideline")
    map = URIRef("https://schema.org/map")
    Genetic = URIRef("https://schema.org/Genetic")
    itemListOrder = URIRef("https://schema.org/itemListOrder")
    isInvolvedInBiologicalProcess = URIRef("https://schema.org/isInvolvedInBiologicalProcess")
    isSimilarTo = URIRef("https://schema.org/isSimilarTo")
    WearableSizeGroupMaternity = URIRef("https://schema.org/WearableSizeGroupMaternity")
    circle = URIRef("https://schema.org/circle")
    eduQuestionType = URIRef("https://schema.org/eduQuestionType")
    yearlyRevenue = URIRef("https://schema.org/yearlyRevenue")
    legislationTransposes = URIRef("https://schema.org/legislationTransposes")
    Anesthesia = URIRef("https://schema.org/Anesthesia")
    Legislation = URIRef("https://schema.org/Legislation")
    accelerationTime = URIRef("https://schema.org/accelerationTime")
    hasPart = URIRef("https://schema.org/hasPart")
    Hackathon = URIRef("https://schema.org/Hackathon")
    dateSent = URIRef("https://schema.org/dateSent")
    PrognosisHealthAspect = URIRef("https://schema.org/PrognosisHealthAspect")
    LymphaticVessel = URIRef("https://schema.org/LymphaticVessel")
    Recruiting = URIRef("https://schema.org/Recruiting")
    Consortium = URIRef("https://schema.org/Consortium")
    playMode = URIRef("https://schema.org/playMode")
    doorTime = URIRef("https://schema.org/doorTime")
    CreateAction = URIRef("https://schema.org/CreateAction")
    requirements = URIRef("https://schema.org/requirements")
    assemblyVersion = URIRef("https://schema.org/assemblyVersion")
    departureStation = URIRef("https://schema.org/departureStation")
    howPerformed = URIRef("https://schema.org/howPerformed")
    WriteAction = URIRef("https://schema.org/WriteAction")
    EngineSpecification = URIRef("https://schema.org/EngineSpecification")
    Rating = URIRef("https://schema.org/Rating")
    OfficeEquipmentStore = URIRef("https://schema.org/OfficeEquipmentStore")
    Suspended = URIRef("https://schema.org/Suspended")
    TransformedContent = URIRef("https://schema.org/TransformedContent")
    SearchResultsPage = URIRef("https://schema.org/SearchResultsPage")
    termsOfService = URIRef("https://schema.org/termsOfService")
    numberOfCredits = URIRef("https://schema.org/numberOfCredits")
    PartiallyInForce = URIRef("https://schema.org/PartiallyInForce")
    ownedThrough = URIRef("https://schema.org/ownedThrough")
    workPerformed = URIRef("https://schema.org/workPerformed")
    WearableSizeSystemDE = URIRef("https://schema.org/WearableSizeSystemDE")
    EUEnergyEfficiencyCategoryG = URIRef("https://schema.org/EUEnergyEfficiencyCategoryG")
    provider = URIRef("https://schema.org/provider")
    maximumIntake = URIRef("https://schema.org/maximumIntake")
    depth = URIRef("https://schema.org/depth")
    ethicsPolicy = URIRef("https://schema.org/ethicsPolicy")
    applicationDeadline = URIRef("https://schema.org/applicationDeadline")
    PlayGameAction = URIRef("https://schema.org/PlayGameAction")
    spouse = URIRef("https://schema.org/spouse")
    Nonprofit501c26 = URIRef("https://schema.org/Nonprofit501c26")
    dataset = URIRef("https://schema.org/dataset")
    headline = URIRef("https://schema.org/headline")
    postalCodePrefix = URIRef("https://schema.org/postalCodePrefix")
    relatedAnatomy = URIRef("https://schema.org/relatedAnatomy")
    lesser = URIRef("https://schema.org/lesser")
    Role = URIRef("https://schema.org/Role")
    Accommodation = URIRef("https://schema.org/Accommodation")
    ReturnFeesCustomerResponsibility = URIRef("https://schema.org/ReturnFeesCustomerResponsibility")
    DeliveryTimeSettings = URIRef("https://schema.org/DeliveryTimeSettings")
    numberOfBedrooms = URIRef("https://schema.org/numberOfBedrooms")
    firstAppearance = URIRef("https://schema.org/firstAppearance")
    Newspaper = URIRef("https://schema.org/Newspaper")
    hasVariant = URIRef("https://schema.org/hasVariant")
    WearableSizeSystemUS = URIRef("https://schema.org/WearableSizeSystemUS")
    handlingTime = URIRef("https://schema.org/handlingTime")
    ChildCare = URIRef("https://schema.org/ChildCare")
    TVEpisode = URIRef("https://schema.org/TVEpisode")
    startDate = URIRef("https://schema.org/startDate")
    InformAction = URIRef("https://schema.org/InformAction")
    PoliceStation = URIRef("https://schema.org/PoliceStation")
    EUEnergyEfficiencyCategoryA3Plus = URIRef("https://schema.org/EUEnergyEfficiencyCategoryA3Plus")
    isAcceptingNewPatients = URIRef("https://schema.org/isAcceptingNewPatients")
    steeringPosition = URIRef("https://schema.org/steeringPosition")
    molecularFormula = URIRef("https://schema.org/molecularFormula")
    availabilityEnds = URIRef("https://schema.org/availabilityEnds")
    isConsumableFor = URIRef("https://schema.org/isConsumableFor")
    itemOffered = URIRef("https://schema.org/itemOffered")
    hasMenuSection = URIRef("https://schema.org/hasMenuSection")
    arrivalAirport = URIRef("https://schema.org/arrivalAirport")
    publishedBy = URIRef("https://schema.org/publishedBy")
    numberedPosition = URIRef("https://schema.org/numberedPosition")
    honorificSuffix = URIRef("https://schema.org/honorificSuffix")
    itemDefectReturnLabelSource = URIRef("https://schema.org/itemDefectReturnLabelSource")
    Nonprofit501c10 = URIRef("https://schema.org/Nonprofit501c10")
    carrierRequirements = URIRef("https://schema.org/carrierRequirements")
    MedicalStudyStatus = URIRef("https://schema.org/MedicalStudyStatus")
    healthPlanPharmacyCategory = URIRef("https://schema.org/healthPlanPharmacyCategory")
    WearableMeasurementOutsideLeg = URIRef("https://schema.org/WearableMeasurementOutsideLeg")
    hasMenu = URIRef("https://schema.org/hasMenu")
    meetsEmissionStandard = URIRef("https://schema.org/meetsEmissionStandard")
    normalRange = URIRef("https://schema.org/normalRange")
    appliesToDeliveryMethod = URIRef("https://schema.org/appliesToDeliveryMethod")
    map = URIRef("https://schema.org/map")
    GeneralContractor = URIRef("https://schema.org/GeneralContractor")
    UserPageVisits = URIRef("https://schema.org/UserPageVisits")
    BorrowAction = URIRef("https://schema.org/BorrowAction")
    EUEnergyEfficiencyCategoryF = URIRef("https://schema.org/EUEnergyEfficiencyCategoryF")
    downvoteCount = URIRef("https://schema.org/downvoteCount")
    suggestedAnswer = URIRef("https://schema.org/suggestedAnswer")
    legislationChanges = URIRef("https://schema.org/legislationChanges")
    renegotiableLoan = URIRef("https://schema.org/renegotiableLoan")
    Bakery = URIRef("https://schema.org/Bakery")
    MoneyTransfer = URIRef("https://schema.org/MoneyTransfer")
    includesHealthPlanFormulary = URIRef("https://schema.org/includesHealthPlanFormulary")
    keywords = URIRef("https://schema.org/keywords")
    reviewBody = URIRef("https://schema.org/reviewBody")
    cashBack = URIRef("https://schema.org/cashBack")
    PartiallyInForce = URIRef("https://schema.org/PartiallyInForce")
    Product = URIRef("https://schema.org/Product")
    cvdNumVentUse = URIRef("https://schema.org/cvdNumVentUse")
    legislationJurisdiction = URIRef("https://schema.org/legislationJurisdiction")
    Ear = URIRef("https://schema.org/Ear")
    aircraft = URIRef("https://schema.org/aircraft")
    Hematologic = URIRef("https://schema.org/Hematologic")
    announcementLocation = URIRef("https://schema.org/announcementLocation")
    OrderCancelled = URIRef("https://schema.org/OrderCancelled")
    Barcode = URIRef("https://schema.org/Barcode")
    bookEdition = URIRef("https://schema.org/bookEdition")
    legislationType = URIRef("https://schema.org/legislationType")
    CookAction = URIRef("https://schema.org/CookAction")
    target = URIRef("https://schema.org/target")
    StructuredValue = URIRef("https://schema.org/StructuredValue")
    PerformingGroup = URIRef("https://schema.org/PerformingGroup")
    Nonprofit501c11 = URIRef("https://schema.org/Nonprofit501c11")
    ineligibleRegion = URIRef("https://schema.org/ineligibleRegion")
    actor = URIRef("https://schema.org/actor")
    timeOfDay = URIRef("https://schema.org/timeOfDay")
    runtimePlatform = URIRef("https://schema.org/runtimePlatform")
    ScreeningEvent = URIRef("https://schema.org/ScreeningEvent")
    playerType = URIRef("https://schema.org/playerType")
    Taxon = URIRef("https://schema.org/Taxon")
    sizeGroup = URIRef("https://schema.org/sizeGroup")
    physiologicalBenefits = URIRef("https://schema.org/physiologicalBenefits")
    contributor = URIRef("https://schema.org/contributor")
    browserRequirements = URIRef("https://schema.org/browserRequirements")
    totalPrice = URIRef("https://schema.org/totalPrice")
    awards = URIRef("https://schema.org/awards")
    Otolaryngologic = URIRef("https://schema.org/Otolaryngologic")
    NonprofitANBI = URIRef("https://schema.org/NonprofitANBI")
    EventScheduled = URIRef("https://schema.org/EventScheduled")
    legislationPassedBy = URIRef("https://schema.org/legislationPassedBy")
    cvdFacilityId = URIRef("https://schema.org/cvdFacilityId")
    processorRequirements = URIRef("https://schema.org/processorRequirements")
    Rheumatologic = URIRef("https://schema.org/Rheumatologic")
    FourWheelDriveConfiguration = URIRef("https://schema.org/FourWheelDriveConfiguration")
    lesserOrEqual = URIRef("https://schema.org/lesserOrEqual")
    successorOf = URIRef("https://schema.org/successorOf")
    availableService = URIRef("https://schema.org/availableService")
    ReviewNewsArticle = URIRef("https://schema.org/ReviewNewsArticle")
    datasetTimeInterval = URIRef("https://schema.org/datasetTimeInterval")
    transcript = URIRef("https://schema.org/transcript")
    IndividualProduct = URIRef("https://schema.org/IndividualProduct")
    license = URIRef("https://schema.org/license")
    EUEnergyEfficiencyCategoryG = URIRef("https://schema.org/EUEnergyEfficiencyCategoryG")
    birthDate = URIRef("https://schema.org/birthDate")
    WearableSizeGroupPetite = URIRef("https://schema.org/WearableSizeGroupPetite")
    bookingAgent = URIRef("https://schema.org/bookingAgent")
    offeredBy = URIRef("https://schema.org/offeredBy")
    GroupBoardingPolicy = URIRef("https://schema.org/GroupBoardingPolicy")
    hasHealthAspect = URIRef("https://schema.org/hasHealthAspect")
    ItemListOrderType = URIRef("https://schema.org/ItemListOrderType")
    elevation = URIRef("https://schema.org/elevation")
    medicineSystem = URIRef("https://schema.org/medicineSystem")
    exchangeRateSpread = URIRef("https://schema.org/exchangeRateSpread")
    trainName = URIRef("https://schema.org/trainName")
    archivedAt = URIRef("https://schema.org/archivedAt")
    buyer = URIRef("https://schema.org/buyer")
    gtin = URIRef("https://schema.org/gtin")
    DrugPrescriptionStatus = URIRef("https://schema.org/DrugPrescriptionStatus")
    PlasticSurgery = URIRef("https://schema.org/PlasticSurgery")
    actors = URIRef("https://schema.org/actors")
    returnPolicyCountry = URIRef("https://schema.org/returnPolicyCountry")
    mpn = URIRef("https://schema.org/mpn")
    contactlessPayment = URIRef("https://schema.org/contactlessPayment")
    VideoObjectSnapshot = URIRef("https://schema.org/VideoObjectSnapshot")
    NailSalon = URIRef("https://schema.org/NailSalon")
    procedure = URIRef("https://schema.org/procedure")
    Gastroenterologic = URIRef("https://schema.org/Gastroenterologic")
    issuedThrough = URIRef("https://schema.org/issuedThrough")
    publicTransportClosuresInfo = URIRef("https://schema.org/publicTransportClosuresInfo")
    gameItem = URIRef("https://schema.org/gameItem")
    announcementLocation = URIRef("https://schema.org/announcementLocation")
    returnPolicyCountry = URIRef("https://schema.org/returnPolicyCountry")
    legislationTransposes = URIRef("https://schema.org/legislationTransposes")
    BowlingAlley = URIRef("https://schema.org/BowlingAlley")
    billingIncrement = URIRef("https://schema.org/billingIncrement")
    tributary = URIRef("https://schema.org/tributary")
    sourceOrganization = URIRef("https://schema.org/sourceOrganization")
    durationOfWarranty = URIRef("https://schema.org/durationOfWarranty")
    availabilityStarts = URIRef("https://schema.org/availabilityStarts")
    includedDataCatalog = URIRef("https://schema.org/includedDataCatalog")
    accessModeSufficient = URIRef("https://schema.org/accessModeSufficient")
    numberOfPlayers = URIRef("https://schema.org/numberOfPlayers")
    manufacturer = URIRef("https://schema.org/manufacturer")
    WantAction = URIRef("https://schema.org/WantAction")
    lesserOrEqual = URIRef("https://schema.org/lesserOrEqual")
    geoMidpoint = URIRef("https://schema.org/geoMidpoint")
    legislationResponsible = URIRef("https://schema.org/legislationResponsible")
    Store = URIRef("https://schema.org/Store")
    doorTime = URIRef("https://schema.org/doorTime")
    sensoryUnit = URIRef("https://schema.org/sensoryUnit")
    SurgicalProcedure = URIRef("https://schema.org/SurgicalProcedure")
    jobStartDate = URIRef("https://schema.org/jobStartDate")
    vehicleIdentificationNumber = URIRef("https://schema.org/vehicleIdentificationNumber")
    followee = URIRef("https://schema.org/followee")
    increasesRiskOf = URIRef("https://schema.org/increasesRiskOf")
    WearableMeasurementCollar = URIRef("https://schema.org/WearableMeasurementCollar")
    contactType = URIRef("https://schema.org/contactType")
    MediaReviewItem = URIRef("https://schema.org/MediaReviewItem")
    legalStatus = URIRef("https://schema.org/legalStatus")
    hasOccupation = URIRef("https://schema.org/hasOccupation")
    variesBy = URIRef("https://schema.org/variesBy")
    faxNumber = URIRef("https://schema.org/faxNumber")
    acceptedPaymentMethod = URIRef("https://schema.org/acceptedPaymentMethod")
    HardwareStore = URIRef("https://schema.org/HardwareStore")
    knowsAbout = URIRef("https://schema.org/knowsAbout")
    CompositeCaptureDigitalSource = URIRef("https://schema.org/CompositeCaptureDigitalSource")
    boardingPolicy = URIRef("https://schema.org/boardingPolicy")
    touristType = URIRef("https://schema.org/touristType")
    measurementQualifier = URIRef("https://schema.org/measurementQualifier")
    LiveBlogPosting = URIRef("https://schema.org/LiveBlogPosting")
    trainName = URIRef("https://schema.org/trainName")
    contentSize = URIRef("https://schema.org/contentSize")
    requiredGender = URIRef("https://schema.org/requiredGender")
    appliesToPaymentMethod = URIRef("https://schema.org/appliesToPaymentMethod")
    LegislationObject = URIRef("https://schema.org/LegislationObject")
    DDxElement = URIRef("https://schema.org/DDxElement")
    WearableMeasurementBack = URIRef("https://schema.org/WearableMeasurementBack")
    median = URIRef("https://schema.org/median")
    MedicalDevice = URIRef("https://schema.org/MedicalDevice")
    smiles = URIRef("https://schema.org/smiles")
    InvoicePrice = URIRef("https://schema.org/InvoicePrice")
    median = URIRef("https://schema.org/median")
    legislationType = URIRef("https://schema.org/legislationType")
    suggestedMinAge = URIRef("https://schema.org/suggestedMinAge")
    nonProprietaryName = URIRef("https://schema.org/nonProprietaryName")
    MusicComposition = URIRef("https://schema.org/MusicComposition")
    category = URIRef("https://schema.org/category")
    occupationalCredentialAwarded = URIRef("https://schema.org/occupationalCredentialAwarded")
    PaymentStatusType = URIRef("https://schema.org/PaymentStatusType")
    recordedAt = URIRef("https://schema.org/recordedAt")
    Consortium = URIRef("https://schema.org/Consortium")
    MedicalEntity = URIRef("https://schema.org/MedicalEntity")
    WearableSizeGroupBig = URIRef("https://schema.org/WearableSizeGroupBig")
    trailer = URIRef("https://schema.org/trailer")
    artist = URIRef("https://schema.org/artist")
    expires = URIRef("https://schema.org/expires")
    OutletStore = URIRef("https://schema.org/OutletStore")
    knowsAbout = URIRef("https://schema.org/knowsAbout")
    Balance = URIRef("https://schema.org/Balance")
    EPRelease = URIRef("https://schema.org/EPRelease")
    timeToComplete = URIRef("https://schema.org/timeToComplete")
    percentile25 = URIRef("https://schema.org/percentile25")
    procedure = URIRef("https://schema.org/procedure")
    slogan = URIRef("https://schema.org/slogan")
    PhysicalTherapy = URIRef("https://schema.org/PhysicalTherapy")
    availabilityEnds = URIRef("https://schema.org/availabilityEnds")
    DepartAction = URIRef("https://schema.org/DepartAction")
    Museum = URIRef("https://schema.org/Museum")
    GeoCoordinates = URIRef("https://schema.org/GeoCoordinates")
    size = URIRef("https://schema.org/size")
    CollegeOrUniversity = URIRef("https://schema.org/CollegeOrUniversity")
    antagonist = URIRef("https://schema.org/antagonist")
    competencyRequired = URIRef("https://schema.org/competencyRequired")
    logo = URIRef("https://schema.org/logo")
    educationalLevel = URIRef("https://schema.org/educationalLevel")
    InviteAction = URIRef("https://schema.org/InviteAction")
    Plumber = URIRef("https://schema.org/Plumber")
    tocEntry = URIRef("https://schema.org/tocEntry")
    Text = URIRef("https://schema.org/Text")
    doseUnit = URIRef("https://schema.org/doseUnit")
    ProductCollection = URIRef("https://schema.org/ProductCollection")
    itemReviewed = URIRef("https://schema.org/itemReviewed")
    diagnosis = URIRef("https://schema.org/diagnosis")
    orderDelivery = URIRef("https://schema.org/orderDelivery")
    collectionSize = URIRef("https://schema.org/collectionSize")
    UserInteraction = URIRef("https://schema.org/UserInteraction")
    CampingPitch = URIRef("https://schema.org/CampingPitch")
    height = URIRef("https://schema.org/height")
    bioChemSimilarity = URIRef("https://schema.org/bioChemSimilarity")
    datePosted = URIRef("https://schema.org/datePosted")
    diseaseSpreadStatistics = URIRef("https://schema.org/diseaseSpreadStatistics")
    TelevisionChannel = URIRef("https://schema.org/TelevisionChannel")
    AuthorizeAction = URIRef("https://schema.org/AuthorizeAction")
    activityFrequency = URIRef("https://schema.org/activityFrequency")
    priceSpecification = URIRef("https://schema.org/priceSpecification")
    ReimbursementCap = URIRef("https://schema.org/ReimbursementCap")
    collection = URIRef("https://schema.org/collection")
    startDate = URIRef("https://schema.org/startDate")
    translationOfWork = URIRef("https://schema.org/translationOfWork")
    citation = URIRef("https://schema.org/citation")
    Place = URIRef("https://schema.org/Place")
    sdDatePublished = URIRef("https://schema.org/sdDatePublished")
    SendAction = URIRef("https://schema.org/SendAction")
    Eye = URIRef("https://schema.org/Eye")
    attendee = URIRef("https://schema.org/attendee")
    attendees = URIRef("https://schema.org/attendees")
    diversityPolicy = URIRef("https://schema.org/diversityPolicy")
    RadioChannel = URIRef("https://schema.org/RadioChannel")
    TextObject = URIRef("https://schema.org/TextObject")
    Dataset = URIRef("https://schema.org/Dataset")
    colorSwatch = URIRef("https://schema.org/colorSwatch")
    yearBuilt = URIRef("https://schema.org/yearBuilt")
    PaymentMethod = URIRef("https://schema.org/PaymentMethod")
    legislationJurisdiction = URIRef("https://schema.org/legislationJurisdiction")
    archivedAt = URIRef("https://schema.org/archivedAt")
    contentLocation = URIRef("https://schema.org/contentLocation")
    DigitalAudioTapeFormat = URIRef("https://schema.org/DigitalAudioTapeFormat")
    passengerSequenceNumber = URIRef("https://schema.org/passengerSequenceNumber")
    sport = URIRef("https://schema.org/sport")
    isAccessoryOrSparePartFor = URIRef("https://schema.org/isAccessoryOrSparePartFor")
    Code = URIRef("https://schema.org/Code")
    ResultsAvailable = URIRef("https://schema.org/ResultsAvailable")
    interestRate = URIRef("https://schema.org/interestRate")
    Completed = URIRef("https://schema.org/Completed")
    SymptomsHealthAspect = URIRef("https://schema.org/SymptomsHealthAspect")
    SizeSpecification = URIRef("https://schema.org/SizeSpecification")
    readonlyValue = URIRef("https://schema.org/readonlyValue")
    DemoGameAvailability = URIRef("https://schema.org/DemoGameAvailability")
    merchant = URIRef("https://schema.org/merchant")
    Conversation = URIRef("https://schema.org/Conversation")
    BreadcrumbList = URIRef("https://schema.org/BreadcrumbList")
    Play = URIRef("https://schema.org/Play")
    certificationIdentification = URIRef("https://schema.org/certificationIdentification")
    hasAdultConsideration = URIRef("https://schema.org/hasAdultConsideration")
    PercutaneousProcedure = URIRef("https://schema.org/PercutaneousProcedure")
    sportsActivityLocation = URIRef("https://schema.org/sportsActivityLocation")
    WearableSizeSystemUS = URIRef("https://schema.org/WearableSizeSystemUS")
    event = URIRef("https://schema.org/event")
    partOfSeries = URIRef("https://schema.org/partOfSeries")
    legislationApplies = URIRef("https://schema.org/legislationApplies")
    isBasedOnUrl = URIRef("https://schema.org/isBasedOnUrl")
    EvidenceLevelB = URIRef("https://schema.org/EvidenceLevelB")
    Drug = URIRef("https://schema.org/Drug")
    MenuSection = URIRef("https://schema.org/MenuSection")
    GovernmentService = URIRef("https://schema.org/GovernmentService")
    algorithm = URIRef("https://schema.org/algorithm")
    risks = URIRef("https://schema.org/risks")
    cssSelector = URIRef("https://schema.org/cssSelector")
    nextItem = URIRef("https://schema.org/nextItem")
    roleName = URIRef("https://schema.org/roleName")
    WearableSizeSystemEN13402 = URIRef("https://schema.org/WearableSizeSystemEN13402")
    MedicalBusiness = URIRef("https://schema.org/MedicalBusiness")
    proprietaryName = URIRef("https://schema.org/proprietaryName")
    occupationalCredentialAwarded = URIRef("https://schema.org/occupationalCredentialAwarded")
    suggestedGender = URIRef("https://schema.org/suggestedGender")
    Downpayment = URIRef("https://schema.org/Downpayment")
    offers = URIRef("https://schema.org/offers")
    IceCreamShop = URIRef("https://schema.org/IceCreamShop")
    image = URIRef("https://schema.org/image")
    hiringOrganization = URIRef("https://schema.org/hiringOrganization")
    DigitalDocumentPermissionType = URIRef("https://schema.org/DigitalDocumentPermissionType")
    physicalRequirement = URIRef("https://schema.org/physicalRequirement")
    healthPlanMarketingUrl = URIRef("https://schema.org/healthPlanMarketingUrl")
    gtin14 = URIRef("https://schema.org/gtin14")
    unsaturatedFatContent = URIRef("https://schema.org/unsaturatedFatContent")
    DigitalPlatformEnumeration = URIRef("https://schema.org/DigitalPlatformEnumeration")
    vehicleTransmission = URIRef("https://schema.org/vehicleTransmission")
    employees = URIRef("https://schema.org/employees")
    events = URIRef("https://schema.org/events")
    discussionUrl = URIRef("https://schema.org/discussionUrl")
    addOn = URIRef("https://schema.org/addOn")
    ItemListUnordered = URIRef("https://schema.org/ItemListUnordered")
    CatholicChurch = URIRef("https://schema.org/CatholicChurch")
    RiverBodyOfWater = URIRef("https://schema.org/RiverBodyOfWater")
    EmployerAggregateRating = URIRef("https://schema.org/EmployerAggregateRating")
    DeleteAction = URIRef("https://schema.org/DeleteAction")
    numberOfAvailableAccommodationUnits = URIRef("https://schema.org/numberOfAvailableAccommodationUnits")
    startOffset = URIRef("https://schema.org/startOffset")
    warranty = URIRef("https://schema.org/warranty")
    title = URIRef("https://schema.org/title")
    DigitalPlatformEnumeration = URIRef("https://schema.org/DigitalPlatformEnumeration")
    travelBans = URIRef("https://schema.org/travelBans")
    OrderItem = URIRef("https://schema.org/OrderItem")
    saturatedFatContent = URIRef("https://schema.org/saturatedFatContent")
    AssessAction = URIRef("https://schema.org/AssessAction")
    member = URIRef("https://schema.org/member")
    Nonprofit501c23 = URIRef("https://schema.org/Nonprofit501c23")
    DietarySupplement = URIRef("https://schema.org/DietarySupplement")
    urlTemplate = URIRef("https://schema.org/urlTemplate")
    Float = URIRef("https://schema.org/Float")
    arrivalBusStop = URIRef("https://schema.org/arrivalBusStop")
    editEIDR = URIRef("https://schema.org/editEIDR")
    doesNotShip = URIRef("https://schema.org/doesNotShip")
    PsychologicalTreatment = URIRef("https://schema.org/PsychologicalTreatment")
    discount = URIRef("https://schema.org/discount")
    TrainStation = URIRef("https://schema.org/TrainStation")
    securityClearanceRequirement = URIRef("https://schema.org/securityClearanceRequirement")
    bloodSupply = URIRef("https://schema.org/bloodSupply")
    materialExtent = URIRef("https://schema.org/materialExtent")
    paymentMethod = URIRef("https://schema.org/paymentMethod")
    isResizable = URIRef("https://schema.org/isResizable")
    pageEnd = URIRef("https://schema.org/pageEnd")
    addressCountry = URIRef("https://schema.org/addressCountry")
    partOfSeason = URIRef("https://schema.org/partOfSeason")
    occupationalCategory = URIRef("https://schema.org/occupationalCategory")
    restPeriods = URIRef("https://schema.org/restPeriods")
    AudiobookFormat = URIRef("https://schema.org/AudiobookFormat")
    recourseLoan = URIRef("https://schema.org/recourseLoan")
    suggestedMeasurement = URIRef("https://schema.org/suggestedMeasurement")
    UserTweets = URIRef("https://schema.org/UserTweets")
    actionOption = URIRef("https://schema.org/actionOption")
    HealthcareConsideration = URIRef("https://schema.org/HealthcareConsideration")
    VacationRental = URIRef("https://schema.org/VacationRental")
    Casino = URIRef("https://schema.org/Casino")
    Trip = URIRef("https://schema.org/Trip")
    reservationFor = URIRef("https://schema.org/reservationFor")
    seasonNumber = URIRef("https://schema.org/seasonNumber")
    ShoppingCenter = URIRef("https://schema.org/ShoppingCenter")
    location = URIRef("https://schema.org/location")
    ContagiousnessHealthAspect = URIRef("https://schema.org/ContagiousnessHealthAspect")
    OTC = URIRef("https://schema.org/OTC")
    legislationLegalForce = URIRef("https://schema.org/legislationLegalForce")
    Saturday = URIRef("https://schema.org/Saturday")
    healthPlanMarketingUrl = URIRef("https://schema.org/healthPlanMarketingUrl")
    MinorHumanEditsDigitalSource = URIRef("https://schema.org/MinorHumanEditsDigitalSource")
    Nonprofit501c2 = URIRef("https://schema.org/Nonprofit501c2")
    relatedDrug = URIRef("https://schema.org/relatedDrug")
    populationType = URIRef("https://schema.org/populationType")
    fatContent = URIRef("https://schema.org/fatContent")
    targetUrl = URIRef("https://schema.org/targetUrl")
    ParentalSupport = URIRef("https://schema.org/ParentalSupport")
    color = URIRef("https://schema.org/color")
    TherapeuticProcedure = URIRef("https://schema.org/TherapeuticProcedure")
    appliesToPaymentMethod = URIRef("https://schema.org/appliesToPaymentMethod")
    PostalAddress = URIRef("https://schema.org/PostalAddress")
    accountablePerson = URIRef("https://schema.org/accountablePerson")
    depth = URIRef("https://schema.org/depth")
    educationalLevel = URIRef("https://schema.org/educationalLevel")
    maximumIntake = URIRef("https://schema.org/maximumIntake")
    Nonprofit501c5 = URIRef("https://schema.org/Nonprofit501c5")
    breastfeedingWarning = URIRef("https://schema.org/breastfeedingWarning")
    costCategory = URIRef("https://schema.org/costCategory")
    Surgical = URIRef("https://schema.org/Surgical")
    wheelbase = URIRef("https://schema.org/wheelbase")
    PublicationIssue = URIRef("https://schema.org/PublicationIssue")
    duration = URIRef("https://schema.org/duration")
    DrugCost = URIRef("https://schema.org/DrugCost")
    MolecularEntity = URIRef("https://schema.org/MolecularEntity")
    MedicalObservationalStudy = URIRef("https://schema.org/MedicalObservationalStudy")
    numberOfBedrooms = URIRef("https://schema.org/numberOfBedrooms")
    usesDevice = URIRef("https://schema.org/usesDevice")
    SportsClub = URIRef("https://schema.org/SportsClub")
    keywords = URIRef("https://schema.org/keywords")
    minPrice = URIRef("https://schema.org/minPrice")
    callSign = URIRef("https://schema.org/callSign")
    costOrigin = URIRef("https://schema.org/costOrigin")
    ComicCoverArt = URIRef("https://schema.org/ComicCoverArt")
    petsAllowed = URIRef("https://schema.org/petsAllowed")
    HyperTocEntry = URIRef("https://schema.org/HyperTocEntry")
    requiredQuantity = URIRef("https://schema.org/requiredQuantity")
    infectiousAgent = URIRef("https://schema.org/infectiousAgent")
    flightNumber = URIRef("https://schema.org/flightNumber")
    exerciseType = URIRef("https://schema.org/exerciseType")
    floorSize = URIRef("https://schema.org/floorSize")
    termsOfService = URIRef("https://schema.org/termsOfService")
    datePublished = URIRef("https://schema.org/datePublished")
    branchCode = URIRef("https://schema.org/branchCode")
    NGO = URIRef("https://schema.org/NGO")
    validThrough = URIRef("https://schema.org/validThrough")
    MedicalEvidenceLevel = URIRef("https://schema.org/MedicalEvidenceLevel")
    publicAccess = URIRef("https://schema.org/publicAccess")
    seatingCapacity = URIRef("https://schema.org/seatingCapacity")
    character = URIRef("https://schema.org/character")
    WPFooter = URIRef("https://schema.org/WPFooter")
    hasMerchantReturnPolicy = URIRef("https://schema.org/hasMerchantReturnPolicy")
    MediaEnumeration = URIRef("https://schema.org/MediaEnumeration")
    hasRepresentation = URIRef("https://schema.org/hasRepresentation")
    countryOfLastProcessing = URIRef("https://schema.org/countryOfLastProcessing")
    CDFormat = URIRef("https://schema.org/CDFormat")
    expressedIn = URIRef("https://schema.org/expressedIn")
    sensoryRequirement = URIRef("https://schema.org/sensoryRequirement")
    countryOfLastProcessing = URIRef("https://schema.org/countryOfLastProcessing")
    MedicalDevicePurpose = URIRef("https://schema.org/MedicalDevicePurpose")
    releaseDate = URIRef("https://schema.org/releaseDate")
    HighSchool = URIRef("https://schema.org/HighSchool")
    usedToDiagnose = URIRef("https://schema.org/usedToDiagnose")
    itemOffered = URIRef("https://schema.org/itemOffered")
    PodcastSeries = URIRef("https://schema.org/PodcastSeries")
    LegalForceStatus = URIRef("https://schema.org/LegalForceStatus")
    baseSalary = URIRef("https://schema.org/baseSalary")
    IgnoreAction = URIRef("https://schema.org/IgnoreAction")
    warrantyScope = URIRef("https://schema.org/warrantyScope")
    taxID = URIRef("https://schema.org/taxID")
    costPerUnit = URIRef("https://schema.org/costPerUnit")
    ticketToken = URIRef("https://schema.org/ticketToken")
    priceCurrency = URIRef("https://schema.org/priceCurrency")
    greaterOrEqual = URIRef("https://schema.org/greaterOrEqual")
    HardwareStore = URIRef("https://schema.org/HardwareStore")
    DrugClass = URIRef("https://schema.org/DrugClass")
    ownedFrom = URIRef("https://schema.org/ownedFrom")
    Distance = URIRef("https://schema.org/Distance")
    requiredMinAge = URIRef("https://schema.org/requiredMinAge")
    Nonprofit501c26 = URIRef("https://schema.org/Nonprofit501c26")
    medicalSpecialty = URIRef("https://schema.org/medicalSpecialty")
    marginOfError = URIRef("https://schema.org/marginOfError")
    iataCode = URIRef("https://schema.org/iataCode")
    albumProductionType = URIRef("https://schema.org/albumProductionType")
    BikeStore = URIRef("https://schema.org/BikeStore")
    restockingFee = URIRef("https://schema.org/restockingFee")
    isLocatedInSubcellularLocation = URIRef("https://schema.org/isLocatedInSubcellularLocation")
    LandmarksOrHistoricalBuildings = URIRef("https://schema.org/LandmarksOrHistoricalBuildings")
    paymentMethodId = URIRef("https://schema.org/paymentMethodId")
    isBasedOnUrl = URIRef("https://schema.org/isBasedOnUrl")
    StadiumOrArena = URIRef("https://schema.org/StadiumOrArena")
    DanceEvent = URIRef("https://schema.org/DanceEvent")
    relevantSpecialty = URIRef("https://schema.org/relevantSpecialty")
    amountOfThisGood = URIRef("https://schema.org/amountOfThisGood")
    WearableSizeGroupHusky = URIRef("https://schema.org/WearableSizeGroupHusky")
    typeOfGood = URIRef("https://schema.org/typeOfGood")
    cvdNumICUBedsOcc = URIRef("https://schema.org/cvdNumICUBedsOcc")
    Distance = URIRef("https://schema.org/Distance")
    publisher = URIRef("https://schema.org/publisher")
    directors = URIRef("https://schema.org/directors")
    EmployerAggregateRating = URIRef("https://schema.org/EmployerAggregateRating")
    Conversation = URIRef("https://schema.org/Conversation")
    broadcastSignalModulation = URIRef("https://schema.org/broadcastSignalModulation")
    serialNumber = URIRef("https://schema.org/serialNumber")
    Car = URIRef("https://schema.org/Car")
    MedicalProcedureType = URIRef("https://schema.org/MedicalProcedureType")
    accessMode = URIRef("https://schema.org/accessMode")
    LodgingBusiness = URIRef("https://schema.org/LodgingBusiness")
    arrivalBusStop = URIRef("https://schema.org/arrivalBusStop")
    PaintAction = URIRef("https://schema.org/PaintAction")
    unitCode = URIRef("https://schema.org/unitCode")
    firstPerformance = URIRef("https://schema.org/firstPerformance")
    EUEnergyEfficiencyCategoryA3Plus = URIRef("https://schema.org/EUEnergyEfficiencyCategoryA3Plus")
    Midwifery = URIRef("https://schema.org/Midwifery")
    StagesHealthAspect = URIRef("https://schema.org/StagesHealthAspect")
    TakeAction = URIRef("https://schema.org/TakeAction")
    Clip = URIRef("https://schema.org/Clip")
    asin = URIRef("https://schema.org/asin")
    paymentAccepted = URIRef("https://schema.org/paymentAccepted")
    beforeMedia = URIRef("https://schema.org/beforeMedia")
    CoOp = URIRef("https://schema.org/CoOp")
    editor = URIRef("https://schema.org/editor")
    foodEvent = URIRef("https://schema.org/foodEvent")
    legislationDate = URIRef("https://schema.org/legislationDate")
    constraintProperty = URIRef("https://schema.org/constraintProperty")
    AgreeAction = URIRef("https://schema.org/AgreeAction")
    infectiousAgent = URIRef("https://schema.org/infectiousAgent")
    customerRemorseReturnShippingFeesAmount = URIRef("https://schema.org/customerRemorseReturnShippingFeesAmount")
    hasMolecularFunction = URIRef("https://schema.org/hasMolecularFunction")
    SingleCenterTrial = URIRef("https://schema.org/SingleCenterTrial")
    recordLabel = URIRef("https://schema.org/recordLabel")
    percentile75 = URIRef("https://schema.org/percentile75")
    duns = URIRef("https://schema.org/duns")
    superEvent = URIRef("https://schema.org/superEvent")
    mainEntityOfPage = URIRef("https://schema.org/mainEntityOfPage")
    MedicalTrial = URIRef("https://schema.org/MedicalTrial")
    endDate = URIRef("https://schema.org/endDate")
    game = URIRef("https://schema.org/game")
    ReviewNewsArticle = URIRef("https://schema.org/ReviewNewsArticle")
    ChemicalSubstance = URIRef("https://schema.org/ChemicalSubstance")
    availableDeliveryMethod = URIRef("https://schema.org/availableDeliveryMethod")
    MerchantReturnUnspecified = URIRef("https://schema.org/MerchantReturnUnspecified")
    VinylFormat = URIRef("https://schema.org/VinylFormat")
    gameItem = URIRef("https://schema.org/gameItem")
    hasPart = URIRef("https://schema.org/hasPart")
    Florist = URIRef("https://schema.org/Florist")
    DataFeedItem = URIRef("https://schema.org/DataFeedItem")
    availabilityEnds = URIRef("https://schema.org/availabilityEnds")
    MerchantReturnPolicy = URIRef("https://schema.org/MerchantReturnPolicy")
    ComicCoverArt = URIRef("https://schema.org/ComicCoverArt")
    associatedMediaReview = URIRef("https://schema.org/associatedMediaReview")
    characterAttribute = URIRef("https://schema.org/characterAttribute")
    monoisotopicMolecularWeight = URIRef("https://schema.org/monoisotopicMolecularWeight")
    GovernmentOrganization = URIRef("https://schema.org/GovernmentOrganization")
    artworkSurface = URIRef("https://schema.org/artworkSurface")
    originalMediaContextDescription = URIRef("https://schema.org/originalMediaContextDescription")
    productionDate = URIRef("https://schema.org/productionDate")
    productSupported = URIRef("https://schema.org/productSupported")
    isrcCode = URIRef("https://schema.org/isrcCode")
    floorSize = URIRef("https://schema.org/floorSize")
    PriceTypeEnumeration = URIRef("https://schema.org/PriceTypeEnumeration")
    additionalProperty = URIRef("https://schema.org/additionalProperty")
    isResizable = URIRef("https://schema.org/isResizable")
    billingPeriod = URIRef("https://schema.org/billingPeriod")
    subTrip = URIRef("https://schema.org/subTrip")
    exerciseType = URIRef("https://schema.org/exerciseType")
    naics = URIRef("https://schema.org/naics")
    reviewAspect = URIRef("https://schema.org/reviewAspect")
    hasCategoryCode = URIRef("https://schema.org/hasCategoryCode")
    datePosted = URIRef("https://schema.org/datePosted")
    MathSolver = URIRef("https://schema.org/MathSolver")
    creditText = URIRef("https://schema.org/creditText")
    awards = URIRef("https://schema.org/awards")
    targetName = URIRef("https://schema.org/targetName")
    hasCourse = URIRef("https://schema.org/hasCourse")
    numChildren = URIRef("https://schema.org/numChildren")
    members = URIRef("https://schema.org/members")
    gender = URIRef("https://schema.org/gender")
    WebAPI = URIRef("https://schema.org/WebAPI")
    gtin13 = URIRef("https://schema.org/gtin13")
    Neurologic = URIRef("https://schema.org/Neurologic")
    orderItemStatus = URIRef("https://schema.org/orderItemStatus")
    PreventionHealthAspect = URIRef("https://schema.org/PreventionHealthAspect")
    fiberContent = URIRef("https://schema.org/fiberContent")
    homeLocation = URIRef("https://schema.org/homeLocation")
    postalCodeBegin = URIRef("https://schema.org/postalCodeBegin")
    WearableSizeGroupExtraTall = URIRef("https://schema.org/WearableSizeGroupExtraTall")
    InteractAction = URIRef("https://schema.org/InteractAction")
    TripleBlindedTrial = URIRef("https://schema.org/TripleBlindedTrial")
    orderDate = URIRef("https://schema.org/orderDate")
    BodyMeasurementWaist = URIRef("https://schema.org/BodyMeasurementWaist")
    distinguishingSign = URIRef("https://schema.org/distinguishingSign")
    OnlineBusiness = URIRef("https://schema.org/OnlineBusiness")
    mainEntity = URIRef("https://schema.org/mainEntity")
    additionalVariable = URIRef("https://schema.org/additionalVariable")
    Campground = URIRef("https://schema.org/Campground")
    loanType = URIRef("https://schema.org/loanType")
    Genetic = URIRef("https://schema.org/Genetic")
    AmpStory = URIRef("https://schema.org/AmpStory")
    CassetteFormat = URIRef("https://schema.org/CassetteFormat")
    TransferAction = URIRef("https://schema.org/TransferAction")
    WorkersUnion = URIRef("https://schema.org/WorkersUnion")
    numberOfCredits = URIRef("https://schema.org/numberOfCredits")
    printPage = URIRef("https://schema.org/printPage")
    interactionService = URIRef("https://schema.org/interactionService")
    measuredProperty = URIRef("https://schema.org/measuredProperty")
    healthPlanNetworkTier = URIRef("https://schema.org/healthPlanNetworkTier")
    AutoRental = URIRef("https://schema.org/AutoRental")
    dosageForm = URIRef("https://schema.org/dosageForm")
    albumReleaseType = URIRef("https://schema.org/albumReleaseType")
    gtin14 = URIRef("https://schema.org/gtin14")
    validThrough = URIRef("https://schema.org/validThrough")
    spokenByCharacter = URIRef("https://schema.org/spokenByCharacter")
    callSign = URIRef("https://schema.org/callSign")
    associatedMedia = URIRef("https://schema.org/associatedMedia")
    WatchAction = URIRef("https://schema.org/WatchAction")
    sdDatePublished = URIRef("https://schema.org/sdDatePublished")
    petsAllowed = URIRef("https://schema.org/petsAllowed")
    CourseInstance = URIRef("https://schema.org/CourseInstance")
    EUEnergyEfficiencyCategoryA3Plus = URIRef("https://schema.org/EUEnergyEfficiencyCategoryA3Plus")
    NutritionInformation = URIRef("https://schema.org/NutritionInformation")
    cookingMethod = URIRef("https://schema.org/cookingMethod")
    photo = URIRef("https://schema.org/photo")
    handlingTime = URIRef("https://schema.org/handlingTime")
    tripOrigin = URIRef("https://schema.org/tripOrigin")
    ReadPermission = URIRef("https://schema.org/ReadPermission")
    featureList = URIRef("https://schema.org/featureList")
    incentives = URIRef("https://schema.org/incentives")
    deliveryMethod = URIRef("https://schema.org/deliveryMethod")
    availableTest = URIRef("https://schema.org/availableTest")
    diversityPolicy = URIRef("https://schema.org/diversityPolicy")
    issuedBy = URIRef("https://schema.org/issuedBy")
    DepartAction = URIRef("https://schema.org/DepartAction")
    encodings = URIRef("https://schema.org/encodings")
    instructor = URIRef("https://schema.org/instructor")
    customer = URIRef("https://schema.org/customer")
    endorsee = URIRef("https://schema.org/endorsee")
    Appearance = URIRef("https://schema.org/Appearance")
    UserCheckins = URIRef("https://schema.org/UserCheckins")
    annualPercentageRate = URIRef("https://schema.org/annualPercentageRate")
    BodyOfWater = URIRef("https://schema.org/BodyOfWater")
    MixtapeAlbum = URIRef("https://schema.org/MixtapeAlbum")
    RentalCarReservation = URIRef("https://schema.org/RentalCarReservation")
    geoRadius = URIRef("https://schema.org/geoRadius")
    PriceComponentTypeEnumeration = URIRef("https://schema.org/PriceComponentTypeEnumeration")
    torque = URIRef("https://schema.org/torque")
    faxNumber = URIRef("https://schema.org/faxNumber")
    CreativeWorkSeason = URIRef("https://schema.org/CreativeWorkSeason")
    muscleAction = URIRef("https://schema.org/muscleAction")
    wordCount = URIRef("https://schema.org/wordCount")
    TollFree = URIRef("https://schema.org/TollFree")
    warrantyPromise = URIRef("https://schema.org/warrantyPromise")
    LiquorStore = URIRef("https://schema.org/LiquorStore")
    ArchiveOrganization = URIRef("https://schema.org/ArchiveOrganization")
    ChildrensEvent = URIRef("https://schema.org/ChildrensEvent")
    height = URIRef("https://schema.org/height")
    AcceptAction = URIRef("https://schema.org/AcceptAction")
    contentReferenceTime = URIRef("https://schema.org/contentReferenceTime")
    departureBusStop = URIRef("https://schema.org/departureBusStop")
    clinicalPharmacology = URIRef("https://schema.org/clinicalPharmacology")
    partOfInvoice = URIRef("https://schema.org/partOfInvoice")
    applicationSuite = URIRef("https://schema.org/applicationSuite")
    ReturnLabelInBox = URIRef("https://schema.org/ReturnLabelInBox")
    workLocation = URIRef("https://schema.org/workLocation")
    connectedTo = URIRef("https://schema.org/connectedTo")
    gtin = URIRef("https://schema.org/gtin")
    suitableForDiet = URIRef("https://schema.org/suitableForDiet")
    accessibilityControl = URIRef("https://schema.org/accessibilityControl")
    sportsEvent = URIRef("https://schema.org/sportsEvent")
    startTime = URIRef("https://schema.org/startTime")
    toLocation = URIRef("https://schema.org/toLocation")
    OfferCatalog = URIRef("https://schema.org/OfferCatalog")
    Neurologic = URIRef("https://schema.org/Neurologic")
    ReturnShippingFees = URIRef("https://schema.org/ReturnShippingFees")
    expectedArrivalFrom = URIRef("https://schema.org/expectedArrivalFrom")
    DryCleaningOrLaundry = URIRef("https://schema.org/DryCleaningOrLaundry")
    starRating = URIRef("https://schema.org/starRating")
    diagram = URIRef("https://schema.org/diagram")
    funder = URIRef("https://schema.org/funder")
    TravelAction = URIRef("https://schema.org/TravelAction")
    vehicleConfiguration = URIRef("https://schema.org/vehicleConfiguration")
    sportsActivityLocation = URIRef("https://schema.org/sportsActivityLocation")
    asin = URIRef("https://schema.org/asin")
    geoCoveredBy = URIRef("https://schema.org/geoCoveredBy")
    sku = URIRef("https://schema.org/sku")
    merchantReturnDays = URIRef("https://schema.org/merchantReturnDays")
    weightTotal = URIRef("https://schema.org/weightTotal")
    educationalProgramMode = URIRef("https://schema.org/educationalProgramMode")
    inDefinedTermSet = URIRef("https://schema.org/inDefinedTermSet")
    positiveNotes = URIRef("https://schema.org/positiveNotes")
    actor = URIRef("https://schema.org/actor")
    specialOpeningHoursSpecification = URIRef("https://schema.org/specialOpeningHoursSpecification")
    ReimbursementCap = URIRef("https://schema.org/ReimbursementCap")
    isGift = URIRef("https://schema.org/isGift")
    author = URIRef("https://schema.org/author")
    HousePainter = URIRef("https://schema.org/HousePainter")
    arterialBranch = URIRef("https://schema.org/arterialBranch")
    geoRadius = URIRef("https://schema.org/geoRadius")
    TVEpisode = URIRef("https://schema.org/TVEpisode")
    DrugPregnancyCategory = URIRef("https://schema.org/DrugPregnancyCategory")
    EUEnergyEfficiencyCategoryA3Plus = URIRef("https://schema.org/EUEnergyEfficiencyCategoryA3Plus")
    name = URIRef("https://schema.org/name")
    duration = URIRef("https://schema.org/duration")
    significantLinks = URIRef("https://schema.org/significantLinks")
    EmployerReview = URIRef("https://schema.org/EmployerReview")
    isBasedOnUrl = URIRef("https://schema.org/isBasedOnUrl")
    CampingPitch = URIRef("https://schema.org/CampingPitch")
    actionApplication = URIRef("https://schema.org/actionApplication")
    name = URIRef("https://schema.org/name")
    endorsee = URIRef("https://schema.org/endorsee")
    deathPlace = URIRef("https://schema.org/deathPlace")
    MedicalAudience = URIRef("https://schema.org/MedicalAudience")
    MusculoskeletalExam = URIRef("https://schema.org/MusculoskeletalExam")
    checkoutTime = URIRef("https://schema.org/checkoutTime")
    RespiratoryTherapy = URIRef("https://schema.org/RespiratoryTherapy")
    hasEnergyEfficiencyCategory = URIRef("https://schema.org/hasEnergyEfficiencyCategory")
    sku = URIRef("https://schema.org/sku")
    FurnitureStore = URIRef("https://schema.org/FurnitureStore")
    merchantReturnDays = URIRef("https://schema.org/merchantReturnDays")
    offersPrescriptionByMail = URIRef("https://schema.org/offersPrescriptionByMail")
    brand = URIRef("https://schema.org/brand")
    smiles = URIRef("https://schema.org/smiles")
    HobbyShop = URIRef("https://schema.org/HobbyShop")
    SellAction = URIRef("https://schema.org/SellAction")
    OccupationalTherapy = URIRef("https://schema.org/OccupationalTherapy")
    hostingOrganization = URIRef("https://schema.org/hostingOrganization")
    material = URIRef("https://schema.org/material")
    SpecialAnnouncement = URIRef("https://schema.org/SpecialAnnouncement")
    itemDefectReturnFees = URIRef("https://schema.org/itemDefectReturnFees")
    recommendationStrength = URIRef("https://schema.org/recommendationStrength")
    estimatedSalary = URIRef("https://schema.org/estimatedSalary")
    PublicationEvent = URIRef("https://schema.org/PublicationEvent")
    UpdateAction = URIRef("https://schema.org/UpdateAction")
    Park = URIRef("https://schema.org/Park")
    providesBroadcastService = URIRef("https://schema.org/providesBroadcastService")
    itemDefectReturnFees = URIRef("https://schema.org/itemDefectReturnFees")
    endOffset = URIRef("https://schema.org/endOffset")
    BrainStructure = URIRef("https://schema.org/BrainStructure")
    CompoundPriceSpecification = URIRef("https://schema.org/CompoundPriceSpecification")
    target = URIRef("https://schema.org/target")
    checkoutPageURLTemplate = URIRef("https://schema.org/checkoutPageURLTemplate")
    WearableSizeGroupHusky = URIRef("https://schema.org/WearableSizeGroupHusky")
    HyperTocEntry = URIRef("https://schema.org/HyperTocEntry")
    maximumAttendeeCapacity = URIRef("https://schema.org/maximumAttendeeCapacity")
    includesHealthPlanNetwork = URIRef("https://schema.org/includesHealthPlanNetwork")
    priceRange = URIRef("https://schema.org/priceRange")
    arrivalBusStop = URIRef("https://schema.org/arrivalBusStop")
    negativeNotes = URIRef("https://schema.org/negativeNotes")
    Nonprofit501c20 = URIRef("https://schema.org/Nonprofit501c20")
    text = URIRef("https://schema.org/text")
    guidelineDate = URIRef("https://schema.org/guidelineDate")
    totalPaymentDue = URIRef("https://schema.org/totalPaymentDue")
    eligibleDuration = URIRef("https://schema.org/eligibleDuration")
    DatedMoneySpecification = URIRef("https://schema.org/DatedMoneySpecification")
    exampleOfWork = URIRef("https://schema.org/exampleOfWork")
    sportsActivityLocation = URIRef("https://schema.org/sportsActivityLocation")
    loanPaymentFrequency = URIRef("https://schema.org/loanPaymentFrequency")
    shippingDetails = URIRef("https://schema.org/shippingDetails")
    associatedPathophysiology = URIRef("https://schema.org/associatedPathophysiology")
    subtitleLanguage = URIRef("https://schema.org/subtitleLanguage")
    phoneticText = URIRef("https://schema.org/phoneticText")
    EditedOrCroppedContent = URIRef("https://schema.org/EditedOrCroppedContent")
    dataFeedElement = URIRef("https://schema.org/dataFeedElement")
    loanPaymentAmount = URIRef("https://schema.org/loanPaymentAmount")
    iataCode = URIRef("https://schema.org/iataCode")
    appearance = URIRef("https://schema.org/appearance")
    UnofficialLegalValue = URIRef("https://schema.org/UnofficialLegalValue")
    WebContent = URIRef("https://schema.org/WebContent")
    AmusementPark = URIRef("https://schema.org/AmusementPark")
    EventCancelled = URIRef("https://schema.org/EventCancelled")
    causeOf = URIRef("https://schema.org/causeOf")
    Festival = URIRef("https://schema.org/Festival")
    isConsumableFor = URIRef("https://schema.org/isConsumableFor")
    seasonNumber = URIRef("https://schema.org/seasonNumber")
    Vein = URIRef("https://schema.org/Vein")
    subjectOf = URIRef("https://schema.org/subjectOf")
    artform = URIRef("https://schema.org/artform")
    codeRepository = URIRef("https://schema.org/codeRepository")
    accessibilityControl = URIRef("https://schema.org/accessibilityControl")
    ownershipFundingInfo = URIRef("https://schema.org/ownershipFundingInfo")
    LegislativeBuilding = URIRef("https://schema.org/LegislativeBuilding")
    InformAction = URIRef("https://schema.org/InformAction")
    legislationResponsible = URIRef("https://schema.org/legislationResponsible")
    experienceInPlaceOfEducation = URIRef("https://schema.org/experienceInPlaceOfEducation")
    smiles = URIRef("https://schema.org/smiles")
    providesBroadcastService = URIRef("https://schema.org/providesBroadcastService")
    usageInfo = URIRef("https://schema.org/usageInfo")
    EducationalAudience = URIRef("https://schema.org/EducationalAudience")
    members = URIRef("https://schema.org/members")
    howPerformed = URIRef("https://schema.org/howPerformed")
    maxValue = URIRef("https://schema.org/maxValue")
    study = URIRef("https://schema.org/study")
    clipNumber = URIRef("https://schema.org/clipNumber")
    transcript = URIRef("https://schema.org/transcript")
    ShortStory = URIRef("https://schema.org/ShortStory")
    locationCreated = URIRef("https://schema.org/locationCreated")
    UseAction = URIRef("https://schema.org/UseAction")
    ContactPoint = URIRef("https://schema.org/ContactPoint")
    fundedItem = URIRef("https://schema.org/fundedItem")
    Toxicologic = URIRef("https://schema.org/Toxicologic")
    studyLocation = URIRef("https://schema.org/studyLocation")
    byArtist = URIRef("https://schema.org/byArtist")
    gtin13 = URIRef("https://schema.org/gtin13")
    ScholarlyArticle = URIRef("https://schema.org/ScholarlyArticle")
    marginOfError = URIRef("https://schema.org/marginOfError")
    SportsOrganization = URIRef("https://schema.org/SportsOrganization")
    diseasePreventionInfo = URIRef("https://schema.org/diseasePreventionInfo")
    HowToStep = URIRef("https://schema.org/HowToStep")
    AcceptAction = URIRef("https://schema.org/AcceptAction")
    physiologicalBenefits = URIRef("https://schema.org/physiologicalBenefits")
    AmpStory = URIRef("https://schema.org/AmpStory")
    courseSchedule = URIRef("https://schema.org/courseSchedule")
    HowToTool = URIRef("https://schema.org/HowToTool")
    seatingCapacity = URIRef("https://schema.org/seatingCapacity")
    fuelCapacity = URIRef("https://schema.org/fuelCapacity")
    validIn = URIRef("https://schema.org/validIn")
    broadcastSignalModulation = URIRef("https://schema.org/broadcastSignalModulation")
    scheduledTime = URIRef("https://schema.org/scheduledTime")
    DepositAccount = URIRef("https://schema.org/DepositAccount")
    candidate = URIRef("https://schema.org/candidate")
    availableStrength = URIRef("https://schema.org/availableStrength")
    Terminated = URIRef("https://schema.org/Terminated")
    Nonprofit501c20 = URIRef("https://schema.org/Nonprofit501c20")
    cargoVolume = URIRef("https://schema.org/cargoVolume")
    maximumPhysicalAttendeeCapacity = URIRef("https://schema.org/maximumPhysicalAttendeeCapacity")
    openingHoursSpecification = URIRef("https://schema.org/openingHoursSpecification")
    gameEdition = URIRef("https://schema.org/gameEdition")
    cvdNumBeds = URIRef("https://schema.org/cvdNumBeds")
    ComicStory = URIRef("https://schema.org/ComicStory")
    webCheckinTime = URIRef("https://schema.org/webCheckinTime")
    dateSent = URIRef("https://schema.org/dateSent")
    funder = URIRef("https://schema.org/funder")
    offeredBy = URIRef("https://schema.org/offeredBy")
    InForce = URIRef("https://schema.org/InForce")
    episodeNumber = URIRef("https://schema.org/episodeNumber")
    ArchiveOrganization = URIRef("https://schema.org/ArchiveOrganization")
    Blog = URIRef("https://schema.org/Blog")
    DateTime = URIRef("https://schema.org/DateTime")
    bloodSupply = URIRef("https://schema.org/bloodSupply")
    priceCurrency = URIRef("https://schema.org/priceCurrency")
    Muscle = URIRef("https://schema.org/Muscle")
    includedInHealthInsurancePlan = URIRef("https://schema.org/includedInHealthInsurancePlan")
    originalMediaLink = URIRef("https://schema.org/originalMediaLink")
    WearableSizeSystemUK = URIRef("https://schema.org/WearableSizeSystemUK")
    lesserOrEqual = URIRef("https://schema.org/lesserOrEqual")
    ElectronicsStore = URIRef("https://schema.org/ElectronicsStore")
    pageStart = URIRef("https://schema.org/pageStart")
    LegalForceStatus = URIRef("https://schema.org/LegalForceStatus")
    underName = URIRef("https://schema.org/underName")
    boardingGroup = URIRef("https://schema.org/boardingGroup")
    FullRefund = URIRef("https://schema.org/FullRefund")
    availableFrom = URIRef("https://schema.org/availableFrom")
    OpeningHoursSpecification = URIRef("https://schema.org/OpeningHoursSpecification")
    BodyMeasurementFoot = URIRef("https://schema.org/BodyMeasurementFoot")
    tracks = URIRef("https://schema.org/tracks")
    UserPageVisits = URIRef("https://schema.org/UserPageVisits")
    globalLocationNumber = URIRef("https://schema.org/globalLocationNumber")
    freeShippingThreshold = URIRef("https://schema.org/freeShippingThreshold")
    StatisticalVariable = URIRef("https://schema.org/StatisticalVariable")
    accountMinimumInflow = URIRef("https://schema.org/accountMinimumInflow")
    Neck = URIRef("https://schema.org/Neck")
    Campground = URIRef("https://schema.org/Campground")
    Quantity = URIRef("https://schema.org/Quantity")
    WearableSizeGroupShort = URIRef("https://schema.org/WearableSizeGroupShort")
    availableLanguage = URIRef("https://schema.org/availableLanguage")
    contactOption = URIRef("https://schema.org/contactOption")
    menu = URIRef("https://schema.org/menu")
    newsUpdatesAndGuidelines = URIRef("https://schema.org/newsUpdatesAndGuidelines")
    ReturnByMail = URIRef("https://schema.org/ReturnByMail")
    PaymentCard = URIRef("https://schema.org/PaymentCard")
    gender = URIRef("https://schema.org/gender")
    CompleteDataFeed = URIRef("https://schema.org/CompleteDataFeed")
    healthcareReportingData = URIRef("https://schema.org/healthcareReportingData")
    RepaymentSpecification = URIRef("https://schema.org/RepaymentSpecification")
    numberOfFullBathrooms = URIRef("https://schema.org/numberOfFullBathrooms")
    repeatFrequency = URIRef("https://schema.org/repeatFrequency")
    petsAllowed = URIRef("https://schema.org/petsAllowed")
    SuperficialAnatomy = URIRef("https://schema.org/SuperficialAnatomy")
    AddAction = URIRef("https://schema.org/AddAction")
    recipeIngredient = URIRef("https://schema.org/recipeIngredient")
    hoursAvailable = URIRef("https://schema.org/hoursAvailable")
    MerchantReturnNotPermitted = URIRef("https://schema.org/MerchantReturnNotPermitted")
    GovernmentOffice = URIRef("https://schema.org/GovernmentOffice")
    AskPublicNewsArticle = URIRef("https://schema.org/AskPublicNewsArticle")
    RefundTypeEnumeration = URIRef("https://schema.org/RefundTypeEnumeration")
    MeetingRoom = URIRef("https://schema.org/MeetingRoom")
    MultiCenterTrial = URIRef("https://schema.org/MultiCenterTrial")
    gameLocation = URIRef("https://schema.org/gameLocation")
    address = URIRef("https://schema.org/address")
    answerExplanation = URIRef("https://schema.org/answerExplanation")
    associatedMediaReview = URIRef("https://schema.org/associatedMediaReview")
    itemOffered = URIRef("https://schema.org/itemOffered")
    partOfSystem = URIRef("https://schema.org/partOfSystem")
    leaseLength = URIRef("https://schema.org/leaseLength")
    dateModified = URIRef("https://schema.org/dateModified")
    ChooseAction = URIRef("https://schema.org/ChooseAction")
    foodEstablishment = URIRef("https://schema.org/foodEstablishment")
    Longitudinal = URIRef("https://schema.org/Longitudinal")
    NewsArticle = URIRef("https://schema.org/NewsArticle")
    billingIncrement = URIRef("https://schema.org/billingIncrement")
    MedicalGuideline = URIRef("https://schema.org/MedicalGuideline")
    AskPublicNewsArticle = URIRef("https://schema.org/AskPublicNewsArticle")
    gtin14 = URIRef("https://schema.org/gtin14")
    Language = URIRef("https://schema.org/Language")
    businessFunction = URIRef("https://schema.org/businessFunction")
    parentOrganization = URIRef("https://schema.org/parentOrganization")
    MediaReview = URIRef("https://schema.org/MediaReview")
    layoutImage = URIRef("https://schema.org/layoutImage")
    RadiationTherapy = URIRef("https://schema.org/RadiationTherapy")
    associatedReview = URIRef("https://schema.org/associatedReview")
    usNPI = URIRef("https://schema.org/usNPI")
    memberOf = URIRef("https://schema.org/memberOf")
    deathPlace = URIRef("https://schema.org/deathPlace")
    Restaurant = URIRef("https://schema.org/Restaurant")
    MeetingRoom = URIRef("https://schema.org/MeetingRoom")
    Museum = URIRef("https://schema.org/Museum")
    ReviewNewsArticle = URIRef("https://schema.org/ReviewNewsArticle")
    PerformAction = URIRef("https://schema.org/PerformAction")
    MerchantReturnPolicySeasonalOverride = URIRef("https://schema.org/MerchantReturnPolicySeasonalOverride")
    codeSampleType = URIRef("https://schema.org/codeSampleType")
    loanRepaymentForm = URIRef("https://schema.org/loanRepaymentForm")
    contraindication = URIRef("https://schema.org/contraindication")
    negativeNotes = URIRef("https://schema.org/negativeNotes")
    isInvolvedInBiologicalProcess = URIRef("https://schema.org/isInvolvedInBiologicalProcess")
    dependencies = URIRef("https://schema.org/dependencies")
    url = URIRef("https://schema.org/url")
    version = URIRef("https://schema.org/version")
    HowItWorksHealthAspect = URIRef("https://schema.org/HowItWorksHealthAspect")
    minPrice = URIRef("https://schema.org/minPrice")
    inverseOf = URIRef("https://schema.org/inverseOf")
    recommendationStrength = URIRef("https://schema.org/recommendationStrength")
    contactPoints = URIRef("https://schema.org/contactPoints")
    discussionUrl = URIRef("https://schema.org/discussionUrl")
    leaseLength = URIRef("https://schema.org/leaseLength")
    BodyMeasurementBust = URIRef("https://schema.org/BodyMeasurementBust")
    WorkBasedProgram = URIRef("https://schema.org/WorkBasedProgram")
    ResumeAction = URIRef("https://schema.org/ResumeAction")
    taxID = URIRef("https://schema.org/taxID")
    preOp = URIRef("https://schema.org/preOp")
    healthcareReportingData = URIRef("https://schema.org/healthcareReportingData")
    yearsInOperation = URIRef("https://schema.org/yearsInOperation")
    eduQuestionType = URIRef("https://schema.org/eduQuestionType")
    performerIn = URIRef("https://schema.org/performerIn")
    EnergyEfficiencyEnumeration = URIRef("https://schema.org/EnergyEfficiencyEnumeration")
    episode = URIRef("https://schema.org/episode")
    geoContains = URIRef("https://schema.org/geoContains")
    WearableMeasurementCollar = URIRef("https://schema.org/WearableMeasurementCollar")
    merchant = URIRef("https://schema.org/merchant")
    numberOfSeasons = URIRef("https://schema.org/numberOfSeasons")
    accountId = URIRef("https://schema.org/accountId")
    SportsOrganization = URIRef("https://schema.org/SportsOrganization")
    menu = URIRef("https://schema.org/menu")
    PhysicalExam = URIRef("https://schema.org/PhysicalExam")
    Head = URIRef("https://schema.org/Head")
    event = URIRef("https://schema.org/event")
    ccRecipient = URIRef("https://schema.org/ccRecipient")
    statType = URIRef("https://schema.org/statType")
    followee = URIRef("https://schema.org/followee")
    emissionsCO2 = URIRef("https://schema.org/emissionsCO2")
    UserDownloads = URIRef("https://schema.org/UserDownloads")
    bioChemSimilarity = URIRef("https://schema.org/bioChemSimilarity")
    ComputerStore = URIRef("https://schema.org/ComputerStore")
    DigitalDocumentPermission = URIRef("https://schema.org/DigitalDocumentPermission")
    variableMeasured = URIRef("https://schema.org/variableMeasured")
    foodEstablishment = URIRef("https://schema.org/foodEstablishment")
    termDuration = URIRef("https://schema.org/termDuration")
    replacer = URIRef("https://schema.org/replacer")
    warranty = URIRef("https://schema.org/warranty")
    payload = URIRef("https://schema.org/payload")
    variableMeasured = URIRef("https://schema.org/variableMeasured")
    GameServer = URIRef("https://schema.org/GameServer")
    FoodService = URIRef("https://schema.org/FoodService")
    affectedBy = URIRef("https://schema.org/affectedBy")
    TechArticle = URIRef("https://schema.org/TechArticle")
    valueReference = URIRef("https://schema.org/valueReference")
    LakeBodyOfWater = URIRef("https://schema.org/LakeBodyOfWater")
    functionalClass = URIRef("https://schema.org/functionalClass")
    primaryPrevention = URIRef("https://schema.org/primaryPrevention")
    WearableSizeSystemUS = URIRef("https://schema.org/WearableSizeSystemUS")
    instrument = URIRef("https://schema.org/instrument")
    BodyOfWater = URIRef("https://schema.org/BodyOfWater")
    subTest = URIRef("https://schema.org/subTest")
    returnPolicyCategory = URIRef("https://schema.org/returnPolicyCategory")
    publishedBy = URIRef("https://schema.org/publishedBy")
    Downpayment = URIRef("https://schema.org/Downpayment")
    Throat = URIRef("https://schema.org/Throat")
    Audience = URIRef("https://schema.org/Audience")
    supportingData = URIRef("https://schema.org/supportingData")
    JobPosting = URIRef("https://schema.org/JobPosting")
    originalMediaLink = URIRef("https://schema.org/originalMediaLink")
    ActiveNotRecruiting = URIRef("https://schema.org/ActiveNotRecruiting")
    doseSchedule = URIRef("https://schema.org/doseSchedule")
    suggestedMeasurement = URIRef("https://schema.org/suggestedMeasurement")
    MobilePhoneStore = URIRef("https://schema.org/MobilePhoneStore")
    toRecipient = URIRef("https://schema.org/toRecipient")
    MedicalGuidelineContraindication = URIRef("https://schema.org/MedicalGuidelineContraindication")
    seller = URIRef("https://schema.org/seller")
    EatAction = URIRef("https://schema.org/EatAction")
    bookingTime = URIRef("https://schema.org/bookingTime")
    productionDate = URIRef("https://schema.org/productionDate")
    EmploymentAgency = URIRef("https://schema.org/EmploymentAgency")
    itinerary = URIRef("https://schema.org/itinerary")
    TennisComplex = URIRef("https://schema.org/TennisComplex")
    isConsumableFor = URIRef("https://schema.org/isConsumableFor")
    Consortium = URIRef("https://schema.org/Consortium")
    healthPlanDrugTier = URIRef("https://schema.org/healthPlanDrugTier")
    educationalProgramMode = URIRef("https://schema.org/educationalProgramMode")
    photos = URIRef("https://schema.org/photos")
    Endocrine = URIRef("https://schema.org/Endocrine")
    Cardiovascular = URIRef("https://schema.org/Cardiovascular")
    Answer = URIRef("https://schema.org/Answer")
    ratingExplanation = URIRef("https://schema.org/ratingExplanation")
    vendor = URIRef("https://schema.org/vendor")
    catalog = URIRef("https://schema.org/catalog")
    lodgingUnitType = URIRef("https://schema.org/lodgingUnitType")
    legislationLegalForce = URIRef("https://schema.org/legislationLegalForce")
    copyrightYear = URIRef("https://schema.org/copyrightYear")
    BroadcastChannel = URIRef("https://schema.org/BroadcastChannel")
    MedicalGuidelineRecommendation = URIRef("https://schema.org/MedicalGuidelineRecommendation")
    contentLocation = URIRef("https://schema.org/contentLocation")
    size = URIRef("https://schema.org/size")
    BodyMeasurementNeck = URIRef("https://schema.org/BodyMeasurementNeck")
    StagedContent = URIRef("https://schema.org/StagedContent")
    PaymentMethod = URIRef("https://schema.org/PaymentMethod")
    WearableMeasurementChestOrBust = URIRef("https://schema.org/WearableMeasurementChestOrBust")
    supply = URIRef("https://schema.org/supply")
    educationRequirements = URIRef("https://schema.org/educationRequirements")
    occupationalCategory = URIRef("https://schema.org/occupationalCategory")
    repeatFrequency = URIRef("https://schema.org/repeatFrequency")
    DietarySupplement = URIRef("https://schema.org/DietarySupplement")
    RecommendedDoseSchedule = URIRef("https://schema.org/RecommendedDoseSchedule")
    defaultValue = URIRef("https://schema.org/defaultValue")
    RecyclingCenter = URIRef("https://schema.org/RecyclingCenter")
    CompositeWithTrainedAlgorithmicMediaDigitalSource = URIRef("https://schema.org/CompositeWithTrainedAlgorithmicMediaDigitalSource")
    previousStartDate = URIRef("https://schema.org/previousStartDate")
    typicalCreditsPerTerm = URIRef("https://schema.org/typicalCreditsPerTerm")
    billingIncrement = URIRef("https://schema.org/billingIncrement")
    Nonprofit501c19 = URIRef("https://schema.org/Nonprofit501c19")
    includedComposition = URIRef("https://schema.org/includedComposition")
    PodcastSeason = URIRef("https://schema.org/PodcastSeason")
    Observation = URIRef("https://schema.org/Observation")
    HowToItem = URIRef("https://schema.org/HowToItem")
    mapType = URIRef("https://schema.org/mapType")
    WriteAction = URIRef("https://schema.org/WriteAction")
    gameEdition = URIRef("https://schema.org/gameEdition")
    MultiCenterTrial = URIRef("https://schema.org/MultiCenterTrial")
    duringMedia = URIRef("https://schema.org/duringMedia")
    recourseLoan = URIRef("https://schema.org/recourseLoan")
    PetStore = URIRef("https://schema.org/PetStore")
    gtin14 = URIRef("https://schema.org/gtin14")
    PaymentMethod = URIRef("https://schema.org/PaymentMethod")
    Installment = URIRef("https://schema.org/Installment")
    Nonprofit501c11 = URIRef("https://schema.org/Nonprofit501c11")
    deliveryLeadTime = URIRef("https://schema.org/deliveryLeadTime")
    directApply = URIRef("https://schema.org/directApply")
    UKNonprofitType = URIRef("https://schema.org/UKNonprofitType")
    securityScreening = URIRef("https://schema.org/securityScreening")
    Map = URIRef("https://schema.org/Map")
    meetsEmissionStandard = URIRef("https://schema.org/meetsEmissionStandard")
    RsvpResponseMaybe = URIRef("https://schema.org/RsvpResponseMaybe")
    PayAction = URIRef("https://schema.org/PayAction")
    healthPlanPharmacyCategory = URIRef("https://schema.org/healthPlanPharmacyCategory")
    Embassy = URIRef("https://schema.org/Embassy")
    ReservationCancelled = URIRef("https://schema.org/ReservationCancelled")
    TobaccoNicotineConsideration = URIRef("https://schema.org/TobaccoNicotineConsideration")
    OrderItem = URIRef("https://schema.org/OrderItem")
    ReportageNewsArticle = URIRef("https://schema.org/ReportageNewsArticle")
    releaseOf = URIRef("https://schema.org/releaseOf")
    significantLinks = URIRef("https://schema.org/significantLinks")
    containsPlace = URIRef("https://schema.org/containsPlace")
    jobLocation = URIRef("https://schema.org/jobLocation")
    currency = URIRef("https://schema.org/currency")
    FDAcategoryX = URIRef("https://schema.org/FDAcategoryX")
    duns = URIRef("https://schema.org/duns")
    address = URIRef("https://schema.org/address")
    medicalSpecialty = URIRef("https://schema.org/medicalSpecialty")
    awayTeam = URIRef("https://schema.org/awayTeam")
    answerCount = URIRef("https://schema.org/answerCount")
    speechToTextMarkup = URIRef("https://schema.org/speechToTextMarkup")
    countriesSupported = URIRef("https://schema.org/countriesSupported")
    issuedBy = URIRef("https://schema.org/issuedBy")
    artMedium = URIRef("https://schema.org/artMedium")
    relatedAnatomy = URIRef("https://schema.org/relatedAnatomy")
    employee = URIRef("https://schema.org/employee")
    teaches = URIRef("https://schema.org/teaches")
    coursePrerequisites = URIRef("https://schema.org/coursePrerequisites")
    streetAddress = URIRef("https://schema.org/streetAddress")
    offeredBy = URIRef("https://schema.org/offeredBy")
    validThrough = URIRef("https://schema.org/validThrough")
    proficiencyLevel = URIRef("https://schema.org/proficiencyLevel")
    includedRiskFactor = URIRef("https://schema.org/includedRiskFactor")
    circle = URIRef("https://schema.org/circle")
    Class = URIRef("https://schema.org/Class")
    muscleAction = URIRef("https://schema.org/muscleAction")
    OpeningHoursSpecification = URIRef("https://schema.org/OpeningHoursSpecification")
    DrugLegalStatus = URIRef("https://schema.org/DrugLegalStatus")
    requiredQuantity = URIRef("https://schema.org/requiredQuantity")
    numberOfAxles = URIRef("https://schema.org/numberOfAxles")
    contentReferenceTime = URIRef("https://schema.org/contentReferenceTime")
    childTaxon = URIRef("https://schema.org/childTaxon")
    activityDuration = URIRef("https://schema.org/activityDuration")
    publishingPrinciples = URIRef("https://schema.org/publishingPrinciples")
    MedicalProcedure = URIRef("https://schema.org/MedicalProcedure")
    slogan = URIRef("https://schema.org/slogan")
    measurementQualifier = URIRef("https://schema.org/measurementQualifier")
    isAccessoryOrSparePartFor = URIRef("https://schema.org/isAccessoryOrSparePartFor")
    branch = URIRef("https://schema.org/branch")
    newsUpdatesAndGuidelines = URIRef("https://schema.org/newsUpdatesAndGuidelines")
    EmailMessage = URIRef("https://schema.org/EmailMessage")
    numTracks = URIRef("https://schema.org/numTracks")
    negativeNotes = URIRef("https://schema.org/negativeNotes")
    LikeAction = URIRef("https://schema.org/LikeAction")
    accessCode = URIRef("https://schema.org/accessCode")
    vehicleInteriorType = URIRef("https://schema.org/vehicleInteriorType")
    codingSystem = URIRef("https://schema.org/codingSystem")
    cvdFacilityCounty = URIRef("https://schema.org/cvdFacilityCounty")
    EditedOrCroppedContent = URIRef("https://schema.org/EditedOrCroppedContent")
    departureTime = URIRef("https://schema.org/departureTime")
    longitude = URIRef("https://schema.org/longitude")
    PharmacySpecialty = URIRef("https://schema.org/PharmacySpecialty")
    relatedDrug = URIRef("https://schema.org/relatedDrug")
    ConfirmAction = URIRef("https://schema.org/ConfirmAction")
    seatingType = URIRef("https://schema.org/seatingType")
    BedDetails = URIRef("https://schema.org/BedDetails")
    Rheumatologic = URIRef("https://schema.org/Rheumatologic")
    encodesCreativeWork = URIRef("https://schema.org/encodesCreativeWork")
    CheckOutAction = URIRef("https://schema.org/CheckOutAction")
    Syllabus = URIRef("https://schema.org/Syllabus")
    MedicalWebPage = URIRef("https://schema.org/MedicalWebPage")
    mediaItemAppearance = URIRef("https://schema.org/mediaItemAppearance")
    ReturnByMail = URIRef("https://schema.org/ReturnByMail")
    PreventionHealthAspect = URIRef("https://schema.org/PreventionHealthAspect")
    Integer = URIRef("https://schema.org/Integer")
    LifestyleModification = URIRef("https://schema.org/LifestyleModification")
    hasDeliveryMethod = URIRef("https://schema.org/hasDeliveryMethod")
    Rating = URIRef("https://schema.org/Rating")
    loanPaymentAmount = URIRef("https://schema.org/loanPaymentAmount")
    quest = URIRef("https://schema.org/quest")
    ApprovedIndication = URIRef("https://schema.org/ApprovedIndication")
    GraphicNovel = URIRef("https://schema.org/GraphicNovel")
    CompositeWithTrainedAlgorithmicMediaDigitalSource = URIRef("https://schema.org/CompositeWithTrainedAlgorithmicMediaDigitalSource")
    openingHours = URIRef("https://schema.org/openingHours")
    availableTest = URIRef("https://schema.org/availableTest")
    accountOverdraftLimit = URIRef("https://schema.org/accountOverdraftLimit")
    BrokerageAccount = URIRef("https://schema.org/BrokerageAccount")
    issuedThrough = URIRef("https://schema.org/issuedThrough")
    foodEvent = URIRef("https://schema.org/foodEvent")
    expectedArrivalFrom = URIRef("https://schema.org/expectedArrivalFrom")
    linkRelationship = URIRef("https://schema.org/linkRelationship")
    reviewCount = URIRef("https://schema.org/reviewCount")
    employee = URIRef("https://schema.org/employee")
    releaseOf = URIRef("https://schema.org/releaseOf")
    episode = URIRef("https://schema.org/episode")
    BroadcastEvent = URIRef("https://schema.org/BroadcastEvent")
    DietNutrition = URIRef("https://schema.org/DietNutrition")
    AudioObjectSnapshot = URIRef("https://schema.org/AudioObjectSnapshot")
    childTaxon = URIRef("https://schema.org/childTaxon")
    spatial = URIRef("https://schema.org/spatial")
    pickupLocation = URIRef("https://schema.org/pickupLocation")
    MusicAlbumProductionType = URIRef("https://schema.org/MusicAlbumProductionType")
    possibleTreatment = URIRef("https://schema.org/possibleTreatment")
    ConvenienceStore = URIRef("https://schema.org/ConvenienceStore")
    underName = URIRef("https://schema.org/underName")
    addressCountry = URIRef("https://schema.org/addressCountry")
    TollFree = URIRef("https://schema.org/TollFree")
    LimitedByGuaranteeCharity = URIRef("https://schema.org/LimitedByGuaranteeCharity")
    PriceTypeEnumeration = URIRef("https://schema.org/PriceTypeEnumeration")
    cvdNumVent = URIRef("https://schema.org/cvdNumVent")
    CDFormat = URIRef("https://schema.org/CDFormat")
    utterances = URIRef("https://schema.org/utterances")
    MaximumDoseSchedule = URIRef("https://schema.org/MaximumDoseSchedule")
    ResearchProject = URIRef("https://schema.org/ResearchProject")
    letterer = URIRef("https://schema.org/letterer")
    suggestedMaxAge = URIRef("https://schema.org/suggestedMaxAge")
    InsuranceAgency = URIRef("https://schema.org/InsuranceAgency")
    blogPosts = URIRef("https://schema.org/blogPosts")
    dosageForm = URIRef("https://schema.org/dosageForm")
    significantLinks = URIRef("https://schema.org/significantLinks")
    hasDefinedTerm = URIRef("https://schema.org/hasDefinedTerm")
    Terminated = URIRef("https://schema.org/Terminated")
    organizer = URIRef("https://schema.org/organizer")
    BedType = URIRef("https://schema.org/BedType")
    tocEntry = URIRef("https://schema.org/tocEntry")
    exerciseType = URIRef("https://schema.org/exerciseType")
    hasVariant = URIRef("https://schema.org/hasVariant")
    videoFrameSize = URIRef("https://schema.org/videoFrameSize")
    colorist = URIRef("https://schema.org/colorist")
    exerciseRelatedDiet = URIRef("https://schema.org/exerciseRelatedDiet")
    syllabusSections = URIRef("https://schema.org/syllabusSections")
    authenticator = URIRef("https://schema.org/authenticator")
    VitalSign = URIRef("https://schema.org/VitalSign")
    warrantyScope = URIRef("https://schema.org/warrantyScope")
    currency = URIRef("https://schema.org/currency")
    endDate = URIRef("https://schema.org/endDate")
    photo = URIRef("https://schema.org/photo")
    ethicsPolicy = URIRef("https://schema.org/ethicsPolicy")
    season = URIRef("https://schema.org/season")
    diversityStaffingReport = URIRef("https://schema.org/diversityStaffingReport")
    timeOfDay = URIRef("https://schema.org/timeOfDay")
    collectionSize = URIRef("https://schema.org/collectionSize")
    prescribingInfo = URIRef("https://schema.org/prescribingInfo")
    healthPlanCopayOption = URIRef("https://schema.org/healthPlanCopayOption")
    scheduledPaymentDate = URIRef("https://schema.org/scheduledPaymentDate")
    WPFooter = URIRef("https://schema.org/WPFooter")
    accessibilityControl = URIRef("https://schema.org/accessibilityControl")
    DataDownload = URIRef("https://schema.org/DataDownload")
    OnlineStore = URIRef("https://schema.org/OnlineStore")
    offerCount = URIRef("https://schema.org/offerCount")
    MusicRelease = URIRef("https://schema.org/MusicRelease")
    calories = URIRef("https://schema.org/calories")
    pregnancyCategory = URIRef("https://schema.org/pregnancyCategory")
    Grant = URIRef("https://schema.org/Grant")
    QualitativeValue = URIRef("https://schema.org/QualitativeValue")
    downPayment = URIRef("https://schema.org/downPayment")
    eduQuestionType = URIRef("https://schema.org/eduQuestionType")
    availableIn = URIRef("https://schema.org/availableIn")
    description = URIRef("https://schema.org/description")
    NoninvasiveProcedure = URIRef("https://schema.org/NoninvasiveProcedure")
    inverseOf = URIRef("https://schema.org/inverseOf")
    legislationType = URIRef("https://schema.org/legislationType")
    accountOverdraftLimit = URIRef("https://schema.org/accountOverdraftLimit")
    EventReservation = URIRef("https://schema.org/EventReservation")
    WearableSizeGroupExtraShort = URIRef("https://schema.org/WearableSizeGroupExtraShort")
    vehicleTransmission = URIRef("https://schema.org/vehicleTransmission")
    MolecularEntity = URIRef("https://schema.org/MolecularEntity")
    copyrightHolder = URIRef("https://schema.org/copyrightHolder")
    risks = URIRef("https://schema.org/risks")
    School = URIRef("https://schema.org/School")
    MerchantReturnPolicySeasonalOverride = URIRef("https://schema.org/MerchantReturnPolicySeasonalOverride")
    pregnancyWarning = URIRef("https://schema.org/pregnancyWarning")
    noBylinesPolicy = URIRef("https://schema.org/noBylinesPolicy")
    arrivalAirport = URIRef("https://schema.org/arrivalAirport")
    actionPlatform = URIRef("https://schema.org/actionPlatform")
    CorrectionComment = URIRef("https://schema.org/CorrectionComment")
    TypeAndQuantityNode = URIRef("https://schema.org/TypeAndQuantityNode")
    courseCode = URIRef("https://schema.org/courseCode")
    businessDays = URIRef("https://schema.org/businessDays")
    OrderAction = URIRef("https://schema.org/OrderAction")
    Installment = URIRef("https://schema.org/Installment")
    offersPrescriptionByMail = URIRef("https://schema.org/offersPrescriptionByMail")
    isBasedOn = URIRef("https://schema.org/isBasedOn")
    fuelType = URIRef("https://schema.org/fuelType")
    height = URIRef("https://schema.org/height")
    valueReference = URIRef("https://schema.org/valueReference")
    geo = URIRef("https://schema.org/geo")
    replyToUrl = URIRef("https://schema.org/replyToUrl")
    knowsLanguage = URIRef("https://schema.org/knowsLanguage")
    numberOfPages = URIRef("https://schema.org/numberOfPages")
    Bone = URIRef("https://schema.org/Bone")
    NonprofitType = URIRef("https://schema.org/NonprofitType")
    duns = URIRef("https://schema.org/duns")
    occupationalCategory = URIRef("https://schema.org/occupationalCategory")
    OnlineOnly = URIRef("https://schema.org/OnlineOnly")
    photo = URIRef("https://schema.org/photo")
    homeLocation = URIRef("https://schema.org/homeLocation")
    returnPolicySeasonalOverride = URIRef("https://schema.org/returnPolicySeasonalOverride")
    departurePlatform = URIRef("https://schema.org/departurePlatform")
    inCodeSet = URIRef("https://schema.org/inCodeSet")
    Notary = URIRef("https://schema.org/Notary")
    OfflineEventAttendanceMode = URIRef("https://schema.org/OfflineEventAttendanceMode")
    bankAccountType = URIRef("https://schema.org/bankAccountType")
    ArchiveComponent = URIRef("https://schema.org/ArchiveComponent")
    mealService = URIRef("https://schema.org/mealService")
    OrganizeAction = URIRef("https://schema.org/OrganizeAction")
    PrimaryCare = URIRef("https://schema.org/PrimaryCare")
    vehicleSeatingCapacity = URIRef("https://schema.org/vehicleSeatingCapacity")
    SomeProducts = URIRef("https://schema.org/SomeProducts")
    ExercisePlan = URIRef("https://schema.org/ExercisePlan")
    members = URIRef("https://schema.org/members")
    numberOfRooms = URIRef("https://schema.org/numberOfRooms")
    numberOfAirbags = URIRef("https://schema.org/numberOfAirbags")
    NonprofitSBBI = URIRef("https://schema.org/NonprofitSBBI")
    ComicIssue = URIRef("https://schema.org/ComicIssue")
    reviews = URIRef("https://schema.org/reviews")
    PrognosisHealthAspect = URIRef("https://schema.org/PrognosisHealthAspect")
    spatialCoverage = URIRef("https://schema.org/spatialCoverage")
    workPerformed = URIRef("https://schema.org/workPerformed")
    identifier = URIRef("https://schema.org/identifier")
    maximumVirtualAttendeeCapacity = URIRef("https://schema.org/maximumVirtualAttendeeCapacity")
    iswcCode = URIRef("https://schema.org/iswcCode")
    PathologyTest = URIRef("https://schema.org/PathologyTest")
    supersededBy = URIRef("https://schema.org/supersededBy")
    ComicIssue = URIRef("https://schema.org/ComicIssue")
    HalalDiet = URIRef("https://schema.org/HalalDiet")
    recipe = URIRef("https://schema.org/recipe")
    ContactPointOption = URIRef("https://schema.org/ContactPointOption")
    releasedEvent = URIRef("https://schema.org/releasedEvent")
    lender = URIRef("https://schema.org/lender")
    recordedIn = URIRef("https://schema.org/recordedIn")
    resultComment = URIRef("https://schema.org/resultComment")
    ParentAudience = URIRef("https://schema.org/ParentAudience")
    creativeWorkStatus = URIRef("https://schema.org/creativeWorkStatus")
    MedicalRiskScore = URIRef("https://schema.org/MedicalRiskScore")
    temporal = URIRef("https://schema.org/temporal")
    workPresented = URIRef("https://schema.org/workPresented")
    Project = URIRef("https://schema.org/Project")
    RadioEpisode = URIRef("https://schema.org/RadioEpisode")
    director = URIRef("https://schema.org/director")
    OfflineTemporarily = URIRef("https://schema.org/OfflineTemporarily")
    ListenAction = URIRef("https://schema.org/ListenAction")
    TrainedAlgorithmicMediaDigitalSource = URIRef("https://schema.org/TrainedAlgorithmicMediaDigitalSource")
    Message = URIRef("https://schema.org/Message")
    OfferCatalog = URIRef("https://schema.org/OfferCatalog")
    SubscribeAction = URIRef("https://schema.org/SubscribeAction")
    assembly = URIRef("https://schema.org/assembly")
    inSupportOf = URIRef("https://schema.org/inSupportOf")
    articleBody = URIRef("https://schema.org/articleBody")
    PoliceStation = URIRef("https://schema.org/PoliceStation")
    countryOfOrigin = URIRef("https://schema.org/countryOfOrigin")
    Message = URIRef("https://schema.org/Message")
    answerExplanation = URIRef("https://schema.org/answerExplanation")
    DigitalPlatformEnumeration = URIRef("https://schema.org/DigitalPlatformEnumeration")
    color = URIRef("https://schema.org/color")
    naturalProgression = URIRef("https://schema.org/naturalProgression")
    KeepProduct = URIRef("https://schema.org/KeepProduct")
    BuyAction = URIRef("https://schema.org/BuyAction")
    ScreeningEvent = URIRef("https://schema.org/ScreeningEvent")
    HomeAndConstructionBusiness = URIRef("https://schema.org/HomeAndConstructionBusiness")
    DatedMoneySpecification = URIRef("https://schema.org/DatedMoneySpecification")
    nationality = URIRef("https://schema.org/nationality")
    contributor = URIRef("https://schema.org/contributor")
    trackingNumber = URIRef("https://schema.org/trackingNumber")
    HealthTopicContent = URIRef("https://schema.org/HealthTopicContent")
    isPartOf = URIRef("https://schema.org/isPartOf")
    hospitalAffiliation = URIRef("https://schema.org/hospitalAffiliation")
    Syllabus = URIRef("https://schema.org/Syllabus")
    acrissCode = URIRef("https://schema.org/acrissCode")
    ownershipFundingInfo = URIRef("https://schema.org/ownershipFundingInfo")
    pageStart = URIRef("https://schema.org/pageStart")
    ShoeStore = URIRef("https://schema.org/ShoeStore")
    CriticReview = URIRef("https://schema.org/CriticReview")
    GamePlayMode = URIRef("https://schema.org/GamePlayMode")
    namedPosition = URIRef("https://schema.org/namedPosition")
    totalPaymentDue = URIRef("https://schema.org/totalPaymentDue")
    UsedCondition = URIRef("https://schema.org/UsedCondition")
    HyperToc = URIRef("https://schema.org/HyperToc")
    MedicalRiskFactor = URIRef("https://schema.org/MedicalRiskFactor")
    representativeOfPage = URIRef("https://schema.org/representativeOfPage")
    isResizable = URIRef("https://schema.org/isResizable")
    validUntil = URIRef("https://schema.org/validUntil")
    PregnancyHealthAspect = URIRef("https://schema.org/PregnancyHealthAspect")
    partOfTVSeries = URIRef("https://schema.org/partOfTVSeries")
    audience = URIRef("https://schema.org/audience")
    claimInterpreter = URIRef("https://schema.org/claimInterpreter")
    providerMobility = URIRef("https://schema.org/providerMobility")
    MediaObject = URIRef("https://schema.org/MediaObject")
    CommunityHealth = URIRef("https://schema.org/CommunityHealth")
    departureTerminal = URIRef("https://schema.org/departureTerminal")
    dateRead = URIRef("https://schema.org/dateRead")
    gamePlatform = URIRef("https://schema.org/gamePlatform")
    firstAppearance = URIRef("https://schema.org/firstAppearance")
    WearableSizeGroupMisses = URIRef("https://schema.org/WearableSizeGroupMisses")
    IgnoreAction = URIRef("https://schema.org/IgnoreAction")
    sponsor = URIRef("https://schema.org/sponsor")
    costCurrency = URIRef("https://schema.org/costCurrency")
    freeShippingThreshold = URIRef("https://schema.org/freeShippingThreshold")
    encodingFormat = URIRef("https://schema.org/encodingFormat")
    AutoBodyShop = URIRef("https://schema.org/AutoBodyShop")
    isLocatedInSubcellularLocation = URIRef("https://schema.org/isLocatedInSubcellularLocation")
    ingredients = URIRef("https://schema.org/ingredients")
    departurePlatform = URIRef("https://schema.org/departurePlatform")
    MedicalDevice = URIRef("https://schema.org/MedicalDevice")
    MedicalDevicePurpose = URIRef("https://schema.org/MedicalDevicePurpose")
    gameLocation = URIRef("https://schema.org/gameLocation")
    spouse = URIRef("https://schema.org/spouse")
    providesService = URIRef("https://schema.org/providesService")
    PrintDigitalSource = URIRef("https://schema.org/PrintDigitalSource")
    MedicalEnumeration = URIRef("https://schema.org/MedicalEnumeration")
    XPathType = URIRef("https://schema.org/XPathType")
    PostalAddress = URIRef("https://schema.org/PostalAddress")
    RearWheelDriveConfiguration = URIRef("https://schema.org/RearWheelDriveConfiguration")
    successorOf = URIRef("https://schema.org/successorOf")
    postalCodeRange = URIRef("https://schema.org/postalCodeRange")
    arrivalTerminal = URIRef("https://schema.org/arrivalTerminal")
    inventoryLevel = URIRef("https://schema.org/inventoryLevel")
    BrokerageAccount = URIRef("https://schema.org/BrokerageAccount")
    sourceOrganization = URIRef("https://schema.org/sourceOrganization")
    PlaceOfWorship = URIRef("https://schema.org/PlaceOfWorship")
    InternetCafe = URIRef("https://schema.org/InternetCafe")
    Nonprofit501c4 = URIRef("https://schema.org/Nonprofit501c4")
    HealthAndBeautyBusiness = URIRef("https://schema.org/HealthAndBeautyBusiness")
    recipient = URIRef("https://schema.org/recipient")
    BusinessFunction = URIRef("https://schema.org/BusinessFunction")
    QuantitativeValue = URIRef("https://schema.org/QuantitativeValue")
    BroadcastRelease = URIRef("https://schema.org/BroadcastRelease")
    bioChemSimilarity = URIRef("https://schema.org/bioChemSimilarity")
    abstract = URIRef("https://schema.org/abstract")
    AlbumRelease = URIRef("https://schema.org/AlbumRelease")
    programName = URIRef("https://schema.org/programName")
    department = URIRef("https://schema.org/department")
    UserComments = URIRef("https://schema.org/UserComments")
    sugarContent = URIRef("https://schema.org/sugarContent")
    legislationIdentifier = URIRef("https://schema.org/legislationIdentifier")
    answerCount = URIRef("https://schema.org/answerCount")
    MedicalIntangible = URIRef("https://schema.org/MedicalIntangible")
    HealthAndBeautyBusiness = URIRef("https://schema.org/HealthAndBeautyBusiness")
    artEdition = URIRef("https://schema.org/artEdition")
    TypesHealthAspect = URIRef("https://schema.org/TypesHealthAspect")
    volumeNumber = URIRef("https://schema.org/volumeNumber")
    dropoffTime = URIRef("https://schema.org/dropoffTime")
    SeekToAction = URIRef("https://schema.org/SeekToAction")
    DataFeedItem = URIRef("https://schema.org/DataFeedItem")
    blogPost = URIRef("https://schema.org/blogPost")
    participant = URIRef("https://schema.org/participant")
    OrderPaymentDue = URIRef("https://schema.org/OrderPaymentDue")
    returnFees = URIRef("https://schema.org/returnFees")
    cvdNumC19HOPats = URIRef("https://schema.org/cvdNumC19HOPats")
    cvdNumC19OverflowPats = URIRef("https://schema.org/cvdNumC19OverflowPats")
    ListPrice = URIRef("https://schema.org/ListPrice")
    vehicleSpecialUsage = URIRef("https://schema.org/vehicleSpecialUsage")
    ResearchProject = URIRef("https://schema.org/ResearchProject")
    trialDesign = URIRef("https://schema.org/trialDesign")
    followup = URIRef("https://schema.org/followup")
    FDAcategoryA = URIRef("https://schema.org/FDAcategoryA")
    membershipNumber = URIRef("https://schema.org/membershipNumber")
    HealthInsurancePlan = URIRef("https://schema.org/HealthInsurancePlan")
    SurgicalProcedure = URIRef("https://schema.org/SurgicalProcedure")
    award = URIRef("https://schema.org/award")
    MedicalObservationalStudyDesign = URIRef("https://schema.org/MedicalObservationalStudyDesign")
    UserPlays = URIRef("https://schema.org/UserPlays")
    Musculoskeletal = URIRef("https://schema.org/Musculoskeletal")
    Abdomen = URIRef("https://schema.org/Abdomen")
    returnFees = URIRef("https://schema.org/returnFees")
    actionableFeedbackPolicy = URIRef("https://schema.org/actionableFeedbackPolicy")
    Electrician = URIRef("https://schema.org/Electrician")
    defaultValue = URIRef("https://schema.org/defaultValue")
    WPHeader = URIRef("https://schema.org/WPHeader")
    refundType = URIRef("https://schema.org/refundType")
    Nonprofit501c1 = URIRef("https://schema.org/Nonprofit501c1")
    BusinessAudience = URIRef("https://schema.org/BusinessAudience")
    DangerousGoodConsideration = URIRef("https://schema.org/DangerousGoodConsideration")
    lodgingUnitDescription = URIRef("https://schema.org/lodgingUnitDescription")
    correctionsPolicy = URIRef("https://schema.org/correctionsPolicy")
    interactionCount = URIRef("https://schema.org/interactionCount")
    titleEIDR = URIRef("https://schema.org/titleEIDR")
    ActionAccessSpecification = URIRef("https://schema.org/ActionAccessSpecification")
    Beach = URIRef("https://schema.org/Beach")
    USNonprofitType = URIRef("https://schema.org/USNonprofitType")
    educationalCredentialAwarded = URIRef("https://schema.org/educationalCredentialAwarded")
    exchangeRateSpread = URIRef("https://schema.org/exchangeRateSpread")
    archiveHeld = URIRef("https://schema.org/archiveHeld")
    postalCodePrefix = URIRef("https://schema.org/postalCodePrefix")
    travelBans = URIRef("https://schema.org/travelBans")
    costCurrency = URIRef("https://schema.org/costCurrency")
    runtimePlatform = URIRef("https://schema.org/runtimePlatform")
    pagination = URIRef("https://schema.org/pagination")
    WearableSizeGroupPlus = URIRef("https://schema.org/WearableSizeGroupPlus")
    ExchangeRefund = URIRef("https://schema.org/ExchangeRefund")
    isAccessibleForFree = URIRef("https://schema.org/isAccessibleForFree")
    spokenByCharacter = URIRef("https://schema.org/spokenByCharacter")
    childTaxon = URIRef("https://schema.org/childTaxon")
    targetPlatform = URIRef("https://schema.org/targetPlatform")
    Canal = URIRef("https://schema.org/Canal")
    WearableMeasurementOutsideLeg = URIRef("https://schema.org/WearableMeasurementOutsideLeg")
    dropoffLocation = URIRef("https://schema.org/dropoffLocation")
    infectiousAgentClass = URIRef("https://schema.org/infectiousAgentClass")
    Substance = URIRef("https://schema.org/Substance")
    governmentBenefitsInfo = URIRef("https://schema.org/governmentBenefitsInfo")
    hasHealthAspect = URIRef("https://schema.org/hasHealthAspect")
    meetsEmissionStandard = URIRef("https://schema.org/meetsEmissionStandard")
    gameLocation = URIRef("https://schema.org/gameLocation")
    departureStation = URIRef("https://schema.org/departureStation")
    spatial = URIRef("https://schema.org/spatial")
    StatisticalPopulation = URIRef("https://schema.org/StatisticalPopulation")
    address = URIRef("https://schema.org/address")
    genre = URIRef("https://schema.org/genre")
    countriesNotSupported = URIRef("https://schema.org/countriesNotSupported")
    PreventionIndication = URIRef("https://schema.org/PreventionIndication")
    endorsee = URIRef("https://schema.org/endorsee")
    supply = URIRef("https://schema.org/supply")
    userInteractionCount = URIRef("https://schema.org/userInteractionCount")
    WebPage = URIRef("https://schema.org/WebPage")
    BackgroundNewsArticle = URIRef("https://schema.org/BackgroundNewsArticle")
    seatRow = URIRef("https://schema.org/seatRow")
    taxonRank = URIRef("https://schema.org/taxonRank")
    StagesHealthAspect = URIRef("https://schema.org/StagesHealthAspect")
    BankAccount = URIRef("https://schema.org/BankAccount")
    WearableSizeGroupRegular = URIRef("https://schema.org/WearableSizeGroupRegular")
    ComedyEvent = URIRef("https://schema.org/ComedyEvent")
    BackgroundNewsArticle = URIRef("https://schema.org/BackgroundNewsArticle")
    Psychiatric = URIRef("https://schema.org/Psychiatric")
    MedicalProcedure = URIRef("https://schema.org/MedicalProcedure")
    tourBookingPage = URIRef("https://schema.org/tourBookingPage")
    ActivationFee = URIRef("https://schema.org/ActivationFee")
    amountOfThisGood = URIRef("https://schema.org/amountOfThisGood")
    seller = URIRef("https://schema.org/seller")
    competencyRequired = URIRef("https://schema.org/competencyRequired")
    normalRange = URIRef("https://schema.org/normalRange")
    bodyLocation = URIRef("https://schema.org/bodyLocation")
    cvdNumVentUse = URIRef("https://schema.org/cvdNumVentUse")
    WearableSizeSystemEnumeration = URIRef("https://schema.org/WearableSizeSystemEnumeration")
    partOfSeries = URIRef("https://schema.org/partOfSeries")
    Invoice = URIRef("https://schema.org/Invoice")
    numChildren = URIRef("https://schema.org/numChildren")
    auditDate = URIRef("https://schema.org/auditDate")
    MedicalAudience = URIRef("https://schema.org/MedicalAudience")
    AssessAction = URIRef("https://schema.org/AssessAction")
    accessibilityHazard = URIRef("https://schema.org/accessibilityHazard")
    sodiumContent = URIRef("https://schema.org/sodiumContent")
    collection = URIRef("https://schema.org/collection")
    LivingWithHealthAspect = URIRef("https://schema.org/LivingWithHealthAspect")
    BrokerageAccount = URIRef("https://schema.org/BrokerageAccount")
    ArchiveOrganization = URIRef("https://schema.org/ArchiveOrganization")
    cvdFacilityCounty = URIRef("https://schema.org/cvdFacilityCounty")
    geoOverlaps = URIRef("https://schema.org/geoOverlaps")
    sdDatePublished = URIRef("https://schema.org/sdDatePublished")
    additionalProperty = URIRef("https://schema.org/additionalProperty")
    healthPlanDrugTier = URIRef("https://schema.org/healthPlanDrugTier")
    SpeakableSpecification = URIRef("https://schema.org/SpeakableSpecification")
    width = URIRef("https://schema.org/width")
    DefinedRegion = URIRef("https://schema.org/DefinedRegion")
    Map = URIRef("https://schema.org/Map")
    healthPlanCoinsuranceRate = URIRef("https://schema.org/healthPlanCoinsuranceRate")
    sport = URIRef("https://schema.org/sport")
    softwareRequirements = URIRef("https://schema.org/softwareRequirements")
    MerchantReturnFiniteReturnWindow = URIRef("https://schema.org/MerchantReturnFiniteReturnWindow")
    parentTaxon = URIRef("https://schema.org/parentTaxon")
    Playground = URIRef("https://schema.org/Playground")
    foodEvent = URIRef("https://schema.org/foodEvent")
    priceComponent = URIRef("https://schema.org/priceComponent")
    StudioAlbum = URIRef("https://schema.org/StudioAlbum")
    AutoRepair = URIRef("https://schema.org/AutoRepair")
    albumRelease = URIRef("https://schema.org/albumRelease")
    abridged = URIRef("https://schema.org/abridged")
    UserCheckins = URIRef("https://schema.org/UserCheckins")
    Quotation = URIRef("https://schema.org/Quotation")
    serviceLocation = URIRef("https://schema.org/serviceLocation")
    priceComponentType = URIRef("https://schema.org/priceComponentType")
    percentile90 = URIRef("https://schema.org/percentile90")
    cholesterolContent = URIRef("https://schema.org/cholesterolContent")
    sdPublisher = URIRef("https://schema.org/sdPublisher")
    CookAction = URIRef("https://schema.org/CookAction")
    bioChemSimilarity = URIRef("https://schema.org/bioChemSimilarity")
    postalCode = URIRef("https://schema.org/postalCode")
    articleSection = URIRef("https://schema.org/articleSection")
    requiresSubscription = URIRef("https://schema.org/requiresSubscription")
    url = URIRef("https://schema.org/url")
    interpretedAsClaim = URIRef("https://schema.org/interpretedAsClaim")
    MedicalSign = URIRef("https://schema.org/MedicalSign")
    underName = URIRef("https://schema.org/underName")
    educationalAlignment = URIRef("https://schema.org/educationalAlignment")
    temporal = URIRef("https://schema.org/temporal")
    renegotiableLoan = URIRef("https://schema.org/renegotiableLoan")
    MobilePhoneStore = URIRef("https://schema.org/MobilePhoneStore")
    spouse = URIRef("https://schema.org/spouse")
    busNumber = URIRef("https://schema.org/busNumber")
    FundingAgency = URIRef("https://schema.org/FundingAgency")
    marginOfError = URIRef("https://schema.org/marginOfError")
    gameServer = URIRef("https://schema.org/gameServer")
    MedicalTestPanel = URIRef("https://schema.org/MedicalTestPanel")
    Suspended = URIRef("https://schema.org/Suspended")
    performer = URIRef("https://schema.org/performer")
    Hospital = URIRef("https://schema.org/Hospital")
    reviews = URIRef("https://schema.org/reviews")
    iswcCode = URIRef("https://schema.org/iswcCode")
    albumProductionType = URIRef("https://schema.org/albumProductionType")
    CableOrSatelliteService = URIRef("https://schema.org/CableOrSatelliteService")
    sponsor = URIRef("https://schema.org/sponsor")
    exifData = URIRef("https://schema.org/exifData")
    SpokenWordAlbum = URIRef("https://schema.org/SpokenWordAlbum")
    statType = URIRef("https://schema.org/statType")
    numberOfLoanPayments = URIRef("https://schema.org/numberOfLoanPayments")
    CertificationActive = URIRef("https://schema.org/CertificationActive")
    videoFormat = URIRef("https://schema.org/videoFormat")
    MiddleSchool = URIRef("https://schema.org/MiddleSchool")
    Optician = URIRef("https://schema.org/Optician")
    BarOrPub = URIRef("https://schema.org/BarOrPub")
    healthPlanDrugTier = URIRef("https://schema.org/healthPlanDrugTier")
    OpinionNewsArticle = URIRef("https://schema.org/OpinionNewsArticle")
    Nonprofit501a = URIRef("https://schema.org/Nonprofit501a")
    fuelEfficiency = URIRef("https://schema.org/fuelEfficiency")
    MediaReview = URIRef("https://schema.org/MediaReview")
    State = URIRef("https://schema.org/State")
    Painting = URIRef("https://schema.org/Painting")
    VideoGameClip = URIRef("https://schema.org/VideoGameClip")
    CatholicChurch = URIRef("https://schema.org/CatholicChurch")
    WearableSizeSystemJP = URIRef("https://schema.org/WearableSizeSystemJP")
    subtitleLanguage = URIRef("https://schema.org/subtitleLanguage")
    gettingTestedInfo = URIRef("https://schema.org/gettingTestedInfo")
    BookSeries = URIRef("https://schema.org/BookSeries")
    expectedPrognosis = URIRef("https://schema.org/expectedPrognosis")
    signDetected = URIRef("https://schema.org/signDetected")
    archivedAt = URIRef("https://schema.org/archivedAt")
    BoatTerminal = URIRef("https://schema.org/BoatTerminal")
    workPerformed = URIRef("https://schema.org/workPerformed")
    Nonprofit501f = URIRef("https://schema.org/Nonprofit501f")
    SiteNavigationElement = URIRef("https://schema.org/SiteNavigationElement")
    diagram = URIRef("https://schema.org/diagram")
    parent = URIRef("https://schema.org/parent")
    ShortStory = URIRef("https://schema.org/ShortStory")
    Completed = URIRef("https://schema.org/Completed")
    maintainer = URIRef("https://schema.org/maintainer")
    accessibilityHazard = URIRef("https://schema.org/accessibilityHazard")
    birthPlace = URIRef("https://schema.org/birthPlace")
    CDCPMDRecord = URIRef("https://schema.org/CDCPMDRecord")
    vehicleSeatingCapacity = URIRef("https://schema.org/vehicleSeatingCapacity")
    DataDrivenMediaDigitalSource = URIRef("https://schema.org/DataDrivenMediaDigitalSource")
    LeftHandDriving = URIRef("https://schema.org/LeftHandDriving")
    endDate = URIRef("https://schema.org/endDate")
    suggestedMaxAge = URIRef("https://schema.org/suggestedMaxAge")
    DataType = URIRef("https://schema.org/DataType")
    homeLocation = URIRef("https://schema.org/homeLocation")
    hasCertification = URIRef("https://schema.org/hasCertification")
    Surgical = URIRef("https://schema.org/Surgical")
    RadioChannel = URIRef("https://schema.org/RadioChannel")
    additionalNumberOfGuests = URIRef("https://schema.org/additionalNumberOfGuests")
    legislationLegalValue = URIRef("https://schema.org/legislationLegalValue")
    associatedMediaReview = URIRef("https://schema.org/associatedMediaReview")
    foodWarning = URIRef("https://schema.org/foodWarning")
    StagesHealthAspect = URIRef("https://schema.org/StagesHealthAspect")
    isAccessibleForFree = URIRef("https://schema.org/isAccessibleForFree")
    monthsOfExperience = URIRef("https://schema.org/monthsOfExperience")
    Attorney = URIRef("https://schema.org/Attorney")
    HealthInsurancePlan = URIRef("https://schema.org/HealthInsurancePlan")
    BookmarkAction = URIRef("https://schema.org/BookmarkAction")
    accountMinimumInflow = URIRef("https://schema.org/accountMinimumInflow")
    Nonprofit501c25 = URIRef("https://schema.org/Nonprofit501c25")
    HinduTemple = URIRef("https://schema.org/HinduTemple")
    Article = URIRef("https://schema.org/Article")
    normalRange = URIRef("https://schema.org/normalRange")
    shippingRate = URIRef("https://schema.org/shippingRate")
    targetDescription = URIRef("https://schema.org/targetDescription")
    BodyMeasurementHead = URIRef("https://schema.org/BodyMeasurementHead")
    hasDefinedTerm = URIRef("https://schema.org/hasDefinedTerm")
    height = URIRef("https://schema.org/height")
    serverStatus = URIRef("https://schema.org/serverStatus")
    pageStart = URIRef("https://schema.org/pageStart")
    itemReviewed = URIRef("https://schema.org/itemReviewed")
    documentation = URIRef("https://schema.org/documentation")
    MedicalResearcher = URIRef("https://schema.org/MedicalResearcher")
    estimatedSalary = URIRef("https://schema.org/estimatedSalary")
    OfflineTemporarily = URIRef("https://schema.org/OfflineTemporarily")
    nextItem = URIRef("https://schema.org/nextItem")
    maximumIntake = URIRef("https://schema.org/maximumIntake")
    Course = URIRef("https://schema.org/Course")
    financialAidEligible = URIRef("https://schema.org/financialAidEligible")
    UnemploymentSupport = URIRef("https://schema.org/UnemploymentSupport")
    variesBy = URIRef("https://schema.org/variesBy")
    geoDisjoint = URIRef("https://schema.org/geoDisjoint")
    returnPolicyCountry = URIRef("https://schema.org/returnPolicyCountry")
    inChIKey = URIRef("https://schema.org/inChIKey")
    landlord = URIRef("https://schema.org/landlord")
    executableLibraryName = URIRef("https://schema.org/executableLibraryName")
    embeddedTextCaption = URIRef("https://schema.org/embeddedTextCaption")
    SingleFamilyResidence = URIRef("https://schema.org/SingleFamilyResidence")
    availableService = URIRef("https://schema.org/availableService")
    sdDatePublished = URIRef("https://schema.org/sdDatePublished")
    characterAttribute = URIRef("https://schema.org/characterAttribute")
    alumni = URIRef("https://schema.org/alumni")
    MovieRentalStore = URIRef("https://schema.org/MovieRentalStore")
    comprisedOf = URIRef("https://schema.org/comprisedOf")
    noBylinesPolicy = URIRef("https://schema.org/noBylinesPolicy")
    associatedArticle = URIRef("https://schema.org/associatedArticle")
    serverStatus = URIRef("https://schema.org/serverStatus")
    founder = URIRef("https://schema.org/founder")
    BioChemEntity = URIRef("https://schema.org/BioChemEntity")
    appliesToPaymentMethod = URIRef("https://schema.org/appliesToPaymentMethod")
    UserPlays = URIRef("https://schema.org/UserPlays")
    leiCode = URIRef("https://schema.org/leiCode")
    GameAvailabilityEnumeration = URIRef("https://schema.org/GameAvailabilityEnumeration")
    funding = URIRef("https://schema.org/funding")
    foundingLocation = URIRef("https://schema.org/foundingLocation")
    hasBroadcastChannel = URIRef("https://schema.org/hasBroadcastChannel")
    relevantSpecialty = URIRef("https://schema.org/relevantSpecialty")
    employmentUnit = URIRef("https://schema.org/employmentUnit")
    address = URIRef("https://schema.org/address")
    healthcareReportingData = URIRef("https://schema.org/healthcareReportingData")
    fileSize = URIRef("https://schema.org/fileSize")
    practicesAt = URIRef("https://schema.org/practicesAt")
    DemoGameAvailability = URIRef("https://schema.org/DemoGameAvailability")
    musicArrangement = URIRef("https://schema.org/musicArrangement")
    ReturnMethodEnumeration = URIRef("https://schema.org/ReturnMethodEnumeration")
    PaidLeave = URIRef("https://schema.org/PaidLeave")
    Course = URIRef("https://schema.org/Course")
    BookmarkAction = URIRef("https://schema.org/BookmarkAction")
    TreatmentIndication = URIRef("https://schema.org/TreatmentIndication")
    parentOrganization = URIRef("https://schema.org/parentOrganization")
    SteeringPositionValue = URIRef("https://schema.org/SteeringPositionValue")
    contentRating = URIRef("https://schema.org/contentRating")
    characterName = URIRef("https://schema.org/characterName")
    processingTime = URIRef("https://schema.org/processingTime")
    Canal = URIRef("https://schema.org/Canal")
    application = URIRef("https://schema.org/application")
    birthDate = URIRef("https://schema.org/birthDate")
    isicV4 = URIRef("https://schema.org/isicV4")
    WearableSizeGroupEnumeration = URIRef("https://schema.org/WearableSizeGroupEnumeration")
    ScreeningEvent = URIRef("https://schema.org/ScreeningEvent")
    recordingOf = URIRef("https://schema.org/recordingOf")
    SpeakableSpecification = URIRef("https://schema.org/SpeakableSpecification")
    geoDisjoint = URIRef("https://schema.org/geoDisjoint")
    typicalCreditsPerTerm = URIRef("https://schema.org/typicalCreditsPerTerm")
    healthPlanPharmacyCategory = URIRef("https://schema.org/healthPlanPharmacyCategory")
    toLocation = URIRef("https://schema.org/toLocation")
    bankAccountType = URIRef("https://schema.org/bankAccountType")
    structuralClass = URIRef("https://schema.org/structuralClass")
    gracePeriod = URIRef("https://schema.org/gracePeriod")
    ConstraintNode = URIRef("https://schema.org/ConstraintNode")
    ServiceChannel = URIRef("https://schema.org/ServiceChannel")
    paymentDue = URIRef("https://schema.org/paymentDue")
    clipNumber = URIRef("https://schema.org/clipNumber")
    printSection = URIRef("https://schema.org/printSection")
    dependencies = URIRef("https://schema.org/dependencies")
    OrderInTransit = URIRef("https://schema.org/OrderInTransit")
    Statement = URIRef("https://schema.org/Statement")
    permittedUsage = URIRef("https://schema.org/permittedUsage")
    sportsTeam = URIRef("https://schema.org/sportsTeam")
    ownedThrough = URIRef("https://schema.org/ownedThrough")
    estimatedCost = URIRef("https://schema.org/estimatedCost")
    byMonthDay = URIRef("https://schema.org/byMonthDay")
    availabilityEnds = URIRef("https://schema.org/availabilityEnds")
    PathologyTest = URIRef("https://schema.org/PathologyTest")
    ServiceChannel = URIRef("https://schema.org/ServiceChannel")
    translator = URIRef("https://schema.org/translator")
    geo = URIRef("https://schema.org/geo")
    programPrerequisites = URIRef("https://schema.org/programPrerequisites")
    usNPI = URIRef("https://schema.org/usNPI")
    DemoGameAvailability = URIRef("https://schema.org/DemoGameAvailability")
    AddAction = URIRef("https://schema.org/AddAction")
    prepTime = URIRef("https://schema.org/prepTime")
    steps = URIRef("https://schema.org/steps")
    floorLimit = URIRef("https://schema.org/floorLimit")
    ethicsPolicy = URIRef("https://schema.org/ethicsPolicy")
    afterMedia = URIRef("https://schema.org/afterMedia")
    dissolutionDate = URIRef("https://schema.org/dissolutionDate")
    pagination = URIRef("https://schema.org/pagination")
    Protozoa = URIRef("https://schema.org/Protozoa")
    Specialty = URIRef("https://schema.org/Specialty")
    inCodeSet = URIRef("https://schema.org/inCodeSet")
    TraditionalChinese = URIRef("https://schema.org/TraditionalChinese")
    studySubject = URIRef("https://schema.org/studySubject")
    CafeOrCoffeeShop = URIRef("https://schema.org/CafeOrCoffeeShop")
    HowToTip = URIRef("https://schema.org/HowToTip")
    episodes = URIRef("https://schema.org/episodes")
    ReimbursementCap = URIRef("https://schema.org/ReimbursementCap")
    audienceType = URIRef("https://schema.org/audienceType")
    assesses = URIRef("https://schema.org/assesses")
    coach = URIRef("https://schema.org/coach")
    spatial = URIRef("https://schema.org/spatial")
    DeactivateAction = URIRef("https://schema.org/DeactivateAction")
    downloadUrl = URIRef("https://schema.org/downloadUrl")
    safetyConsideration = URIRef("https://schema.org/safetyConsideration")
    PublicSwimmingPool = URIRef("https://schema.org/PublicSwimmingPool")
    BusOrCoach = URIRef("https://schema.org/BusOrCoach")
    albumRelease = URIRef("https://schema.org/albumRelease")
    sampleType = URIRef("https://schema.org/sampleType")
    WearableSizeGroupTall = URIRef("https://schema.org/WearableSizeGroupTall")
    DrugPrescriptionStatus = URIRef("https://schema.org/DrugPrescriptionStatus")
    Mass = URIRef("https://schema.org/Mass")
    proprietaryName = URIRef("https://schema.org/proprietaryName")
    gettingTestedInfo = URIRef("https://schema.org/gettingTestedInfo")
    SportsActivityLocation = URIRef("https://schema.org/SportsActivityLocation")
    agentInteractionStatistic = URIRef("https://schema.org/agentInteractionStatistic")
    lesser = URIRef("https://schema.org/lesser")
    Physician = URIRef("https://schema.org/Physician")
    director = URIRef("https://schema.org/director")
    requiresSubscription = URIRef("https://schema.org/requiresSubscription")
    HotelRoom = URIRef("https://schema.org/HotelRoom")
    orderStatus = URIRef("https://schema.org/orderStatus")
    Ear = URIRef("https://schema.org/Ear")
    knows = URIRef("https://schema.org/knows")
    validFor = URIRef("https://schema.org/validFor")
    ProductCollection = URIRef("https://schema.org/ProductCollection")
    fundedItem = URIRef("https://schema.org/fundedItem")
    legislationDate = URIRef("https://schema.org/legislationDate")
    RentalVehicleUsage = URIRef("https://schema.org/RentalVehicleUsage")
    Emergency = URIRef("https://schema.org/Emergency")
    tongueWeight = URIRef("https://schema.org/tongueWeight")
    Poster = URIRef("https://schema.org/Poster")
    BodyMeasurementHeight = URIRef("https://schema.org/BodyMeasurementHeight")
    BefriendAction = URIRef("https://schema.org/BefriendAction")
    InForce = URIRef("https://schema.org/InForce")
    Course = URIRef("https://schema.org/Course")
    interactionStatistic = URIRef("https://schema.org/interactionStatistic")
    estimatedCost = URIRef("https://schema.org/estimatedCost")
    SuperficialAnatomy = URIRef("https://schema.org/SuperficialAnatomy")
    availableService = URIRef("https://schema.org/availableService")
    SexualContentConsideration = URIRef("https://schema.org/SexualContentConsideration")
    LegalValueLevel = URIRef("https://schema.org/LegalValueLevel")
    cvdNumICUBeds = URIRef("https://schema.org/cvdNumICUBeds")
    NLNonprofitType = URIRef("https://schema.org/NLNonprofitType")
    WholesaleStore = URIRef("https://schema.org/WholesaleStore")
    duration = URIRef("https://schema.org/duration")
    Substance = URIRef("https://schema.org/Substance")
    additionalNumberOfGuests = URIRef("https://schema.org/additionalNumberOfGuests")
    repeatCount = URIRef("https://schema.org/repeatCount")
    postOp = URIRef("https://schema.org/postOp")
    UsedCondition = URIRef("https://schema.org/UsedCondition")
    observationDate = URIRef("https://schema.org/observationDate")
    contentSize = URIRef("https://schema.org/contentSize")
    encodesCreativeWork = URIRef("https://schema.org/encodesCreativeWork")
    RelatedTopicsHealthAspect = URIRef("https://schema.org/RelatedTopicsHealthAspect")
    transmissionMethod = URIRef("https://schema.org/transmissionMethod")
    bestRating = URIRef("https://schema.org/bestRating")
    directors = URIRef("https://schema.org/directors")
    tourBookingPage = URIRef("https://schema.org/tourBookingPage")
    device = URIRef("https://schema.org/device")
    broker = URIRef("https://schema.org/broker")
    BefriendAction = URIRef("https://schema.org/BefriendAction")
    hasCredential = URIRef("https://schema.org/hasCredential")
    merchantReturnLink = URIRef("https://schema.org/merchantReturnLink")
    availableOnDevice = URIRef("https://schema.org/availableOnDevice")
    knows = URIRef("https://schema.org/knows")
    productionDate = URIRef("https://schema.org/productionDate")
    tool = URIRef("https://schema.org/tool")
    returnPolicyCountry = URIRef("https://schema.org/returnPolicyCountry")
    CurrencyConversionService = URIRef("https://schema.org/CurrencyConversionService")
    ExchangeRateSpecification = URIRef("https://schema.org/ExchangeRateSpecification")
    Mountain = URIRef("https://schema.org/Mountain")
    eventAttendanceMode = URIRef("https://schema.org/eventAttendanceMode")
    ingredients = URIRef("https://schema.org/ingredients")
    OutOfStock = URIRef("https://schema.org/OutOfStock")
    costCategory = URIRef("https://schema.org/costCategory")
    WearableSizeSystemFR = URIRef("https://schema.org/WearableSizeSystemFR")
    DigitalDocumentPermissionType = URIRef("https://schema.org/DigitalDocumentPermissionType")
    numberOfFullBathrooms = URIRef("https://schema.org/numberOfFullBathrooms")
    ChooseAction = URIRef("https://schema.org/ChooseAction")
    State = URIRef("https://schema.org/State")
    emissionsCO2 = URIRef("https://schema.org/emissionsCO2")
    nonprofitStatus = URIRef("https://schema.org/nonprofitStatus")
    unitCode = URIRef("https://schema.org/unitCode")
    inLanguage = URIRef("https://schema.org/inLanguage")
    additionalName = URIRef("https://schema.org/additionalName")
    status = URIRef("https://schema.org/status")
    ZoneBoardingPolicy = URIRef("https://schema.org/ZoneBoardingPolicy")
    DefinitiveLegalValue = URIRef("https://schema.org/DefinitiveLegalValue")
    postalCodeBegin = URIRef("https://schema.org/postalCodeBegin")
    originAddress = URIRef("https://schema.org/originAddress")
    EatAction = URIRef("https://schema.org/EatAction")
    email = URIRef("https://schema.org/email")
    ReportageNewsArticle = URIRef("https://schema.org/ReportageNewsArticle")
    runtime = URIRef("https://schema.org/runtime")
    artEdition = URIRef("https://schema.org/artEdition")
    ComicSeries = URIRef("https://schema.org/ComicSeries")
    RoofingContractor = URIRef("https://schema.org/RoofingContractor")
    departureAirport = URIRef("https://schema.org/departureAirport")
    seasons = URIRef("https://schema.org/seasons")
    Pediatric = URIRef("https://schema.org/Pediatric")
    Audience = URIRef("https://schema.org/Audience")
    ResultsAvailable = URIRef("https://schema.org/ResultsAvailable")
    accessibilityAPI = URIRef("https://schema.org/accessibilityAPI")
    LimitedByGuaranteeCharity = URIRef("https://schema.org/LimitedByGuaranteeCharity")
    RadioClip = URIRef("https://schema.org/RadioClip")
    guidelineDate = URIRef("https://schema.org/guidelineDate")
    VenueMap = URIRef("https://schema.org/VenueMap")
    healthPlanCopayOption = URIRef("https://schema.org/healthPlanCopayOption")
    Longitudinal = URIRef("https://schema.org/Longitudinal")
    sampleType = URIRef("https://schema.org/sampleType")
    authenticator = URIRef("https://schema.org/authenticator")
    acceptedAnswer = URIRef("https://schema.org/acceptedAnswer")
    LinkRole = URIRef("https://schema.org/LinkRole")
    SideEffectsHealthAspect = URIRef("https://schema.org/SideEffectsHealthAspect")
    award = URIRef("https://schema.org/award")
    occupancy = URIRef("https://schema.org/occupancy")
    ImagingTest = URIRef("https://schema.org/ImagingTest")
    ratingCount = URIRef("https://schema.org/ratingCount")
    ShippingRateSettings = URIRef("https://schema.org/ShippingRateSettings")
    StoreCreditRefund = URIRef("https://schema.org/StoreCreditRefund")
    paymentMethodId = URIRef("https://schema.org/paymentMethodId")
    timeOfDay = URIRef("https://schema.org/timeOfDay")
    ParkingFacility = URIRef("https://schema.org/ParkingFacility")
    Table = URIRef("https://schema.org/Table")
    courseSchedule = URIRef("https://schema.org/courseSchedule")
    musicGroupMember = URIRef("https://schema.org/musicGroupMember")
    author = URIRef("https://schema.org/author")
    biomechnicalClass = URIRef("https://schema.org/biomechnicalClass")
    Protozoa = URIRef("https://schema.org/Protozoa")
    branch = URIRef("https://schema.org/branch")
    reservationStatus = URIRef("https://schema.org/reservationStatus")
    legislationLegalValue = URIRef("https://schema.org/legislationLegalValue")
    shippingDetails = URIRef("https://schema.org/shippingDetails")
    MoneyTransfer = URIRef("https://schema.org/MoneyTransfer")
    eventStatus = URIRef("https://schema.org/eventStatus")
    httpMethod = URIRef("https://schema.org/httpMethod")
    MinorHumanEditsDigitalSource = URIRef("https://schema.org/MinorHumanEditsDigitalSource")
    NGO = URIRef("https://schema.org/NGO")
    givenName = URIRef("https://schema.org/givenName")
    hasCourse = URIRef("https://schema.org/hasCourse")
    unitText = URIRef("https://schema.org/unitText")
    validFor = URIRef("https://schema.org/validFor")
    exceptDate = URIRef("https://schema.org/exceptDate")
    HealthInsurancePlan = URIRef("https://schema.org/HealthInsurancePlan")
    warrantyScope = URIRef("https://schema.org/warrantyScope")
    estimatedFlightDuration = URIRef("https://schema.org/estimatedFlightDuration")
    employmentType = URIRef("https://schema.org/employmentType")
    domiciledMortgage = URIRef("https://schema.org/domiciledMortgage")
    HowToSupply = URIRef("https://schema.org/HowToSupply")
    Pond = URIRef("https://schema.org/Pond")
    branch = URIRef("https://schema.org/branch")
    yearlyRevenue = URIRef("https://schema.org/yearlyRevenue")
    knowsLanguage = URIRef("https://schema.org/knowsLanguage")
    hasAdultConsideration = URIRef("https://schema.org/hasAdultConsideration")
    additionalType = URIRef("https://schema.org/additionalType")
    FindAction = URIRef("https://schema.org/FindAction")
    greater = URIRef("https://schema.org/greater")
    dateCreated = URIRef("https://schema.org/dateCreated")
    uploadDate = URIRef("https://schema.org/uploadDate")
    overdosage = URIRef("https://schema.org/overdosage")
    estimatedCost = URIRef("https://schema.org/estimatedCost")
    rxcui = URIRef("https://schema.org/rxcui")
    BusStop = URIRef("https://schema.org/BusStop")
    hasMeasurement = URIRef("https://schema.org/hasMeasurement")
    ReportedDoseSchedule = URIRef("https://schema.org/ReportedDoseSchedule")
    httpMethod = URIRef("https://schema.org/httpMethod")
    ResultsNotAvailable = URIRef("https://schema.org/ResultsNotAvailable")
    AllergiesHealthAspect = URIRef("https://schema.org/AllergiesHealthAspect")
    Event = URIRef("https://schema.org/Event")
    slogan = URIRef("https://schema.org/slogan")
    cvdNumC19Died = URIRef("https://schema.org/cvdNumC19Died")
    amenityFeature = URIRef("https://schema.org/amenityFeature")
    isLiveBroadcast = URIRef("https://schema.org/isLiveBroadcast")
    membershipNumber = URIRef("https://schema.org/membershipNumber")
    ViolenceConsideration = URIRef("https://schema.org/ViolenceConsideration")
    MusicPlaylist = URIRef("https://schema.org/MusicPlaylist")
    HighSchool = URIRef("https://schema.org/HighSchool")
    numberOfBeds = URIRef("https://schema.org/numberOfBeds")
    Occupation = URIRef("https://schema.org/Occupation")
    Schedule = URIRef("https://schema.org/Schedule")
    returnLabelSource = URIRef("https://schema.org/returnLabelSource")
    hoursAvailable = URIRef("https://schema.org/hoursAvailable")
    hostingOrganization = URIRef("https://schema.org/hostingOrganization")
    articleBody = URIRef("https://schema.org/articleBody")
    episodes = URIRef("https://schema.org/episodes")
    numberOfForwardGears = URIRef("https://schema.org/numberOfForwardGears")
    SalePrice = URIRef("https://schema.org/SalePrice")
    courseMode = URIRef("https://schema.org/courseMode")
    drug = URIRef("https://schema.org/drug")
    catalogNumber = URIRef("https://schema.org/catalogNumber")
    emissionsCO2 = URIRef("https://schema.org/emissionsCO2")
    archivedAt = URIRef("https://schema.org/archivedAt")
    Drug = URIRef("https://schema.org/Drug")
    isVariantOf = URIRef("https://schema.org/isVariantOf")
    engineType = URIRef("https://schema.org/engineType")
    IndividualPhysician = URIRef("https://schema.org/IndividualPhysician")
    UKTrust = URIRef("https://schema.org/UKTrust")
    fundedItem = URIRef("https://schema.org/fundedItem")
    UnincorporatedAssociationCharity = URIRef("https://schema.org/UnincorporatedAssociationCharity")
    BodyMeasurementHips = URIRef("https://schema.org/BodyMeasurementHips")
    eligibleDuration = URIRef("https://schema.org/eligibleDuration")
    CharitableIncorporatedOrganization = URIRef("https://schema.org/CharitableIncorporatedOrganization")
    AMRadioChannel = URIRef("https://schema.org/AMRadioChannel")
    taxonRank = URIRef("https://schema.org/taxonRank")
    paymentStatus = URIRef("https://schema.org/paymentStatus")
    director = URIRef("https://schema.org/director")
    MathSolver = URIRef("https://schema.org/MathSolver")
    paymentUrl = URIRef("https://schema.org/paymentUrl")
    State = URIRef("https://schema.org/State")
    financialAidEligible = URIRef("https://schema.org/financialAidEligible")
    RemixAlbum = URIRef("https://schema.org/RemixAlbum")
    interestRate = URIRef("https://schema.org/interestRate")
    broadcastTimezone = URIRef("https://schema.org/broadcastTimezone")
    followee = URIRef("https://schema.org/followee")
    EUEnergyEfficiencyCategoryA = URIRef("https://schema.org/EUEnergyEfficiencyCategoryA")
    WeaponConsideration = URIRef("https://schema.org/WeaponConsideration")
    honorificSuffix = URIRef("https://schema.org/honorificSuffix")
    latitude = URIRef("https://schema.org/latitude")
    BankAccount = URIRef("https://schema.org/BankAccount")
    shippingSettingsLink = URIRef("https://schema.org/shippingSettingsLink")
    status = URIRef("https://schema.org/status")
    commentText = URIRef("https://schema.org/commentText")
    videoFormat = URIRef("https://schema.org/videoFormat")
    productGroupID = URIRef("https://schema.org/productGroupID")
    programType = URIRef("https://schema.org/programType")
    newsUpdatesAndGuidelines = URIRef("https://schema.org/newsUpdatesAndGuidelines")
    MathSolver = URIRef("https://schema.org/MathSolver")
    artMedium = URIRef("https://schema.org/artMedium")
    playMode = URIRef("https://schema.org/playMode")
    gtin14 = URIRef("https://schema.org/gtin14")
    coach = URIRef("https://schema.org/coach")
    TripleBlindedTrial = URIRef("https://schema.org/TripleBlindedTrial")
    AssessAction = URIRef("https://schema.org/AssessAction")
    QualitativeValue = URIRef("https://schema.org/QualitativeValue")
    WearableSizeGroupShort = URIRef("https://schema.org/WearableSizeGroupShort")
    members = URIRef("https://schema.org/members")
    diet = URIRef("https://schema.org/diet")
    globalLocationNumber = URIRef("https://schema.org/globalLocationNumber")
    FollowAction = URIRef("https://schema.org/FollowAction")
    guidelineSubject = URIRef("https://schema.org/guidelineSubject")
    doseUnit = URIRef("https://schema.org/doseUnit")
    warranty = URIRef("https://schema.org/warranty")
    Person = URIRef("https://schema.org/Person")
    DislikeAction = URIRef("https://schema.org/DislikeAction")
    bodyType = URIRef("https://schema.org/bodyType")
    postalCodeEnd = URIRef("https://schema.org/postalCodeEnd")
    Diet = URIRef("https://schema.org/Diet")
    PublicToilet = URIRef("https://schema.org/PublicToilet")
    album = URIRef("https://schema.org/album")
    MedicalSymptom = URIRef("https://schema.org/MedicalSymptom")
    supplyTo = URIRef("https://schema.org/supplyTo")
    experienceInPlaceOfEducation = URIRef("https://schema.org/experienceInPlaceOfEducation")
    serviceOperator = URIRef("https://schema.org/serviceOperator")
    EUEnergyEfficiencyEnumeration = URIRef("https://schema.org/EUEnergyEfficiencyEnumeration")
    PriceTypeEnumeration = URIRef("https://schema.org/PriceTypeEnumeration")
    VideoGameClip = URIRef("https://schema.org/VideoGameClip")
    WearableMeasurementWaist = URIRef("https://schema.org/WearableMeasurementWaist")
    auditDate = URIRef("https://schema.org/auditDate")
    legislationResponsible = URIRef("https://schema.org/legislationResponsible")
    WearableSizeSystemIT = URIRef("https://schema.org/WearableSizeSystemIT")
    alumni = URIRef("https://schema.org/alumni")
    earlyPrepaymentPenalty = URIRef("https://schema.org/earlyPrepaymentPenalty")
    siblings = URIRef("https://schema.org/siblings")
    speakable = URIRef("https://schema.org/speakable")
    Nonprofit501c8 = URIRef("https://schema.org/Nonprofit501c8")
    DeliveryEvent = URIRef("https://schema.org/DeliveryEvent")
    strengthValue = URIRef("https://schema.org/strengthValue")
    minimumPaymentDue = URIRef("https://schema.org/minimumPaymentDue")
    inverseOf = URIRef("https://schema.org/inverseOf")
    shippingLabel = URIRef("https://schema.org/shippingLabel")
    url = URIRef("https://schema.org/url")
    carrierRequirements = URIRef("https://schema.org/carrierRequirements")
    Syllabus = URIRef("https://schema.org/Syllabus")
    InsertAction = URIRef("https://schema.org/InsertAction")
    startOffset = URIRef("https://schema.org/startOffset")
    shippingDetails = URIRef("https://schema.org/shippingDetails")
    thumbnail = URIRef("https://schema.org/thumbnail")
    CampingPitch = URIRef("https://schema.org/CampingPitch")
    interpretedAsClaim = URIRef("https://schema.org/interpretedAsClaim")
    ExerciseAction = URIRef("https://schema.org/ExerciseAction")
    MusicEvent = URIRef("https://schema.org/MusicEvent")
    DeliveryChargeSpecification = URIRef("https://schema.org/DeliveryChargeSpecification")
    JobPosting = URIRef("https://schema.org/JobPosting")
    departureGate = URIRef("https://schema.org/departureGate")
    BoatTerminal = URIRef("https://schema.org/BoatTerminal")
    billingDuration = URIRef("https://schema.org/billingDuration")
    readBy = URIRef("https://schema.org/readBy")
    renegotiableLoan = URIRef("https://schema.org/renegotiableLoan")
    TechArticle = URIRef("https://schema.org/TechArticle")
    SpokenWordAlbum = URIRef("https://schema.org/SpokenWordAlbum")
    branchCode = URIRef("https://schema.org/branchCode")
    Gene = URIRef("https://schema.org/Gene")
    Motorcycle = URIRef("https://schema.org/Motorcycle")
    GovernmentBenefitsType = URIRef("https://schema.org/GovernmentBenefitsType")
    UKNonprofitType = URIRef("https://schema.org/UKNonprofitType")
    numberOfAirbags = URIRef("https://schema.org/numberOfAirbags")
    relatedAnatomy = URIRef("https://schema.org/relatedAnatomy")
    PlasticSurgery = URIRef("https://schema.org/PlasticSurgery")
    VitalSign = URIRef("https://schema.org/VitalSign")
    appliesToDeliveryMethod = URIRef("https://schema.org/appliesToDeliveryMethod")
    expectsAcceptanceOf = URIRef("https://schema.org/expectsAcceptanceOf")
    bookEdition = URIRef("https://schema.org/bookEdition")
    OfferForLease = URIRef("https://schema.org/OfferForLease")
    isAvailableGenerically = URIRef("https://schema.org/isAvailableGenerically")
    usedToDiagnose = URIRef("https://schema.org/usedToDiagnose")
    MoveAction = URIRef("https://schema.org/MoveAction")
    scheduleTimezone = URIRef("https://schema.org/scheduleTimezone")
    UnofficialLegalValue = URIRef("https://schema.org/UnofficialLegalValue")
    Nonprofit501c12 = URIRef("https://schema.org/Nonprofit501c12")
    entertainmentBusiness = URIRef("https://schema.org/entertainmentBusiness")
    toLocation = URIRef("https://schema.org/toLocation")
    EventAttendanceModeEnumeration = URIRef("https://schema.org/EventAttendanceModeEnumeration")
    AssignAction = URIRef("https://schema.org/AssignAction")
    strengthValue = URIRef("https://schema.org/strengthValue")
    recipient = URIRef("https://schema.org/recipient")
    inSupportOf = URIRef("https://schema.org/inSupportOf")
    hasMap = URIRef("https://schema.org/hasMap")
    isAccessoryOrSparePartFor = URIRef("https://schema.org/isAccessoryOrSparePartFor")
    MedicalObservationalStudy = URIRef("https://schema.org/MedicalObservationalStudy")
    hasBioPolymerSequence = URIRef("https://schema.org/hasBioPolymerSequence")
    numberOfEmployees = URIRef("https://schema.org/numberOfEmployees")
    TrainStation = URIRef("https://schema.org/TrainStation")
    broadcastFrequency = URIRef("https://schema.org/broadcastFrequency")
    trailerWeight = URIRef("https://schema.org/trailerWeight")
    drug = URIRef("https://schema.org/drug")
    isAcceptingNewPatients = URIRef("https://schema.org/isAcceptingNewPatients")
    originatesFrom = URIRef("https://schema.org/originatesFrom")
    PostalCodeRangeSpecification = URIRef("https://schema.org/PostalCodeRangeSpecification")
    events = URIRef("https://schema.org/events")
    FullRefund = URIRef("https://schema.org/FullRefund")
    legislationChanges = URIRef("https://schema.org/legislationChanges")
    LegislationObject = URIRef("https://schema.org/LegislationObject")
    OTC = URIRef("https://schema.org/OTC")
    Nerve = URIRef("https://schema.org/Nerve")
    populationType = URIRef("https://schema.org/populationType")
    steeringPosition = URIRef("https://schema.org/steeringPosition")
    doesNotShip = URIRef("https://schema.org/doesNotShip")
    datePublished = URIRef("https://schema.org/datePublished")
    passengerSequenceNumber = URIRef("https://schema.org/passengerSequenceNumber")
    CovidTestingFacility = URIRef("https://schema.org/CovidTestingFacility")
    SingleRelease = URIRef("https://schema.org/SingleRelease")
    Duration = URIRef("https://schema.org/Duration")
    OTC = URIRef("https://schema.org/OTC")
    MedicalOrganization = URIRef("https://schema.org/MedicalOrganization")
    awayTeam = URIRef("https://schema.org/awayTeam")
    HowToSection = URIRef("https://schema.org/HowToSection")
    realEstateAgent = URIRef("https://schema.org/realEstateAgent")
    publicationType = URIRef("https://schema.org/publicationType")
    SurgicalProcedure = URIRef("https://schema.org/SurgicalProcedure")
    cvdNumBedsOcc = URIRef("https://schema.org/cvdNumBedsOcc")
    reviewBody = URIRef("https://schema.org/reviewBody")
    branchOf = URIRef("https://schema.org/branchOf")
    clinicalPharmacology = URIRef("https://schema.org/clinicalPharmacology")
    encodesBioChemEntity = URIRef("https://schema.org/encodesBioChemEntity")
    Nonprofit501d = URIRef("https://schema.org/Nonprofit501d")
    MediaEnumeration = URIRef("https://schema.org/MediaEnumeration")
    broadcastSignalModulation = URIRef("https://schema.org/broadcastSignalModulation")
    Distillery = URIRef("https://schema.org/Distillery")
    memberOf = URIRef("https://schema.org/memberOf")
    requiredMaxAge = URIRef("https://schema.org/requiredMaxAge")
    regionDrained = URIRef("https://schema.org/regionDrained")
    mapType = URIRef("https://schema.org/mapType")
    caption = URIRef("https://schema.org/caption")
    saturatedFatContent = URIRef("https://schema.org/saturatedFatContent")
    postalCode = URIRef("https://schema.org/postalCode")
    AutoRental = URIRef("https://schema.org/AutoRental")
    ShortStory = URIRef("https://schema.org/ShortStory")
    arrivalTerminal = URIRef("https://schema.org/arrivalTerminal")
    potentialUse = URIRef("https://schema.org/potentialUse")
    WriteAction = URIRef("https://schema.org/WriteAction")
    GasStation = URIRef("https://schema.org/GasStation")
    discusses = URIRef("https://schema.org/discusses")
    knownVehicleDamages = URIRef("https://schema.org/knownVehicleDamages")
    includesAttraction = URIRef("https://schema.org/includesAttraction")
    ParentalSupport = URIRef("https://schema.org/ParentalSupport")
    ParcelDelivery = URIRef("https://schema.org/ParcelDelivery")
    Language = URIRef("https://schema.org/Language")
    itemDefectReturnLabelSource = URIRef("https://schema.org/itemDefectReturnLabelSource")
    MedicalContraindication = URIRef("https://schema.org/MedicalContraindication")
    UKNonprofitType = URIRef("https://schema.org/UKNonprofitType")
    TrainReservation = URIRef("https://schema.org/TrainReservation")
    ControlAction = URIRef("https://schema.org/ControlAction")
    actor = URIRef("https://schema.org/actor")
    cvdNumICUBeds = URIRef("https://schema.org/cvdNumICUBeds")
    recordLabel = URIRef("https://schema.org/recordLabel")
    countryOfLastProcessing = URIRef("https://schema.org/countryOfLastProcessing")
    ReturnMethodEnumeration = URIRef("https://schema.org/ReturnMethodEnumeration")
    masthead = URIRef("https://schema.org/masthead")
    NewsMediaOrganization = URIRef("https://schema.org/NewsMediaOrganization")
    RadioClip = URIRef("https://schema.org/RadioClip")
    cvdNumC19Died = URIRef("https://schema.org/cvdNumC19Died")
    serviceOutput = URIRef("https://schema.org/serviceOutput")
    OrderItem = URIRef("https://schema.org/OrderItem")
    actor = URIRef("https://schema.org/actor")
    drugClass = URIRef("https://schema.org/drugClass")
    providesBroadcastService = URIRef("https://schema.org/providesBroadcastService")
    inChI = URIRef("https://schema.org/inChI")
    FireStation = URIRef("https://schema.org/FireStation")
    birthPlace = URIRef("https://schema.org/birthPlace")
    geoCoveredBy = URIRef("https://schema.org/geoCoveredBy")
    ReturnLabelSourceEnumeration = URIRef("https://schema.org/ReturnLabelSourceEnumeration")
    GasStation = URIRef("https://schema.org/GasStation")
    bodyLocation = URIRef("https://schema.org/bodyLocation")
    chemicalComposition = URIRef("https://schema.org/chemicalComposition")
    spatialCoverage = URIRef("https://schema.org/spatialCoverage")
    insertion = URIRef("https://schema.org/insertion")
    openingHours = URIRef("https://schema.org/openingHours")
    Nonprofit501c20 = URIRef("https://schema.org/Nonprofit501c20")
    ListenAction = URIRef("https://schema.org/ListenAction")
    healthCondition = URIRef("https://schema.org/healthCondition")
    BusinessEntityType = URIRef("https://schema.org/BusinessEntityType")
    valueReference = URIRef("https://schema.org/valueReference")
    ccRecipient = URIRef("https://schema.org/ccRecipient")
    teaches = URIRef("https://schema.org/teaches")
    NewsMediaOrganization = URIRef("https://schema.org/NewsMediaOrganization")
    potentialUse = URIRef("https://schema.org/potentialUse")
    cvdNumICUBedsOcc = URIRef("https://schema.org/cvdNumICUBedsOcc")
    Toxicologic = URIRef("https://schema.org/Toxicologic")
    depth = URIRef("https://schema.org/depth")
    applicationContact = URIRef("https://schema.org/applicationContact")
    purchaseDate = URIRef("https://schema.org/purchaseDate")
    variableMeasured = URIRef("https://schema.org/variableMeasured")
    parentService = URIRef("https://schema.org/parentService")
    LakeBodyOfWater = URIRef("https://schema.org/LakeBodyOfWater")
    cvdNumBeds = URIRef("https://schema.org/cvdNumBeds")
    associatedReview = URIRef("https://schema.org/associatedReview")
    isVariantOf = URIRef("https://schema.org/isVariantOf")
    DesktopWebPlatform = URIRef("https://schema.org/DesktopWebPlatform")
    reviewBody = URIRef("https://schema.org/reviewBody")
    assesses = URIRef("https://schema.org/assesses")
    Season = URIRef("https://schema.org/Season")
    pageStart = URIRef("https://schema.org/pageStart")
    jobTitle = URIRef("https://schema.org/jobTitle")
    honorificSuffix = URIRef("https://schema.org/honorificSuffix")
    isrcCode = URIRef("https://schema.org/isrcCode")
    HowTo = URIRef("https://schema.org/HowTo")
    isFamilyFriendly = URIRef("https://schema.org/isFamilyFriendly")
    offers = URIRef("https://schema.org/offers")
    PreventionIndication = URIRef("https://schema.org/PreventionIndication")
    Thing = URIRef("https://schema.org/Thing")
    Physician = URIRef("https://schema.org/Physician")
    pagination = URIRef("https://schema.org/pagination")
    gtin13 = URIRef("https://schema.org/gtin13")
    PodcastSeason = URIRef("https://schema.org/PodcastSeason")
    DefinedTermSet = URIRef("https://schema.org/DefinedTermSet")
    CategoryCodeSet = URIRef("https://schema.org/CategoryCodeSet")
    ReviewNewsArticle = URIRef("https://schema.org/ReviewNewsArticle")
    pagination = URIRef("https://schema.org/pagination")
    publishedBy = URIRef("https://schema.org/publishedBy")
    RsvpResponseYes = URIRef("https://schema.org/RsvpResponseYes")
    customerRemorseReturnFees = URIRef("https://schema.org/customerRemorseReturnFees")
    colleagues = URIRef("https://schema.org/colleagues")
    Zoo = URIRef("https://schema.org/Zoo")
    validFor = URIRef("https://schema.org/validFor")
    ticketToken = URIRef("https://schema.org/ticketToken")
    ApprovedIndication = URIRef("https://schema.org/ApprovedIndication")
    hasDeliveryMethod = URIRef("https://schema.org/hasDeliveryMethod")
    DigitalPlatformEnumeration = URIRef("https://schema.org/DigitalPlatformEnumeration")
    startDate = URIRef("https://schema.org/startDate")
    enginePower = URIRef("https://schema.org/enginePower")
    issn = URIRef("https://schema.org/issn")
    performers = URIRef("https://schema.org/performers")
    legislationPassedBy = URIRef("https://schema.org/legislationPassedBy")
    itemListOrder = URIRef("https://schema.org/itemListOrder")
    numberOfEpisodes = URIRef("https://schema.org/numberOfEpisodes")
    includedInDataCatalog = URIRef("https://schema.org/includedInDataCatalog")
    inChI = URIRef("https://schema.org/inChI")
    conditionsOfAccess = URIRef("https://schema.org/conditionsOfAccess")
    accountOverdraftLimit = URIRef("https://schema.org/accountOverdraftLimit")
    confirmationNumber = URIRef("https://schema.org/confirmationNumber")
    BackgroundNewsArticle = URIRef("https://schema.org/BackgroundNewsArticle")
    DVDFormat = URIRef("https://schema.org/DVDFormat")
    HealthPlanCostSharingSpecification = URIRef("https://schema.org/HealthPlanCostSharingSpecification")
    VisualArtwork = URIRef("https://schema.org/VisualArtwork")
    busName = URIRef("https://schema.org/busName")
    ImageGallery = URIRef("https://schema.org/ImageGallery")
    trackingUrl = URIRef("https://schema.org/trackingUrl")
    PrependAction = URIRef("https://schema.org/PrependAction")
    PublicToilet = URIRef("https://schema.org/PublicToilet")
    playMode = URIRef("https://schema.org/playMode")
    SRP = URIRef("https://schema.org/SRP")
    Nonprofit501c25 = URIRef("https://schema.org/Nonprofit501c25")
    mpn = URIRef("https://schema.org/mpn")
    composer = URIRef("https://schema.org/composer")
    constraintProperty = URIRef("https://schema.org/constraintProperty")
    isEncodedByBioChemEntity = URIRef("https://schema.org/isEncodedByBioChemEntity")
    suggestedAge = URIRef("https://schema.org/suggestedAge")
    hasCertification = URIRef("https://schema.org/hasCertification")
    category = URIRef("https://schema.org/category")
    subStageSuffix = URIRef("https://schema.org/subStageSuffix")
    correction = URIRef("https://schema.org/correction")
    EUEnergyEfficiencyCategoryA = URIRef("https://schema.org/EUEnergyEfficiencyCategoryA")
    borrower = URIRef("https://schema.org/borrower")
    InsuranceAgency = URIRef("https://schema.org/InsuranceAgency")
    MolecularEntity = URIRef("https://schema.org/MolecularEntity")
    endorsee = URIRef("https://schema.org/endorsee")
    editEIDR = URIRef("https://schema.org/editEIDR")
    frequency = URIRef("https://schema.org/frequency")
    sourcedFrom = URIRef("https://schema.org/sourcedFrom")
    maps = URIRef("https://schema.org/maps")
    cvdCollectionDate = URIRef("https://schema.org/cvdCollectionDate")
    loanType = URIRef("https://schema.org/loanType")
    courseWorkload = URIRef("https://schema.org/courseWorkload")
    Motel = URIRef("https://schema.org/Motel")
    NLNonprofitType = URIRef("https://schema.org/NLNonprofitType")
    expertConsiderations = URIRef("https://schema.org/expertConsiderations")
    DryCleaningOrLaundry = URIRef("https://schema.org/DryCleaningOrLaundry")
    closes = URIRef("https://schema.org/closes")
    orderDate = URIRef("https://schema.org/orderDate")
    asin = URIRef("https://schema.org/asin")
    duration = URIRef("https://schema.org/duration")
    validFor = URIRef("https://schema.org/validFor")
    ReturnLabelSourceEnumeration = URIRef("https://schema.org/ReturnLabelSourceEnumeration")
    Schedule = URIRef("https://schema.org/Schedule")
    alternativeOf = URIRef("https://schema.org/alternativeOf")
    ownedFrom = URIRef("https://schema.org/ownedFrom")
    MusicAlbumReleaseType = URIRef("https://schema.org/MusicAlbumReleaseType")
    TakeAction = URIRef("https://schema.org/TakeAction")
    ExerciseGym = URIRef("https://schema.org/ExerciseGym")
    AppendAction = URIRef("https://schema.org/AppendAction")
    OwnershipInfo = URIRef("https://schema.org/OwnershipInfo")
    BusTrip = URIRef("https://schema.org/BusTrip")
    ContactPage = URIRef("https://schema.org/ContactPage")
    InfectiousAgentClass = URIRef("https://schema.org/InfectiousAgentClass")
    offers = URIRef("https://schema.org/offers")
    itemLocation = URIRef("https://schema.org/itemLocation")
    afterMedia = URIRef("https://schema.org/afterMedia")
    drainsTo = URIRef("https://schema.org/drainsTo")
    Hackathon = URIRef("https://schema.org/Hackathon")
    Attorney = URIRef("https://schema.org/Attorney")
    legislationApplies = URIRef("https://schema.org/legislationApplies")
    SuperficialAnatomy = URIRef("https://schema.org/SuperficialAnatomy")
    DefenceEstablishment = URIRef("https://schema.org/DefenceEstablishment")
    InternationalTrial = URIRef("https://schema.org/InternationalTrial")
    FoodEvent = URIRef("https://schema.org/FoodEvent")
    TelevisionChannel = URIRef("https://schema.org/TelevisionChannel")
    shippingDetails = URIRef("https://schema.org/shippingDetails")
    functionalClass = URIRef("https://schema.org/functionalClass")
    ReturnInStore = URIRef("https://schema.org/ReturnInStore")
    estimatesRiskOf = URIRef("https://schema.org/estimatesRiskOf")
    valueMaxLength = URIRef("https://schema.org/valueMaxLength")
    directApply = URIRef("https://schema.org/directApply")
    addressCountry = URIRef("https://schema.org/addressCountry")
    renegotiableLoan = URIRef("https://schema.org/renegotiableLoan")
    buyer = URIRef("https://schema.org/buyer")
    cashBack = URIRef("https://schema.org/cashBack")
    photo = URIRef("https://schema.org/photo")
    SingleRelease = URIRef("https://schema.org/SingleRelease")
    originatesFrom = URIRef("https://schema.org/originatesFrom")
    leiCode = URIRef("https://schema.org/leiCode")
    MediaObject = URIRef("https://schema.org/MediaObject")
    Quiz = URIRef("https://schema.org/Quiz")
    busName = URIRef("https://schema.org/busName")
    functionalClass = URIRef("https://schema.org/functionalClass")
    RestrictedDiet = URIRef("https://schema.org/RestrictedDiet")
    Osteopathic = URIRef("https://schema.org/Osteopathic")
    WarrantyPromise = URIRef("https://schema.org/WarrantyPromise")
    dateReceived = URIRef("https://schema.org/dateReceived")
    status = URIRef("https://schema.org/status")
    AutoDealer = URIRef("https://schema.org/AutoDealer")
    carrier = URIRef("https://schema.org/carrier")
    contentReferenceTime = URIRef("https://schema.org/contentReferenceTime")
    DrugCostCategory = URIRef("https://schema.org/DrugCostCategory")
    educationalUse = URIRef("https://schema.org/educationalUse")
    PartiallyInForce = URIRef("https://schema.org/PartiallyInForce")
    OpinionNewsArticle = URIRef("https://schema.org/OpinionNewsArticle")
    sha256 = URIRef("https://schema.org/sha256")
    parentItem = URIRef("https://schema.org/parentItem")
    blogPosts = URIRef("https://schema.org/blogPosts")
    Book = URIRef("https://schema.org/Book")
    Observation = URIRef("https://schema.org/Observation")
    telephone = URIRef("https://schema.org/telephone")
    translationOfWork = URIRef("https://schema.org/translationOfWork")
    quarantineGuidelines = URIRef("https://schema.org/quarantineGuidelines")
    instrument = URIRef("https://schema.org/instrument")
    DrugCostCategory = URIRef("https://schema.org/DrugCostCategory")
    exerciseCourse = URIRef("https://schema.org/exerciseCourse")
    iupacName = URIRef("https://schema.org/iupacName")
    postalCode = URIRef("https://schema.org/postalCode")
    FinancialService = URIRef("https://schema.org/FinancialService")
    isicV4 = URIRef("https://schema.org/isicV4")
    loanMortgageMandateAmount = URIRef("https://schema.org/loanMortgageMandateAmount")
    TreatmentsHealthAspect = URIRef("https://schema.org/TreatmentsHealthAspect")
    worstRating = URIRef("https://schema.org/worstRating")
    BodyMeasurementFoot = URIRef("https://schema.org/BodyMeasurementFoot")
    DataDownload = URIRef("https://schema.org/DataDownload")
    Service = URIRef("https://schema.org/Service")
    isBasedOn = URIRef("https://schema.org/isBasedOn")
    episodeNumber = URIRef("https://schema.org/episodeNumber")
    MultiCenterTrial = URIRef("https://schema.org/MultiCenterTrial")
    endTime = URIRef("https://schema.org/endTime")
    publisherImprint = URIRef("https://schema.org/publisherImprint")
    AdultEntertainment = URIRef("https://schema.org/AdultEntertainment")
    isFamilyFriendly = URIRef("https://schema.org/isFamilyFriendly")
    RandomizedTrial = URIRef("https://schema.org/RandomizedTrial")
    numberOfRooms = URIRef("https://schema.org/numberOfRooms")
    busNumber = URIRef("https://schema.org/busNumber")
    RadiationTherapy = URIRef("https://schema.org/RadiationTherapy")
    WesternConventional = URIRef("https://schema.org/WesternConventional")
    itemReviewed = URIRef("https://schema.org/itemReviewed")
    CompilationAlbum = URIRef("https://schema.org/CompilationAlbum")
    LiteraryEvent = URIRef("https://schema.org/LiteraryEvent")
    verificationFactCheckingPolicy = URIRef("https://schema.org/verificationFactCheckingPolicy")
    ParcelService = URIRef("https://schema.org/ParcelService")
    modelDate = URIRef("https://schema.org/modelDate")
    videoFormat = URIRef("https://schema.org/videoFormat")
    releaseNotes = URIRef("https://schema.org/releaseNotes")
    Nonprofit501n = URIRef("https://schema.org/Nonprofit501n")
    pickupLocation = URIRef("https://schema.org/pickupLocation")
    dateCreated = URIRef("https://schema.org/dateCreated")
    jurisdiction = URIRef("https://schema.org/jurisdiction")
    Recipe = URIRef("https://schema.org/Recipe")
    schoolClosuresInfo = URIRef("https://schema.org/schoolClosuresInfo")
    ratingValue = URIRef("https://schema.org/ratingValue")
    recipient = URIRef("https://schema.org/recipient")
    VideoObjectSnapshot = URIRef("https://schema.org/VideoObjectSnapshot")
    GeneralContractor = URIRef("https://schema.org/GeneralContractor")
    alternativeHeadline = URIRef("https://schema.org/alternativeHeadline")
    URL = URIRef("https://schema.org/URL")
    Hospital = URIRef("https://schema.org/Hospital")
    PerformanceRole = URIRef("https://schema.org/PerformanceRole")
    geo = URIRef("https://schema.org/geo")
    countryOfAssembly = URIRef("https://schema.org/countryOfAssembly")
    brand = URIRef("https://schema.org/brand")
    specialty = URIRef("https://schema.org/specialty")
    confirmationNumber = URIRef("https://schema.org/confirmationNumber")
    RelatedTopicsHealthAspect = URIRef("https://schema.org/RelatedTopicsHealthAspect")
    InForce = URIRef("https://schema.org/InForce")
    EducationalOccupationalProgram = URIRef("https://schema.org/EducationalOccupationalProgram")
    recordedAt = URIRef("https://schema.org/recordedAt")
    Aquarium = URIRef("https://schema.org/Aquarium")
    DecontextualizedContent = URIRef("https://schema.org/DecontextualizedContent")
    PaymentService = URIRef("https://schema.org/PaymentService")
    availability = URIRef("https://schema.org/availability")
    track = URIRef("https://schema.org/track")
    orderedItem = URIRef("https://schema.org/orderedItem")
    conditionsOfAccess = URIRef("https://schema.org/conditionsOfAccess")
    datePublished = URIRef("https://schema.org/datePublished")
    identifier = URIRef("https://schema.org/identifier")
    numberOfLoanPayments = URIRef("https://schema.org/numberOfLoanPayments")
    menuAddOn = URIRef("https://schema.org/menuAddOn")
    CDFormat = URIRef("https://schema.org/CDFormat")
    discusses = URIRef("https://schema.org/discusses")
    SizeGroupEnumeration = URIRef("https://schema.org/SizeGroupEnumeration")
    author = URIRef("https://schema.org/author")
    doseSchedule = URIRef("https://schema.org/doseSchedule")
    addressRegion = URIRef("https://schema.org/addressRegion")
    arterialBranch = URIRef("https://schema.org/arterialBranch")
    BloodTest = URIRef("https://schema.org/BloodTest")
    chemicalRole = URIRef("https://schema.org/chemicalRole")
    accountMinimumInflow = URIRef("https://schema.org/accountMinimumInflow")
    WearableSizeGroupRegular = URIRef("https://schema.org/WearableSizeGroupRegular")
    AnimalShelter = URIRef("https://schema.org/AnimalShelter")
    suggestedAge = URIRef("https://schema.org/suggestedAge")
    BroadcastFrequencySpecification = URIRef("https://schema.org/BroadcastFrequencySpecification")
    WearableMeasurementHips = URIRef("https://schema.org/WearableMeasurementHips")
    activityDuration = URIRef("https://schema.org/activityDuration")
    leaseLength = URIRef("https://schema.org/leaseLength")
    softwareRequirements = URIRef("https://schema.org/softwareRequirements")
    LegalForceStatus = URIRef("https://schema.org/LegalForceStatus")
    owns = URIRef("https://schema.org/owns")
    InvestmentOrDeposit = URIRef("https://schema.org/InvestmentOrDeposit")
    usedToDiagnose = URIRef("https://schema.org/usedToDiagnose")
    recipeYield = URIRef("https://schema.org/recipeYield")
    messageAttachment = URIRef("https://schema.org/messageAttachment")
    ShareAction = URIRef("https://schema.org/ShareAction")
    startDate = URIRef("https://schema.org/startDate")
    InteractionCounter = URIRef("https://schema.org/InteractionCounter")
    WearableSizeGroupPlus = URIRef("https://schema.org/WearableSizeGroupPlus")
    MortgageLoan = URIRef("https://schema.org/MortgageLoan")
    DayOfWeek = URIRef("https://schema.org/DayOfWeek")
    GettingAccessHealthAspect = URIRef("https://schema.org/GettingAccessHealthAspect")
    Male = URIRef("https://schema.org/Male")
    episodeNumber = URIRef("https://schema.org/episodeNumber")
    specialOpeningHoursSpecification = URIRef("https://schema.org/specialOpeningHoursSpecification")
    study = URIRef("https://schema.org/study")
    cheatCode = URIRef("https://schema.org/cheatCode")
    creditText = URIRef("https://schema.org/creditText")
    childTaxon = URIRef("https://schema.org/childTaxon")
    hasCertification = URIRef("https://schema.org/hasCertification")
    BackgroundNewsArticle = URIRef("https://schema.org/BackgroundNewsArticle")
    proficiencyLevel = URIRef("https://schema.org/proficiencyLevel")
    assemblyVersion = URIRef("https://schema.org/assemblyVersion")
    Brewery = URIRef("https://schema.org/Brewery")
    expectsAcceptanceOf = URIRef("https://schema.org/expectsAcceptanceOf")
    artMedium = URIRef("https://schema.org/artMedium")
    Drawing = URIRef("https://schema.org/Drawing")
    smiles = URIRef("https://schema.org/smiles")
    speakable = URIRef("https://schema.org/speakable")
    typicalTest = URIRef("https://schema.org/typicalTest")
    mediaAuthenticityCategory = URIRef("https://schema.org/mediaAuthenticityCategory")
    value = URIRef("https://schema.org/value")
    Season = URIRef("https://schema.org/Season")
    stage = URIRef("https://schema.org/stage")
    diet = URIRef("https://schema.org/diet")
    molecularFormula = URIRef("https://schema.org/molecularFormula")
    course = URIRef("https://schema.org/course")
    HealthAspectEnumeration = URIRef("https://schema.org/HealthAspectEnumeration")
    version = URIRef("https://schema.org/version")
    childMaxAge = URIRef("https://schema.org/childMaxAge")
    Event = URIRef("https://schema.org/Event")
    discount = URIRef("https://schema.org/discount")
    alternativeHeadline = URIRef("https://schema.org/alternativeHeadline")
    maximumEnrollment = URIRef("https://schema.org/maximumEnrollment")
    WearableSizeSystemEN13402 = URIRef("https://schema.org/WearableSizeSystemEN13402")
    MathSolver = URIRef("https://schema.org/MathSolver")
    OnlineStore = URIRef("https://schema.org/OnlineStore")
    Locksmith = URIRef("https://schema.org/Locksmith")
    BioChemEntity = URIRef("https://schema.org/BioChemEntity")
    HobbyShop = URIRef("https://schema.org/HobbyShop")
    XPathType = URIRef("https://schema.org/XPathType")
    LocationFeatureSpecification = URIRef("https://schema.org/LocationFeatureSpecification")
    interpretedAsClaim = URIRef("https://schema.org/interpretedAsClaim")
    customerRemorseReturnFees = URIRef("https://schema.org/customerRemorseReturnFees")
    runsTo = URIRef("https://schema.org/runsTo")
    EndorseAction = URIRef("https://schema.org/EndorseAction")
    arrivalStation = URIRef("https://schema.org/arrivalStation")
    Nonprofit501k = URIRef("https://schema.org/Nonprofit501k")
    Canal = URIRef("https://schema.org/Canal")
    broadcastSignalModulation = URIRef("https://schema.org/broadcastSignalModulation")
    Guide = URIRef("https://schema.org/Guide")
    gtin12 = URIRef("https://schema.org/gtin12")
    healthcareReportingData = URIRef("https://schema.org/healthcareReportingData")
    exerciseRelatedDiet = URIRef("https://schema.org/exerciseRelatedDiet")
    numberOfCredits = URIRef("https://schema.org/numberOfCredits")
    distribution = URIRef("https://schema.org/distribution")
    lender = URIRef("https://schema.org/lender")
    nonEqual = URIRef("https://schema.org/nonEqual")
    maximumPhysicalAttendeeCapacity = URIRef("https://schema.org/maximumPhysicalAttendeeCapacity")
    photos = URIRef("https://schema.org/photos")
    fuelType = URIRef("https://schema.org/fuelType")
    Nonprofit501c25 = URIRef("https://schema.org/Nonprofit501c25")
    HealthInsurancePlan = URIRef("https://schema.org/HealthInsurancePlan")
    Certification = URIRef("https://schema.org/Certification")
    publication = URIRef("https://schema.org/publication")
    SelfCareHealthAspect = URIRef("https://schema.org/SelfCareHealthAspect")
    candidate = URIRef("https://schema.org/candidate")
    percentile25 = URIRef("https://schema.org/percentile25")
    eligibleRegion = URIRef("https://schema.org/eligibleRegion")
    appearance = URIRef("https://schema.org/appearance")
    Thesis = URIRef("https://schema.org/Thesis")
    price = URIRef("https://schema.org/price")
    hasOccupation = URIRef("https://schema.org/hasOccupation")
    artMedium = URIRef("https://schema.org/artMedium")
    maximumAttendeeCapacity = URIRef("https://schema.org/maximumAttendeeCapacity")
    codeSampleType = URIRef("https://schema.org/codeSampleType")
    serviceArea = URIRef("https://schema.org/serviceArea")
    missionCoveragePrioritiesPolicy = URIRef("https://schema.org/missionCoveragePrioritiesPolicy")
    acceptedAnswer = URIRef("https://schema.org/acceptedAnswer")
    dateIssued = URIRef("https://schema.org/dateIssued")
    numberOfRooms = URIRef("https://schema.org/numberOfRooms")
    audienceType = URIRef("https://schema.org/audienceType")
    colorSwatch = URIRef("https://schema.org/colorSwatch")
    employerOverview = URIRef("https://schema.org/employerOverview")
    itemDefectReturnShippingFeesAmount = URIRef("https://schema.org/itemDefectReturnShippingFeesAmount")
    headline = URIRef("https://schema.org/headline")
    thumbnail = URIRef("https://schema.org/thumbnail")
    spouse = URIRef("https://schema.org/spouse")
    hasEnergyConsumptionDetails = URIRef("https://schema.org/hasEnergyConsumptionDetails")
    nerveMotor = URIRef("https://schema.org/nerveMotor")
    children = URIRef("https://schema.org/children")
    mileageFromOdometer = URIRef("https://schema.org/mileageFromOdometer")
    agentInteractionStatistic = URIRef("https://schema.org/agentInteractionStatistic")
    OnlineFull = URIRef("https://schema.org/OnlineFull")
    occupancy = URIRef("https://schema.org/occupancy")
    Pathology = URIRef("https://schema.org/Pathology")
    geoContains = URIRef("https://schema.org/geoContains")
    inCodeSet = URIRef("https://schema.org/inCodeSet")
    measurementMethod = URIRef("https://schema.org/measurementMethod")
    DiscussionForumPosting = URIRef("https://schema.org/DiscussionForumPosting")
    hasMenuItem = URIRef("https://schema.org/hasMenuItem")
    pickupLocation = URIRef("https://schema.org/pickupLocation")
    reservationStatus = URIRef("https://schema.org/reservationStatus")
    comment = URIRef("https://schema.org/comment")
    BodyMeasurementNeck = URIRef("https://schema.org/BodyMeasurementNeck")
    weight = URIRef("https://schema.org/weight")
    loanType = URIRef("https://schema.org/loanType")
    trainName = URIRef("https://schema.org/trainName")
    circle = URIRef("https://schema.org/circle")
    affectedBy = URIRef("https://schema.org/affectedBy")
    wordCount = URIRef("https://schema.org/wordCount")
    IceCreamShop = URIRef("https://schema.org/IceCreamShop")
    AutomatedTeller = URIRef("https://schema.org/AutomatedTeller")
    temporalCoverage = URIRef("https://schema.org/temporalCoverage")
    orderedItem = URIRef("https://schema.org/orderedItem")
    handlingTime = URIRef("https://schema.org/handlingTime")
    worstRating = URIRef("https://schema.org/worstRating")
    transitTime = URIRef("https://schema.org/transitTime")
    LakeBodyOfWater = URIRef("https://schema.org/LakeBodyOfWater")
    SchoolDistrict = URIRef("https://schema.org/SchoolDistrict")
    resultReview = URIRef("https://schema.org/resultReview")
    CompilationAlbum = URIRef("https://schema.org/CompilationAlbum")
    siblings = URIRef("https://schema.org/siblings")
    SoftwareApplication = URIRef("https://schema.org/SoftwareApplication")
    Atlas = URIRef("https://schema.org/Atlas")
    Collection = URIRef("https://schema.org/Collection")
    SoftwareSourceCode = URIRef("https://schema.org/SoftwareSourceCode")
    DefinedTermSet = URIRef("https://schema.org/DefinedTermSet")
    WearableSizeSystemDE = URIRef("https://schema.org/WearableSizeSystemDE")
    estimatedCost = URIRef("https://schema.org/estimatedCost")
    ineligibleRegion = URIRef("https://schema.org/ineligibleRegion")
    WebPage = URIRef("https://schema.org/WebPage")
    specialCommitments = URIRef("https://schema.org/specialCommitments")
    PartiallyInForce = URIRef("https://schema.org/PartiallyInForce")
    EducationalOrganization = URIRef("https://schema.org/EducationalOrganization")
    logo = URIRef("https://schema.org/logo")
    bccRecipient = URIRef("https://schema.org/bccRecipient")
    catalog = URIRef("https://schema.org/catalog")
    geoContains = URIRef("https://schema.org/geoContains")
    NonprofitType = URIRef("https://schema.org/NonprofitType")
    CheckOutAction = URIRef("https://schema.org/CheckOutAction")
    produces = URIRef("https://schema.org/produces")
    OnlineStore = URIRef("https://schema.org/OnlineStore")
    hasMenuSection = URIRef("https://schema.org/hasMenuSection")
    previousItem = URIRef("https://schema.org/previousItem")
    OneTimePayments = URIRef("https://schema.org/OneTimePayments")
    replacer = URIRef("https://schema.org/replacer")
    license = URIRef("https://schema.org/license")
    linkRelationship = URIRef("https://schema.org/linkRelationship")
    validThrough = URIRef("https://schema.org/validThrough")
    legislationChanges = URIRef("https://schema.org/legislationChanges")
    returnMethod = URIRef("https://schema.org/returnMethod")
    reservationId = URIRef("https://schema.org/reservationId")
    ShippingRateSettings = URIRef("https://schema.org/ShippingRateSettings")
    CookAction = URIRef("https://schema.org/CookAction")
    event = URIRef("https://schema.org/event")
    LodgingReservation = URIRef("https://schema.org/LodgingReservation")
    referenceQuantity = URIRef("https://schema.org/referenceQuantity")
    byMonth = URIRef("https://schema.org/byMonth")
    homeLocation = URIRef("https://schema.org/homeLocation")
    GeoCircle = URIRef("https://schema.org/GeoCircle")
    WearableMeasurementInseam = URIRef("https://schema.org/WearableMeasurementInseam")
    applicableCountry = URIRef("https://schema.org/applicableCountry")
    verificationFactCheckingPolicy = URIRef("https://schema.org/verificationFactCheckingPolicy")
    hasMerchantReturnPolicy = URIRef("https://schema.org/hasMerchantReturnPolicy")
    includedRiskFactor = URIRef("https://schema.org/includedRiskFactor")
    courseSchedule = URIRef("https://schema.org/courseSchedule")
    broadcastFrequency = URIRef("https://schema.org/broadcastFrequency")
    isAccessibleForFree = URIRef("https://schema.org/isAccessibleForFree")
    fromLocation = URIRef("https://schema.org/fromLocation")
    PublicToilet = URIRef("https://schema.org/PublicToilet")
    transitTime = URIRef("https://schema.org/transitTime")
    expectedArrivalUntil = URIRef("https://schema.org/expectedArrivalUntil")
    vehicleInteriorType = URIRef("https://schema.org/vehicleInteriorType")
    Vessel = URIRef("https://schema.org/Vessel")
    Emergency = URIRef("https://schema.org/Emergency")
    measurementMethod = URIRef("https://schema.org/measurementMethod")
    WearableSizeGroupTall = URIRef("https://schema.org/WearableSizeGroupTall")
    ownershipFundingInfo = URIRef("https://schema.org/ownershipFundingInfo")
    printEdition = URIRef("https://schema.org/printEdition")
    bankAccountType = URIRef("https://schema.org/bankAccountType")
    accommodationCategory = URIRef("https://schema.org/accommodationCategory")
    Artery = URIRef("https://schema.org/Artery")
    actionAccessibilityRequirement = URIRef("https://schema.org/actionAccessibilityRequirement")
    doseSchedule = URIRef("https://schema.org/doseSchedule")
    foundingLocation = URIRef("https://schema.org/foundingLocation")
    contentUrl = URIRef("https://schema.org/contentUrl")
    bed = URIRef("https://schema.org/bed")
    DigitalDocumentPermissionType = URIRef("https://schema.org/DigitalDocumentPermissionType")
    bioChemInteraction = URIRef("https://schema.org/bioChemInteraction")
    genre = URIRef("https://schema.org/genre")
    itemLocation = URIRef("https://schema.org/itemLocation")
    paymentMethod = URIRef("https://schema.org/paymentMethod")
    PositiveFilmDigitalSource = URIRef("https://schema.org/PositiveFilmDigitalSource")
    cvdNumC19HOPats = URIRef("https://schema.org/cvdNumC19HOPats")
    ExchangeRateSpecification = URIRef("https://schema.org/ExchangeRateSpecification")
    DataType = URIRef("https://schema.org/DataType")
    isConsumableFor = URIRef("https://schema.org/isConsumableFor")
    SearchRescueOrganization = URIRef("https://schema.org/SearchRescueOrganization")
    provider = URIRef("https://schema.org/provider")
    broadcastFrequency = URIRef("https://schema.org/broadcastFrequency")
    cvdNumC19MechVentPats = URIRef("https://schema.org/cvdNumC19MechVentPats")
    leaseLength = URIRef("https://schema.org/leaseLength")
    Diagnostic = URIRef("https://schema.org/Diagnostic")
    programType = URIRef("https://schema.org/programType")
    deliveryTime = URIRef("https://schema.org/deliveryTime")
    question = URIRef("https://schema.org/question")
    Chiropractic = URIRef("https://schema.org/Chiropractic")
    availabilityStarts = URIRef("https://schema.org/availabilityStarts")
    BlogPosting = URIRef("https://schema.org/BlogPosting")
    deliveryLeadTime = URIRef("https://schema.org/deliveryLeadTime")
    securityClearanceRequirement = URIRef("https://schema.org/securityClearanceRequirement")
    backstory = URIRef("https://schema.org/backstory")
    measurementQualifier = URIRef("https://schema.org/measurementQualifier")
    OccupationalExperienceRequirements = URIRef("https://schema.org/OccupationalExperienceRequirements")
    primaryImageOfPage = URIRef("https://schema.org/primaryImageOfPage")
    EducationalOrganization = URIRef("https://schema.org/EducationalOrganization")
    travelBans = URIRef("https://schema.org/travelBans")
    RefundTypeEnumeration = URIRef("https://schema.org/RefundTypeEnumeration")
    brand = URIRef("https://schema.org/brand")
    merchantReturnLink = URIRef("https://schema.org/merchantReturnLink")
    DiagnosticLab = URIRef("https://schema.org/DiagnosticLab")
    availableStrength = URIRef("https://schema.org/availableStrength")
    BoatTerminal = URIRef("https://schema.org/BoatTerminal")
    significance = URIRef("https://schema.org/significance")
    UserComments = URIRef("https://schema.org/UserComments")
    SizeSystemEnumeration = URIRef("https://schema.org/SizeSystemEnumeration")
    bookEdition = URIRef("https://schema.org/bookEdition")
    CreativeWorkSeries = URIRef("https://schema.org/CreativeWorkSeries")
    OccupationalExperienceRequirements = URIRef("https://schema.org/OccupationalExperienceRequirements")
    tool = URIRef("https://schema.org/tool")
    numberOfBeds = URIRef("https://schema.org/numberOfBeds")
    PhysiciansOffice = URIRef("https://schema.org/PhysiciansOffice")
    Dermatologic = URIRef("https://schema.org/Dermatologic")
    CollegeOrUniversity = URIRef("https://schema.org/CollegeOrUniversity")
    legislationJurisdiction = URIRef("https://schema.org/legislationJurisdiction")
    EventPostponed = URIRef("https://schema.org/EventPostponed")
    Rating = URIRef("https://schema.org/Rating")
    knowsLanguage = URIRef("https://schema.org/knowsLanguage")
    postOfficeBoxNumber = URIRef("https://schema.org/postOfficeBoxNumber")
    Number = URIRef("https://schema.org/Number")
    VirtualRecordingDigitalSource = URIRef("https://schema.org/VirtualRecordingDigitalSource")
    FilmAction = URIRef("https://schema.org/FilmAction")
    amountOfThisGood = URIRef("https://schema.org/amountOfThisGood")
    track = URIRef("https://schema.org/track")
    LikeAction = URIRef("https://schema.org/LikeAction")
    option = URIRef("https://schema.org/option")
    EmployeeRole = URIRef("https://schema.org/EmployeeRole")
    studySubject = URIRef("https://schema.org/studySubject")
    firstAppearance = URIRef("https://schema.org/firstAppearance")
    BusStop = URIRef("https://schema.org/BusStop")
    ReturnLabelSourceEnumeration = URIRef("https://schema.org/ReturnLabelSourceEnumeration")
    addressCountry = URIRef("https://schema.org/addressCountry")
    XRay = URIRef("https://schema.org/XRay")
    MusicGroup = URIRef("https://schema.org/MusicGroup")
    image = URIRef("https://schema.org/image")
    includedInDataCatalog = URIRef("https://schema.org/includedInDataCatalog")
    applicantLocationRequirements = URIRef("https://schema.org/applicantLocationRequirements")
    merchantReturnDays = URIRef("https://schema.org/merchantReturnDays")
    titleEIDR = URIRef("https://schema.org/titleEIDR")
    WearableSizeSystemAU = URIRef("https://schema.org/WearableSizeSystemAU")
    HealthAspectEnumeration = URIRef("https://schema.org/HealthAspectEnumeration")
    primaryImageOfPage = URIRef("https://schema.org/primaryImageOfPage")
    PostOffice = URIRef("https://schema.org/PostOffice")
    BedAndBreakfast = URIRef("https://schema.org/BedAndBreakfast")
    isBasedOn = URIRef("https://schema.org/isBasedOn")
    provider = URIRef("https://schema.org/provider")
    dataset = URIRef("https://schema.org/dataset")
    OfficialLegalValue = URIRef("https://schema.org/OfficialLegalValue")
    termCode = URIRef("https://schema.org/termCode")
    administrationRoute = URIRef("https://schema.org/administrationRoute")
    sha256 = URIRef("https://schema.org/sha256")
    Beach = URIRef("https://schema.org/Beach")
    name = URIRef("https://schema.org/name")
    valueName = URIRef("https://schema.org/valueName")
    PaymentStatusType = URIRef("https://schema.org/PaymentStatusType")
    embedUrl = URIRef("https://schema.org/embedUrl")
    signOrSymptom = URIRef("https://schema.org/signOrSymptom")
    branchCode = URIRef("https://schema.org/branchCode")
    shippingDestination = URIRef("https://schema.org/shippingDestination")
    fiberContent = URIRef("https://schema.org/fiberContent")
    StatisticalVariable = URIRef("https://schema.org/StatisticalVariable")
    intensity = URIRef("https://schema.org/intensity")
    afterMedia = URIRef("https://schema.org/afterMedia")
    applicableLocation = URIRef("https://schema.org/applicableLocation")
    serviceType = URIRef("https://schema.org/serviceType")
    pageEnd = URIRef("https://schema.org/pageEnd")
    saturatedFatContent = URIRef("https://schema.org/saturatedFatContent")
    mainEntityOfPage = URIRef("https://schema.org/mainEntityOfPage")
    PerformanceRole = URIRef("https://schema.org/PerformanceRole")
    CoverArt = URIRef("https://schema.org/CoverArt")
    CoOp = URIRef("https://schema.org/CoOp")
    contactlessPayment = URIRef("https://schema.org/contactlessPayment")
    MedicalDevicePurpose = URIRef("https://schema.org/MedicalDevicePurpose")
    affiliation = URIRef("https://schema.org/affiliation")
    SendAction = URIRef("https://schema.org/SendAction")
    ProductModel = URIRef("https://schema.org/ProductModel")
    fundedItem = URIRef("https://schema.org/fundedItem")
    alignmentType = URIRef("https://schema.org/alignmentType")
    jobLocationType = URIRef("https://schema.org/jobLocationType")
    FlightReservation = URIRef("https://schema.org/FlightReservation")
    accountOverdraftLimit = URIRef("https://schema.org/accountOverdraftLimit")
    Hotel = URIRef("https://schema.org/Hotel")
    ReviewAction = URIRef("https://schema.org/ReviewAction")
    geoIntersects = URIRef("https://schema.org/geoIntersects")
    Brewery = URIRef("https://schema.org/Brewery")
    postalCodeEnd = URIRef("https://schema.org/postalCodeEnd")
    learningResourceType = URIRef("https://schema.org/learningResourceType")
    Nonprofit501c24 = URIRef("https://schema.org/Nonprofit501c24")
    ReportageNewsArticle = URIRef("https://schema.org/ReportageNewsArticle")
    estimatedSalary = URIRef("https://schema.org/estimatedSalary")
    Person = URIRef("https://schema.org/Person")
    Genetic = URIRef("https://schema.org/Genetic")
    Midwifery = URIRef("https://schema.org/Midwifery")
    shippingSettingsLink = URIRef("https://schema.org/shippingSettingsLink")
    isAccessoryOrSparePartFor = URIRef("https://schema.org/isAccessoryOrSparePartFor")
    LifestyleModification = URIRef("https://schema.org/LifestyleModification")
    eligibilityToWorkRequirement = URIRef("https://schema.org/eligibilityToWorkRequirement")
    photo = URIRef("https://schema.org/photo")
    BoatReservation = URIRef("https://schema.org/BoatReservation")
    GatedResidenceCommunity = URIRef("https://schema.org/GatedResidenceCommunity")
    Dataset = URIRef("https://schema.org/Dataset")
    recipeCuisine = URIRef("https://schema.org/recipeCuisine")
    CommentAction = URIRef("https://schema.org/CommentAction")
    supersededBy = URIRef("https://schema.org/supersededBy")
    driveWheelConfiguration = URIRef("https://schema.org/driveWheelConfiguration")
    hasAdultConsideration = URIRef("https://schema.org/hasAdultConsideration")
    hasHealthAspect = URIRef("https://schema.org/hasHealthAspect")
    renegotiableLoan = URIRef("https://schema.org/renegotiableLoan")
    LandmarksOrHistoricalBuildings = URIRef("https://schema.org/LandmarksOrHistoricalBuildings")
    broadcastSubChannel = URIRef("https://schema.org/broadcastSubChannel")
    legislationPassedBy = URIRef("https://schema.org/legislationPassedBy")
    EmploymentAgency = URIRef("https://schema.org/EmploymentAgency")
    accessibilitySummary = URIRef("https://schema.org/accessibilitySummary")
    itemOffered = URIRef("https://schema.org/itemOffered")
    childTaxon = URIRef("https://schema.org/childTaxon")
    DeliveryChargeSpecification = URIRef("https://schema.org/DeliveryChargeSpecification")
    workHours = URIRef("https://schema.org/workHours")
    cvdNumVent = URIRef("https://schema.org/cvdNumVent")
    assesses = URIRef("https://schema.org/assesses")
    WearableSizeSystemUS = URIRef("https://schema.org/WearableSizeSystemUS")
    applicableCountry = URIRef("https://schema.org/applicableCountry")
    legislationPassedBy = URIRef("https://schema.org/legislationPassedBy")
    numberOfFullBathrooms = URIRef("https://schema.org/numberOfFullBathrooms")
    interactingDrug = URIRef("https://schema.org/interactingDrug")
    MonetaryAmountDistribution = URIRef("https://schema.org/MonetaryAmountDistribution")
    ActionAccessSpecification = URIRef("https://schema.org/ActionAccessSpecification")
    dietFeatures = URIRef("https://schema.org/dietFeatures")
    WearableSizeGroupWomens = URIRef("https://schema.org/WearableSizeGroupWomens")
    CurrencyConversionService = URIRef("https://schema.org/CurrencyConversionService")
    DigitalCaptureDigitalSource = URIRef("https://schema.org/DigitalCaptureDigitalSource")
    CompositeSyntheticDigitalSource = URIRef("https://schema.org/CompositeSyntheticDigitalSource")
    hasCertification = URIRef("https://schema.org/hasCertification")
    recognizedBy = URIRef("https://schema.org/recognizedBy")
    bed = URIRef("https://schema.org/bed")
    isRelatedTo = URIRef("https://schema.org/isRelatedTo")
    parents = URIRef("https://schema.org/parents")
    dosageForm = URIRef("https://schema.org/dosageForm")
    permissionType = URIRef("https://schema.org/permissionType")
    PriceSpecification = URIRef("https://schema.org/PriceSpecification")
    EmploymentAgency = URIRef("https://schema.org/EmploymentAgency")
    MerchantReturnUnspecified = URIRef("https://schema.org/MerchantReturnUnspecified")
    MusicStore = URIRef("https://schema.org/MusicStore")
    partOfTrip = URIRef("https://schema.org/partOfTrip")
    maxValue = URIRef("https://schema.org/maxValue")
    Nonprofit501c7 = URIRef("https://schema.org/Nonprofit501c7")
    WantAction = URIRef("https://schema.org/WantAction")
    hasMerchantReturnPolicy = URIRef("https://schema.org/hasMerchantReturnPolicy")
    billingIncrement = URIRef("https://schema.org/billingIncrement")
    boardingPolicy = URIRef("https://schema.org/boardingPolicy")
    CompositeWithTrainedAlgorithmicMediaDigitalSource = URIRef("https://schema.org/CompositeWithTrainedAlgorithmicMediaDigitalSource")
    MulticellularParasite = URIRef("https://schema.org/MulticellularParasite")
    GovernmentService = URIRef("https://schema.org/GovernmentService")
    HealthPlanNetwork = URIRef("https://schema.org/HealthPlanNetwork")
    worstRating = URIRef("https://schema.org/worstRating")
    RelatedTopicsHealthAspect = URIRef("https://schema.org/RelatedTopicsHealthAspect")
    funding = URIRef("https://schema.org/funding")
    SearchRescueOrganization = URIRef("https://schema.org/SearchRescueOrganization")
    cssSelector = URIRef("https://schema.org/cssSelector")
    duration = URIRef("https://schema.org/duration")
    SocialMediaPosting = URIRef("https://schema.org/SocialMediaPosting")
    timeOfDay = URIRef("https://schema.org/timeOfDay")
    MedicalSpecialty = URIRef("https://schema.org/MedicalSpecialty")
    UserInteraction = URIRef("https://schema.org/UserInteraction")
    Energy = URIRef("https://schema.org/Energy")
    LegalForceStatus = URIRef("https://schema.org/LegalForceStatus")
    Skin = URIRef("https://schema.org/Skin")
    includedRiskFactor = URIRef("https://schema.org/includedRiskFactor")
    PlasticSurgery = URIRef("https://schema.org/PlasticSurgery")
    leiCode = URIRef("https://schema.org/leiCode")
    variantCover = URIRef("https://schema.org/variantCover")
    cookTime = URIRef("https://schema.org/cookTime")
    WearableSizeGroupBoys = URIRef("https://schema.org/WearableSizeGroupBoys")
    location = URIRef("https://schema.org/location")
    sampleType = URIRef("https://schema.org/sampleType")
    educationRequirements = URIRef("https://schema.org/educationRequirements")
    sensoryRequirement = URIRef("https://schema.org/sensoryRequirement")
    priceType = URIRef("https://schema.org/priceType")
    specialCommitments = URIRef("https://schema.org/specialCommitments")
    MedicalStudy = URIRef("https://schema.org/MedicalStudy")
    WearableSizeSystemBR = URIRef("https://schema.org/WearableSizeSystemBR")
    eligibilityToWorkRequirement = URIRef("https://schema.org/eligibilityToWorkRequirement")
    ownedFrom = URIRef("https://schema.org/ownedFrom")
    isUnlabelledFallback = URIRef("https://schema.org/isUnlabelledFallback")
    customerRemorseReturnFees = URIRef("https://schema.org/customerRemorseReturnFees")
    organizer = URIRef("https://schema.org/organizer")
    copyrightNotice = URIRef("https://schema.org/copyrightNotice")
    monthlyMinimumRepaymentAmount = URIRef("https://schema.org/monthlyMinimumRepaymentAmount")
    titleEIDR = URIRef("https://schema.org/titleEIDR")
    interpretedAsClaim = URIRef("https://schema.org/interpretedAsClaim")
    AppendAction = URIRef("https://schema.org/AppendAction")
    Vein = URIRef("https://schema.org/Vein")
    hospitalAffiliation = URIRef("https://schema.org/hospitalAffiliation")
    CreativeWorkSeries = URIRef("https://schema.org/CreativeWorkSeries")
    PublicationIssue = URIRef("https://schema.org/PublicationIssue")
    reservationFor = URIRef("https://schema.org/reservationFor")
    WriteAction = URIRef("https://schema.org/WriteAction")
    SelfStorage = URIRef("https://schema.org/SelfStorage")
    inLanguage = URIRef("https://schema.org/inLanguage")
    MusicVenue = URIRef("https://schema.org/MusicVenue")
    accommodationFloorPlan = URIRef("https://schema.org/accommodationFloorPlan")
    PodcastEpisode = URIRef("https://schema.org/PodcastEpisode")
    BodyMeasurementChest = URIRef("https://schema.org/BodyMeasurementChest")
    diversityPolicy = URIRef("https://schema.org/diversityPolicy")
    inPlaylist = URIRef("https://schema.org/inPlaylist")
    cholesterolContent = URIRef("https://schema.org/cholesterolContent")
    step = URIRef("https://schema.org/step")
    biomechnicalClass = URIRef("https://schema.org/biomechnicalClass")
    endDate = URIRef("https://schema.org/endDate")
    isVariantOf = URIRef("https://schema.org/isVariantOf")
    diseasePreventionInfo = URIRef("https://schema.org/diseasePreventionInfo")
    AdvertiserContentArticle = URIRef("https://schema.org/AdvertiserContentArticle")
    AutoRental = URIRef("https://schema.org/AutoRental")
    nonprofitStatus = URIRef("https://schema.org/nonprofitStatus")
    SpeechPathology = URIRef("https://schema.org/SpeechPathology")
    AgreeAction = URIRef("https://schema.org/AgreeAction")
    ReviewAction = URIRef("https://schema.org/ReviewAction")
    GenderType = URIRef("https://schema.org/GenderType")
    GeneralContractor = URIRef("https://schema.org/GeneralContractor")
    FoodEstablishmentReservation = URIRef("https://schema.org/FoodEstablishmentReservation")
    MusicRelease = URIRef("https://schema.org/MusicRelease")
    numberOfEpisodes = URIRef("https://schema.org/numberOfEpisodes")
    parents = URIRef("https://schema.org/parents")
    billingAddress = URIRef("https://schema.org/billingAddress")
    availability = URIRef("https://schema.org/availability")
    MediaManipulationRatingEnumeration = URIRef("https://schema.org/MediaManipulationRatingEnumeration")
    EmployeeRole = URIRef("https://schema.org/EmployeeRole")
    FlightReservation = URIRef("https://schema.org/FlightReservation")
    WearableMeasurementTypeEnumeration = URIRef("https://schema.org/WearableMeasurementTypeEnumeration")
    EventReservation = URIRef("https://schema.org/EventReservation")
    Dataset = URIRef("https://schema.org/Dataset")
    MedicalEvidenceLevel = URIRef("https://schema.org/MedicalEvidenceLevel")
    WPSideBar = URIRef("https://schema.org/WPSideBar")
    ConvenienceStore = URIRef("https://schema.org/ConvenienceStore")
    gameAvailabilityType = URIRef("https://schema.org/gameAvailabilityType")
    creativeWorkStatus = URIRef("https://schema.org/creativeWorkStatus")
    BusinessEntityType = URIRef("https://schema.org/BusinessEntityType")
    DietNutrition = URIRef("https://schema.org/DietNutrition")
    directors = URIRef("https://schema.org/directors")
    DepartmentStore = URIRef("https://schema.org/DepartmentStore")
    Hotel = URIRef("https://schema.org/Hotel")
    BodyMeasurementArm = URIRef("https://schema.org/BodyMeasurementArm")
    Nonprofit501c15 = URIRef("https://schema.org/Nonprofit501c15")
    originAddress = URIRef("https://schema.org/originAddress")
    maxPrice = URIRef("https://schema.org/maxPrice")
    replyToUrl = URIRef("https://schema.org/replyToUrl")
    regionDrained = URIRef("https://schema.org/regionDrained")
    pathophysiology = URIRef("https://schema.org/pathophysiology")
    step = URIRef("https://schema.org/step")
    partOfTVSeries = URIRef("https://schema.org/partOfTVSeries")
    Nonprofit501c28 = URIRef("https://schema.org/Nonprofit501c28")
    propertyID = URIRef("https://schema.org/propertyID")
    BodyMeasurementHead = URIRef("https://schema.org/BodyMeasurementHead")
    PerformanceRole = URIRef("https://schema.org/PerformanceRole")
    WearableSizeSystemContinental = URIRef("https://schema.org/WearableSizeSystemContinental")
    BusinessSupport = URIRef("https://schema.org/BusinessSupport")
    areaServed = URIRef("https://schema.org/areaServed")
    minimumPaymentDue = URIRef("https://schema.org/minimumPaymentDue")
    InvoicePrice = URIRef("https://schema.org/InvoicePrice")
    hasCategoryCode = URIRef("https://schema.org/hasCategoryCode")
    BroadcastService = URIRef("https://schema.org/BroadcastService")
    Nonprofit501c3 = URIRef("https://schema.org/Nonprofit501c3")
    FundingScheme = URIRef("https://schema.org/FundingScheme")
    StadiumOrArena = URIRef("https://schema.org/StadiumOrArena")
    distance = URIRef("https://schema.org/distance")
    Apartment = URIRef("https://schema.org/Apartment")
    AerobicActivity = URIRef("https://schema.org/AerobicActivity")
    departurePlatform = URIRef("https://schema.org/departurePlatform")
    option = URIRef("https://schema.org/option")
    antagonist = URIRef("https://schema.org/antagonist")
    affectedBy = URIRef("https://schema.org/affectedBy")
    healthPlanDrugOption = URIRef("https://schema.org/healthPlanDrugOption")
    eligibleCustomerType = URIRef("https://schema.org/eligibleCustomerType")
    NegativeFilmDigitalSource = URIRef("https://schema.org/NegativeFilmDigitalSource")
    distribution = URIRef("https://schema.org/distribution")
    associatedDisease = URIRef("https://schema.org/associatedDisease")
    HyperTocEntry = URIRef("https://schema.org/HyperTocEntry")
    LegalForceStatus = URIRef("https://schema.org/LegalForceStatus")
    SingleBlindedTrial = URIRef("https://schema.org/SingleBlindedTrial")
    HowToSupply = URIRef("https://schema.org/HowToSupply")
    ReactAction = URIRef("https://schema.org/ReactAction")
    MedicalCondition = URIRef("https://schema.org/MedicalCondition")
    petsAllowed = URIRef("https://schema.org/petsAllowed")
    SeaBodyOfWater = URIRef("https://schema.org/SeaBodyOfWater")
    musicBy = URIRef("https://schema.org/musicBy")
    productGroupID = URIRef("https://schema.org/productGroupID")
    TrackAction = URIRef("https://schema.org/TrackAction")
    actionableFeedbackPolicy = URIRef("https://schema.org/actionableFeedbackPolicy")
    duration = URIRef("https://schema.org/duration")
    maintainer = URIRef("https://schema.org/maintainer")
    fromLocation = URIRef("https://schema.org/fromLocation")
    Taxon = URIRef("https://schema.org/Taxon")
    department = URIRef("https://schema.org/department")
    broadcastDisplayName = URIRef("https://schema.org/broadcastDisplayName")
    includedDataCatalog = URIRef("https://schema.org/includedDataCatalog")
    bookFormat = URIRef("https://schema.org/bookFormat")
    typicalCreditsPerTerm = URIRef("https://schema.org/typicalCreditsPerTerm")
    vehicleInteriorType = URIRef("https://schema.org/vehicleInteriorType")
    MedicalDevicePurpose = URIRef("https://schema.org/MedicalDevicePurpose")
    TouristInformationCenter = URIRef("https://schema.org/TouristInformationCenter")
    endTime = URIRef("https://schema.org/endTime")
    director = URIRef("https://schema.org/director")
    SolveMathAction = URIRef("https://schema.org/SolveMathAction")
    Residence = URIRef("https://schema.org/Residence")
    eligibleRegion = URIRef("https://schema.org/eligibleRegion")
    audience = URIRef("https://schema.org/audience")
    validFor = URIRef("https://schema.org/validFor")
    occupationalCredentialAwarded = URIRef("https://schema.org/occupationalCredentialAwarded")
    audio = URIRef("https://schema.org/audio")
    BusReservation = URIRef("https://schema.org/BusReservation")
    pageStart = URIRef("https://schema.org/pageStart")
    Quantity = URIRef("https://schema.org/Quantity")
    interactingDrug = URIRef("https://schema.org/interactingDrug")
    tissueSample = URIRef("https://schema.org/tissueSample")
    observationPeriod = URIRef("https://schema.org/observationPeriod")
    Pond = URIRef("https://schema.org/Pond")
    QualitativeValue = URIRef("https://schema.org/QualitativeValue")
    bodyType = URIRef("https://schema.org/bodyType")
    OpinionNewsArticle = URIRef("https://schema.org/OpinionNewsArticle")
    additionalProperty = URIRef("https://schema.org/additionalProperty")
    positiveNotes = URIRef("https://schema.org/positiveNotes")
    petsAllowed = URIRef("https://schema.org/petsAllowed")
    HowToItem = URIRef("https://schema.org/HowToItem")
    percentile75 = URIRef("https://schema.org/percentile75")
    video = URIRef("https://schema.org/video")
    MusicComposition = URIRef("https://schema.org/MusicComposition")
    MobileApplication = URIRef("https://schema.org/MobileApplication")
    resultComment = URIRef("https://schema.org/resultComment")
    unnamedSourcesPolicy = URIRef("https://schema.org/unnamedSourcesPolicy")
    Boolean = URIRef("https://schema.org/Boolean")
    postalCodeRange = URIRef("https://schema.org/postalCodeRange")
    Pediatric = URIRef("https://schema.org/Pediatric")
    sharedContent = URIRef("https://schema.org/sharedContent")
    Electrician = URIRef("https://schema.org/Electrician")
    WPAdBlock = URIRef("https://schema.org/WPAdBlock")
    utterances = URIRef("https://schema.org/utterances")
    GovernmentBuilding = URIRef("https://schema.org/GovernmentBuilding")
    inPlaylist = URIRef("https://schema.org/inPlaylist")
    byArtist = URIRef("https://schema.org/byArtist")
    HairSalon = URIRef("https://schema.org/HairSalon")
    LocalBusiness = URIRef("https://schema.org/LocalBusiness")
    cvdNumTotBeds = URIRef("https://schema.org/cvdNumTotBeds")
    category = URIRef("https://schema.org/category")
    WearableSizeGroupPetite = URIRef("https://schema.org/WearableSizeGroupPetite")
    Brand = URIRef("https://schema.org/Brand")
    servesCuisine = URIRef("https://schema.org/servesCuisine")
    DecontextualizedContent = URIRef("https://schema.org/DecontextualizedContent")
    billingDuration = URIRef("https://schema.org/billingDuration")
    boardingPolicy = URIRef("https://schema.org/boardingPolicy")
    seatSection = URIRef("https://schema.org/seatSection")
    typicalAgeRange = URIRef("https://schema.org/typicalAgeRange")
    recipe = URIRef("https://schema.org/recipe")
    recipient = URIRef("https://schema.org/recipient")
    CableOrSatelliteService = URIRef("https://schema.org/CableOrSatelliteService")
    WholesaleStore = URIRef("https://schema.org/WholesaleStore")
    syllabusSections = URIRef("https://schema.org/syllabusSections")
    Room = URIRef("https://schema.org/Room")
    mechanismOfAction = URIRef("https://schema.org/mechanismOfAction")
    address = URIRef("https://schema.org/address")
    CreativeWork = URIRef("https://schema.org/CreativeWork")
    InsertAction = URIRef("https://schema.org/InsertAction")
    Claim = URIRef("https://schema.org/Claim")
    opponent = URIRef("https://schema.org/opponent")
    interactionStatistic = URIRef("https://schema.org/interactionStatistic")
    pathophysiology = URIRef("https://schema.org/pathophysiology")
    healthPlanCopayOption = URIRef("https://schema.org/healthPlanCopayOption")
    discusses = URIRef("https://schema.org/discusses")
    DryCleaningOrLaundry = URIRef("https://schema.org/DryCleaningOrLaundry")
    lowPrice = URIRef("https://schema.org/lowPrice")
    StrengthTraining = URIRef("https://schema.org/StrengthTraining")
    weightTotal = URIRef("https://schema.org/weightTotal")
    recordedAs = URIRef("https://schema.org/recordedAs")
    priceSpecification = URIRef("https://schema.org/priceSpecification")
    numberOfEmployees = URIRef("https://schema.org/numberOfEmployees")
    healthPlanDrugOption = URIRef("https://schema.org/healthPlanDrugOption")
    NotInForce = URIRef("https://schema.org/NotInForce")
    authenticator = URIRef("https://schema.org/authenticator")
    legislationPassedBy = URIRef("https://schema.org/legislationPassedBy")
    targetUrl = URIRef("https://schema.org/targetUrl")
    subEvents = URIRef("https://schema.org/subEvents")
    ShareAction = URIRef("https://schema.org/ShareAction")
    mileageFromOdometer = URIRef("https://schema.org/mileageFromOdometer")
    Nerve = URIRef("https://schema.org/Nerve")
    itinerary = URIRef("https://schema.org/itinerary")
    RisksOrComplicationsHealthAspect = URIRef("https://schema.org/RisksOrComplicationsHealthAspect")
    workHours = URIRef("https://schema.org/workHours")
    usesDevice = URIRef("https://schema.org/usesDevice")
    founders = URIRef("https://schema.org/founders")
    relatedTherapy = URIRef("https://schema.org/relatedTherapy")
    termsPerYear = URIRef("https://schema.org/termsPerYear")
    MerchantReturnEnumeration = URIRef("https://schema.org/MerchantReturnEnumeration")
    valueRequired = URIRef("https://schema.org/valueRequired")
    SearchResultsPage = URIRef("https://schema.org/SearchResultsPage")
    NGO = URIRef("https://schema.org/NGO")
    Pond = URIRef("https://schema.org/Pond")
    downPayment = URIRef("https://schema.org/downPayment")
    physicalRequirement = URIRef("https://schema.org/physicalRequirement")
    employees = URIRef("https://schema.org/employees")
    MedicalEvidenceLevel = URIRef("https://schema.org/MedicalEvidenceLevel")
    lyrics = URIRef("https://schema.org/lyrics")
    DiagnosticLab = URIRef("https://schema.org/DiagnosticLab")
    copyrightYear = URIRef("https://schema.org/copyrightYear")
    assesses = URIRef("https://schema.org/assesses")
    ConstraintNode = URIRef("https://schema.org/ConstraintNode")
    UpdateAction = URIRef("https://schema.org/UpdateAction")
    TrainStation = URIRef("https://schema.org/TrainStation")
    applicationContact = URIRef("https://schema.org/applicationContact")
    MedicalSign = URIRef("https://schema.org/MedicalSign")
    diseasePreventionInfo = URIRef("https://schema.org/diseasePreventionInfo")
    hasMenu = URIRef("https://schema.org/hasMenu")
    AMRadioChannel = URIRef("https://schema.org/AMRadioChannel")
    backstory = URIRef("https://schema.org/backstory")
    CategoryCodeSet = URIRef("https://schema.org/CategoryCodeSet")
    RefurbishedCondition = URIRef("https://schema.org/RefurbishedCondition")
    legislationType = URIRef("https://schema.org/legislationType")
    negativeNotes = URIRef("https://schema.org/negativeNotes")
    dateline = URIRef("https://schema.org/dateline")
    warrantyScope = URIRef("https://schema.org/warrantyScope")
    equal = URIRef("https://schema.org/equal")
    ReturnMethodEnumeration = URIRef("https://schema.org/ReturnMethodEnumeration")
    yearBuilt = URIRef("https://schema.org/yearBuilt")
    ReplyAction = URIRef("https://schema.org/ReplyAction")
    resultReview = URIRef("https://schema.org/resultReview")
    CategoryCode = URIRef("https://schema.org/CategoryCode")
    AggregateRating = URIRef("https://schema.org/AggregateRating")
    SingleBlindedTrial = URIRef("https://schema.org/SingleBlindedTrial")
    transitTime = URIRef("https://schema.org/transitTime")
    embeddedTextCaption = URIRef("https://schema.org/embeddedTextCaption")
    serviceSmsNumber = URIRef("https://schema.org/serviceSmsNumber")
    ccRecipient = URIRef("https://schema.org/ccRecipient")
    diversityPolicy = URIRef("https://schema.org/diversityPolicy")
    publisher = URIRef("https://schema.org/publisher")
    includesHealthPlanFormulary = URIRef("https://schema.org/includesHealthPlanFormulary")
    Protein = URIRef("https://schema.org/Protein")
    InteractionCounter = URIRef("https://schema.org/InteractionCounter")
    securityClearanceRequirement = URIRef("https://schema.org/securityClearanceRequirement")
    itemLocation = URIRef("https://schema.org/itemLocation")
    ineligibleRegion = URIRef("https://schema.org/ineligibleRegion")
    HowOrWhereHealthAspect = URIRef("https://schema.org/HowOrWhereHealthAspect")
    musicBy = URIRef("https://schema.org/musicBy")
    RandomizedTrial = URIRef("https://schema.org/RandomizedTrial")
    containedIn = URIRef("https://schema.org/containedIn")
    activityDuration = URIRef("https://schema.org/activityDuration")
    QualitativeValue = URIRef("https://schema.org/QualitativeValue")
    GeospatialGeometry = URIRef("https://schema.org/GeospatialGeometry")
    GolfCourse = URIRef("https://schema.org/GolfCourse")
    BusReservation = URIRef("https://schema.org/BusReservation")
    infectiousAgentClass = URIRef("https://schema.org/infectiousAgentClass")
    ExchangeRateSpecification = URIRef("https://schema.org/ExchangeRateSpecification")
    speechToTextMarkup = URIRef("https://schema.org/speechToTextMarkup")
    quest = URIRef("https://schema.org/quest")
    roofLoad = URIRef("https://schema.org/roofLoad")
    eventStatus = URIRef("https://schema.org/eventStatus")
    course = URIRef("https://schema.org/course")
    sugarContent = URIRef("https://schema.org/sugarContent")
    duringMedia = URIRef("https://schema.org/duringMedia")
    category = URIRef("https://schema.org/category")
    isVariantOf = URIRef("https://schema.org/isVariantOf")
    keywords = URIRef("https://schema.org/keywords")
    translator = URIRef("https://schema.org/translator")
    jobStartDate = URIRef("https://schema.org/jobStartDate")
    UserDownloads = URIRef("https://schema.org/UserDownloads")
    MedicalDevice = URIRef("https://schema.org/MedicalDevice")
    downloadUrl = URIRef("https://schema.org/downloadUrl")
    MusicReleaseFormatType = URIRef("https://schema.org/MusicReleaseFormatType")
    MedicalSpecialty = URIRef("https://schema.org/MedicalSpecialty")
    CafeOrCoffeeShop = URIRef("https://schema.org/CafeOrCoffeeShop")
    expressedIn = URIRef("https://schema.org/expressedIn")
    grantee = URIRef("https://schema.org/grantee")
    correction = URIRef("https://schema.org/correction")
    Observational = URIRef("https://schema.org/Observational")
    appearance = URIRef("https://schema.org/appearance")
    AllergiesHealthAspect = URIRef("https://schema.org/AllergiesHealthAspect")
    featureList = URIRef("https://schema.org/featureList")
    Terminated = URIRef("https://schema.org/Terminated")
    actors = URIRef("https://schema.org/actors")
    Otolaryngologic = URIRef("https://schema.org/Otolaryngologic")
    GeoShape = URIRef("https://schema.org/GeoShape")
    DrugCostCategory = URIRef("https://schema.org/DrugCostCategory")
    issn = URIRef("https://schema.org/issn")
    translator = URIRef("https://schema.org/translator")
    ComputerStore = URIRef("https://schema.org/ComputerStore")
    byMonthWeek = URIRef("https://schema.org/byMonthWeek")
    occupationalCategory = URIRef("https://schema.org/occupationalCategory")
    healthPlanCoinsuranceRate = URIRef("https://schema.org/healthPlanCoinsuranceRate")
    MedicalRiskScore = URIRef("https://schema.org/MedicalRiskScore")
    inBroadcastLineup = URIRef("https://schema.org/inBroadcastLineup")
    itemDefectReturnShippingFeesAmount = URIRef("https://schema.org/itemDefectReturnShippingFeesAmount")
    hasMeasurement = URIRef("https://schema.org/hasMeasurement")
    PositiveFilmDigitalSource = URIRef("https://schema.org/PositiveFilmDigitalSource")
    DayOfWeek = URIRef("https://schema.org/DayOfWeek")
    ReturnLabelInBox = URIRef("https://schema.org/ReturnLabelInBox")
    WearableSizeSystemJP = URIRef("https://schema.org/WearableSizeSystemJP")
    ActivateAction = URIRef("https://schema.org/ActivateAction")
    OpinionNewsArticle = URIRef("https://schema.org/OpinionNewsArticle")
    DrawAction = URIRef("https://schema.org/DrawAction")
    BuyAction = URIRef("https://schema.org/BuyAction")
    UserReview = URIRef("https://schema.org/UserReview")
    CheckAction = URIRef("https://schema.org/CheckAction")
    PoliticalParty = URIRef("https://schema.org/PoliticalParty")
    inker = URIRef("https://schema.org/inker")
    programmingLanguage = URIRef("https://schema.org/programmingLanguage")
    HowToDirection = URIRef("https://schema.org/HowToDirection")
    LeftHandDriving = URIRef("https://schema.org/LeftHandDriving")
    address = URIRef("https://schema.org/address")
    vehicleTransmission = URIRef("https://schema.org/vehicleTransmission")
    inCodeSet = URIRef("https://schema.org/inCodeSet")
    valueReference = URIRef("https://schema.org/valueReference")
    specialty = URIRef("https://schema.org/specialty")
    transitTimeLabel = URIRef("https://schema.org/transitTimeLabel")
    HowTo = URIRef("https://schema.org/HowTo")
    productionCompany = URIRef("https://schema.org/productionCompany")
    billingAddress = URIRef("https://schema.org/billingAddress")
    eligibleCustomerType = URIRef("https://schema.org/eligibleCustomerType")
    BookFormatType = URIRef("https://schema.org/BookFormatType")
    servingSize = URIRef("https://schema.org/servingSize")
    musicalKey = URIRef("https://schema.org/musicalKey")
    eventAttendanceMode = URIRef("https://schema.org/eventAttendanceMode")
    WearableSizeGroupBig = URIRef("https://schema.org/WearableSizeGroupBig")
    Suite = URIRef("https://schema.org/Suite")
    tickerSymbol = URIRef("https://schema.org/tickerSymbol")
    StadiumOrArena = URIRef("https://schema.org/StadiumOrArena")
    locationCreated = URIRef("https://schema.org/locationCreated")
    shippingDestination = URIRef("https://schema.org/shippingDestination")
    nonProprietaryName = URIRef("https://schema.org/nonProprietaryName")
    smiles = URIRef("https://schema.org/smiles")
    containsSeason = URIRef("https://schema.org/containsSeason")
    colleague = URIRef("https://schema.org/colleague")
    MedicalDevice = URIRef("https://schema.org/MedicalDevice")
    DriveWheelConfigurationValue = URIRef("https://schema.org/DriveWheelConfigurationValue")
    eligibleTransactionVolume = URIRef("https://schema.org/eligibleTransactionVolume")
    loanPaymentFrequency = URIRef("https://schema.org/loanPaymentFrequency")
    releaseOf = URIRef("https://schema.org/releaseOf")
    experienceInPlaceOfEducation = URIRef("https://schema.org/experienceInPlaceOfEducation")
    countriesNotSupported = URIRef("https://schema.org/countriesNotSupported")
    broadcastAffiliateOf = URIRef("https://schema.org/broadcastAffiliateOf")
    abstract = URIRef("https://schema.org/abstract")
    countryOfAssembly = URIRef("https://schema.org/countryOfAssembly")
    drainsTo = URIRef("https://schema.org/drainsTo")
    transitTimeLabel = URIRef("https://schema.org/transitTimeLabel")
    TaxiReservation = URIRef("https://schema.org/TaxiReservation")
    option = URIRef("https://schema.org/option")
    Guide = URIRef("https://schema.org/Guide")
    TipAction = URIRef("https://schema.org/TipAction")
    SoldOut = URIRef("https://schema.org/SoldOut")
    holdingArchive = URIRef("https://schema.org/holdingArchive")
    Patient = URIRef("https://schema.org/Patient")
    funding = URIRef("https://schema.org/funding")
    travelBans = URIRef("https://schema.org/travelBans")
    TipAction = URIRef("https://schema.org/TipAction")
    loanTerm = URIRef("https://schema.org/loanTerm")
    creator = URIRef("https://schema.org/creator")
    Apartment = URIRef("https://schema.org/Apartment")
    DeleteAction = URIRef("https://schema.org/DeleteAction")
    OfficialLegalValue = URIRef("https://schema.org/OfficialLegalValue")
    variantCover = URIRef("https://schema.org/variantCover")
    ProductCollection = URIRef("https://schema.org/ProductCollection")
    offers = URIRef("https://schema.org/offers")
    encodingFormat = URIRef("https://schema.org/encodingFormat")
    subtitleLanguage = URIRef("https://schema.org/subtitleLanguage")
    ListenAction = URIRef("https://schema.org/ListenAction")
    titleEIDR = URIRef("https://schema.org/titleEIDR")
    Homeopathic = URIRef("https://schema.org/Homeopathic")
    timeToComplete = URIRef("https://schema.org/timeToComplete")
    MensClothingStore = URIRef("https://schema.org/MensClothingStore")
    branchOf = URIRef("https://schema.org/branchOf")
    language = URIRef("https://schema.org/language")
    WearableSizeGroupTall = URIRef("https://schema.org/WearableSizeGroupTall")
    legislationLegalForce = URIRef("https://schema.org/legislationLegalForce")
    Occupation = URIRef("https://schema.org/Occupation")
    inSupportOf = URIRef("https://schema.org/inSupportOf")
    temporalCoverage = URIRef("https://schema.org/temporalCoverage")
    shippingLabel = URIRef("https://schema.org/shippingLabel")
    AudioObject = URIRef("https://schema.org/AudioObject")
    contributor = URIRef("https://schema.org/contributor")
    priceCurrency = URIRef("https://schema.org/priceCurrency")
    educationalLevel = URIRef("https://schema.org/educationalLevel")
    FundingScheme = URIRef("https://schema.org/FundingScheme")
    educationalUse = URIRef("https://schema.org/educationalUse")
    endorsers = URIRef("https://schema.org/endorsers")
    SaleEvent = URIRef("https://schema.org/SaleEvent")
    RealEstateListing = URIRef("https://schema.org/RealEstateListing")
    afterMedia = URIRef("https://schema.org/afterMedia")
    maintainer = URIRef("https://schema.org/maintainer")
    UserPlusOnes = URIRef("https://schema.org/UserPlusOnes")
    diseaseSpreadStatistics = URIRef("https://schema.org/diseaseSpreadStatistics")
    partOfTVSeries = URIRef("https://schema.org/partOfTVSeries")
    subOrganization = URIRef("https://schema.org/subOrganization")
    healthPlanCopay = URIRef("https://schema.org/healthPlanCopay")
    increasesRiskOf = URIRef("https://schema.org/increasesRiskOf")
    reviews = URIRef("https://schema.org/reviews")
    ComputerLanguage = URIRef("https://schema.org/ComputerLanguage")
    familyName = URIRef("https://schema.org/familyName")
    legislationJurisdiction = URIRef("https://schema.org/legislationJurisdiction")
    Project = URIRef("https://schema.org/Project")
    language = URIRef("https://schema.org/language")
    PhysicalTherapy = URIRef("https://schema.org/PhysicalTherapy")
    Nonprofit501c8 = URIRef("https://schema.org/Nonprofit501c8")
    AuthoritativeLegalValue = URIRef("https://schema.org/AuthoritativeLegalValue")
    warning = URIRef("https://schema.org/warning")
    cookTime = URIRef("https://schema.org/cookTime")
    minimumPaymentDue = URIRef("https://schema.org/minimumPaymentDue")
    FoodEstablishment = URIRef("https://schema.org/FoodEstablishment")
    serverStatus = URIRef("https://schema.org/serverStatus")
    FundingScheme = URIRef("https://schema.org/FundingScheme")
    pickupTime = URIRef("https://schema.org/pickupTime")
    citation = URIRef("https://schema.org/citation")
    Painting = URIRef("https://schema.org/Painting")
    serviceLocation = URIRef("https://schema.org/serviceLocation")
    trainingSalary = URIRef("https://schema.org/trainingSalary")
    UserBlocks = URIRef("https://schema.org/UserBlocks")
    GovernmentService = URIRef("https://schema.org/GovernmentService")
    coursePrerequisites = URIRef("https://schema.org/coursePrerequisites")
    slogan = URIRef("https://schema.org/slogan")
    tocEntry = URIRef("https://schema.org/tocEntry")
    mainEntity = URIRef("https://schema.org/mainEntity")
    EditedOrCroppedContent = URIRef("https://schema.org/EditedOrCroppedContent")
    Legislation = URIRef("https://schema.org/Legislation")
    events = URIRef("https://schema.org/events")
    loanRepaymentForm = URIRef("https://schema.org/loanRepaymentForm")
    illustrator = URIRef("https://schema.org/illustrator")
    molecularWeight = URIRef("https://schema.org/molecularWeight")
    additionalProperty = URIRef("https://schema.org/additionalProperty")
    orderQuantity = URIRef("https://schema.org/orderQuantity")
    minValue = URIRef("https://schema.org/minValue")
    subEvents = URIRef("https://schema.org/subEvents")
    energyEfficiencyScaleMax = URIRef("https://schema.org/energyEfficiencyScaleMax")
    exerciseCourse = URIRef("https://schema.org/exerciseCourse")
    occupationalCategory = URIRef("https://schema.org/occupationalCategory")
    answerExplanation = URIRef("https://schema.org/answerExplanation")
    EvidenceLevelB = URIRef("https://schema.org/EvidenceLevelB")
    commentTime = URIRef("https://schema.org/commentTime")
    monoisotopicMolecularWeight = URIRef("https://schema.org/monoisotopicMolecularWeight")
    targetProduct = URIRef("https://schema.org/targetProduct")
    validFrom = URIRef("https://schema.org/validFrom")
    governmentBenefitsInfo = URIRef("https://schema.org/governmentBenefitsInfo")
    Pharmacy = URIRef("https://schema.org/Pharmacy")
    webFeed = URIRef("https://schema.org/webFeed")
    SearchAction = URIRef("https://schema.org/SearchAction")
    structuralClass = URIRef("https://schema.org/structuralClass")
    downPayment = URIRef("https://schema.org/downPayment")
    softwareHelp = URIRef("https://schema.org/softwareHelp")
    serialNumber = URIRef("https://schema.org/serialNumber")
    subStructure = URIRef("https://schema.org/subStructure")
    differentialDiagnosis = URIRef("https://schema.org/differentialDiagnosis")
    XPathType = URIRef("https://schema.org/XPathType")
    text = URIRef("https://schema.org/text")
    ListItem = URIRef("https://schema.org/ListItem")
    DrinkAction = URIRef("https://schema.org/DrinkAction")
    ParkingFacility = URIRef("https://schema.org/ParkingFacility")
    shippingRate = URIRef("https://schema.org/shippingRate")
    AuthoritativeLegalValue = URIRef("https://schema.org/AuthoritativeLegalValue")
    numberOfPreviousOwners = URIRef("https://schema.org/numberOfPreviousOwners")
    courseSchedule = URIRef("https://schema.org/courseSchedule")
    circle = URIRef("https://schema.org/circle")
    unitCode = URIRef("https://schema.org/unitCode")
    EUEnergyEfficiencyCategoryA2Plus = URIRef("https://schema.org/EUEnergyEfficiencyCategoryA2Plus")
    ExercisePlan = URIRef("https://schema.org/ExercisePlan")
    HowOrWhereHealthAspect = URIRef("https://schema.org/HowOrWhereHealthAspect")
    associatedAnatomy = URIRef("https://schema.org/associatedAnatomy")
    CoOp = URIRef("https://schema.org/CoOp")
    countriesNotSupported = URIRef("https://schema.org/countriesNotSupported")
    exchangeRateSpread = URIRef("https://schema.org/exchangeRateSpread")
    NarcoticConsideration = URIRef("https://schema.org/NarcoticConsideration")
    serviceOutput = URIRef("https://schema.org/serviceOutput")
    MovieSeries = URIRef("https://schema.org/MovieSeries")
    bodyType = URIRef("https://schema.org/bodyType")
    TravelAgency = URIRef("https://schema.org/TravelAgency")
    Message = URIRef("https://schema.org/Message")
    measurementDenominator = URIRef("https://schema.org/measurementDenominator")
    ServiceChannel = URIRef("https://schema.org/ServiceChannel")
    WearableMeasurementTypeEnumeration = URIRef("https://schema.org/WearableMeasurementTypeEnumeration")
    MedicalGuideline = URIRef("https://schema.org/MedicalGuideline")
    CollectionPage = URIRef("https://schema.org/CollectionPage")
    SingleFamilyResidence = URIRef("https://schema.org/SingleFamilyResidence")
    vatID = URIRef("https://schema.org/vatID")
    member = URIRef("https://schema.org/member")
    beneficiaryBank = URIRef("https://schema.org/beneficiaryBank")
    Painting = URIRef("https://schema.org/Painting")
    TravelAgency = URIRef("https://schema.org/TravelAgency")
    issuedThrough = URIRef("https://schema.org/issuedThrough")
    eligibleQuantity = URIRef("https://schema.org/eligibleQuantity")
    TieAction = URIRef("https://schema.org/TieAction")
    DangerousGoodConsideration = URIRef("https://schema.org/DangerousGoodConsideration")
    productGroupID = URIRef("https://schema.org/productGroupID")
    knowsAbout = URIRef("https://schema.org/knowsAbout")
    cvdNumICUBeds = URIRef("https://schema.org/cvdNumICUBeds")
    labelDetails = URIRef("https://schema.org/labelDetails")
    ReturnAction = URIRef("https://schema.org/ReturnAction")
    byMonthDay = URIRef("https://schema.org/byMonthDay")
    WebSite = URIRef("https://schema.org/WebSite")
    Dermatologic = URIRef("https://schema.org/Dermatologic")
    secondaryPrevention = URIRef("https://schema.org/secondaryPrevention")
    contactPoint = URIRef("https://schema.org/contactPoint")
    GamePlayMode = URIRef("https://schema.org/GamePlayMode")
    game = URIRef("https://schema.org/game")
    seasonNumber = URIRef("https://schema.org/seasonNumber")
    videoFrameSize = URIRef("https://schema.org/videoFrameSize")
    energyEfficiencyScaleMin = URIRef("https://schema.org/energyEfficiencyScaleMin")
    vehicleSeatingCapacity = URIRef("https://schema.org/vehicleSeatingCapacity")
    measurementTechnique = URIRef("https://schema.org/measurementTechnique")
    skills = URIRef("https://schema.org/skills")
    BodyMeasurementFoot = URIRef("https://schema.org/BodyMeasurementFoot")
    reviews = URIRef("https://schema.org/reviews")
    sdPublisher = URIRef("https://schema.org/sdPublisher")
    variesBy = URIRef("https://schema.org/variesBy")
    Courthouse = URIRef("https://schema.org/Courthouse")
    archivedAt = URIRef("https://schema.org/archivedAt")
    LegalService = URIRef("https://schema.org/LegalService")
    Nonprofit501c4 = URIRef("https://schema.org/Nonprofit501c4")
    AlgorithmicallyEnhancedDigitalSource = URIRef("https://schema.org/AlgorithmicallyEnhancedDigitalSource")
    MusculoskeletalExam = URIRef("https://schema.org/MusculoskeletalExam")
    FreeReturn = URIRef("https://schema.org/FreeReturn")
    postalCodePrefix = URIRef("https://schema.org/postalCodePrefix")
    valueMinLength = URIRef("https://schema.org/valueMinLength")
    cashBack = URIRef("https://schema.org/cashBack")
    containedInPlace = URIRef("https://schema.org/containedInPlace")
    freeShippingThreshold = URIRef("https://schema.org/freeShippingThreshold")
    ComicCoverArt = URIRef("https://schema.org/ComicCoverArt")
    targetPopulation = URIRef("https://schema.org/targetPopulation")
    programPrerequisites = URIRef("https://schema.org/programPrerequisites")
    OpinionNewsArticle = URIRef("https://schema.org/OpinionNewsArticle")
    subTrip = URIRef("https://schema.org/subTrip")
    pickupTime = URIRef("https://schema.org/pickupTime")
    maxValue = URIRef("https://schema.org/maxValue")
    MedicalScholarlyArticle = URIRef("https://schema.org/MedicalScholarlyArticle")
    InteractAction = URIRef("https://schema.org/InteractAction")
    CityHall = URIRef("https://schema.org/CityHall")
    Season = URIRef("https://schema.org/Season")
    Embassy = URIRef("https://schema.org/Embassy")
    digitalSourceType = URIRef("https://schema.org/digitalSourceType")
    about = URIRef("https://schema.org/about")
    expectedArrivalUntil = URIRef("https://schema.org/expectedArrivalUntil")
    gtin13 = URIRef("https://schema.org/gtin13")
    AcceptAction = URIRef("https://schema.org/AcceptAction")
    recipe = URIRef("https://schema.org/recipe")
    GovernmentBuilding = URIRef("https://schema.org/GovernmentBuilding")
    MerchantReturnFiniteReturnWindow = URIRef("https://schema.org/MerchantReturnFiniteReturnWindow")
    AllergiesHealthAspect = URIRef("https://schema.org/AllergiesHealthAspect")
    securityScreening = URIRef("https://schema.org/securityScreening")
    recipeCuisine = URIRef("https://schema.org/recipeCuisine")
    BusOrCoach = URIRef("https://schema.org/BusOrCoach")
    maximumAttendeeCapacity = URIRef("https://schema.org/maximumAttendeeCapacity")
    location = URIRef("https://schema.org/location")
    totalPrice = URIRef("https://schema.org/totalPrice")
    SelfStorage = URIRef("https://schema.org/SelfStorage")
    makesOffer = URIRef("https://schema.org/makesOffer")
    Emergency = URIRef("https://schema.org/Emergency")
    AuthoritativeLegalValue = URIRef("https://schema.org/AuthoritativeLegalValue")
    ParkingMap = URIRef("https://schema.org/ParkingMap")
    text = URIRef("https://schema.org/text")
    headline = URIRef("https://schema.org/headline")
    DJMixAlbum = URIRef("https://schema.org/DJMixAlbum")
    jobStartDate = URIRef("https://schema.org/jobStartDate")
    Wednesday = URIRef("https://schema.org/Wednesday")
    albums = URIRef("https://schema.org/albums")
    knowsLanguage = URIRef("https://schema.org/knowsLanguage")
    sodiumContent = URIRef("https://schema.org/sodiumContent")
    numberOfBedrooms = URIRef("https://schema.org/numberOfBedrooms")
    cvdNumC19HospPats = URIRef("https://schema.org/cvdNumC19HospPats")
    originatesFrom = URIRef("https://schema.org/originatesFrom")
    eligibleRegion = URIRef("https://schema.org/eligibleRegion")
    includedInDataCatalog = URIRef("https://schema.org/includedInDataCatalog")
    beforeMedia = URIRef("https://schema.org/beforeMedia")
    MeasurementTypeEnumeration = URIRef("https://schema.org/MeasurementTypeEnumeration")
    programMembershipUsed = URIRef("https://schema.org/programMembershipUsed")
    slogan = URIRef("https://schema.org/slogan")
    location = URIRef("https://schema.org/location")
    DefinedTermSet = URIRef("https://schema.org/DefinedTermSet")
    sku = URIRef("https://schema.org/sku")
    PalliativeProcedure = URIRef("https://schema.org/PalliativeProcedure")
    cssSelector = URIRef("https://schema.org/cssSelector")
    merchant = URIRef("https://schema.org/merchant")
    Aquarium = URIRef("https://schema.org/Aquarium")
    Play = URIRef("https://schema.org/Play")
    termCode = URIRef("https://schema.org/termCode")
    MedicalIntangible = URIRef("https://schema.org/MedicalIntangible")
    ReservationStatusType = URIRef("https://schema.org/ReservationStatusType")
    numberOfAvailableAccommodationUnits = URIRef("https://schema.org/numberOfAvailableAccommodationUnits")
    numberOfLoanPayments = URIRef("https://schema.org/numberOfLoanPayments")
    geoCovers = URIRef("https://schema.org/geoCovers")
    DefinedTermSet = URIRef("https://schema.org/DefinedTermSet")
    Resort = URIRef("https://schema.org/Resort")
    BodyMeasurementBust = URIRef("https://schema.org/BodyMeasurementBust")
    BackgroundNewsArticle = URIRef("https://schema.org/BackgroundNewsArticle")
    sender = URIRef("https://schema.org/sender")
    PostOffice = URIRef("https://schema.org/PostOffice")
    WearableSizeGroupMisses = URIRef("https://schema.org/WearableSizeGroupMisses")
    observationPeriod = URIRef("https://schema.org/observationPeriod")
    AskAction = URIRef("https://schema.org/AskAction")
    securityScreening = URIRef("https://schema.org/securityScreening")
    orderNumber = URIRef("https://schema.org/orderNumber")
    Play = URIRef("https://schema.org/Play")
    leiCode = URIRef("https://schema.org/leiCode")
    Legislation = URIRef("https://schema.org/Legislation")
    awards = URIRef("https://schema.org/awards")
    slogan = URIRef("https://schema.org/slogan")
    Article = URIRef("https://schema.org/Article")
    Clinician = URIRef("https://schema.org/Clinician")
    healthcareReportingData = URIRef("https://schema.org/healthcareReportingData")
    free = URIRef("https://schema.org/free")
    jobImmediateStart = URIRef("https://schema.org/jobImmediateStart")
    worksFor = URIRef("https://schema.org/worksFor")
    sensoryUnit = URIRef("https://schema.org/sensoryUnit")
    Prion = URIRef("https://schema.org/Prion")
    BodyMeasurementHead = URIRef("https://schema.org/BodyMeasurementHead")
    EmployeeRole = URIRef("https://schema.org/EmployeeRole")
    LearningResource = URIRef("https://schema.org/LearningResource")
    FilmAction = URIRef("https://schema.org/FilmAction")
    broadcastServiceTier = URIRef("https://schema.org/broadcastServiceTier")
    Collection = URIRef("https://schema.org/Collection")
    healthPlanMarketingUrl = URIRef("https://schema.org/healthPlanMarketingUrl")
    subtitleLanguage = URIRef("https://schema.org/subtitleLanguage")
    ComicStory = URIRef("https://schema.org/ComicStory")
    MedicalStudy = URIRef("https://schema.org/MedicalStudy")
    isInvolvedInBiologicalProcess = URIRef("https://schema.org/isInvolvedInBiologicalProcess")
    Bacteria = URIRef("https://schema.org/Bacteria")
    Midwifery = URIRef("https://schema.org/Midwifery")
    GlutenFreeDiet = URIRef("https://schema.org/GlutenFreeDiet")
    doseValue = URIRef("https://schema.org/doseValue")
    description = URIRef("https://schema.org/description")
    recipient = URIRef("https://schema.org/recipient")
    certificationStatus = URIRef("https://schema.org/certificationStatus")
    albums = URIRef("https://schema.org/albums")
    claimReviewed = URIRef("https://schema.org/claimReviewed")
    QAPage = URIRef("https://schema.org/QAPage")
    ReturnLabelInBox = URIRef("https://schema.org/ReturnLabelInBox")
    MedicalIndication = URIRef("https://schema.org/MedicalIndication")
    legislationLegalForce = URIRef("https://schema.org/legislationLegalForce")
    partOfSeason = URIRef("https://schema.org/partOfSeason")
    RealEstateListing = URIRef("https://schema.org/RealEstateListing")
    Geriatric = URIRef("https://schema.org/Geriatric")
    educationRequirements = URIRef("https://schema.org/educationRequirements")
    ticketToken = URIRef("https://schema.org/ticketToken")
    TrainStation = URIRef("https://schema.org/TrainStation")
    CovidTestingFacility = URIRef("https://schema.org/CovidTestingFacility")
    validThrough = URIRef("https://schema.org/validThrough")
    orderDate = URIRef("https://schema.org/orderDate")
    Room = URIRef("https://schema.org/Room")
    relatedLink = URIRef("https://schema.org/relatedLink")
    PublicationIssue = URIRef("https://schema.org/PublicationIssue")
    vehicleIdentificationNumber = URIRef("https://schema.org/vehicleIdentificationNumber")
    maxPrice = URIRef("https://schema.org/maxPrice")
    programName = URIRef("https://schema.org/programName")
    sibling = URIRef("https://schema.org/sibling")
    productSupported = URIRef("https://schema.org/productSupported")
    InfectiousDisease = URIRef("https://schema.org/InfectiousDisease")
    greater = URIRef("https://schema.org/greater")
    subOrganization = URIRef("https://schema.org/subOrganization")
    encodingFormat = URIRef("https://schema.org/encodingFormat")
    validIn = URIRef("https://schema.org/validIn")
    BusinessEvent = URIRef("https://schema.org/BusinessEvent")
    Landform = URIRef("https://schema.org/Landform")
    ReportedDoseSchedule = URIRef("https://schema.org/ReportedDoseSchedule")
    GenderType = URIRef("https://schema.org/GenderType")
    SiteNavigationElement = URIRef("https://schema.org/SiteNavigationElement")
    accessibilitySummary = URIRef("https://schema.org/accessibilitySummary")
    passengerPriorityStatus = URIRef("https://schema.org/passengerPriorityStatus")
    ineligibleRegion = URIRef("https://schema.org/ineligibleRegion")
    Saturday = URIRef("https://schema.org/Saturday")
    InfectiousAgentClass = URIRef("https://schema.org/InfectiousAgentClass")
    significantLinks = URIRef("https://schema.org/significantLinks")
    clinicalPharmacology = URIRef("https://schema.org/clinicalPharmacology")
    Urologic = URIRef("https://schema.org/Urologic")
    LegislationObject = URIRef("https://schema.org/LegislationObject")
    Action = URIRef("https://schema.org/Action")
    MusicAlbum = URIRef("https://schema.org/MusicAlbum")
    AlgorithmicMediaDigitalSource = URIRef("https://schema.org/AlgorithmicMediaDigitalSource")
    educationalLevel = URIRef("https://schema.org/educationalLevel")
    SizeSystemMetric = URIRef("https://schema.org/SizeSystemMetric")
    version = URIRef("https://schema.org/version")
    exceptDate = URIRef("https://schema.org/exceptDate")
    currency = URIRef("https://schema.org/currency")
    associatedAnatomy = URIRef("https://schema.org/associatedAnatomy")
    durationOfWarranty = URIRef("https://schema.org/durationOfWarranty")
    itemListElement = URIRef("https://schema.org/itemListElement")
    EventMovedOnline = URIRef("https://schema.org/EventMovedOnline")
    credentialCategory = URIRef("https://schema.org/credentialCategory")
    BrokerageAccount = URIRef("https://schema.org/BrokerageAccount")
    PhysicalActivityCategory = URIRef("https://schema.org/PhysicalActivityCategory")
    tourBookingPage = URIRef("https://schema.org/tourBookingPage")
    hasAdultConsideration = URIRef("https://schema.org/hasAdultConsideration")
    DayOfWeek = URIRef("https://schema.org/DayOfWeek")
    wheelbase = URIRef("https://schema.org/wheelbase")
    doseUnit = URIRef("https://schema.org/doseUnit")
    NonprofitType = URIRef("https://schema.org/NonprofitType")
    relatedAnatomy = URIRef("https://schema.org/relatedAnatomy")
    CompleteDataFeed = URIRef("https://schema.org/CompleteDataFeed")
    UsedCondition = URIRef("https://schema.org/UsedCondition")
    colorSwatch = URIRef("https://schema.org/colorSwatch")
    DriveWheelConfigurationValue = URIRef("https://schema.org/DriveWheelConfigurationValue")
    artworkSurface = URIRef("https://schema.org/artworkSurface")
    InteractionCounter = URIRef("https://schema.org/InteractionCounter")
    AudioObjectSnapshot = URIRef("https://schema.org/AudioObjectSnapshot")
    lowPrice = URIRef("https://schema.org/lowPrice")
    alcoholWarning = URIRef("https://schema.org/alcoholWarning")
    Electrician = URIRef("https://schema.org/Electrician")
    domiciledMortgage = URIRef("https://schema.org/domiciledMortgage")
    mainContentOfPage = URIRef("https://schema.org/mainContentOfPage")
    StagesHealthAspect = URIRef("https://schema.org/StagesHealthAspect")
    numberOfForwardGears = URIRef("https://schema.org/numberOfForwardGears")
    disambiguatingDescription = URIRef("https://schema.org/disambiguatingDescription")
    parentTaxon = URIRef("https://schema.org/parentTaxon")
    Nonprofit501c6 = URIRef("https://schema.org/Nonprofit501c6")
    includesHealthPlanFormulary = URIRef("https://schema.org/includesHealthPlanFormulary")
    LodgingBusiness = URIRef("https://schema.org/LodgingBusiness")
    parentTaxon = URIRef("https://schema.org/parentTaxon")
    WearableSizeSystemIT = URIRef("https://schema.org/WearableSizeSystemIT")
    PriceSpecification = URIRef("https://schema.org/PriceSpecification")
    WearableSizeSystemJP = URIRef("https://schema.org/WearableSizeSystemJP")
    valueReference = URIRef("https://schema.org/valueReference")
    QuantitativeValueDistribution = URIRef("https://schema.org/QuantitativeValueDistribution")
    VisualArtsEvent = URIRef("https://schema.org/VisualArtsEvent")
    billingStart = URIRef("https://schema.org/billingStart")
    MonetaryAmount = URIRef("https://schema.org/MonetaryAmount")
    dateCreated = URIRef("https://schema.org/dateCreated")
    relatedStructure = URIRef("https://schema.org/relatedStructure")
    AboutPage = URIRef("https://schema.org/AboutPage")
    costCategory = URIRef("https://schema.org/costCategory")
    screenshot = URIRef("https://schema.org/screenshot")
    DrugCost = URIRef("https://schema.org/DrugCost")
    requiredMinAge = URIRef("https://schema.org/requiredMinAge")
    billingDuration = URIRef("https://schema.org/billingDuration")
    trackingNumber = URIRef("https://schema.org/trackingNumber")
    textValue = URIRef("https://schema.org/textValue")
    reportNumber = URIRef("https://schema.org/reportNumber")
    cvdNumVentUse = URIRef("https://schema.org/cvdNumVentUse")
    callSign = URIRef("https://schema.org/callSign")
    recordedIn = URIRef("https://schema.org/recordedIn")
    gameAvailabilityType = URIRef("https://schema.org/gameAvailabilityType")
    affiliation = URIRef("https://schema.org/affiliation")
    acquireLicensePage = URIRef("https://schema.org/acquireLicensePage")
    Nonprofit501c28 = URIRef("https://schema.org/Nonprofit501c28")
    Anesthesia = URIRef("https://schema.org/Anesthesia")
    ProductModel = URIRef("https://schema.org/ProductModel")
    MovingCompany = URIRef("https://schema.org/MovingCompany")
    verificationFactCheckingPolicy = URIRef("https://schema.org/verificationFactCheckingPolicy")
    Airline = URIRef("https://schema.org/Airline")
    SideEffectsHealthAspect = URIRef("https://schema.org/SideEffectsHealthAspect")
    DigitalAudioTapeFormat = URIRef("https://schema.org/DigitalAudioTapeFormat")
    LegislationObject = URIRef("https://schema.org/LegislationObject")
    PhotographAction = URIRef("https://schema.org/PhotographAction")
    incentiveCompensation = URIRef("https://schema.org/incentiveCompensation")
    evidenceOrigin = URIRef("https://schema.org/evidenceOrigin")
    broadcastChannelId = URIRef("https://schema.org/broadcastChannelId")
    attendees = URIRef("https://schema.org/attendees")
    owns = URIRef("https://schema.org/owns")
    mediaAuthenticityCategory = URIRef("https://schema.org/mediaAuthenticityCategory")
    programType = URIRef("https://schema.org/programType")
    Comment = URIRef("https://schema.org/Comment")
    holdingArchive = URIRef("https://schema.org/holdingArchive")
    WebContent = URIRef("https://schema.org/WebContent")
    InsertAction = URIRef("https://schema.org/InsertAction")
    Date = URIRef("https://schema.org/Date")
    BookFormatType = URIRef("https://schema.org/BookFormatType")
    logo = URIRef("https://schema.org/logo")
    Nonprofit501c11 = URIRef("https://schema.org/Nonprofit501c11")
    Canal = URIRef("https://schema.org/Canal")
    Radiography = URIRef("https://schema.org/Radiography")
    unnamedSourcesPolicy = URIRef("https://schema.org/unnamedSourcesPolicy")
    characterName = URIRef("https://schema.org/characterName")
    dataset = URIRef("https://schema.org/dataset")
    postalCodeEnd = URIRef("https://schema.org/postalCodeEnd")
    departureBoatTerminal = URIRef("https://schema.org/departureBoatTerminal")
    travelBans = URIRef("https://schema.org/travelBans")
    WearableSizeGroupMens = URIRef("https://schema.org/WearableSizeGroupMens")
    associatedPathophysiology = URIRef("https://schema.org/associatedPathophysiology")
    pathophysiology = URIRef("https://schema.org/pathophysiology")
    OfficialLegalValue = URIRef("https://schema.org/OfficialLegalValue")
    MedicalEntity = URIRef("https://schema.org/MedicalEntity")
    Thing = URIRef("https://schema.org/Thing")
    WantAction = URIRef("https://schema.org/WantAction")
    legislationApplies = URIRef("https://schema.org/legislationApplies")
    UnRegisterAction = URIRef("https://schema.org/UnRegisterAction")
    TireShop = URIRef("https://schema.org/TireShop")
    Property = URIRef("https://schema.org/Property")
    birthDate = URIRef("https://schema.org/birthDate")
    EUEnergyEfficiencyCategoryE = URIRef("https://schema.org/EUEnergyEfficiencyCategoryE")
    material = URIRef("https://schema.org/material")
    totalPrice = URIRef("https://schema.org/totalPrice")
    maps = URIRef("https://schema.org/maps")
    broadcastFrequencyValue = URIRef("https://schema.org/broadcastFrequencyValue")
    claimInterpreter = URIRef("https://schema.org/claimInterpreter")
    EPRelease = URIRef("https://schema.org/EPRelease")
    actors = URIRef("https://schema.org/actors")
    parents = URIRef("https://schema.org/parents")
    eligibleCustomerType = URIRef("https://schema.org/eligibleCustomerType")
    endDate = URIRef("https://schema.org/endDate")
    certificationStatus = URIRef("https://schema.org/certificationStatus")
    firstPerformance = URIRef("https://schema.org/firstPerformance")
    inProductGroupWithID = URIRef("https://schema.org/inProductGroupWithID")
    Nonprofit501c6 = URIRef("https://schema.org/Nonprofit501c6")
    bodyType = URIRef("https://schema.org/bodyType")
    WearableSizeGroupGirls = URIRef("https://schema.org/WearableSizeGroupGirls")
    expectedPrognosis = URIRef("https://schema.org/expectedPrognosis")
    usesDevice = URIRef("https://schema.org/usesDevice")
    rangeIncludes = URIRef("https://schema.org/rangeIncludes")
    WebApplication = URIRef("https://schema.org/WebApplication")
    OrderDelivered = URIRef("https://schema.org/OrderDelivered")
    location = URIRef("https://schema.org/location")
    stageAsNumber = URIRef("https://schema.org/stageAsNumber")
    Message = URIRef("https://schema.org/Message")
    leaseLength = URIRef("https://schema.org/leaseLength")
    performerIn = URIRef("https://schema.org/performerIn")
    Ligament = URIRef("https://schema.org/Ligament")
    Nonprofit501c16 = URIRef("https://schema.org/Nonprofit501c16")
    step = URIRef("https://schema.org/step")
    educationalFramework = URIRef("https://schema.org/educationalFramework")
    WPHeader = URIRef("https://schema.org/WPHeader")
    parentTaxon = URIRef("https://schema.org/parentTaxon")
    BackOrder = URIRef("https://schema.org/BackOrder")
    RadioStation = URIRef("https://schema.org/RadioStation")
    identifyingTest = URIRef("https://schema.org/identifyingTest")
    pregnancyCategory = URIRef("https://schema.org/pregnancyCategory")
    streetAddress = URIRef("https://schema.org/streetAddress")
    credentialCategory = URIRef("https://schema.org/credentialCategory")
    contentUrl = URIRef("https://schema.org/contentUrl")
    MiddleSchool = URIRef("https://schema.org/MiddleSchool")
    encodings = URIRef("https://schema.org/encodings")
    isPartOfBioChemEntity = URIRef("https://schema.org/isPartOfBioChemEntity")
    startOffset = URIRef("https://schema.org/startOffset")
    foodEvent = URIRef("https://schema.org/foodEvent")
    accountMinimumInflow = URIRef("https://schema.org/accountMinimumInflow")
    Store = URIRef("https://schema.org/Store")
    VideoGallery = URIRef("https://schema.org/VideoGallery")
    numConstraints = URIRef("https://schema.org/numConstraints")
    touristType = URIRef("https://schema.org/touristType")
    mechanismOfAction = URIRef("https://schema.org/mechanismOfAction")
    supply = URIRef("https://schema.org/supply")
    amountOfThisGood = URIRef("https://schema.org/amountOfThisGood")
    priceComponentType = URIRef("https://schema.org/priceComponentType")
    regionDrained = URIRef("https://schema.org/regionDrained")
    SkiResort = URIRef("https://schema.org/SkiResort")
    MedicalRiskFactor = URIRef("https://schema.org/MedicalRiskFactor")
    torque = URIRef("https://schema.org/torque")
    contactType = URIRef("https://schema.org/contactType")
    cookTime = URIRef("https://schema.org/cookTime")
    offers = URIRef("https://schema.org/offers")
    proteinContent = URIRef("https://schema.org/proteinContent")
    maximumIntake = URIRef("https://schema.org/maximumIntake")
    subStageSuffix = URIRef("https://schema.org/subStageSuffix")
    minPrice = URIRef("https://schema.org/minPrice")
    sizeSystem = URIRef("https://schema.org/sizeSystem")
    offersPrescriptionByMail = URIRef("https://schema.org/offersPrescriptionByMail")
    usageInfo = URIRef("https://schema.org/usageInfo")
    EUEnergyEfficiencyCategoryG = URIRef("https://schema.org/EUEnergyEfficiencyCategoryG")
    carrier = URIRef("https://schema.org/carrier")
    Hackathon = URIRef("https://schema.org/Hackathon")
    AlbumRelease = URIRef("https://schema.org/AlbumRelease")
    competitor = URIRef("https://schema.org/competitor")
    ReadAction = URIRef("https://schema.org/ReadAction")
    parentTaxon = URIRef("https://schema.org/parentTaxon")
    encodingFormat = URIRef("https://schema.org/encodingFormat")
    workExample = URIRef("https://schema.org/workExample")
    HealthCare = URIRef("https://schema.org/HealthCare")
    Schedule = URIRef("https://schema.org/Schedule")
    DoubleBlindedTrial = URIRef("https://schema.org/DoubleBlindedTrial")
    sizeGroup = URIRef("https://schema.org/sizeGroup")
    legislationType = URIRef("https://schema.org/legislationType")
    FollowAction = URIRef("https://schema.org/FollowAction")
    Legislation = URIRef("https://schema.org/Legislation")
    Appearance = URIRef("https://schema.org/Appearance")
    recordedIn = URIRef("https://schema.org/recordedIn")
    legislationDate = URIRef("https://schema.org/legislationDate")
    softwareAddOn = URIRef("https://schema.org/softwareAddOn")
    tracks = URIRef("https://schema.org/tracks")
    issueNumber = URIRef("https://schema.org/issueNumber")
    ScheduleAction = URIRef("https://schema.org/ScheduleAction")
    DataFeed = URIRef("https://schema.org/DataFeed")
    subEvent = URIRef("https://schema.org/subEvent")
    distinguishingSign = URIRef("https://schema.org/distinguishingSign")
    TouristTrip = URIRef("https://schema.org/TouristTrip")
    typeOfGood = URIRef("https://schema.org/typeOfGood")
    Nonprofit501c12 = URIRef("https://schema.org/Nonprofit501c12")
    audience = URIRef("https://schema.org/audience")
    CovidTestingFacility = URIRef("https://schema.org/CovidTestingFacility")
    GasStation = URIRef("https://schema.org/GasStation")
    Observation = URIRef("https://schema.org/Observation")
    UsageOrScheduleHealthAspect = URIRef("https://schema.org/UsageOrScheduleHealthAspect")
    educationalUse = URIRef("https://schema.org/educationalUse")
    Taxon = URIRef("https://schema.org/Taxon")
    CarUsageType = URIRef("https://schema.org/CarUsageType")
    certificationIdentification = URIRef("https://schema.org/certificationIdentification")
    nonProprietaryName = URIRef("https://schema.org/nonProprietaryName")
    checkoutTime = URIRef("https://schema.org/checkoutTime")
    eventSchedule = URIRef("https://schema.org/eventSchedule")
    material = URIRef("https://schema.org/material")
    WearableSizeSystemContinental = URIRef("https://schema.org/WearableSizeSystemContinental")
    ReplaceAction = URIRef("https://schema.org/ReplaceAction")
    BodyMeasurementTypeEnumeration = URIRef("https://schema.org/BodyMeasurementTypeEnumeration")
    cvdNumC19HospPats = URIRef("https://schema.org/cvdNumC19HospPats")
    healthCondition = URIRef("https://schema.org/healthCondition")
    postOp = URIRef("https://schema.org/postOp")
    itinerary = URIRef("https://schema.org/itinerary")
    courseWorkload = URIRef("https://schema.org/courseWorkload")
    billingDuration = URIRef("https://schema.org/billingDuration")
    drugClass = URIRef("https://schema.org/drugClass")
    employees = URIRef("https://schema.org/employees")
    composer = URIRef("https://schema.org/composer")
    material = URIRef("https://schema.org/material")
    duplicateTherapy = URIRef("https://schema.org/duplicateTherapy")
    SeeDoctorHealthAspect = URIRef("https://schema.org/SeeDoctorHealthAspect")
    PreventionHealthAspect = URIRef("https://schema.org/PreventionHealthAspect")
    unnamedSourcesPolicy = URIRef("https://schema.org/unnamedSourcesPolicy")
    title = URIRef("https://schema.org/title")
    Diagnostic = URIRef("https://schema.org/Diagnostic")
    educationalProgramMode = URIRef("https://schema.org/educationalProgramMode")
    FailedActionStatus = URIRef("https://schema.org/FailedActionStatus")
    PublicHealth = URIRef("https://schema.org/PublicHealth")
    steps = URIRef("https://schema.org/steps")
    datePosted = URIRef("https://schema.org/datePosted")
    AlcoholConsideration = URIRef("https://schema.org/AlcoholConsideration")
    accelerationTime = URIRef("https://schema.org/accelerationTime")
    chemicalRole = URIRef("https://schema.org/chemicalRole")
    unnamedSourcesPolicy = URIRef("https://schema.org/unnamedSourcesPolicy")
    PhysicalExam = URIRef("https://schema.org/PhysicalExam")
    materialExtent = URIRef("https://schema.org/materialExtent")
    SafetyHealthAspect = URIRef("https://schema.org/SafetyHealthAspect")
    providesService = URIRef("https://schema.org/providesService")
    WorkersUnion = URIRef("https://schema.org/WorkersUnion")
    browserRequirements = URIRef("https://schema.org/browserRequirements")
    free = URIRef("https://schema.org/free")
    hasOfferCatalog = URIRef("https://schema.org/hasOfferCatalog")
    EUEnergyEfficiencyEnumeration = URIRef("https://schema.org/EUEnergyEfficiencyEnumeration")
    Claim = URIRef("https://schema.org/Claim")
    servesCuisine = URIRef("https://schema.org/servesCuisine")
    medicalAudience = URIRef("https://schema.org/medicalAudience")
    predecessorOf = URIRef("https://schema.org/predecessorOf")
    MerchantReturnEnumeration = URIRef("https://schema.org/MerchantReturnEnumeration")
    variesBy = URIRef("https://schema.org/variesBy")
    BodyMeasurementInsideLeg = URIRef("https://schema.org/BodyMeasurementInsideLeg")
    DiagnosticProcedure = URIRef("https://schema.org/DiagnosticProcedure")
    funding = URIRef("https://schema.org/funding")
    DigitalArtDigitalSource = URIRef("https://schema.org/DigitalArtDigitalSource")
    subReservation = URIRef("https://schema.org/subReservation")
    bodyLocation = URIRef("https://schema.org/bodyLocation")
    totalTime = URIRef("https://schema.org/totalTime")
    SalePrice = URIRef("https://schema.org/SalePrice")
    Newspaper = URIRef("https://schema.org/Newspaper")
    opponent = URIRef("https://schema.org/opponent")
    addOn = URIRef("https://schema.org/addOn")
    AskAction = URIRef("https://schema.org/AskAction")
    workLocation = URIRef("https://schema.org/workLocation")
    hasBioPolymerSequence = URIRef("https://schema.org/hasBioPolymerSequence")
    step = URIRef("https://schema.org/step")
    syllabusSections = URIRef("https://schema.org/syllabusSections")
    insertion = URIRef("https://schema.org/insertion")
    PotentialActionStatus = URIRef("https://schema.org/PotentialActionStatus")
    Lung = URIRef("https://schema.org/Lung")
    EUEnergyEfficiencyEnumeration = URIRef("https://schema.org/EUEnergyEfficiencyEnumeration")
    LimitedByGuaranteeCharity = URIRef("https://schema.org/LimitedByGuaranteeCharity")
    hasCertification = URIRef("https://schema.org/hasCertification")
    MSRP = URIRef("https://schema.org/MSRP")
    acrissCode = URIRef("https://schema.org/acrissCode")
    timeToComplete = URIRef("https://schema.org/timeToComplete")
    organizer = URIRef("https://schema.org/organizer")
    EUEnergyEfficiencyCategoryC = URIRef("https://schema.org/EUEnergyEfficiencyCategoryC")
    catalog = URIRef("https://schema.org/catalog")
    GeoCoordinates = URIRef("https://schema.org/GeoCoordinates")
    arrivalTerminal = URIRef("https://schema.org/arrivalTerminal")
    ApartmentComplex = URIRef("https://schema.org/ApartmentComplex")
    includedRiskFactor = URIRef("https://schema.org/includedRiskFactor")
    repeatFrequency = URIRef("https://schema.org/repeatFrequency")
    includesHealthPlanFormulary = URIRef("https://schema.org/includesHealthPlanFormulary")
    Wednesday = URIRef("https://schema.org/Wednesday")
    cvdNumC19OverflowPats = URIRef("https://schema.org/cvdNumC19OverflowPats")
    MedicalAudienceType = URIRef("https://schema.org/MedicalAudienceType")
    OfferForLease = URIRef("https://schema.org/OfferForLease")
    EndorsementRating = URIRef("https://schema.org/EndorsementRating")
    arrivalTime = URIRef("https://schema.org/arrivalTime")
    DataDrivenMediaDigitalSource = URIRef("https://schema.org/DataDrivenMediaDigitalSource")
    reportNumber = URIRef("https://schema.org/reportNumber")
    MaximumDoseSchedule = URIRef("https://schema.org/MaximumDoseSchedule")
    loanPaymentFrequency = URIRef("https://schema.org/loanPaymentFrequency")
    Gene = URIRef("https://schema.org/Gene")
    line = URIRef("https://schema.org/line")
    SatiricalArticle = URIRef("https://schema.org/SatiricalArticle")
    mpn = URIRef("https://schema.org/mpn")
    EUEnergyEfficiencyCategoryE = URIRef("https://schema.org/EUEnergyEfficiencyCategoryE")
    musicArrangement = URIRef("https://schema.org/musicArrangement")
    includesHealthPlanFormulary = URIRef("https://schema.org/includesHealthPlanFormulary")
    ratingExplanation = URIRef("https://schema.org/ratingExplanation")
    countriesNotSupported = URIRef("https://schema.org/countriesNotSupported")
    correctionsPolicy = URIRef("https://schema.org/correctionsPolicy")
    availableThrough = URIRef("https://schema.org/availableThrough")
    negativeNotes = URIRef("https://schema.org/negativeNotes")
    paymentMethodId = URIRef("https://schema.org/paymentMethodId")
    WearableMeasurementLength = URIRef("https://schema.org/WearableMeasurementLength")
    educationRequirements = URIRef("https://schema.org/educationRequirements")
    InteractionCounter = URIRef("https://schema.org/InteractionCounter")
    reservedTicket = URIRef("https://schema.org/reservedTicket")
    logo = URIRef("https://schema.org/logo")
    category = URIRef("https://schema.org/category")
    isAvailableGenerically = URIRef("https://schema.org/isAvailableGenerically")
    PsychologicalTreatment = URIRef("https://schema.org/PsychologicalTreatment")
    currentExchangeRate = URIRef("https://schema.org/currentExchangeRate")
    AlgorithmicMediaDigitalSource = URIRef("https://schema.org/AlgorithmicMediaDigitalSource")
    serviceArea = URIRef("https://schema.org/serviceArea")
    Nonprofit501c10 = URIRef("https://schema.org/Nonprofit501c10")
    LockerDelivery = URIRef("https://schema.org/LockerDelivery")
    programmingLanguage = URIRef("https://schema.org/programmingLanguage")
    deathPlace = URIRef("https://schema.org/deathPlace")
    Cardiovascular = URIRef("https://schema.org/Cardiovascular")
    OrderStatus = URIRef("https://schema.org/OrderStatus")
    creditedTo = URIRef("https://schema.org/creditedTo")
    expressedIn = URIRef("https://schema.org/expressedIn")
    recordingOf = URIRef("https://schema.org/recordingOf")
    departureTerminal = URIRef("https://schema.org/departureTerminal")
    floorSize = URIRef("https://schema.org/floorSize")
    answerExplanation = URIRef("https://schema.org/answerExplanation")
    DownloadAction = URIRef("https://schema.org/DownloadAction")
    targetDescription = URIRef("https://schema.org/targetDescription")
    availableThrough = URIRef("https://schema.org/availableThrough")
    originalMediaLink = URIRef("https://schema.org/originalMediaLink")
    Gene = URIRef("https://schema.org/Gene")
    HinduTemple = URIRef("https://schema.org/HinduTemple")
    healthPlanNetworkTier = URIRef("https://schema.org/healthPlanNetworkTier")
    byMonthWeek = URIRef("https://schema.org/byMonthWeek")
    layoutImage = URIRef("https://schema.org/layoutImage")
    drug = URIRef("https://schema.org/drug")
    loanPaymentAmount = URIRef("https://schema.org/loanPaymentAmount")
    studyDesign = URIRef("https://schema.org/studyDesign")
    memberOf = URIRef("https://schema.org/memberOf")
    GameAvailabilityEnumeration = URIRef("https://schema.org/GameAvailabilityEnumeration")
    object = URIRef("https://schema.org/object")
    isicV4 = URIRef("https://schema.org/isicV4")
    phoneticText = URIRef("https://schema.org/phoneticText")
    serviceArea = URIRef("https://schema.org/serviceArea")
    physiologicalBenefits = URIRef("https://schema.org/physiologicalBenefits")
    exerciseRelatedDiet = URIRef("https://schema.org/exerciseRelatedDiet")
    Nonprofit501c27 = URIRef("https://schema.org/Nonprofit501c27")
    seatNumber = URIRef("https://schema.org/seatNumber")
    funder = URIRef("https://schema.org/funder")
    Nonprofit501c11 = URIRef("https://schema.org/Nonprofit501c11")
    tocEntry = URIRef("https://schema.org/tocEntry")
    menu = URIRef("https://schema.org/menu")
    benefitsSummaryUrl = URIRef("https://schema.org/benefitsSummaryUrl")
    SearchResultsPage = URIRef("https://schema.org/SearchResultsPage")
    alternativeOf = URIRef("https://schema.org/alternativeOf")
    steeringPosition = URIRef("https://schema.org/steeringPosition")
    MovieTheater = URIRef("https://schema.org/MovieTheater")
    Radiography = URIRef("https://schema.org/Radiography")
    ToyStore = URIRef("https://schema.org/ToyStore")
    participant = URIRef("https://schema.org/participant")
    sharedContent = URIRef("https://schema.org/sharedContent")
    map = URIRef("https://schema.org/map")
    energyEfficiencyScaleMax = URIRef("https://schema.org/energyEfficiencyScaleMax")
    numberOfRooms = URIRef("https://schema.org/numberOfRooms")
    Nonprofit527 = URIRef("https://schema.org/Nonprofit527")
    SymptomsHealthAspect = URIRef("https://schema.org/SymptomsHealthAspect")
    StudioAlbum = URIRef("https://schema.org/StudioAlbum")
    nerve = URIRef("https://schema.org/nerve")
    educationalRole = URIRef("https://schema.org/educationalRole")
    legislationIdentifier = URIRef("https://schema.org/legislationIdentifier")
    algorithm = URIRef("https://schema.org/algorithm")
    VoteAction = URIRef("https://schema.org/VoteAction")
    DefinedRegion = URIRef("https://schema.org/DefinedRegion")
    articleSection = URIRef("https://schema.org/articleSection")
    numConstraints = URIRef("https://schema.org/numConstraints")
    FollowAction = URIRef("https://schema.org/FollowAction")
    Taxi = URIRef("https://schema.org/Taxi")
    Integer = URIRef("https://schema.org/Integer")
    targetCollection = URIRef("https://schema.org/targetCollection")
    copyrightYear = URIRef("https://schema.org/copyrightYear")
    member = URIRef("https://schema.org/member")
    includesHealthPlanNetwork = URIRef("https://schema.org/includesHealthPlanNetwork")
    AchieveAction = URIRef("https://schema.org/AchieveAction")
    legalName = URIRef("https://schema.org/legalName")
    sameAs = URIRef("https://schema.org/sameAs")
    termsOfService = URIRef("https://schema.org/termsOfService")
    FinancialProduct = URIRef("https://schema.org/FinancialProduct")
    DiscoverAction = URIRef("https://schema.org/DiscoverAction")
    Bakery = URIRef("https://schema.org/Bakery")
    DeliveryChargeSpecification = URIRef("https://schema.org/DeliveryChargeSpecification")
    tocContinuation = URIRef("https://schema.org/tocContinuation")
    WatchAction = URIRef("https://schema.org/WatchAction")
    hasPOS = URIRef("https://schema.org/hasPOS")
    query = URIRef("https://schema.org/query")
    Newspaper = URIRef("https://schema.org/Newspaper")
    servicePhone = URIRef("https://schema.org/servicePhone")
    includesAttraction = URIRef("https://schema.org/includesAttraction")
    MisconceptionsHealthAspect = URIRef("https://schema.org/MisconceptionsHealthAspect")
    duplicateTherapy = URIRef("https://schema.org/duplicateTherapy")
    illustrator = URIRef("https://schema.org/illustrator")
    expertConsiderations = URIRef("https://schema.org/expertConsiderations")
    stepValue = URIRef("https://schema.org/stepValue")
    TVSeason = URIRef("https://schema.org/TVSeason")
    ComputerStore = URIRef("https://schema.org/ComputerStore")
    SinglePlayer = URIRef("https://schema.org/SinglePlayer")
    riskFactor = URIRef("https://schema.org/riskFactor")
    EmployerReview = URIRef("https://schema.org/EmployerReview")
    legalStatus = URIRef("https://schema.org/legalStatus")
    occupationalCredentialAwarded = URIRef("https://schema.org/occupationalCredentialAwarded")
    guidelineDate = URIRef("https://schema.org/guidelineDate")
    iupacName = URIRef("https://schema.org/iupacName")
    measurementTechnique = URIRef("https://schema.org/measurementTechnique")
    Nonprofit501e = URIRef("https://schema.org/Nonprofit501e")
    teaches = URIRef("https://schema.org/teaches")
    Nonprofit501d = URIRef("https://schema.org/Nonprofit501d")
    callSign = URIRef("https://schema.org/callSign")
    MusicAlbumReleaseType = URIRef("https://schema.org/MusicAlbumReleaseType")
    bookingAgent = URIRef("https://schema.org/bookingAgent")
    UserComments = URIRef("https://schema.org/UserComments")
    vehicleInteriorColor = URIRef("https://schema.org/vehicleInteriorColor")
    ContactPoint = URIRef("https://schema.org/ContactPoint")
    BoardingPolicyType = URIRef("https://schema.org/BoardingPolicyType")
    contentType = URIRef("https://schema.org/contentType")
    priceSpecification = URIRef("https://schema.org/priceSpecification")
    EmployerReview = URIRef("https://schema.org/EmployerReview")
    AerobicActivity = URIRef("https://schema.org/AerobicActivity")
    targetUrl = URIRef("https://schema.org/targetUrl")
    EUEnergyEfficiencyCategoryG = URIRef("https://schema.org/EUEnergyEfficiencyCategoryG")
    embeddedTextCaption = URIRef("https://schema.org/embeddedTextCaption")
    DataFeedItem = URIRef("https://schema.org/DataFeedItem")
    artform = URIRef("https://schema.org/artform")
    chemicalComposition = URIRef("https://schema.org/chemicalComposition")
    acceptedAnswer = URIRef("https://schema.org/acceptedAnswer")
    ContactPage = URIRef("https://schema.org/ContactPage")
    availableLanguage = URIRef("https://schema.org/availableLanguage")
    hasDefinedTerm = URIRef("https://schema.org/hasDefinedTerm")
    ticketNumber = URIRef("https://schema.org/ticketNumber")
    colorist = URIRef("https://schema.org/colorist")
    returnLabelSource = URIRef("https://schema.org/returnLabelSource")
    ActivateAction = URIRef("https://schema.org/ActivateAction")
    gettingTestedInfo = URIRef("https://schema.org/gettingTestedInfo")
    ReactAction = URIRef("https://schema.org/ReactAction")
    LiveBlogPosting = URIRef("https://schema.org/LiveBlogPosting")
    EventMovedOnline = URIRef("https://schema.org/EventMovedOnline")
    molecularWeight = URIRef("https://schema.org/molecularWeight")
    InviteAction = URIRef("https://schema.org/InviteAction")
    MusicAlbumReleaseType = URIRef("https://schema.org/MusicAlbumReleaseType")
    coach = URIRef("https://schema.org/coach")
    MedicalTestPanel = URIRef("https://schema.org/MedicalTestPanel")
    spatialCoverage = URIRef("https://schema.org/spatialCoverage")
    serviceType = URIRef("https://schema.org/serviceType")
    acquireLicensePage = URIRef("https://schema.org/acquireLicensePage")
    fundedItem = URIRef("https://schema.org/fundedItem")
    codingSystem = URIRef("https://schema.org/codingSystem")
    orderDate = URIRef("https://schema.org/orderDate")
    intensity = URIRef("https://schema.org/intensity")
    Menu = URIRef("https://schema.org/Menu")
    comprisedOf = URIRef("https://schema.org/comprisedOf")
    PaymentCard = URIRef("https://schema.org/PaymentCard")
    numberOfPreviousOwners = URIRef("https://schema.org/numberOfPreviousOwners")
    bed = URIRef("https://schema.org/bed")
    associatedDisease = URIRef("https://schema.org/associatedDisease")
    releaseDate = URIRef("https://schema.org/releaseDate")
    maintainer = URIRef("https://schema.org/maintainer")
    partOfSeries = URIRef("https://schema.org/partOfSeries")
    validThrough = URIRef("https://schema.org/validThrough")
    evidenceOrigin = URIRef("https://schema.org/evidenceOrigin")
    incentives = URIRef("https://schema.org/incentives")
    Campground = URIRef("https://schema.org/Campground")
    ReportageNewsArticle = URIRef("https://schema.org/ReportageNewsArticle")
    genre = URIRef("https://schema.org/genre")
    author = URIRef("https://schema.org/author")
    includedComposition = URIRef("https://schema.org/includedComposition")
    shippingOrigin = URIRef("https://schema.org/shippingOrigin")
    beforeMedia = URIRef("https://schema.org/beforeMedia")
    course = URIRef("https://schema.org/course")
    editEIDR = URIRef("https://schema.org/editEIDR")
    RisksOrComplicationsHealthAspect = URIRef("https://schema.org/RisksOrComplicationsHealthAspect")
    ImagingTest = URIRef("https://schema.org/ImagingTest")
    characterAttribute = URIRef("https://schema.org/characterAttribute")
    Quantity = URIRef("https://schema.org/Quantity")
    Discontinued = URIRef("https://schema.org/Discontinued")
    sourcedFrom = URIRef("https://schema.org/sourcedFrom")
    uploadDate = URIRef("https://schema.org/uploadDate")
    accountOverdraftLimit = URIRef("https://schema.org/accountOverdraftLimit")
    DanceGroup = URIRef("https://schema.org/DanceGroup")
    workload = URIRef("https://schema.org/workload")
    unitCode = URIRef("https://schema.org/unitCode")
    albums = URIRef("https://schema.org/albums")
    eligibleCustomerType = URIRef("https://schema.org/eligibleCustomerType")
    numberOfLoanPayments = URIRef("https://schema.org/numberOfLoanPayments")
    restockingFee = URIRef("https://schema.org/restockingFee")
    MarryAction = URIRef("https://schema.org/MarryAction")
    address = URIRef("https://schema.org/address")
    BodyMeasurementArm = URIRef("https://schema.org/BodyMeasurementArm")
    OrderReturned = URIRef("https://schema.org/OrderReturned")
    Demand = URIRef("https://schema.org/Demand")
    DrugStrength = URIRef("https://schema.org/DrugStrength")
    hasEnergyEfficiencyCategory = URIRef("https://schema.org/hasEnergyEfficiencyCategory")
    serviceArea = URIRef("https://schema.org/serviceArea")
    MedicalTherapy = URIRef("https://schema.org/MedicalTherapy")
    gameEdition = URIRef("https://schema.org/gameEdition")
    colorSwatch = URIRef("https://schema.org/colorSwatch")
    processorRequirements = URIRef("https://schema.org/processorRequirements")
    HealthCare = URIRef("https://schema.org/HealthCare")
    DrinkAction = URIRef("https://schema.org/DrinkAction")
    DriveWheelConfigurationValue = URIRef("https://schema.org/DriveWheelConfigurationValue")
    WorkBasedProgram = URIRef("https://schema.org/WorkBasedProgram")
    publicationType = URIRef("https://schema.org/publicationType")
    Review = URIRef("https://schema.org/Review")
    contraindication = URIRef("https://schema.org/contraindication")
    commentText = URIRef("https://schema.org/commentText")
    cvdCollectionDate = URIRef("https://schema.org/cvdCollectionDate")
    vendor = URIRef("https://schema.org/vendor")
    billingAddress = URIRef("https://schema.org/billingAddress")
    review = URIRef("https://schema.org/review")
    practicesAt = URIRef("https://schema.org/practicesAt")
    numberOfFullBathrooms = URIRef("https://schema.org/numberOfFullBathrooms")
    ComicSeries = URIRef("https://schema.org/ComicSeries")
    minValue = URIRef("https://schema.org/minValue")
    legislationTransposes = URIRef("https://schema.org/legislationTransposes")
    Substance = URIRef("https://schema.org/Substance")
    partOfSystem = URIRef("https://schema.org/partOfSystem")
    agentInteractionStatistic = URIRef("https://schema.org/agentInteractionStatistic")
    Protein = URIRef("https://schema.org/Protein")
    Book = URIRef("https://schema.org/Book")
    webFeed = URIRef("https://schema.org/webFeed")
    contentReferenceTime = URIRef("https://schema.org/contentReferenceTime")
    sensoryRequirement = URIRef("https://schema.org/sensoryRequirement")
    WebContent = URIRef("https://schema.org/WebContent")
    BowlingAlley = URIRef("https://schema.org/BowlingAlley")
    name = URIRef("https://schema.org/name")
    PhysicalActivityCategory = URIRef("https://schema.org/PhysicalActivityCategory")
    StatisticalVariable = URIRef("https://schema.org/StatisticalVariable")
    AccountingService = URIRef("https://schema.org/AccountingService")
    borrower = URIRef("https://schema.org/borrower")
    itemListElement = URIRef("https://schema.org/itemListElement")
    doesNotShip = URIRef("https://schema.org/doesNotShip")
    MotorcycleRepair = URIRef("https://schema.org/MotorcycleRepair")
    OneTimePayments = URIRef("https://schema.org/OneTimePayments")
    monthsOfExperience = URIRef("https://schema.org/monthsOfExperience")
    typeOfGood = URIRef("https://schema.org/typeOfGood")
    SoundtrackAlbum = URIRef("https://schema.org/SoundtrackAlbum")
    educationalLevel = URIRef("https://schema.org/educationalLevel")
    availableStrength = URIRef("https://schema.org/availableStrength")
    Otolaryngologic = URIRef("https://schema.org/Otolaryngologic")
    CssSelectorType = URIRef("https://schema.org/CssSelectorType")
    actionApplication = URIRef("https://schema.org/actionApplication")
    infectiousAgent = URIRef("https://schema.org/infectiousAgent")
    Patient = URIRef("https://schema.org/Patient")
    interestRate = URIRef("https://schema.org/interestRate")
    EUEnergyEfficiencyCategoryB = URIRef("https://schema.org/EUEnergyEfficiencyCategoryB")
    ListPrice = URIRef("https://schema.org/ListPrice")
    correctionsPolicy = URIRef("https://schema.org/correctionsPolicy")
    faxNumber = URIRef("https://schema.org/faxNumber")
    PlaceboControlledTrial = URIRef("https://schema.org/PlaceboControlledTrial")
    Gynecologic = URIRef("https://schema.org/Gynecologic")
    Sunday = URIRef("https://schema.org/Sunday")
    priceComponent = URIRef("https://schema.org/priceComponent")
    associatedPathophysiology = URIRef("https://schema.org/associatedPathophysiology")
    CompleteDataFeed = URIRef("https://schema.org/CompleteDataFeed")
    priceRange = URIRef("https://schema.org/priceRange")
    Sculpture = URIRef("https://schema.org/Sculpture")
    touristType = URIRef("https://schema.org/touristType")
    prescribingInfo = URIRef("https://schema.org/prescribingInfo")
    foodEstablishment = URIRef("https://schema.org/foodEstablishment")
    certificationIdentification = URIRef("https://schema.org/certificationIdentification")
    SpeechPathology = URIRef("https://schema.org/SpeechPathology")
    hasEnergyConsumptionDetails = URIRef("https://schema.org/hasEnergyConsumptionDetails")
    episode = URIRef("https://schema.org/episode")
    NailSalon = URIRef("https://schema.org/NailSalon")
    sdLicense = URIRef("https://schema.org/sdLicense")
    TattooParlor = URIRef("https://schema.org/TattooParlor")
    broadcastServiceTier = URIRef("https://schema.org/broadcastServiceTier")
    Locksmith = URIRef("https://schema.org/Locksmith")
    potentialAction = URIRef("https://schema.org/potentialAction")
    characterAttribute = URIRef("https://schema.org/characterAttribute")
    MolecularEntity = URIRef("https://schema.org/MolecularEntity")
    WearableSizeSystemBR = URIRef("https://schema.org/WearableSizeSystemBR")
    orderStatus = URIRef("https://schema.org/orderStatus")
    RepaymentSpecification = URIRef("https://schema.org/RepaymentSpecification")
    musicBy = URIRef("https://schema.org/musicBy")
    PriceComponentTypeEnumeration = URIRef("https://schema.org/PriceComponentTypeEnumeration")
    diversityPolicy = URIRef("https://schema.org/diversityPolicy")
    potentialUse = URIRef("https://schema.org/potentialUse")
    isBasedOn = URIRef("https://schema.org/isBasedOn")
    LifestyleModification = URIRef("https://schema.org/LifestyleModification")
    callSign = URIRef("https://schema.org/callSign")
    GettingAccessHealthAspect = URIRef("https://schema.org/GettingAccessHealthAspect")
    Beach = URIRef("https://schema.org/Beach")
    skills = URIRef("https://schema.org/skills")
    performerIn = URIRef("https://schema.org/performerIn")
    TouristDestination = URIRef("https://schema.org/TouristDestination")
    nutrition = URIRef("https://schema.org/nutrition")
    requiredCollateral = URIRef("https://schema.org/requiredCollateral")
    EUEnergyEfficiencyCategoryA = URIRef("https://schema.org/EUEnergyEfficiencyCategoryA")
    MedicalCode = URIRef("https://schema.org/MedicalCode")
    EUEnergyEfficiencyCategoryB = URIRef("https://schema.org/EUEnergyEfficiencyCategoryB")
    liveBlogUpdate = URIRef("https://schema.org/liveBlogUpdate")
    icaoCode = URIRef("https://schema.org/icaoCode")
    cssSelector = URIRef("https://schema.org/cssSelector")
    strengthUnit = URIRef("https://schema.org/strengthUnit")
    DecontextualizedContent = URIRef("https://schema.org/DecontextualizedContent")
    Lung = URIRef("https://schema.org/Lung")
    xpath = URIRef("https://schema.org/xpath")
    LocalBusiness = URIRef("https://schema.org/LocalBusiness")
    EUEnergyEfficiencyCategoryD = URIRef("https://schema.org/EUEnergyEfficiencyCategoryD")
    DemoAlbum = URIRef("https://schema.org/DemoAlbum")
    driveWheelConfiguration = URIRef("https://schema.org/driveWheelConfiguration")
    InsuranceAgency = URIRef("https://schema.org/InsuranceAgency")
    CompletedActionStatus = URIRef("https://schema.org/CompletedActionStatus")
    ParentalSupport = URIRef("https://schema.org/ParentalSupport")
    gtin8 = URIRef("https://schema.org/gtin8")
    playersOnline = URIRef("https://schema.org/playersOnline")
    amount = URIRef("https://schema.org/amount")
    SportingGoodsStore = URIRef("https://schema.org/SportingGoodsStore")
    MedicalClinic = URIRef("https://schema.org/MedicalClinic")
    recommendationStrength = URIRef("https://schema.org/recommendationStrength")
    reservationFor = URIRef("https://schema.org/reservationFor")
    eventSchedule = URIRef("https://schema.org/eventSchedule")
    appliesToDeliveryMethod = URIRef("https://schema.org/appliesToDeliveryMethod")
    PaymentMethod = URIRef("https://schema.org/PaymentMethod")
    ActiveActionStatus = URIRef("https://schema.org/ActiveActionStatus")
    variableMeasured = URIRef("https://schema.org/variableMeasured")
    softwareHelp = URIRef("https://schema.org/softwareHelp")
    EducationalOrganization = URIRef("https://schema.org/EducationalOrganization")
    LegalValueLevel = URIRef("https://schema.org/LegalValueLevel")
    speechToTextMarkup = URIRef("https://schema.org/speechToTextMarkup")
    hasMerchantReturnPolicy = URIRef("https://schema.org/hasMerchantReturnPolicy")
    recipeInstructions = URIRef("https://schema.org/recipeInstructions")
    UserBlocks = URIRef("https://schema.org/UserBlocks")
    cvdNumC19HospPats = URIRef("https://schema.org/cvdNumC19HospPats")
    MSRP = URIRef("https://schema.org/MSRP")
    installUrl = URIRef("https://schema.org/installUrl")
    AlgorithmicallyEnhancedDigitalSource = URIRef("https://schema.org/AlgorithmicallyEnhancedDigitalSource")
    CommentPermission = URIRef("https://schema.org/CommentPermission")
    BodyMeasurementWeight = URIRef("https://schema.org/BodyMeasurementWeight")
    actionableFeedbackPolicy = URIRef("https://schema.org/actionableFeedbackPolicy")
    actionApplication = URIRef("https://schema.org/actionApplication")
    lodgingUnitType = URIRef("https://schema.org/lodgingUnitType")
    pageStart = URIRef("https://schema.org/pageStart")
    DrivingSchoolVehicleUsage = URIRef("https://schema.org/DrivingSchoolVehicleUsage")
    DrawAction = URIRef("https://schema.org/DrawAction")
    distinguishingSign = URIRef("https://schema.org/distinguishingSign")
    Nonprofit501c2 = URIRef("https://schema.org/Nonprofit501c2")
    candidate = URIRef("https://schema.org/candidate")
    containsPlace = URIRef("https://schema.org/containsPlace")
    byMonthWeek = URIRef("https://schema.org/byMonthWeek")
    PreSale = URIRef("https://schema.org/PreSale")
    MusicAlbumProductionType = URIRef("https://schema.org/MusicAlbumProductionType")
    MovieRentalStore = URIRef("https://schema.org/MovieRentalStore")
    paymentAccepted = URIRef("https://schema.org/paymentAccepted")
    member = URIRef("https://schema.org/member")
    itemCondition = URIRef("https://schema.org/itemCondition")
    OccupationalActivity = URIRef("https://schema.org/OccupationalActivity")
    cvdNumVent = URIRef("https://schema.org/cvdNumVent")
    typeOfGood = URIRef("https://schema.org/typeOfGood")
    currenciesAccepted = URIRef("https://schema.org/currenciesAccepted")
    availableLanguage = URIRef("https://schema.org/availableLanguage")
    paymentMethodId = URIRef("https://schema.org/paymentMethodId")
    storageRequirements = URIRef("https://schema.org/storageRequirements")
    typeOfGood = URIRef("https://schema.org/typeOfGood")
    availableOnDevice = URIRef("https://schema.org/availableOnDevice")
    gender = URIRef("https://schema.org/gender")
    dateDeleted = URIRef("https://schema.org/dateDeleted")
    valueAddedTaxIncluded = URIRef("https://schema.org/valueAddedTaxIncluded")
    publishingPrinciples = URIRef("https://schema.org/publishingPrinciples")
    ToyStore = URIRef("https://schema.org/ToyStore")
    OnlineOnly = URIRef("https://schema.org/OnlineOnly")
    acrissCode = URIRef("https://schema.org/acrissCode")
    equal = URIRef("https://schema.org/equal")
    pageStart = URIRef("https://schema.org/pageStart")
    gtin = URIRef("https://schema.org/gtin")
    departureBusStop = URIRef("https://schema.org/departureBusStop")
    paymentAccepted = URIRef("https://schema.org/paymentAccepted")
    governmentBenefitsInfo = URIRef("https://schema.org/governmentBenefitsInfo")
    diversityPolicy = URIRef("https://schema.org/diversityPolicy")
    hoursAvailable = URIRef("https://schema.org/hoursAvailable")
    actionPlatform = URIRef("https://schema.org/actionPlatform")
    MerchantReturnPolicy = URIRef("https://schema.org/MerchantReturnPolicy")
    returnFees = URIRef("https://schema.org/returnFees")
    license = URIRef("https://schema.org/license")
    paymentStatus = URIRef("https://schema.org/paymentStatus")
    arrivalAirport = URIRef("https://schema.org/arrivalAirport")
    Nonprofit501c20 = URIRef("https://schema.org/Nonprofit501c20")
    episodes = URIRef("https://schema.org/episodes")
    ScreeningHealthAspect = URIRef("https://schema.org/ScreeningHealthAspect")
    inventoryLevel = URIRef("https://schema.org/inventoryLevel")
    fuelType = URIRef("https://schema.org/fuelType")
    MoneyTransfer = URIRef("https://schema.org/MoneyTransfer")
    Nonprofit501c1 = URIRef("https://schema.org/Nonprofit501c1")
    catalog = URIRef("https://schema.org/catalog")
    diversityPolicy = URIRef("https://schema.org/diversityPolicy")
    givenName = URIRef("https://schema.org/givenName")
    seatNumber = URIRef("https://schema.org/seatNumber")
    breadcrumb = URIRef("https://schema.org/breadcrumb")
    funding = URIRef("https://schema.org/funding")
    childTaxon = URIRef("https://schema.org/childTaxon")
    RespiratoryTherapy = URIRef("https://schema.org/RespiratoryTherapy")
    trainingSalary = URIRef("https://schema.org/trainingSalary")
    proprietaryName = URIRef("https://schema.org/proprietaryName")
    AdvertiserContentArticle = URIRef("https://schema.org/AdvertiserContentArticle")
    Dentistry = URIRef("https://schema.org/Dentistry")
    backstory = URIRef("https://schema.org/backstory")
    actionOption = URIRef("https://schema.org/actionOption")
    maximumPhysicalAttendeeCapacity = URIRef("https://schema.org/maximumPhysicalAttendeeCapacity")
    mainEntityOfPage = URIRef("https://schema.org/mainEntityOfPage")
    director = URIRef("https://schema.org/director")
    LiquorStore = URIRef("https://schema.org/LiquorStore")
    healthPlanNetworkId = URIRef("https://schema.org/healthPlanNetworkId")
    AutoPartsStore = URIRef("https://schema.org/AutoPartsStore")
    bookFormat = URIRef("https://schema.org/bookFormat")
    BookmarkAction = URIRef("https://schema.org/BookmarkAction")
    evidenceOrigin = URIRef("https://schema.org/evidenceOrigin")
    estimatedSalary = URIRef("https://schema.org/estimatedSalary")
    sizeGroup = URIRef("https://schema.org/sizeGroup")
    employmentType = URIRef("https://schema.org/employmentType")
    ReportedDoseSchedule = URIRef("https://schema.org/ReportedDoseSchedule")
    Playground = URIRef("https://schema.org/Playground")
    inAlbum = URIRef("https://schema.org/inAlbum")
    ProfilePage = URIRef("https://schema.org/ProfilePage")
    GovernmentOrganization = URIRef("https://schema.org/GovernmentOrganization")
    Completed = URIRef("https://schema.org/Completed")
    MedicalStudyStatus = URIRef("https://schema.org/MedicalStudyStatus")
    WearableSizeSystemEurope = URIRef("https://schema.org/WearableSizeSystemEurope")
    measurementTechnique = URIRef("https://schema.org/measurementTechnique")
    incentives = URIRef("https://schema.org/incentives")
    copyrightYear = URIRef("https://schema.org/copyrightYear")
    countryOfOrigin = URIRef("https://schema.org/countryOfOrigin")
    Nerve = URIRef("https://schema.org/Nerve")
    foodEstablishment = URIRef("https://schema.org/foodEstablishment")
    eligibleTransactionVolume = URIRef("https://schema.org/eligibleTransactionVolume")
    enginePower = URIRef("https://schema.org/enginePower")
    QuoteAction = URIRef("https://schema.org/QuoteAction")
    SellAction = URIRef("https://schema.org/SellAction")
    correction = URIRef("https://schema.org/correction")
    WearableMeasurementSleeve = URIRef("https://schema.org/WearableMeasurementSleeve")
    CompositeCaptureDigitalSource = URIRef("https://schema.org/CompositeCaptureDigitalSource")
    tickerSymbol = URIRef("https://schema.org/tickerSymbol")
    weight = URIRef("https://schema.org/weight")
    WearableMeasurementOutsideLeg = URIRef("https://schema.org/WearableMeasurementOutsideLeg")
    textValue = URIRef("https://schema.org/textValue")
    priceCurrency = URIRef("https://schema.org/priceCurrency")
    paymentUrl = URIRef("https://schema.org/paymentUrl")
    requiredMinAge = URIRef("https://schema.org/requiredMinAge")
    Geriatric = URIRef("https://schema.org/Geriatric")
    diet = URIRef("https://schema.org/diet")
    sportsEvent = URIRef("https://schema.org/sportsEvent")
    workload = URIRef("https://schema.org/workload")
    specialCommitments = URIRef("https://schema.org/specialCommitments")
    PlayAction = URIRef("https://schema.org/PlayAction")
    accessibilitySummary = URIRef("https://schema.org/accessibilitySummary")
    appearance = URIRef("https://schema.org/appearance")
    highPrice = URIRef("https://schema.org/highPrice")
    interactionCount = URIRef("https://schema.org/interactionCount")
    engineDisplacement = URIRef("https://schema.org/engineDisplacement")
    OrganizeAction = URIRef("https://schema.org/OrganizeAction")
    Rheumatologic = URIRef("https://schema.org/Rheumatologic")
    membershipNumber = URIRef("https://schema.org/membershipNumber")
    billingStart = URIRef("https://schema.org/billingStart")
    StatisticalPopulation = URIRef("https://schema.org/StatisticalPopulation")
    musicReleaseFormat = URIRef("https://schema.org/musicReleaseFormat")
    DecontextualizedContent = URIRef("https://schema.org/DecontextualizedContent")
    honorificPrefix = URIRef("https://schema.org/honorificPrefix")
    contactPoint = URIRef("https://schema.org/contactPoint")
    scheduledTime = URIRef("https://schema.org/scheduledTime")
    prepTime = URIRef("https://schema.org/prepTime")
    isAvailableGenerically = URIRef("https://schema.org/isAvailableGenerically")
    BodyMeasurementInsideLeg = URIRef("https://schema.org/BodyMeasurementInsideLeg")
    LoanOrCredit = URIRef("https://schema.org/LoanOrCredit")
    genre = URIRef("https://schema.org/genre")
    subEvent = URIRef("https://schema.org/subEvent")
    InvestmentFund = URIRef("https://schema.org/InvestmentFund")
    validThrough = URIRef("https://schema.org/validThrough")
    MobileWebPlatform = URIRef("https://schema.org/MobileWebPlatform")
    cholesterolContent = URIRef("https://schema.org/cholesterolContent")
    TouristDestination = URIRef("https://schema.org/TouristDestination")
    diagram = URIRef("https://schema.org/diagram")
    Library = URIRef("https://schema.org/Library")
    availabilityEnds = URIRef("https://schema.org/availabilityEnds")
    House = URIRef("https://schema.org/House")
    deathPlace = URIRef("https://schema.org/deathPlace")
    MultiPlayer = URIRef("https://schema.org/MultiPlayer")
    gamePlatform = URIRef("https://schema.org/gamePlatform")
    additionalProperty = URIRef("https://schema.org/additionalProperty")
    penciler = URIRef("https://schema.org/penciler")
    Fungus = URIRef("https://schema.org/Fungus")
    programPrerequisites = URIRef("https://schema.org/programPrerequisites")
    issn = URIRef("https://schema.org/issn")
    KosherDiet = URIRef("https://schema.org/KosherDiet")
    CreativeWork = URIRef("https://schema.org/CreativeWork")
    isBasedOnUrl = URIRef("https://schema.org/isBasedOnUrl")
    employmentType = URIRef("https://schema.org/employmentType")
    identifyingExam = URIRef("https://schema.org/identifyingExam")
    productID = URIRef("https://schema.org/productID")
    educationalCredentialAwarded = URIRef("https://schema.org/educationalCredentialAwarded")
    AnatomicalStructure = URIRef("https://schema.org/AnatomicalStructure")
    awayTeam = URIRef("https://schema.org/awayTeam")
    broadcaster = URIRef("https://schema.org/broadcaster")
    awards = URIRef("https://schema.org/awards")
    Volcano = URIRef("https://schema.org/Volcano")
    productID = URIRef("https://schema.org/productID")
    FinancialProduct = URIRef("https://schema.org/FinancialProduct")
    inChIKey = URIRef("https://schema.org/inChIKey")
    Hematologic = URIRef("https://schema.org/Hematologic")
    hasBioChemEntityPart = URIRef("https://schema.org/hasBioChemEntityPart")
    monthlyMinimumRepaymentAmount = URIRef("https://schema.org/monthlyMinimumRepaymentAmount")
    GraphicNovel = URIRef("https://schema.org/GraphicNovel")
    isVariantOf = URIRef("https://schema.org/isVariantOf")
    Periodical = URIRef("https://schema.org/Periodical")
    originalMediaLink = URIRef("https://schema.org/originalMediaLink")
    warrantyPromise = URIRef("https://schema.org/warrantyPromise")
    offerCount = URIRef("https://schema.org/offerCount")
    alumniOf = URIRef("https://schema.org/alumniOf")
    requiresSubscription = URIRef("https://schema.org/requiresSubscription")
    Radiography = URIRef("https://schema.org/Radiography")
    TheaterGroup = URIRef("https://schema.org/TheaterGroup")
    performTime = URIRef("https://schema.org/performTime")
    suggestedAnswer = URIRef("https://schema.org/suggestedAnswer")
    overdosage = URIRef("https://schema.org/overdosage")
    Toxicologic = URIRef("https://schema.org/Toxicologic")
    archiveHeld = URIRef("https://schema.org/archiveHeld")
    bitrate = URIRef("https://schema.org/bitrate")
    PatientExperienceHealthAspect = URIRef("https://schema.org/PatientExperienceHealthAspect")
    InStoreOnly = URIRef("https://schema.org/InStoreOnly")
    trackingUrl = URIRef("https://schema.org/trackingUrl")
    suggestedAge = URIRef("https://schema.org/suggestedAge")
    geoDisjoint = URIRef("https://schema.org/geoDisjoint")
    ListPrice = URIRef("https://schema.org/ListPrice")
    roofLoad = URIRef("https://schema.org/roofLoad")
    HealthcareConsideration = URIRef("https://schema.org/HealthcareConsideration")
    taxID = URIRef("https://schema.org/taxID")
    MortgageLoan = URIRef("https://schema.org/MortgageLoan")
    financialAidEligible = URIRef("https://schema.org/financialAidEligible")
    EnergyEfficiencyEnumeration = URIRef("https://schema.org/EnergyEfficiencyEnumeration")
    healthPlanCostSharing = URIRef("https://schema.org/healthPlanCostSharing")
    valueRequired = URIRef("https://schema.org/valueRequired")
    geographicArea = URIRef("https://schema.org/geographicArea")
    nonEqual = URIRef("https://schema.org/nonEqual")
    review = URIRef("https://schema.org/review")
    TypesHealthAspect = URIRef("https://schema.org/TypesHealthAspect")
    numAdults = URIRef("https://schema.org/numAdults")
    clincalPharmacology = URIRef("https://schema.org/clincalPharmacology")
    numberOfCredits = URIRef("https://schema.org/numberOfCredits")
    issueNumber = URIRef("https://schema.org/issueNumber")
    owns = URIRef("https://schema.org/owns")
    fuelType = URIRef("https://schema.org/fuelType")
    biomechnicalClass = URIRef("https://schema.org/biomechnicalClass")
    webFeed = URIRef("https://schema.org/webFeed")
    inChIKey = URIRef("https://schema.org/inChIKey")
    musicBy = URIRef("https://schema.org/musicBy")
    gtin8 = URIRef("https://schema.org/gtin8")
    publishingPrinciples = URIRef("https://schema.org/publishingPrinciples")
    MedicalObservationalStudyDesign = URIRef("https://schema.org/MedicalObservationalStudyDesign")
    causeOf = URIRef("https://schema.org/causeOf")
    EnrollingByInvitation = URIRef("https://schema.org/EnrollingByInvitation")
    repetitions = URIRef("https://schema.org/repetitions")
    billingPeriod = URIRef("https://schema.org/billingPeriod")
    cutoffTime = URIRef("https://schema.org/cutoffTime")
    addressRegion = URIRef("https://schema.org/addressRegion")
    House = URIRef("https://schema.org/House")
    videoQuality = URIRef("https://schema.org/videoQuality")
    departureGate = URIRef("https://schema.org/departureGate")
    DepositAccount = URIRef("https://schema.org/DepositAccount")
    videoFormat = URIRef("https://schema.org/videoFormat")
    RecyclingCenter = URIRef("https://schema.org/RecyclingCenter")
    artist = URIRef("https://schema.org/artist")
    ItemPage = URIRef("https://schema.org/ItemPage")
    duringMedia = URIRef("https://schema.org/duringMedia")
    itinerary = URIRef("https://schema.org/itinerary")
    DataCatalog = URIRef("https://schema.org/DataCatalog")
    WebPageElement = URIRef("https://schema.org/WebPageElement")
    ComicStory = URIRef("https://schema.org/ComicStory")
    sensoryUnit = URIRef("https://schema.org/sensoryUnit")
    scheduledPaymentDate = URIRef("https://schema.org/scheduledPaymentDate")
    defaultValue = URIRef("https://schema.org/defaultValue")
    MerchantReturnUnlimitedWindow = URIRef("https://schema.org/MerchantReturnUnlimitedWindow")
    itemLocation = URIRef("https://schema.org/itemLocation")
    unitText = URIRef("https://schema.org/unitText")
    disambiguatingDescription = URIRef("https://schema.org/disambiguatingDescription")
    EducationEvent = URIRef("https://schema.org/EducationEvent")
    EditedOrCroppedContent = URIRef("https://schema.org/EditedOrCroppedContent")
    paymentUrl = URIRef("https://schema.org/paymentUrl")
    NarcoticConsideration = URIRef("https://schema.org/NarcoticConsideration")
    performers = URIRef("https://schema.org/performers")
    countryOfAssembly = URIRef("https://schema.org/countryOfAssembly")
    question = URIRef("https://schema.org/question")
    RelatedTopicsHealthAspect = URIRef("https://schema.org/RelatedTopicsHealthAspect")
    copyrightHolder = URIRef("https://schema.org/copyrightHolder")
    dataFeedElement = URIRef("https://schema.org/dataFeedElement")
    maximumVirtualAttendeeCapacity = URIRef("https://schema.org/maximumVirtualAttendeeCapacity")
    replacer = URIRef("https://schema.org/replacer")
    ReservationCancelled = URIRef("https://schema.org/ReservationCancelled")
    MedicalSymptom = URIRef("https://schema.org/MedicalSymptom")
    employerOverview = URIRef("https://schema.org/employerOverview")
    acceptedOffer = URIRef("https://schema.org/acceptedOffer")
    callSign = URIRef("https://schema.org/callSign")
    Therapeutic = URIRef("https://schema.org/Therapeutic")
    CT = URIRef("https://schema.org/CT")
    usageInfo = URIRef("https://schema.org/usageInfo")
    EmploymentAgency = URIRef("https://schema.org/EmploymentAgency")
    ReservationConfirmed = URIRef("https://schema.org/ReservationConfirmed")
    serviceOutput = URIRef("https://schema.org/serviceOutput")
    SomeProducts = URIRef("https://schema.org/SomeProducts")
    CharitableIncorporatedOrganization = URIRef("https://schema.org/CharitableIncorporatedOrganization")
    roofLoad = URIRef("https://schema.org/roofLoad")
    embeddedTextCaption = URIRef("https://schema.org/embeddedTextCaption")
    travelBans = URIRef("https://schema.org/travelBans")
    weight = URIRef("https://schema.org/weight")
    numberOfBathroomsTotal = URIRef("https://schema.org/numberOfBathroomsTotal")
    Demand = URIRef("https://schema.org/Demand")
    conditionsOfAccess = URIRef("https://schema.org/conditionsOfAccess")
    postalCode = URIRef("https://schema.org/postalCode")
    BusStop = URIRef("https://schema.org/BusStop")
    WearableSizeGroupBig = URIRef("https://schema.org/WearableSizeGroupBig")
    suggestedAge = URIRef("https://schema.org/suggestedAge")
    mileageFromOdometer = URIRef("https://schema.org/mileageFromOdometer")
    studyLocation = URIRef("https://schema.org/studyLocation")
    WPAdBlock = URIRef("https://schema.org/WPAdBlock")
    isPlanForApartment = URIRef("https://schema.org/isPlanForApartment")
    albumProductionType = URIRef("https://schema.org/albumProductionType")
    NarcoticConsideration = URIRef("https://schema.org/NarcoticConsideration")
    runtime = URIRef("https://schema.org/runtime")
    termCode = URIRef("https://schema.org/termCode")
    ReserveAction = URIRef("https://schema.org/ReserveAction")
    restPeriods = URIRef("https://schema.org/restPeriods")
    lyricist = URIRef("https://schema.org/lyricist")
    screenCount = URIRef("https://schema.org/screenCount")
    MedicalResearcher = URIRef("https://schema.org/MedicalResearcher")
    pageEnd = URIRef("https://schema.org/pageEnd")
    healthCondition = URIRef("https://schema.org/healthCondition")
    FireStation = URIRef("https://schema.org/FireStation")
    driveWheelConfiguration = URIRef("https://schema.org/driveWheelConfiguration")
    leaseLength = URIRef("https://schema.org/leaseLength")
    geoRadius = URIRef("https://schema.org/geoRadius")
    cvdNumC19OFMechVentPats = URIRef("https://schema.org/cvdNumC19OFMechVentPats")
    ApplyAction = URIRef("https://schema.org/ApplyAction")
    collection = URIRef("https://schema.org/collection")
    percentile75 = URIRef("https://schema.org/percentile75")
    inker = URIRef("https://schema.org/inker")
    study = URIRef("https://schema.org/study")
    logo = URIRef("https://schema.org/logo")
    healthPlanCostSharing = URIRef("https://schema.org/healthPlanCostSharing")
    potentialAction = URIRef("https://schema.org/potentialAction")
    fundedItem = URIRef("https://schema.org/fundedItem")
    Female = URIRef("https://schema.org/Female")
    Pathology = URIRef("https://schema.org/Pathology")
    SizeSystemImperial = URIRef("https://schema.org/SizeSystemImperial")
    relatedStructure = URIRef("https://schema.org/relatedStructure")
    relatedStructure = URIRef("https://schema.org/relatedStructure")
    DonateAction = URIRef("https://schema.org/DonateAction")
    eligibleQuantity = URIRef("https://schema.org/eligibleQuantity")
    sizeGroup = URIRef("https://schema.org/sizeGroup")
    TechArticle = URIRef("https://schema.org/TechArticle")
    InvestmentOrDeposit = URIRef("https://schema.org/InvestmentOrDeposit")
    asin = URIRef("https://schema.org/asin")
    BedType = URIRef("https://schema.org/BedType")
    domainIncludes = URIRef("https://schema.org/domainIncludes")
    RadioClip = URIRef("https://schema.org/RadioClip")
    Thing = URIRef("https://schema.org/Thing")
    FoodEvent = URIRef("https://schema.org/FoodEvent")
    Nonprofit501c19 = URIRef("https://schema.org/Nonprofit501c19")
    trainingSalary = URIRef("https://schema.org/trainingSalary")
    SalePrice = URIRef("https://schema.org/SalePrice")
    Sunday = URIRef("https://schema.org/Sunday")
    DeliveryTimeSettings = URIRef("https://schema.org/DeliveryTimeSettings")
    energyEfficiencyScaleMax = URIRef("https://schema.org/energyEfficiencyScaleMax")
    SymptomsHealthAspect = URIRef("https://schema.org/SymptomsHealthAspect")
    membershipPointsEarned = URIRef("https://schema.org/membershipPointsEarned")
    targetPopulation = URIRef("https://schema.org/targetPopulation")
    addressCountry = URIRef("https://schema.org/addressCountry")
    EatAction = URIRef("https://schema.org/EatAction")
    MovieTheater = URIRef("https://schema.org/MovieTheater")
    fiberContent = URIRef("https://schema.org/fiberContent")
    Protein = URIRef("https://schema.org/Protein")
    disambiguatingDescription = URIRef("https://schema.org/disambiguatingDescription")
    departureStation = URIRef("https://schema.org/departureStation")
    liveBlogUpdate = URIRef("https://schema.org/liveBlogUpdate")
    SpecialAnnouncement = URIRef("https://schema.org/SpecialAnnouncement")
    Genitourinary = URIRef("https://schema.org/Genitourinary")
    serialNumber = URIRef("https://schema.org/serialNumber")
    Pathology = URIRef("https://schema.org/Pathology")
    bioChemInteraction = URIRef("https://schema.org/bioChemInteraction")
    WatchAction = URIRef("https://schema.org/WatchAction")
    Movie = URIRef("https://schema.org/Movie")
    closes = URIRef("https://schema.org/closes")
    epidemiology = URIRef("https://schema.org/epidemiology")
    contactlessPayment = URIRef("https://schema.org/contactlessPayment")
    deliveryTime = URIRef("https://schema.org/deliveryTime")
    RadiationTherapy = URIRef("https://schema.org/RadiationTherapy")
    DrugLegalStatus = URIRef("https://schema.org/DrugLegalStatus")
    hasBioPolymerSequence = URIRef("https://schema.org/hasBioPolymerSequence")
    targetProduct = URIRef("https://schema.org/targetProduct")
    Diagnostic = URIRef("https://schema.org/Diagnostic")
    rxcui = URIRef("https://schema.org/rxcui")
    expressedIn = URIRef("https://schema.org/expressedIn")
    Nonprofit501c22 = URIRef("https://schema.org/Nonprofit501c22")
    financialAidEligible = URIRef("https://schema.org/financialAidEligible")
    cvdNumC19OFMechVentPats = URIRef("https://schema.org/cvdNumC19OFMechVentPats")
    FMRadioChannel = URIRef("https://schema.org/FMRadioChannel")
    preOp = URIRef("https://schema.org/preOp")
    fiberContent = URIRef("https://schema.org/fiberContent")
    thumbnail = URIRef("https://schema.org/thumbnail")
    MedicalGuidelineContraindication = URIRef("https://schema.org/MedicalGuidelineContraindication")
    ClothingStore = URIRef("https://schema.org/ClothingStore")
    membershipPointsEarned = URIRef("https://schema.org/membershipPointsEarned")
    TextObject = URIRef("https://schema.org/TextObject")
    SizeSystemEnumeration = URIRef("https://schema.org/SizeSystemEnumeration")
    nutrition = URIRef("https://schema.org/nutrition")
    AllocateAction = URIRef("https://schema.org/AllocateAction")
    WorkersUnion = URIRef("https://schema.org/WorkersUnion")
    LimitedAvailability = URIRef("https://schema.org/LimitedAvailability")
    Product = URIRef("https://schema.org/Product")
    productionCompany = URIRef("https://schema.org/productionCompany")
    mathExpression = URIRef("https://schema.org/mathExpression")
    replyToUrl = URIRef("https://schema.org/replyToUrl")
    Dermatologic = URIRef("https://schema.org/Dermatologic")
    costOrigin = URIRef("https://schema.org/costOrigin")
    numConstraints = URIRef("https://schema.org/numConstraints")
    countriesSupported = URIRef("https://schema.org/countriesSupported")
    publisherImprint = URIRef("https://schema.org/publisherImprint")
    bodyLocation = URIRef("https://schema.org/bodyLocation")
    followup = URIRef("https://schema.org/followup")
    Nonprofit501c18 = URIRef("https://schema.org/Nonprofit501c18")
    MediaSubscription = URIRef("https://schema.org/MediaSubscription")
    WearableSizeGroupMens = URIRef("https://schema.org/WearableSizeGroupMens")
    contactPoints = URIRef("https://schema.org/contactPoints")
    isLocatedInSubcellularLocation = URIRef("https://schema.org/isLocatedInSubcellularLocation")
    FlightReservation = URIRef("https://schema.org/FlightReservation")
    Subscription = URIRef("https://schema.org/Subscription")
    AboutPage = URIRef("https://schema.org/AboutPage")
    payload = URIRef("https://schema.org/payload")
    partOfOrder = URIRef("https://schema.org/partOfOrder")
    partOfOrder = URIRef("https://schema.org/partOfOrder")
    reviewRating = URIRef("https://schema.org/reviewRating")
    diversityStaffingReport = URIRef("https://schema.org/diversityStaffingReport")
    description = URIRef("https://schema.org/description")
    PhysicalActivity = URIRef("https://schema.org/PhysicalActivity")
    FastFoodRestaurant = URIRef("https://schema.org/FastFoodRestaurant")
    Mosque = URIRef("https://schema.org/Mosque")
    VideoObject = URIRef("https://schema.org/VideoObject")
    PublicHealth = URIRef("https://schema.org/PublicHealth")
    governmentBenefitsInfo = URIRef("https://schema.org/governmentBenefitsInfo")
    hasMerchantReturnPolicy = URIRef("https://schema.org/hasMerchantReturnPolicy")
    lodgingUnitDescription = URIRef("https://schema.org/lodgingUnitDescription")
    nextItem = URIRef("https://schema.org/nextItem")
    Friday = URIRef("https://schema.org/Friday")
    TrainedAlgorithmicMediaDigitalSource = URIRef("https://schema.org/TrainedAlgorithmicMediaDigitalSource")
    inventoryLevel = URIRef("https://schema.org/inventoryLevel")
    FDAcategoryC = URIRef("https://schema.org/FDAcategoryC")
    skills = URIRef("https://schema.org/skills")
    AnatomicalStructure = URIRef("https://schema.org/AnatomicalStructure")
    trainNumber = URIRef("https://schema.org/trainNumber")
    BusinessEvent = URIRef("https://schema.org/BusinessEvent")
    diagram = URIRef("https://schema.org/diagram")
    PaymentAutomaticallyApplied = URIRef("https://schema.org/PaymentAutomaticallyApplied")
    contributor = URIRef("https://schema.org/contributor")
    healthPlanId = URIRef("https://schema.org/healthPlanId")
    physicalRequirement = URIRef("https://schema.org/physicalRequirement")
    chemicalComposition = URIRef("https://schema.org/chemicalComposition")
    floorLimit = URIRef("https://schema.org/floorLimit")
    applicationCategory = URIRef("https://schema.org/applicationCategory")
    isUnlabelledFallback = URIRef("https://schema.org/isUnlabelledFallback")
    availableService = URIRef("https://schema.org/availableService")
    Blog = URIRef("https://schema.org/Blog")
    typeOfBed = URIRef("https://schema.org/typeOfBed")
    businessFunction = URIRef("https://schema.org/businessFunction")
    PharmacySpecialty = URIRef("https://schema.org/PharmacySpecialty")
    WearableSizeSystemDE = URIRef("https://schema.org/WearableSizeSystemDE")
    discountCurrency = URIRef("https://schema.org/discountCurrency")
    duringMedia = URIRef("https://schema.org/duringMedia")
    webFeed = URIRef("https://schema.org/webFeed")
    reviewAspect = URIRef("https://schema.org/reviewAspect")
    healthPlanCoinsuranceOption = URIRef("https://schema.org/healthPlanCoinsuranceOption")
    articleSection = URIRef("https://schema.org/articleSection")
    termCode = URIRef("https://schema.org/termCode")
    price = URIRef("https://schema.org/price")
    valueAddedTaxIncluded = URIRef("https://schema.org/valueAddedTaxIncluded")
    startDate = URIRef("https://schema.org/startDate")
    workload = URIRef("https://schema.org/workload")
    NegativeFilmDigitalSource = URIRef("https://schema.org/NegativeFilmDigitalSource")
    cheatCode = URIRef("https://schema.org/cheatCode")
    masthead = URIRef("https://schema.org/masthead")
    SportsEvent = URIRef("https://schema.org/SportsEvent")
    translationOfWork = URIRef("https://schema.org/translationOfWork")
    recipeYield = URIRef("https://schema.org/recipeYield")
    RejectAction = URIRef("https://schema.org/RejectAction")
    Pulmonary = URIRef("https://schema.org/Pulmonary")
    dissolutionDate = URIRef("https://schema.org/dissolutionDate")
    TreatmentIndication = URIRef("https://schema.org/TreatmentIndication")
    LiteraryEvent = URIRef("https://schema.org/LiteraryEvent")
    attendee = URIRef("https://schema.org/attendee")
    WearableMeasurementWidth = URIRef("https://schema.org/WearableMeasurementWidth")
    Nonprofit501c6 = URIRef("https://schema.org/Nonprofit501c6")
    mechanismOfAction = URIRef("https://schema.org/mechanismOfAction")
    Waterfall = URIRef("https://schema.org/Waterfall")
    relatedStructure = URIRef("https://schema.org/relatedStructure")
    imagingTechnique = URIRef("https://schema.org/imagingTechnique")
    codeValue = URIRef("https://schema.org/codeValue")
    energyEfficiencyScaleMin = URIRef("https://schema.org/energyEfficiencyScaleMin")
    relatedDrug = URIRef("https://schema.org/relatedDrug")
    includedInDataCatalog = URIRef("https://schema.org/includedInDataCatalog")
    ownershipFundingInfo = URIRef("https://schema.org/ownershipFundingInfo")
    educationalCredentialAwarded = URIRef("https://schema.org/educationalCredentialAwarded")
    PublicationVolume = URIRef("https://schema.org/PublicationVolume")
    validThrough = URIRef("https://schema.org/validThrough")
    appliesToDeliveryMethod = URIRef("https://schema.org/appliesToDeliveryMethod")
    salaryCurrency = URIRef("https://schema.org/salaryCurrency")
    isUnlabelledFallback = URIRef("https://schema.org/isUnlabelledFallback")
    SizeSystemEnumeration = URIRef("https://schema.org/SizeSystemEnumeration")
    sportsEvent = URIRef("https://schema.org/sportsEvent")
    targetDescription = URIRef("https://schema.org/targetDescription")
    xpath = URIRef("https://schema.org/xpath")
    BodyMeasurementTypeEnumeration = URIRef("https://schema.org/BodyMeasurementTypeEnumeration")
    printColumn = URIRef("https://schema.org/printColumn")
    termDuration = URIRef("https://schema.org/termDuration")
    volumeNumber = URIRef("https://schema.org/volumeNumber")
    trainingSalary = URIRef("https://schema.org/trainingSalary")
    Intangible = URIRef("https://schema.org/Intangible")
    customerRemorseReturnFees = URIRef("https://schema.org/customerRemorseReturnFees")
    merchantReturnDays = URIRef("https://schema.org/merchantReturnDays")
    actionStatus = URIRef("https://schema.org/actionStatus")
    Service = URIRef("https://schema.org/Service")
    merchantReturnLink = URIRef("https://schema.org/merchantReturnLink")
    OfferItemCondition = URIRef("https://schema.org/OfferItemCondition")
    medicalSpecialty = URIRef("https://schema.org/medicalSpecialty")
    MusculoskeletalExam = URIRef("https://schema.org/MusculoskeletalExam")
    BodyMeasurementHead = URIRef("https://schema.org/BodyMeasurementHead")
    WarrantyPromise = URIRef("https://schema.org/WarrantyPromise")
    legalName = URIRef("https://schema.org/legalName")
    merchantReturnLink = URIRef("https://schema.org/merchantReturnLink")
    foodEvent = URIRef("https://schema.org/foodEvent")
    currentExchangeRate = URIRef("https://schema.org/currentExchangeRate")
    FrontWheelDriveConfiguration = URIRef("https://schema.org/FrontWheelDriveConfiguration")
    PaymentChargeSpecification = URIRef("https://schema.org/PaymentChargeSpecification")
    accessCode = URIRef("https://schema.org/accessCode")
    Comment = URIRef("https://schema.org/Comment")
    fundedItem = URIRef("https://schema.org/fundedItem")
    issueNumber = URIRef("https://schema.org/issueNumber")
    TrainTrip = URIRef("https://schema.org/TrainTrip")
    mealService = URIRef("https://schema.org/mealService")
    CategoryCode = URIRef("https://schema.org/CategoryCode")
    coursePrerequisites = URIRef("https://schema.org/coursePrerequisites")
    gtin8 = URIRef("https://schema.org/gtin8")
    UKTrust = URIRef("https://schema.org/UKTrust")
    bccRecipient = URIRef("https://schema.org/bccRecipient")
    BoatTerminal = URIRef("https://schema.org/BoatTerminal")
    valueRequired = URIRef("https://schema.org/valueRequired")
    screenshot = URIRef("https://schema.org/screenshot")
    MedicalIndication = URIRef("https://schema.org/MedicalIndication")
    episodes = URIRef("https://schema.org/episodes")
    DeliveryTimeSettings = URIRef("https://schema.org/DeliveryTimeSettings")
    GovernmentOffice = URIRef("https://schema.org/GovernmentOffice")
    ChemicalSubstance = URIRef("https://schema.org/ChemicalSubstance")
    geoEquals = URIRef("https://schema.org/geoEquals")
    educationRequirements = URIRef("https://schema.org/educationRequirements")
    bed = URIRef("https://schema.org/bed")
    candidate = URIRef("https://schema.org/candidate")
    itemCondition = URIRef("https://schema.org/itemCondition")
    healthPlanCostSharing = URIRef("https://schema.org/healthPlanCostSharing")
    MonetaryAmountDistribution = URIRef("https://schema.org/MonetaryAmountDistribution")
    validFrom = URIRef("https://schema.org/validFrom")
    Volcano = URIRef("https://schema.org/Volcano")
    publicTransportClosuresInfo = URIRef("https://schema.org/publicTransportClosuresInfo")
    quest = URIRef("https://schema.org/quest")
    CityHall = URIRef("https://schema.org/CityHall")
    costCategory = URIRef("https://schema.org/costCategory")
    producer = URIRef("https://schema.org/producer")
    issuedBy = URIRef("https://schema.org/issuedBy")
    CorrectionComment = URIRef("https://schema.org/CorrectionComment")
    warning = URIRef("https://schema.org/warning")
    addressLocality = URIRef("https://schema.org/addressLocality")
    EventPostponed = URIRef("https://schema.org/EventPostponed")
    editor = URIRef("https://schema.org/editor")
    quest = URIRef("https://schema.org/quest")
    studyLocation = URIRef("https://schema.org/studyLocation")
    WearableSizeSystemBR = URIRef("https://schema.org/WearableSizeSystemBR")
    orderDate = URIRef("https://schema.org/orderDate")
    UsageOrScheduleHealthAspect = URIRef("https://schema.org/UsageOrScheduleHealthAspect")
    cvdNumICUBedsOcc = URIRef("https://schema.org/cvdNumICUBedsOcc")
    SocialEvent = URIRef("https://schema.org/SocialEvent")
    EducationalOccupationalProgram = URIRef("https://schema.org/EducationalOccupationalProgram")
    BodyMeasurementArm = URIRef("https://schema.org/BodyMeasurementArm")
    CT = URIRef("https://schema.org/CT")
    DanceEvent = URIRef("https://schema.org/DanceEvent")
    servicePhone = URIRef("https://schema.org/servicePhone")
    BookSeries = URIRef("https://schema.org/BookSeries")
    HealthAspectEnumeration = URIRef("https://schema.org/HealthAspectEnumeration")
    chemicalRole = URIRef("https://schema.org/chemicalRole")
    verificationFactCheckingPolicy = URIRef("https://schema.org/verificationFactCheckingPolicy")
    byDay = URIRef("https://schema.org/byDay")
    functionalClass = URIRef("https://schema.org/functionalClass")
    WearableMeasurementHeight = URIRef("https://schema.org/WearableMeasurementHeight")
    DigitalDocument = URIRef("https://schema.org/DigitalDocument")
    game = URIRef("https://schema.org/game")
    availabilityEnds = URIRef("https://schema.org/availabilityEnds")
    guidelineDate = URIRef("https://schema.org/guidelineDate")
    taxID = URIRef("https://schema.org/taxID")
    partOfSeason = URIRef("https://schema.org/partOfSeason")
    applicantLocationRequirements = URIRef("https://schema.org/applicantLocationRequirements")
    creator = URIRef("https://schema.org/creator")
    tickerSymbol = URIRef("https://schema.org/tickerSymbol")
    Observation = URIRef("https://schema.org/Observation")
    ApartmentComplex = URIRef("https://schema.org/ApartmentComplex")
    HowToDirection = URIRef("https://schema.org/HowToDirection")
    broker = URIRef("https://schema.org/broker")
    toRecipient = URIRef("https://schema.org/toRecipient")
    healthPlanDrugTier = URIRef("https://schema.org/healthPlanDrugTier")
    Taxon = URIRef("https://schema.org/Taxon")
    numberOfDoors = URIRef("https://schema.org/numberOfDoors")
    usNPI = URIRef("https://schema.org/usNPI")
    engineType = URIRef("https://schema.org/engineType")
    amount = URIRef("https://schema.org/amount")
    VeganDiet = URIRef("https://schema.org/VeganDiet")
    DrugPregnancyCategory = URIRef("https://schema.org/DrugPregnancyCategory")
    numberOfForwardGears = URIRef("https://schema.org/numberOfForwardGears")
    addressRegion = URIRef("https://schema.org/addressRegion")
    Reservoir = URIRef("https://schema.org/Reservoir")
    artist = URIRef("https://schema.org/artist")
    releaseOf = URIRef("https://schema.org/releaseOf")
    sha256 = URIRef("https://schema.org/sha256")
    restPeriods = URIRef("https://schema.org/restPeriods")
    exifData = URIRef("https://schema.org/exifData")
    characterName = URIRef("https://schema.org/characterName")
    minimumPaymentDue = URIRef("https://schema.org/minimumPaymentDue")
    address = URIRef("https://schema.org/address")
    ownershipFundingInfo = URIRef("https://schema.org/ownershipFundingInfo")
    language = URIRef("https://schema.org/language")
    rsvpResponse = URIRef("https://schema.org/rsvpResponse")
    typicalAgeRange = URIRef("https://schema.org/typicalAgeRange")
    AdultOrientedEnumeration = URIRef("https://schema.org/AdultOrientedEnumeration")
    lesser = URIRef("https://schema.org/lesser")
    totalJobOpenings = URIRef("https://schema.org/totalJobOpenings")
    partOfTVSeries = URIRef("https://schema.org/partOfTVSeries")
    bed = URIRef("https://schema.org/bed")
    FastFoodRestaurant = URIRef("https://schema.org/FastFoodRestaurant")
    GamePlayMode = URIRef("https://schema.org/GamePlayMode")
    orderItemNumber = URIRef("https://schema.org/orderItemNumber")
    SocialEvent = URIRef("https://schema.org/SocialEvent")
    MediaReview = URIRef("https://schema.org/MediaReview")
    QuoteAction = URIRef("https://schema.org/QuoteAction")
    recommendationStrength = URIRef("https://schema.org/recommendationStrength")
    BodyMeasurementFoot = URIRef("https://schema.org/BodyMeasurementFoot")
    broadcastSubChannel = URIRef("https://schema.org/broadcastSubChannel")
    announcementLocation = URIRef("https://schema.org/announcementLocation")
    Game = URIRef("https://schema.org/Game")
    HealthPlanFormulary = URIRef("https://schema.org/HealthPlanFormulary")
    freeShippingThreshold = URIRef("https://schema.org/freeShippingThreshold")
    HowToStep = URIRef("https://schema.org/HowToStep")
    review = URIRef("https://schema.org/review")
    clipNumber = URIRef("https://schema.org/clipNumber")
    usNPI = URIRef("https://schema.org/usNPI")
    blogPost = URIRef("https://schema.org/blogPost")
    homeTeam = URIRef("https://schema.org/homeTeam")
    copyrightNotice = URIRef("https://schema.org/copyrightNotice")
    SeaBodyOfWater = URIRef("https://schema.org/SeaBodyOfWater")
    publicTransportClosuresInfo = URIRef("https://schema.org/publicTransportClosuresInfo")
    highPrice = URIRef("https://schema.org/highPrice")
    orderNumber = URIRef("https://schema.org/orderNumber")
    billingDuration = URIRef("https://schema.org/billingDuration")
    meetsEmissionStandard = URIRef("https://schema.org/meetsEmissionStandard")
    itinerary = URIRef("https://schema.org/itinerary")
    contentType = URIRef("https://schema.org/contentType")
    documentation = URIRef("https://schema.org/documentation")
    ArchiveComponent = URIRef("https://schema.org/ArchiveComponent")
    MedicalTrial = URIRef("https://schema.org/MedicalTrial")
    EnrollingByInvitation = URIRef("https://schema.org/EnrollingByInvitation")
    Nonprofit501c7 = URIRef("https://schema.org/Nonprofit501c7")
    sportsActivityLocation = URIRef("https://schema.org/sportsActivityLocation")
    recipient = URIRef("https://schema.org/recipient")
    School = URIRef("https://schema.org/School")
    correction = URIRef("https://schema.org/correction")
    MinorHumanEditsDigitalSource = URIRef("https://schema.org/MinorHumanEditsDigitalSource")
    HealthPlanNetwork = URIRef("https://schema.org/HealthPlanNetwork")
    NotYetRecruiting = URIRef("https://schema.org/NotYetRecruiting")
    floorLimit = URIRef("https://schema.org/floorLimit")
    GameAvailabilityEnumeration = URIRef("https://schema.org/GameAvailabilityEnumeration")
    hasOfferCatalog = URIRef("https://schema.org/hasOfferCatalog")
    passengerPriorityStatus = URIRef("https://schema.org/passengerPriorityStatus")
    eventSchedule = URIRef("https://schema.org/eventSchedule")
    borrower = URIRef("https://schema.org/borrower")
    ClothingStore = URIRef("https://schema.org/ClothingStore")
    BuyAction = URIRef("https://schema.org/BuyAction")
    AutoDealer = URIRef("https://schema.org/AutoDealer")
    loser = URIRef("https://schema.org/loser")
    endOffset = URIRef("https://schema.org/endOffset")
    constraintProperty = URIRef("https://schema.org/constraintProperty")
    scheduleTimezone = URIRef("https://schema.org/scheduleTimezone")
    cvdNumTotBeds = URIRef("https://schema.org/cvdNumTotBeds")
    numberOfBathroomsTotal = URIRef("https://schema.org/numberOfBathroomsTotal")
    procedureType = URIRef("https://schema.org/procedureType")
    broadcastFrequencyValue = URIRef("https://schema.org/broadcastFrequencyValue")
    domiciledMortgage = URIRef("https://schema.org/domiciledMortgage")
    ticketedSeat = URIRef("https://schema.org/ticketedSeat")
    composer = URIRef("https://schema.org/composer")
    hasMenuItem = URIRef("https://schema.org/hasMenuItem")
    OrderProblem = URIRef("https://schema.org/OrderProblem")
    aggregateRating = URIRef("https://schema.org/aggregateRating")
    HomeGoodsStore = URIRef("https://schema.org/HomeGoodsStore")
    citation = URIRef("https://schema.org/citation")
    employerOverview = URIRef("https://schema.org/employerOverview")
    TouristInformationCenter = URIRef("https://schema.org/TouristInformationCenter")
    recipient = URIRef("https://schema.org/recipient")
    hasAdultConsideration = URIRef("https://schema.org/hasAdultConsideration")
    category = URIRef("https://schema.org/category")
    correctionsPolicy = URIRef("https://schema.org/correctionsPolicy")
    applicableCountry = URIRef("https://schema.org/applicableCountry")
    TouristAttraction = URIRef("https://schema.org/TouristAttraction")
    OrderReturned = URIRef("https://schema.org/OrderReturned")
    timeToComplete = URIRef("https://schema.org/timeToComplete")
    PhysicalTherapy = URIRef("https://schema.org/PhysicalTherapy")
    hasDefinedTerm = URIRef("https://schema.org/hasDefinedTerm")
    gtin8 = URIRef("https://schema.org/gtin8")
    steeringPosition = URIRef("https://schema.org/steeringPosition")
    numberOfCredits = URIRef("https://schema.org/numberOfCredits")
    correctionsPolicy = URIRef("https://schema.org/correctionsPolicy")
    exercisePlan = URIRef("https://schema.org/exercisePlan")
    performer = URIRef("https://schema.org/performer")
    reportNumber = URIRef("https://schema.org/reportNumber")
    energyEfficiencyScaleMin = URIRef("https://schema.org/energyEfficiencyScaleMin")
    checkoutPageURLTemplate = URIRef("https://schema.org/checkoutPageURLTemplate")
    AlignmentObject = URIRef("https://schema.org/AlignmentObject")
    RespiratoryTherapy = URIRef("https://schema.org/RespiratoryTherapy")
    ReturnAtKiosk = URIRef("https://schema.org/ReturnAtKiosk")
    sponsor = URIRef("https://schema.org/sponsor")
    nutrition = URIRef("https://schema.org/nutrition")
    MovieClip = URIRef("https://schema.org/MovieClip")
    broadcastSignalModulation = URIRef("https://schema.org/broadcastSignalModulation")
    itemCondition = URIRef("https://schema.org/itemCondition")
    Enumeration = URIRef("https://schema.org/Enumeration")
    Protein = URIRef("https://schema.org/Protein")
    Poster = URIRef("https://schema.org/Poster")
    businessFunction = URIRef("https://schema.org/businessFunction")
    ineligibleRegion = URIRef("https://schema.org/ineligibleRegion")
    publishingPrinciples = URIRef("https://schema.org/publishingPrinciples")
    departureAirport = URIRef("https://schema.org/departureAirport")
    NotYetRecruiting = URIRef("https://schema.org/NotYetRecruiting")
    grantee = URIRef("https://schema.org/grantee")
    BodyMeasurementTypeEnumeration = URIRef("https://schema.org/BodyMeasurementTypeEnumeration")
    additionalProperty = URIRef("https://schema.org/additionalProperty")
    suggestedAnswer = URIRef("https://schema.org/suggestedAnswer")
    PublicHealth = URIRef("https://schema.org/PublicHealth")
    WearableSizeGroupInfants = URIRef("https://schema.org/WearableSizeGroupInfants")
    MerchantReturnPolicySeasonalOverride = URIRef("https://schema.org/MerchantReturnPolicySeasonalOverride")
    SRP = URIRef("https://schema.org/SRP")
    VeterinaryCare = URIRef("https://schema.org/VeterinaryCare")
    BroadcastEvent = URIRef("https://schema.org/BroadcastEvent")
    volumeNumber = URIRef("https://schema.org/volumeNumber")
    WearableSizeSystemAU = URIRef("https://schema.org/WearableSizeSystemAU")
    AmusementPark = URIRef("https://schema.org/AmusementPark")
    ShippingRateSettings = URIRef("https://schema.org/ShippingRateSettings")
    permittedUsage = URIRef("https://schema.org/permittedUsage")
    MedicalAudience = URIRef("https://schema.org/MedicalAudience")
    reviews = URIRef("https://schema.org/reviews")
    PaymentDeclined = URIRef("https://schema.org/PaymentDeclined")
    ActiveActionStatus = URIRef("https://schema.org/ActiveActionStatus")
    MerchantReturnUnlimitedWindow = URIRef("https://schema.org/MerchantReturnUnlimitedWindow")
    AdministrativeArea = URIRef("https://schema.org/AdministrativeArea")
    isPartOfBioChemEntity = URIRef("https://schema.org/isPartOfBioChemEntity")
    diseasePreventionInfo = URIRef("https://schema.org/diseasePreventionInfo")
    valueAddedTaxIncluded = URIRef("https://schema.org/valueAddedTaxIncluded")
    MedicalIntangible = URIRef("https://schema.org/MedicalIntangible")
    foodWarning = URIRef("https://schema.org/foodWarning")
    CardiovascularExam = URIRef("https://schema.org/CardiovascularExam")
    position = URIRef("https://schema.org/position")
    TouristTrip = URIRef("https://schema.org/TouristTrip")
    BodyMeasurementUnderbust = URIRef("https://schema.org/BodyMeasurementUnderbust")
    about = URIRef("https://schema.org/about")
    bccRecipient = URIRef("https://schema.org/bccRecipient")
    phoneticText = URIRef("https://schema.org/phoneticText")
    discountCurrency = URIRef("https://schema.org/discountCurrency")
    creativeWorkStatus = URIRef("https://schema.org/creativeWorkStatus")
    nerve = URIRef("https://schema.org/nerve")
    MedicalSignOrSymptom = URIRef("https://schema.org/MedicalSignOrSymptom")
    MotorizedBicycle = URIRef("https://schema.org/MotorizedBicycle")
    handlingTime = URIRef("https://schema.org/handlingTime")
    webFeed = URIRef("https://schema.org/webFeed")
    repeatCount = URIRef("https://schema.org/repeatCount")
    inStoreReturnsOffered = URIRef("https://schema.org/inStoreReturnsOffered")
    encodings = URIRef("https://schema.org/encodings")
    reservedTicket = URIRef("https://schema.org/reservedTicket")
    numConstraints = URIRef("https://schema.org/numConstraints")
    connectedTo = URIRef("https://schema.org/connectedTo")
    openingHoursSpecification = URIRef("https://schema.org/openingHoursSpecification")
    medicineSystem = URIRef("https://schema.org/medicineSystem")
    firstAppearance = URIRef("https://schema.org/firstAppearance")
    playersOnline = URIRef("https://schema.org/playersOnline")
    runsTo = URIRef("https://schema.org/runsTo")
    measurementTechnique = URIRef("https://schema.org/measurementTechnique")
    Vessel = URIRef("https://schema.org/Vessel")
    sharedContent = URIRef("https://schema.org/sharedContent")
    departureTime = URIRef("https://schema.org/departureTime")
    recordedAs = URIRef("https://schema.org/recordedAs")
    illustrator = URIRef("https://schema.org/illustrator")
    ResearchProject = URIRef("https://schema.org/ResearchProject")
    ReturnShippingFees = URIRef("https://schema.org/ReturnShippingFees")
    replacer = URIRef("https://schema.org/replacer")
    transitTime = URIRef("https://schema.org/transitTime")
    partySize = URIRef("https://schema.org/partySize")
    FastFoodRestaurant = URIRef("https://schema.org/FastFoodRestaurant")
    Wholesale = URIRef("https://schema.org/Wholesale")
    accessMode = URIRef("https://schema.org/accessMode")
    itemOffered = URIRef("https://schema.org/itemOffered")
    availableFrom = URIRef("https://schema.org/availableFrom")
    DesktopWebPlatform = URIRef("https://schema.org/DesktopWebPlatform")
    Drug = URIRef("https://schema.org/Drug")
    RejectAction = URIRef("https://schema.org/RejectAction")
    cvdNumVent = URIRef("https://schema.org/cvdNumVent")
    negativeNotes = URIRef("https://schema.org/negativeNotes")
    merchant = URIRef("https://schema.org/merchant")
    application = URIRef("https://schema.org/application")
    author = URIRef("https://schema.org/author")
    imagingTechnique = URIRef("https://schema.org/imagingTechnique")
    totalHistoricalEnrollment = URIRef("https://schema.org/totalHistoricalEnrollment")
    Subscription = URIRef("https://schema.org/Subscription")
    EUEnergyEfficiencyCategoryA1Plus = URIRef("https://schema.org/EUEnergyEfficiencyCategoryA1Plus")
    ContactPoint = URIRef("https://schema.org/ContactPoint")
    applicableLocation = URIRef("https://schema.org/applicableLocation")
    arrivalAirport = URIRef("https://schema.org/arrivalAirport")
    MedicalRiskEstimator = URIRef("https://schema.org/MedicalRiskEstimator")
    Dentist = URIRef("https://schema.org/Dentist")
    EnergyStarEnergyEfficiencyEnumeration = URIRef("https://schema.org/EnergyStarEnergyEfficiencyEnumeration")
    CertificationStatusEnumeration = URIRef("https://schema.org/CertificationStatusEnumeration")
    track = URIRef("https://schema.org/track")
    installUrl = URIRef("https://schema.org/installUrl")
    ownedThrough = URIRef("https://schema.org/ownedThrough")
    ItemListOrderDescending = URIRef("https://schema.org/ItemListOrderDescending")
    OccupationalExperienceRequirements = URIRef("https://schema.org/OccupationalExperienceRequirements")
    Geriatric = URIRef("https://schema.org/Geriatric")
    sportsActivityLocation = URIRef("https://schema.org/sportsActivityLocation")
    letterer = URIRef("https://schema.org/letterer")
    isAccessoryOrSparePartFor = URIRef("https://schema.org/isAccessoryOrSparePartFor")
    coverageEndTime = URIRef("https://schema.org/coverageEndTime")
    weight = URIRef("https://schema.org/weight")
    provider = URIRef("https://schema.org/provider")
    lyrics = URIRef("https://schema.org/lyrics")
    relevantOccupation = URIRef("https://schema.org/relevantOccupation")
    NoninvasiveProcedure = URIRef("https://schema.org/NoninvasiveProcedure")
    roleName = URIRef("https://schema.org/roleName")
    alcoholWarning = URIRef("https://schema.org/alcoholWarning")
    BodyMeasurementTypeEnumeration = URIRef("https://schema.org/BodyMeasurementTypeEnumeration")
    offers = URIRef("https://schema.org/offers")
    MusicRecording = URIRef("https://schema.org/MusicRecording")
    GenderType = URIRef("https://schema.org/GenderType")
    numberOfPlayers = URIRef("https://schema.org/numberOfPlayers")
    produces = URIRef("https://schema.org/produces")
    telephone = URIRef("https://schema.org/telephone")
    discusses = URIRef("https://schema.org/discusses")
    valueName = URIRef("https://schema.org/valueName")
    GatedResidenceCommunity = URIRef("https://schema.org/GatedResidenceCommunity")
    priceCurrency = URIRef("https://schema.org/priceCurrency")
    model = URIRef("https://schema.org/model")
    jobTitle = URIRef("https://schema.org/jobTitle")
    WPSideBar = URIRef("https://schema.org/WPSideBar")
    numberOfPartialBathrooms = URIRef("https://schema.org/numberOfPartialBathrooms")
    carbohydrateContent = URIRef("https://schema.org/carbohydrateContent")
    ProductModel = URIRef("https://schema.org/ProductModel")
    ViewAction = URIRef("https://schema.org/ViewAction")
    roofLoad = URIRef("https://schema.org/roofLoad")
    PublicationEvent = URIRef("https://schema.org/PublicationEvent")
    map = URIRef("https://schema.org/map")
    NonprofitSBBI = URIRef("https://schema.org/NonprofitSBBI")
    BodyMeasurementInsideLeg = URIRef("https://schema.org/BodyMeasurementInsideLeg")
    recipeIngredient = URIRef("https://schema.org/recipeIngredient")
    Retail = URIRef("https://schema.org/Retail")
    currency = URIRef("https://schema.org/currency")
    checkinTime = URIRef("https://schema.org/checkinTime")
    petsAllowed = URIRef("https://schema.org/petsAllowed")
    labelDetails = URIRef("https://schema.org/labelDetails")
    iupacName = URIRef("https://schema.org/iupacName")
    RsvpResponseMaybe = URIRef("https://schema.org/RsvpResponseMaybe")
    naturalProgression = URIRef("https://schema.org/naturalProgression")
    targetPlatform = URIRef("https://schema.org/targetPlatform")
    slogan = URIRef("https://schema.org/slogan")
    HyperToc = URIRef("https://schema.org/HyperToc")
    epidemiology = URIRef("https://schema.org/epidemiology")
    Dermatology = URIRef("https://schema.org/Dermatology")
    BrokerageAccount = URIRef("https://schema.org/BrokerageAccount")
    VisualArtwork = URIRef("https://schema.org/VisualArtwork")
    numberOfBathroomsTotal = URIRef("https://schema.org/numberOfBathroomsTotal")
    EditedOrCroppedContent = URIRef("https://schema.org/EditedOrCroppedContent")
    musicGroupMember = URIRef("https://schema.org/musicGroupMember")
    TrainedAlgorithmicMediaDigitalSource = URIRef("https://schema.org/TrainedAlgorithmicMediaDigitalSource")
    gameLocation = URIRef("https://schema.org/gameLocation")
    Specialty = URIRef("https://schema.org/Specialty")
    hasBroadcastChannel = URIRef("https://schema.org/hasBroadcastChannel")
    translator = URIRef("https://schema.org/translator")
    EventMovedOnline = URIRef("https://schema.org/EventMovedOnline")
    torque = URIRef("https://schema.org/torque")
    HyperToc = URIRef("https://schema.org/HyperToc")
    addressCountry = URIRef("https://schema.org/addressCountry")
    category = URIRef("https://schema.org/category")
    applicationStartDate = URIRef("https://schema.org/applicationStartDate")
    Monday = URIRef("https://schema.org/Monday")
    worksFor = URIRef("https://schema.org/worksFor")
    JewelryStore = URIRef("https://schema.org/JewelryStore")
    SoftwareSourceCode = URIRef("https://schema.org/SoftwareSourceCode")
    MedicalContraindication = URIRef("https://schema.org/MedicalContraindication")
    WearableSizeGroupMisses = URIRef("https://schema.org/WearableSizeGroupMisses")
    healthPlanDrugOption = URIRef("https://schema.org/healthPlanDrugOption")
    priceType = URIRef("https://schema.org/priceType")
    totalPaymentDue = URIRef("https://schema.org/totalPaymentDue")
    vehicleIdentificationNumber = URIRef("https://schema.org/vehicleIdentificationNumber")
    startDate = URIRef("https://schema.org/startDate")
    Pathology = URIRef("https://schema.org/Pathology")
    SoundtrackAlbum = URIRef("https://schema.org/SoundtrackAlbum")
    addressRegion = URIRef("https://schema.org/addressRegion")
    MedicalObservationalStudy = URIRef("https://schema.org/MedicalObservationalStudy")
    TrainTrip = URIRef("https://schema.org/TrainTrip")
    hasBioChemEntityPart = URIRef("https://schema.org/hasBioChemEntityPart")
    ReimbursementCap = URIRef("https://schema.org/ReimbursementCap")
    riskFactor = URIRef("https://schema.org/riskFactor")
    SheetMusic = URIRef("https://schema.org/SheetMusic")
    AudioObjectSnapshot = URIRef("https://schema.org/AudioObjectSnapshot")
    ActivateAction = URIRef("https://schema.org/ActivateAction")
    Researcher = URIRef("https://schema.org/Researcher")
    unitCode = URIRef("https://schema.org/unitCode")
    inventoryLevel = URIRef("https://schema.org/inventoryLevel")
    ProductModel = URIRef("https://schema.org/ProductModel")
    image = URIRef("https://schema.org/image")
    scheduledTime = URIRef("https://schema.org/scheduledTime")
    fuelEfficiency = URIRef("https://schema.org/fuelEfficiency")
    RsvpResponseNo = URIRef("https://schema.org/RsvpResponseNo")
    OfflineEventAttendanceMode = URIRef("https://schema.org/OfflineEventAttendanceMode")
    percentile25 = URIRef("https://schema.org/percentile25")
    artMedium = URIRef("https://schema.org/artMedium")
    subStageSuffix = URIRef("https://schema.org/subStageSuffix")
    parent = URIRef("https://schema.org/parent")
    agentInteractionStatistic = URIRef("https://schema.org/agentInteractionStatistic")
    MedicalStudy = URIRef("https://schema.org/MedicalStudy")
    WearableMeasurementWidth = URIRef("https://schema.org/WearableMeasurementWidth")
    postalCodeBegin = URIRef("https://schema.org/postalCodeBegin")
    knowsAbout = URIRef("https://schema.org/knowsAbout")
    teaches = URIRef("https://schema.org/teaches")
    MedicalObservationalStudy = URIRef("https://schema.org/MedicalObservationalStudy")
    startDate = URIRef("https://schema.org/startDate")
    ProgramMembership = URIRef("https://schema.org/ProgramMembership")
    AdultOrientedEnumeration = URIRef("https://schema.org/AdultOrientedEnumeration")
    EngineSpecification = URIRef("https://schema.org/EngineSpecification")
    Vessel = URIRef("https://schema.org/Vessel")
    answerCount = URIRef("https://schema.org/answerCount")
    taxID = URIRef("https://schema.org/taxID")
    playMode = URIRef("https://schema.org/playMode")
    interactivityType = URIRef("https://schema.org/interactivityType")
    previousStartDate = URIRef("https://schema.org/previousStartDate")
    Invoice = URIRef("https://schema.org/Invoice")
    nonEqual = URIRef("https://schema.org/nonEqual")
    MerchantReturnEnumeration = URIRef("https://schema.org/MerchantReturnEnumeration")
    asin = URIRef("https://schema.org/asin")
    variableMeasured = URIRef("https://schema.org/variableMeasured")
    isBasedOnUrl = URIRef("https://schema.org/isBasedOnUrl")
    UnincorporatedAssociationCharity = URIRef("https://schema.org/UnincorporatedAssociationCharity")
    replyToUrl = URIRef("https://schema.org/replyToUrl")
    physicalRequirement = URIRef("https://schema.org/physicalRequirement")
    USNonprofitType = URIRef("https://schema.org/USNonprofitType")
    HealthAspectEnumeration = URIRef("https://schema.org/HealthAspectEnumeration")
    identifyingExam = URIRef("https://schema.org/identifyingExam")
    geographicArea = URIRef("https://schema.org/geographicArea")
    programType = URIRef("https://schema.org/programType")
    numberOfAxles = URIRef("https://schema.org/numberOfAxles")
    pregnancyCategory = URIRef("https://schema.org/pregnancyCategory")
    commentTime = URIRef("https://schema.org/commentTime")
    WearableSizeGroupBig = URIRef("https://schema.org/WearableSizeGroupBig")
    geoWithin = URIRef("https://schema.org/geoWithin")
    workPresented = URIRef("https://schema.org/workPresented")
    measurementTechnique = URIRef("https://schema.org/measurementTechnique")
    DrugPregnancyCategory = URIRef("https://schema.org/DrugPregnancyCategory")
    Nonprofit501c17 = URIRef("https://schema.org/Nonprofit501c17")
    startDate = URIRef("https://schema.org/startDate")
    award = URIRef("https://schema.org/award")
    cvdFacilityId = URIRef("https://schema.org/cvdFacilityId")
    MedicalConditionStage = URIRef("https://schema.org/MedicalConditionStage")
    DrugPrescriptionStatus = URIRef("https://schema.org/DrugPrescriptionStatus")
    BodyMeasurementWaist = URIRef("https://schema.org/BodyMeasurementWaist")
    applicationStartDate = URIRef("https://schema.org/applicationStartDate")
    MedicalWebPage = URIRef("https://schema.org/MedicalWebPage")
    ChildCare = URIRef("https://schema.org/ChildCare")
    returnShippingFeesAmount = URIRef("https://schema.org/returnShippingFeesAmount")
    MedicineSystem = URIRef("https://schema.org/MedicineSystem")
    dateVehicleFirstRegistered = URIRef("https://schema.org/dateVehicleFirstRegistered")
    gtin13 = URIRef("https://schema.org/gtin13")
    RearWheelDriveConfiguration = URIRef("https://schema.org/RearWheelDriveConfiguration")
    MeetingRoom = URIRef("https://schema.org/MeetingRoom")
    regionsAllowed = URIRef("https://schema.org/regionsAllowed")
    albumReleaseType = URIRef("https://schema.org/albumReleaseType")
    certificationIdentification = URIRef("https://schema.org/certificationIdentification")
    ApplyAction = URIRef("https://schema.org/ApplyAction")
    artform = URIRef("https://schema.org/artform")
    Subscription = URIRef("https://schema.org/Subscription")
    isPlanForApartment = URIRef("https://schema.org/isPlanForApartment")
    CollegeOrUniversity = URIRef("https://schema.org/CollegeOrUniversity")
    acquireLicensePage = URIRef("https://schema.org/acquireLicensePage")
    Text = URIRef("https://schema.org/Text")
    characterName = URIRef("https://schema.org/characterName")
    Clinician = URIRef("https://schema.org/Clinician")
    preparation = URIRef("https://schema.org/preparation")
    deathPlace = URIRef("https://schema.org/deathPlace")
    Nonprofit501c5 = URIRef("https://schema.org/Nonprofit501c5")
    surface = URIRef("https://schema.org/surface")
    fuelConsumption = URIRef("https://schema.org/fuelConsumption")
    VirtualLocation = URIRef("https://schema.org/VirtualLocation")
    OnDemandEvent = URIRef("https://schema.org/OnDemandEvent")
    merchantReturnDays = URIRef("https://schema.org/merchantReturnDays")
    runtimePlatform = URIRef("https://schema.org/runtimePlatform")
    isEncodedByBioChemEntity = URIRef("https://schema.org/isEncodedByBioChemEntity")
    ComicSeries = URIRef("https://schema.org/ComicSeries")
    namedPosition = URIRef("https://schema.org/namedPosition")
    orderItemNumber = URIRef("https://schema.org/orderItemNumber")
    masthead = URIRef("https://schema.org/masthead")
    isPartOf = URIRef("https://schema.org/isPartOf")
    CorrectionComment = URIRef("https://schema.org/CorrectionComment")
    numberOfCredits = URIRef("https://schema.org/numberOfCredits")
    occupancy = URIRef("https://schema.org/occupancy")
    creditedTo = URIRef("https://schema.org/creditedTo")
    LocalBusiness = URIRef("https://schema.org/LocalBusiness")
    RsvpResponseType = URIRef("https://schema.org/RsvpResponseType")
    aggregateRating = URIRef("https://schema.org/aggregateRating")
    Endocrine = URIRef("https://schema.org/Endocrine")
    numberOfRooms = URIRef("https://schema.org/numberOfRooms")
    VideoObjectSnapshot = URIRef("https://schema.org/VideoObjectSnapshot")
    bloodSupply = URIRef("https://schema.org/bloodSupply")
    Preschool = URIRef("https://schema.org/Preschool")
    founder = URIRef("https://schema.org/founder")
    hasDefinedTerm = URIRef("https://schema.org/hasDefinedTerm")
    BusReservation = URIRef("https://schema.org/BusReservation")
    DietarySupplement = URIRef("https://schema.org/DietarySupplement")
    numberOfBathroomsTotal = URIRef("https://schema.org/numberOfBathroomsTotal")
    grantee = URIRef("https://schema.org/grantee")
    salaryUponCompletion = URIRef("https://schema.org/salaryUponCompletion")
    targetProduct = URIRef("https://schema.org/targetProduct")
    weightTotal = URIRef("https://schema.org/weightTotal")
    itemDefectReturnShippingFeesAmount = URIRef("https://schema.org/itemDefectReturnShippingFeesAmount")
    nonprofitStatus = URIRef("https://schema.org/nonprofitStatus")
    suitableForDiet = URIRef("https://schema.org/suitableForDiet")
    issueNumber = URIRef("https://schema.org/issueNumber")
    PropertyValueSpecification = URIRef("https://schema.org/PropertyValueSpecification")
    lesser = URIRef("https://schema.org/lesser")
    InfectiousDisease = URIRef("https://schema.org/InfectiousDisease")
    numberOfEpisodes = URIRef("https://schema.org/numberOfEpisodes")
    prescriptionStatus = URIRef("https://schema.org/prescriptionStatus")
    numberOfEmployees = URIRef("https://schema.org/numberOfEmployees")
    arrivalBusStop = URIRef("https://schema.org/arrivalBusStop")
    dateDeleted = URIRef("https://schema.org/dateDeleted")
    KeepProduct = URIRef("https://schema.org/KeepProduct")
    ExampleMeasurementMethodEnum = URIRef("https://schema.org/ExampleMeasurementMethodEnum")
    Paperback = URIRef("https://schema.org/Paperback")
    validFrom = URIRef("https://schema.org/validFrom")
    postalCodeRange = URIRef("https://schema.org/postalCodeRange")
    molecularWeight = URIRef("https://schema.org/molecularWeight")
    marginOfError = URIRef("https://schema.org/marginOfError")
    returnLabelSource = URIRef("https://schema.org/returnLabelSource")
    workFeatured = URIRef("https://schema.org/workFeatured")
    associatedDisease = URIRef("https://schema.org/associatedDisease")
    drugUnit = URIRef("https://schema.org/drugUnit")
    vehicleModelDate = URIRef("https://schema.org/vehicleModelDate")
    Thursday = URIRef("https://schema.org/Thursday")
    Renal = URIRef("https://schema.org/Renal")
    seriousAdverseOutcome = URIRef("https://schema.org/seriousAdverseOutcome")
    secondaryPrevention = URIRef("https://schema.org/secondaryPrevention")
    mediaAuthenticityCategory = URIRef("https://schema.org/mediaAuthenticityCategory")
    AlgorithmicMediaDigitalSource = URIRef("https://schema.org/AlgorithmicMediaDigitalSource")
    adverseOutcome = URIRef("https://schema.org/adverseOutcome")
    inProductGroupWithID = URIRef("https://schema.org/inProductGroupWithID")
    originalMediaLink = URIRef("https://schema.org/originalMediaLink")
    MedicalTrial = URIRef("https://schema.org/MedicalTrial")
    UnitPriceSpecification = URIRef("https://schema.org/UnitPriceSpecification")
    MotorcycleDealer = URIRef("https://schema.org/MotorcycleDealer")
    bioChemInteraction = URIRef("https://schema.org/bioChemInteraction")
    employees = URIRef("https://schema.org/employees")
    broadcastOfEvent = URIRef("https://schema.org/broadcastOfEvent")
    contentRating = URIRef("https://schema.org/contentRating")
    EnergyStarCertified = URIRef("https://schema.org/EnergyStarCertified")
    subjectOf = URIRef("https://schema.org/subjectOf")
    repeatFrequency = URIRef("https://schema.org/repeatFrequency")
    BodyMeasurementHips = URIRef("https://schema.org/BodyMeasurementHips")
    eligibleQuantity = URIRef("https://schema.org/eligibleQuantity")
    realEstateAgent = URIRef("https://schema.org/realEstateAgent")
    SomeProducts = URIRef("https://schema.org/SomeProducts")
    bitrate = URIRef("https://schema.org/bitrate")
    trailer = URIRef("https://schema.org/trailer")
    associatedMediaReview = URIRef("https://schema.org/associatedMediaReview")
    Flexibility = URIRef("https://schema.org/Flexibility")
    EmailMessage = URIRef("https://schema.org/EmailMessage")
    hasMap = URIRef("https://schema.org/hasMap")
    MedicalBusiness = URIRef("https://schema.org/MedicalBusiness")
    shippingDetails = URIRef("https://schema.org/shippingDetails")
    holdingArchive = URIRef("https://schema.org/holdingArchive")
    MenuItem = URIRef("https://schema.org/MenuItem")
    speechToTextMarkup = URIRef("https://schema.org/speechToTextMarkup")
    AndroidPlatform = URIRef("https://schema.org/AndroidPlatform")
    siblings = URIRef("https://schema.org/siblings")
    FloorPlan = URIRef("https://schema.org/FloorPlan")
    meetsEmissionStandard = URIRef("https://schema.org/meetsEmissionStandard")
    AnaerobicActivity = URIRef("https://schema.org/AnaerobicActivity")
    StoreCreditRefund = URIRef("https://schema.org/StoreCreditRefund")
    ConsumeAction = URIRef("https://schema.org/ConsumeAction")
    countriesSupported = URIRef("https://schema.org/countriesSupported")
    storageRequirements = URIRef("https://schema.org/storageRequirements")
    Nursing = URIRef("https://schema.org/Nursing")
    percentile25 = URIRef("https://schema.org/percentile25")
    relevantSpecialty = URIRef("https://schema.org/relevantSpecialty")
    MerchantReturnUnlimitedWindow = URIRef("https://schema.org/MerchantReturnUnlimitedWindow")
    ReviewAction = URIRef("https://schema.org/ReviewAction")
    schemaVersion = URIRef("https://schema.org/schemaVersion")
    termCode = URIRef("https://schema.org/termCode")
    isFamilyFriendly = URIRef("https://schema.org/isFamilyFriendly")
    arrivalTerminal = URIRef("https://schema.org/arrivalTerminal")
    loanMortgageMandateAmount = URIRef("https://schema.org/loanMortgageMandateAmount")
    partOfSystem = URIRef("https://schema.org/partOfSystem")
    Comment = URIRef("https://schema.org/Comment")
    MusicVideoObject = URIRef("https://schema.org/MusicVideoObject")
    members = URIRef("https://schema.org/members")
    numberOfAvailableAccommodationUnits = URIRef("https://schema.org/numberOfAvailableAccommodationUnits")
    SheetMusic = URIRef("https://schema.org/SheetMusic")
    AggregateRating = URIRef("https://schema.org/AggregateRating")
    legalName = URIRef("https://schema.org/legalName")
    knowsLanguage = URIRef("https://schema.org/knowsLanguage")
    Chapter = URIRef("https://schema.org/Chapter")
    startOffset = URIRef("https://schema.org/startOffset")
    strengthUnit = URIRef("https://schema.org/strengthUnit")
    hasCategoryCode = URIRef("https://schema.org/hasCategoryCode")
    sdLicense = URIRef("https://schema.org/sdLicense")
    IngredientsHealthAspect = URIRef("https://schema.org/IngredientsHealthAspect")
    freeShippingThreshold = URIRef("https://schema.org/freeShippingThreshold")
    EvidenceLevelC = URIRef("https://schema.org/EvidenceLevelC")
    QuantitativeValue = URIRef("https://schema.org/QuantitativeValue")
    cssSelector = URIRef("https://schema.org/cssSelector")
    certificationIdentification = URIRef("https://schema.org/certificationIdentification")
    funder = URIRef("https://schema.org/funder")
    Nonprofit501c28 = URIRef("https://schema.org/Nonprofit501c28")
    accessModeSufficient = URIRef("https://schema.org/accessModeSufficient")
    CaseSeries = URIRef("https://schema.org/CaseSeries")
    Nonprofit501c4 = URIRef("https://schema.org/Nonprofit501c4")
    WearableSizeSystemFR = URIRef("https://schema.org/WearableSizeSystemFR")
    numberOfBedrooms = URIRef("https://schema.org/numberOfBedrooms")
    offerCount = URIRef("https://schema.org/offerCount")
    email = URIRef("https://schema.org/email")
    courseCode = URIRef("https://schema.org/courseCode")
    videoFrameSize = URIRef("https://schema.org/videoFrameSize")
    ticketedSeat = URIRef("https://schema.org/ticketedSeat")
    ResumeAction = URIRef("https://schema.org/ResumeAction")
    hasMeasurement = URIRef("https://schema.org/hasMeasurement")
    SpeechPathology = URIRef("https://schema.org/SpeechPathology")
    trainNumber = URIRef("https://schema.org/trainNumber")
    DrivingSchoolVehicleUsage = URIRef("https://schema.org/DrivingSchoolVehicleUsage")
    creativeWorkStatus = URIRef("https://schema.org/creativeWorkStatus")
    caption = URIRef("https://schema.org/caption")
    observationPeriod = URIRef("https://schema.org/observationPeriod")
    courseMode = URIRef("https://schema.org/courseMode")
    domainIncludes = URIRef("https://schema.org/domainIncludes")
    EmployerReview = URIRef("https://schema.org/EmployerReview")
    AnimalShelter = URIRef("https://schema.org/AnimalShelter")
    totalHistoricalEnrollment = URIRef("https://schema.org/totalHistoricalEnrollment")
    GettingAccessHealthAspect = URIRef("https://schema.org/GettingAccessHealthAspect")
    LegalService = URIRef("https://schema.org/LegalService")
    Gene = URIRef("https://schema.org/Gene")
    MotorcycleDealer = URIRef("https://schema.org/MotorcycleDealer")
    CatholicChurch = URIRef("https://schema.org/CatholicChurch")
    EUEnergyEfficiencyCategoryD = URIRef("https://schema.org/EUEnergyEfficiencyCategoryD")
    status = URIRef("https://schema.org/status")
    MusicAlbum = URIRef("https://schema.org/MusicAlbum")
    acquiredFrom = URIRef("https://schema.org/acquiredFrom")
    interestRate = URIRef("https://schema.org/interestRate")
    WearableSizeGroupShort = URIRef("https://schema.org/WearableSizeGroupShort")
    workload = URIRef("https://schema.org/workload")
    businessFunction = URIRef("https://schema.org/businessFunction")
    observationDate = URIRef("https://schema.org/observationDate")
    PrescriptionOnly = URIRef("https://schema.org/PrescriptionOnly")
    relevantSpecialty = URIRef("https://schema.org/relevantSpecialty")
    availableAtOrFrom = URIRef("https://schema.org/availableAtOrFrom")
    UnRegisterAction = URIRef("https://schema.org/UnRegisterAction")
    DisabilitySupport = URIRef("https://schema.org/DisabilitySupport")
    floorLevel = URIRef("https://schema.org/floorLevel")
    itemShipped = URIRef("https://schema.org/itemShipped")
    TireShop = URIRef("https://schema.org/TireShop")
    EventAttendanceModeEnumeration = URIRef("https://schema.org/EventAttendanceModeEnumeration")
    possibleTreatment = URIRef("https://schema.org/possibleTreatment")
    ProductCollection = URIRef("https://schema.org/ProductCollection")
    bankAccountType = URIRef("https://schema.org/bankAccountType")
    CohortStudy = URIRef("https://schema.org/CohortStudy")
    jobImmediateStart = URIRef("https://schema.org/jobImmediateStart")
    director = URIRef("https://schema.org/director")
    Florist = URIRef("https://schema.org/Florist")
    shippingRate = URIRef("https://schema.org/shippingRate")
    underName = URIRef("https://schema.org/underName")
    competencyRequired = URIRef("https://schema.org/competencyRequired")
    organizer = URIRef("https://schema.org/organizer")
    box = URIRef("https://schema.org/box")
    Nonprofit501f = URIRef("https://schema.org/Nonprofit501f")
    contentUrl = URIRef("https://schema.org/contentUrl")
    SelfCareHealthAspect = URIRef("https://schema.org/SelfCareHealthAspect")
    WearableSizeSystemMX = URIRef("https://schema.org/WearableSizeSystemMX")
    SizeGroupEnumeration = URIRef("https://schema.org/SizeGroupEnumeration")
    Fungus = URIRef("https://schema.org/Fungus")
    step = URIRef("https://schema.org/step")
    numberOfEpisodes = URIRef("https://schema.org/numberOfEpisodes")
    servicePostalAddress = URIRef("https://schema.org/servicePostalAddress")
    legislationDateVersion = URIRef("https://schema.org/legislationDateVersion")
    hiringOrganization = URIRef("https://schema.org/hiringOrganization")
    eventSchedule = URIRef("https://schema.org/eventSchedule")
    issuedThrough = URIRef("https://schema.org/issuedThrough")
    appliesToPaymentMethod = URIRef("https://schema.org/appliesToPaymentMethod")
    GovernmentOrganization = URIRef("https://schema.org/GovernmentOrganization")
    Nonprofit501c16 = URIRef("https://schema.org/Nonprofit501c16")
    returnPolicyCategory = URIRef("https://schema.org/returnPolicyCategory")
    productionDate = URIRef("https://schema.org/productionDate")
    screenCount = URIRef("https://schema.org/screenCount")
    Aquarium = URIRef("https://schema.org/Aquarium")
    Airline = URIRef("https://schema.org/Airline")
    VirtualLocation = URIRef("https://schema.org/VirtualLocation")
    DiagnosticProcedure = URIRef("https://schema.org/DiagnosticProcedure")
    experienceRequirements = URIRef("https://schema.org/experienceRequirements")
    paymentDueDate = URIRef("https://schema.org/paymentDueDate")
    taxonomicRange = URIRef("https://schema.org/taxonomicRange")
    priceValidUntil = URIRef("https://schema.org/priceValidUntil")
    leiCode = URIRef("https://schema.org/leiCode")
    SportsTeam = URIRef("https://schema.org/SportsTeam")
    OnSitePickup = URIRef("https://schema.org/OnSitePickup")
    paymentStatus = URIRef("https://schema.org/paymentStatus")
    BodyMeasurementUnderbust = URIRef("https://schema.org/BodyMeasurementUnderbust")
    maximumEnrollment = URIRef("https://schema.org/maximumEnrollment")
    coverageEndTime = URIRef("https://schema.org/coverageEndTime")
    telephone = URIRef("https://schema.org/telephone")
    gtin13 = URIRef("https://schema.org/gtin13")
    WarrantyPromise = URIRef("https://schema.org/WarrantyPromise")
    geoCovers = URIRef("https://schema.org/geoCovers")
    availableTest = URIRef("https://schema.org/availableTest")
    ArchiveComponent = URIRef("https://schema.org/ArchiveComponent")
    MediaManipulationRatingEnumeration = URIRef("https://schema.org/MediaManipulationRatingEnumeration")
    translationOfWork = URIRef("https://schema.org/translationOfWork")
    recipeInstructions = URIRef("https://schema.org/recipeInstructions")
    numberOfAccommodationUnits = URIRef("https://schema.org/numberOfAccommodationUnits")
    pagination = URIRef("https://schema.org/pagination")
    Statement = URIRef("https://schema.org/Statement")
    Nonprofit501c17 = URIRef("https://schema.org/Nonprofit501c17")
    educationalCredentialAwarded = URIRef("https://schema.org/educationalCredentialAwarded")
    numberOfBedrooms = URIRef("https://schema.org/numberOfBedrooms")
    seatingType = URIRef("https://schema.org/seatingType")
    GeoShape = URIRef("https://schema.org/GeoShape")
    ExampleMeasurementMethodEnum = URIRef("https://schema.org/ExampleMeasurementMethodEnum")
    Movie = URIRef("https://schema.org/Movie")
    FailedActionStatus = URIRef("https://schema.org/FailedActionStatus")
    StoreCreditRefund = URIRef("https://schema.org/StoreCreditRefund")
    UserPageVisits = URIRef("https://schema.org/UserPageVisits")
    domainIncludes = URIRef("https://schema.org/domainIncludes")
    musicBy = URIRef("https://schema.org/musicBy")
    loanPaymentAmount = URIRef("https://schema.org/loanPaymentAmount")
    artMedium = URIRef("https://schema.org/artMedium")
    TypesHealthAspect = URIRef("https://schema.org/TypesHealthAspect")
    AddAction = URIRef("https://schema.org/AddAction")
    PrescriptionOnly = URIRef("https://schema.org/PrescriptionOnly")
    FoodService = URIRef("https://schema.org/FoodService")
    CrossSectional = URIRef("https://schema.org/CrossSectional")
    nsn = URIRef("https://schema.org/nsn")
    exerciseType = URIRef("https://schema.org/exerciseType")
    bankAccountType = URIRef("https://schema.org/bankAccountType")
    PropertyValue = URIRef("https://schema.org/PropertyValue")
    percentile10 = URIRef("https://schema.org/percentile10")
    RepaymentSpecification = URIRef("https://schema.org/RepaymentSpecification")
    Tuesday = URIRef("https://schema.org/Tuesday")
    maximumEnrollment = URIRef("https://schema.org/maximumEnrollment")
    median = URIRef("https://schema.org/median")
    MeasurementTypeEnumeration = URIRef("https://schema.org/MeasurementTypeEnumeration")
    MedicalSymptom = URIRef("https://schema.org/MedicalSymptom")
    printEdition = URIRef("https://schema.org/printEdition")
    awayTeam = URIRef("https://schema.org/awayTeam")
    PaintAction = URIRef("https://schema.org/PaintAction")
    qualifications = URIRef("https://schema.org/qualifications")
    currenciesAccepted = URIRef("https://schema.org/currenciesAccepted")
    UserTweets = URIRef("https://schema.org/UserTweets")
    landlord = URIRef("https://schema.org/landlord")
    departureBoatTerminal = URIRef("https://schema.org/departureBoatTerminal")
    arrivalPlatform = URIRef("https://schema.org/arrivalPlatform")
    activeIngredient = URIRef("https://schema.org/activeIngredient")
    PerformingArtsTheater = URIRef("https://schema.org/PerformingArtsTheater")
    educationRequirements = URIRef("https://schema.org/educationRequirements")
    QAPage = URIRef("https://schema.org/QAPage")
    HinduDiet = URIRef("https://schema.org/HinduDiet")
    recipeYield = URIRef("https://schema.org/recipeYield")
    tickerSymbol = URIRef("https://schema.org/tickerSymbol")
    Thursday = URIRef("https://schema.org/Thursday")
    TypeAndQuantityNode = URIRef("https://schema.org/TypeAndQuantityNode")
    loser = URIRef("https://schema.org/loser")
    publicTransportClosuresInfo = URIRef("https://schema.org/publicTransportClosuresInfo")
    operatingSystem = URIRef("https://schema.org/operatingSystem")
    recipeIngredient = URIRef("https://schema.org/recipeIngredient")
    eventStatus = URIRef("https://schema.org/eventStatus")
    BusTrip = URIRef("https://schema.org/BusTrip")
    roofLoad = URIRef("https://schema.org/roofLoad")
    activityFrequency = URIRef("https://schema.org/activityFrequency")
    potentialUse = URIRef("https://schema.org/potentialUse")
    OfferItemCondition = URIRef("https://schema.org/OfferItemCondition")
    Apartment = URIRef("https://schema.org/Apartment")
    publishedBy = URIRef("https://schema.org/publishedBy")
    MovieClip = URIRef("https://schema.org/MovieClip")
    DigitalArtDigitalSource = URIRef("https://schema.org/DigitalArtDigitalSource")
    serviceArea = URIRef("https://schema.org/serviceArea")
    returnFees = URIRef("https://schema.org/returnFees")
    iso6523Code = URIRef("https://schema.org/iso6523Code")
    amenityFeature = URIRef("https://schema.org/amenityFeature")
    Offer = URIRef("https://schema.org/Offer")
    supportingData = URIRef("https://schema.org/supportingData")
    associatedReview = URIRef("https://schema.org/associatedReview")
    TaxiStand = URIRef("https://schema.org/TaxiStand")
    USNonprofitType = URIRef("https://schema.org/USNonprofitType")
    broadcastTimezone = URIRef("https://schema.org/broadcastTimezone")
    termsPerYear = URIRef("https://schema.org/termsPerYear")
    repeatCount = URIRef("https://schema.org/repeatCount")
    commentText = URIRef("https://schema.org/commentText")
    chemicalComposition = URIRef("https://schema.org/chemicalComposition")
    SafetyHealthAspect = URIRef("https://schema.org/SafetyHealthAspect")
    bioChemInteraction = URIRef("https://schema.org/bioChemInteraction")
    legislationDate = URIRef("https://schema.org/legislationDate")
    blogPosts = URIRef("https://schema.org/blogPosts")
    offeredBy = URIRef("https://schema.org/offeredBy")
    postalCodeEnd = URIRef("https://schema.org/postalCodeEnd")
    credentialCategory = URIRef("https://schema.org/credentialCategory")
    benefits = URIRef("https://schema.org/benefits")
    replacee = URIRef("https://schema.org/replacee")
    owns = URIRef("https://schema.org/owns")
    recordLabel = URIRef("https://schema.org/recordLabel")
    customer = URIRef("https://schema.org/customer")
    backstory = URIRef("https://schema.org/backstory")
    benefitsSummaryUrl = URIRef("https://schema.org/benefitsSummaryUrl")
    programMembershipUsed = URIRef("https://schema.org/programMembershipUsed")
    timeOfDay = URIRef("https://schema.org/timeOfDay")
    SolveMathAction = URIRef("https://schema.org/SolveMathAction")
    nextItem = URIRef("https://schema.org/nextItem")
    monthsOfExperience = URIRef("https://schema.org/monthsOfExperience")
    VideoGameSeries = URIRef("https://schema.org/VideoGameSeries")
    hasEnergyConsumptionDetails = URIRef("https://schema.org/hasEnergyConsumptionDetails")
    HowToTip = URIRef("https://schema.org/HowToTip")
    guidelineDate = URIRef("https://schema.org/guidelineDate")
    hasCategoryCode = URIRef("https://schema.org/hasCategoryCode")
    PaintAction = URIRef("https://schema.org/PaintAction")
    InstallAction = URIRef("https://schema.org/InstallAction")
    HowItWorksHealthAspect = URIRef("https://schema.org/HowItWorksHealthAspect")
    PerformingArtsTheater = URIRef("https://schema.org/PerformingArtsTheater")
    cargoVolume = URIRef("https://schema.org/cargoVolume")
    SaleEvent = URIRef("https://schema.org/SaleEvent")
    doesNotShip = URIRef("https://schema.org/doesNotShip")
    composer = URIRef("https://schema.org/composer")
    healthPlanCoinsuranceRate = URIRef("https://schema.org/healthPlanCoinsuranceRate")
    EUEnergyEfficiencyEnumeration = URIRef("https://schema.org/EUEnergyEfficiencyEnumeration")
    numTracks = URIRef("https://schema.org/numTracks")
    BedType = URIRef("https://schema.org/BedType")
    target = URIRef("https://schema.org/target")
    PaymentDue = URIRef("https://schema.org/PaymentDue")
    PlaceOfWorship = URIRef("https://schema.org/PlaceOfWorship")
    availableTest = URIRef("https://schema.org/availableTest")
    department = URIRef("https://schema.org/department")
    hostingOrganization = URIRef("https://schema.org/hostingOrganization")
    HealthClub = URIRef("https://schema.org/HealthClub")
    medicineSystem = URIRef("https://schema.org/medicineSystem")
    auditDate = URIRef("https://schema.org/auditDate")
    loanPaymentAmount = URIRef("https://schema.org/loanPaymentAmount")
    legislationTransposes = URIRef("https://schema.org/legislationTransposes")
    productionCompany = URIRef("https://schema.org/productionCompany")
    numberOfAirbags = URIRef("https://schema.org/numberOfAirbags")
    DJMixAlbum = URIRef("https://schema.org/DJMixAlbum")
    expressedIn = URIRef("https://schema.org/expressedIn")
    expectedArrivalUntil = URIRef("https://schema.org/expectedArrivalUntil")
    increasesRiskOf = URIRef("https://schema.org/increasesRiskOf")
    ConvenienceStore = URIRef("https://schema.org/ConvenienceStore")
    TVSeason = URIRef("https://schema.org/TVSeason")
    conditionsOfAccess = URIRef("https://schema.org/conditionsOfAccess")
    sizeSystem = URIRef("https://schema.org/sizeSystem")
    fuelType = URIRef("https://schema.org/fuelType")
    Nonprofit501n = URIRef("https://schema.org/Nonprofit501n")
    textValue = URIRef("https://schema.org/textValue")
    MedicalCondition = URIRef("https://schema.org/MedicalCondition")
    Trip = URIRef("https://schema.org/Trip")
    quarantineGuidelines = URIRef("https://schema.org/quarantineGuidelines")
    entertainmentBusiness = URIRef("https://schema.org/entertainmentBusiness")
    XPathType = URIRef("https://schema.org/XPathType")
    endTime = URIRef("https://schema.org/endTime")
    PositiveFilmDigitalSource = URIRef("https://schema.org/PositiveFilmDigitalSource")
    suggestedMinAge = URIRef("https://schema.org/suggestedMinAge")
    season = URIRef("https://schema.org/season")
    ExerciseGym = URIRef("https://schema.org/ExerciseGym")
    paymentDueDate = URIRef("https://schema.org/paymentDueDate")
    LandmarksOrHistoricalBuildings = URIRef("https://schema.org/LandmarksOrHistoricalBuildings")
    video = URIRef("https://schema.org/video")
    codeRepository = URIRef("https://schema.org/codeRepository")
    schemaVersion = URIRef("https://schema.org/schemaVersion")
    originalMediaLink = URIRef("https://schema.org/originalMediaLink")
    Audiobook = URIRef("https://schema.org/Audiobook")
    DrivingSchoolVehicleUsage = URIRef("https://schema.org/DrivingSchoolVehicleUsage")
    albumRelease = URIRef("https://schema.org/albumRelease")
    doesNotShip = URIRef("https://schema.org/doesNotShip")
    propertyID = URIRef("https://schema.org/propertyID")
    usesHealthPlanIdStandard = URIRef("https://schema.org/usesHealthPlanIdStandard")
    partOfSeries = URIRef("https://schema.org/partOfSeries")
    box = URIRef("https://schema.org/box")
    about = URIRef("https://schema.org/about")
    size = URIRef("https://schema.org/size")
    physicalRequirement = URIRef("https://schema.org/physicalRequirement")
    DigitalPlatformEnumeration = URIRef("https://schema.org/DigitalPlatformEnumeration")
    Landform = URIRef("https://schema.org/Landform")
    toLocation = URIRef("https://schema.org/toLocation")
    termsPerYear = URIRef("https://schema.org/termsPerYear")
    suggestedMaxAge = URIRef("https://schema.org/suggestedMaxAge")
    maxValue = URIRef("https://schema.org/maxValue")
    AnalysisNewsArticle = URIRef("https://schema.org/AnalysisNewsArticle")
    object = URIRef("https://schema.org/object")
    FloorPlan = URIRef("https://schema.org/FloorPlan")
    itemDefectReturnLabelSource = URIRef("https://schema.org/itemDefectReturnLabelSource")
    funding = URIRef("https://schema.org/funding")
    variantCover = URIRef("https://schema.org/variantCover")
    endDate = URIRef("https://schema.org/endDate")
    Recruiting = URIRef("https://schema.org/Recruiting")
    ElementarySchool = URIRef("https://schema.org/ElementarySchool")
    healthPlanPharmacyCategory = URIRef("https://schema.org/healthPlanPharmacyCategory")
    addressCountry = URIRef("https://schema.org/addressCountry")
    carrierRequirements = URIRef("https://schema.org/carrierRequirements")
    RadioBroadcastService = URIRef("https://schema.org/RadioBroadcastService")
    FDAcategoryD = URIRef("https://schema.org/FDAcategoryD")
    travelBans = URIRef("https://schema.org/travelBans")
    EUEnergyEfficiencyCategoryD = URIRef("https://schema.org/EUEnergyEfficiencyCategoryD")
    numberOfFullBathrooms = URIRef("https://schema.org/numberOfFullBathrooms")
    availableAtOrFrom = URIRef("https://schema.org/availableAtOrFrom")
    leaseLength = URIRef("https://schema.org/leaseLength")
    CompleteDataFeed = URIRef("https://schema.org/CompleteDataFeed")
    OpenTrial = URIRef("https://schema.org/OpenTrial")
    Cardiovascular = URIRef("https://schema.org/Cardiovascular")
    enginePower = URIRef("https://schema.org/enginePower")
    EnergyConsumptionDetails = URIRef("https://schema.org/EnergyConsumptionDetails")
    CheckOutAction = URIRef("https://schema.org/CheckOutAction")
    MerchantReturnUnspecified = URIRef("https://schema.org/MerchantReturnUnspecified")
    competitor = URIRef("https://schema.org/competitor")
    programPrerequisites = URIRef("https://schema.org/programPrerequisites")
    fatContent = URIRef("https://schema.org/fatContent")
    ReturnFeesEnumeration = URIRef("https://schema.org/ReturnFeesEnumeration")
    serviceLocation = URIRef("https://schema.org/serviceLocation")
    DiscussionForumPosting = URIRef("https://schema.org/DiscussionForumPosting")
    partySize = URIRef("https://schema.org/partySize")
    directors = URIRef("https://schema.org/directors")
    chemicalRole = URIRef("https://schema.org/chemicalRole")
    contactOption = URIRef("https://schema.org/contactOption")
    eligibleRegion = URIRef("https://schema.org/eligibleRegion")
    isicV4 = URIRef("https://schema.org/isicV4")
    encodingFormat = URIRef("https://schema.org/encodingFormat")
    qualifications = URIRef("https://schema.org/qualifications")
    CoverArt = URIRef("https://schema.org/CoverArt")
    OTC = URIRef("https://schema.org/OTC")
    pattern = URIRef("https://schema.org/pattern")
    RentalCarReservation = URIRef("https://schema.org/RentalCarReservation")
    CompositeSyntheticDigitalSource = URIRef("https://schema.org/CompositeSyntheticDigitalSource")
    applicationSuite = URIRef("https://schema.org/applicationSuite")
    maxPrice = URIRef("https://schema.org/maxPrice")
    LowLactoseDiet = URIRef("https://schema.org/LowLactoseDiet")
    NightClub = URIRef("https://schema.org/NightClub")
    thumbnailUrl = URIRef("https://schema.org/thumbnailUrl")
    nsn = URIRef("https://schema.org/nsn")
    serverStatus = URIRef("https://schema.org/serverStatus")
    multipleValues = URIRef("https://schema.org/multipleValues")
    eligibleRegion = URIRef("https://schema.org/eligibleRegion")
    gameLocation = URIRef("https://schema.org/gameLocation")
    numberOfPreviousOwners = URIRef("https://schema.org/numberOfPreviousOwners")
    bioChemSimilarity = URIRef("https://schema.org/bioChemSimilarity")
    PublicHolidays = URIRef("https://schema.org/PublicHolidays")
    subEvent = URIRef("https://schema.org/subEvent")
    Oncologic = URIRef("https://schema.org/Oncologic")
    color = URIRef("https://schema.org/color")
    dateRead = URIRef("https://schema.org/dateRead")
    Nonprofit501c13 = URIRef("https://schema.org/Nonprofit501c13")
    inChI = URIRef("https://schema.org/inChI")
    numberOfAccommodationUnits = URIRef("https://schema.org/numberOfAccommodationUnits")
    Nonprofit501c27 = URIRef("https://schema.org/Nonprofit501c27")
    suggestedAge = URIRef("https://schema.org/suggestedAge")
    Nonprofit501c22 = URIRef("https://schema.org/Nonprofit501c22")
    SoftwareApplication = URIRef("https://schema.org/SoftwareApplication")
    HotelRoom = URIRef("https://schema.org/HotelRoom")
    geoWithin = URIRef("https://schema.org/geoWithin")
    bitrate = URIRef("https://schema.org/bitrate")
    itemListOrder = URIRef("https://schema.org/itemListOrder")
    track = URIRef("https://schema.org/track")
    ApplyAction = URIRef("https://schema.org/ApplyAction")
    transmissionMethod = URIRef("https://schema.org/transmissionMethod")
    accountMinimumInflow = URIRef("https://schema.org/accountMinimumInflow")
    AlbumRelease = URIRef("https://schema.org/AlbumRelease")
    possibleComplication = URIRef("https://schema.org/possibleComplication")
    ElectronicsStore = URIRef("https://schema.org/ElectronicsStore")
    DietarySupplement = URIRef("https://schema.org/DietarySupplement")
    materialExtent = URIRef("https://schema.org/materialExtent")
    beneficiaryBank = URIRef("https://schema.org/beneficiaryBank")
    EmailMessage = URIRef("https://schema.org/EmailMessage")
    pickupLocation = URIRef("https://schema.org/pickupLocation")
    SizeSystemEnumeration = URIRef("https://schema.org/SizeSystemEnumeration")
    InvoicePrice = URIRef("https://schema.org/InvoicePrice")
    lyrics = URIRef("https://schema.org/lyrics")
    guideline = URIRef("https://schema.org/guideline")
    recipeIngredient = URIRef("https://schema.org/recipeIngredient")
    encodingFormat = URIRef("https://schema.org/encodingFormat")
    ShippingDeliveryTime = URIRef("https://schema.org/ShippingDeliveryTime")
    associatedAnatomy = URIRef("https://schema.org/associatedAnatomy")
    numberOfSeasons = URIRef("https://schema.org/numberOfSeasons")
    MerchantReturnNotPermitted = URIRef("https://schema.org/MerchantReturnNotPermitted")
    FDAnotEvaluated = URIRef("https://schema.org/FDAnotEvaluated")
    DrugPrescriptionStatus = URIRef("https://schema.org/DrugPrescriptionStatus")
    playerType = URIRef("https://schema.org/playerType")
    populationType = URIRef("https://schema.org/populationType")
    experienceRequirements = URIRef("https://schema.org/experienceRequirements")
    UnitPriceSpecification = URIRef("https://schema.org/UnitPriceSpecification")
    trailer = URIRef("https://schema.org/trailer")
    noBylinesPolicy = URIRef("https://schema.org/noBylinesPolicy")
    Code = URIRef("https://schema.org/Code")
    potentialUse = URIRef("https://schema.org/potentialUse")
    ImageObjectSnapshot = URIRef("https://schema.org/ImageObjectSnapshot")
    Nonprofit501c22 = URIRef("https://schema.org/Nonprofit501c22")
    numberOfPreviousOwners = URIRef("https://schema.org/numberOfPreviousOwners")
    Musculoskeletal = URIRef("https://schema.org/Musculoskeletal")
    DefinedRegion = URIRef("https://schema.org/DefinedRegion")
    BodyMeasurementWaist = URIRef("https://schema.org/BodyMeasurementWaist")
    hasMeasurement = URIRef("https://schema.org/hasMeasurement")
    Sunday = URIRef("https://schema.org/Sunday")
    purchaseDate = URIRef("https://schema.org/purchaseDate")
    FoodEstablishment = URIRef("https://schema.org/FoodEstablishment")
    BodyMeasurementUnderbust = URIRef("https://schema.org/BodyMeasurementUnderbust")
    itemLocation = URIRef("https://schema.org/itemLocation")
    SportingGoodsStore = URIRef("https://schema.org/SportingGoodsStore")
    ChemicalSubstance = URIRef("https://schema.org/ChemicalSubstance")
    WPHeader = URIRef("https://schema.org/WPHeader")
    WearableSizeSystemEN13402 = URIRef("https://schema.org/WearableSizeSystemEN13402")
    owns = URIRef("https://schema.org/owns")
    currency = URIRef("https://schema.org/currency")
    creditText = URIRef("https://schema.org/creditText")
    season = URIRef("https://schema.org/season")
    relatedTherapy = URIRef("https://schema.org/relatedTherapy")
    coverageEndTime = URIRef("https://schema.org/coverageEndTime")
    ComicCoverArt = URIRef("https://schema.org/ComicCoverArt")
    ChooseAction = URIRef("https://schema.org/ChooseAction")
    DefinedRegion = URIRef("https://schema.org/DefinedRegion")
    CovidTestingFacility = URIRef("https://schema.org/CovidTestingFacility")
    SuspendAction = URIRef("https://schema.org/SuspendAction")
    MortgageLoan = URIRef("https://schema.org/MortgageLoan")
    collectionSize = URIRef("https://schema.org/collectionSize")
    AutomotiveBusiness = URIRef("https://schema.org/AutomotiveBusiness")
    healthPlanNetworkId = URIRef("https://schema.org/healthPlanNetworkId")
    baseSalary = URIRef("https://schema.org/baseSalary")
    ImageObject = URIRef("https://schema.org/ImageObject")
    surface = URIRef("https://schema.org/surface")
    itemDefectReturnLabelSource = URIRef("https://schema.org/itemDefectReturnLabelSource")
    originatesFrom = URIRef("https://schema.org/originatesFrom")
    PsychologicalTreatment = URIRef("https://schema.org/PsychologicalTreatment")
    seller = URIRef("https://schema.org/seller")
    MensClothingStore = URIRef("https://schema.org/MensClothingStore")
    hasDeliveryMethod = URIRef("https://schema.org/hasDeliveryMethod")
    partOfTVSeries = URIRef("https://schema.org/partOfTVSeries")
    NewCondition = URIRef("https://schema.org/NewCondition")
    TheaterEvent = URIRef("https://schema.org/TheaterEvent")
    MusicReleaseFormatType = URIRef("https://schema.org/MusicReleaseFormatType")
    hasCertification = URIRef("https://schema.org/hasCertification")
    permittedUsage = URIRef("https://schema.org/permittedUsage")
    subEvent = URIRef("https://schema.org/subEvent")
    opens = URIRef("https://schema.org/opens")
    Periodical = URIRef("https://schema.org/Periodical")
    Drawing = URIRef("https://schema.org/Drawing")
    InvoicePrice = URIRef("https://schema.org/InvoicePrice")
    PawnShop = URIRef("https://schema.org/PawnShop")
    releaseDate = URIRef("https://schema.org/releaseDate")
    foundingLocation = URIRef("https://schema.org/foundingLocation")
    returnLabelSource = URIRef("https://schema.org/returnLabelSource")
    isPartOf = URIRef("https://schema.org/isPartOf")
    guideline = URIRef("https://schema.org/guideline")
    Optometric = URIRef("https://schema.org/Optometric")
    identifier = URIRef("https://schema.org/identifier")
    Crematorium = URIRef("https://schema.org/Crematorium")
    hasEnergyConsumptionDetails = URIRef("https://schema.org/hasEnergyConsumptionDetails")
    learningResourceType = URIRef("https://schema.org/learningResourceType")
    WearableSizeSystemGS1 = URIRef("https://schema.org/WearableSizeSystemGS1")
    schemaVersion = URIRef("https://schema.org/schemaVersion")
    Apartment = URIRef("https://schema.org/Apartment")
    knownVehicleDamages = URIRef("https://schema.org/knownVehicleDamages")
    activityFrequency = URIRef("https://schema.org/activityFrequency")
    vehicleConfiguration = URIRef("https://schema.org/vehicleConfiguration")
    BroadcastChannel = URIRef("https://schema.org/BroadcastChannel")
    AnatomicalStructure = URIRef("https://schema.org/AnatomicalStructure")
    EmployerAggregateRating = URIRef("https://schema.org/EmployerAggregateRating")
    HearingImpairedSupported = URIRef("https://schema.org/HearingImpairedSupported")
    AutoPartsStore = URIRef("https://schema.org/AutoPartsStore")
    requiredCollateral = URIRef("https://schema.org/requiredCollateral")
    dateRead = URIRef("https://schema.org/dateRead")
    benefits = URIRef("https://schema.org/benefits")
    Optician = URIRef("https://schema.org/Optician")
    Neuro = URIRef("https://schema.org/Neuro")
    numberOfForwardGears = URIRef("https://schema.org/numberOfForwardGears")
    CommunicateAction = URIRef("https://schema.org/CommunicateAction")
    value = URIRef("https://schema.org/value")
    MedicalDevice = URIRef("https://schema.org/MedicalDevice")
    gameItem = URIRef("https://schema.org/gameItem")
    workExample = URIRef("https://schema.org/workExample")
    loanPaymentFrequency = URIRef("https://schema.org/loanPaymentFrequency")
    category = URIRef("https://schema.org/category")
    answerExplanation = URIRef("https://schema.org/answerExplanation")
    DeactivateAction = URIRef("https://schema.org/DeactivateAction")
    Aquarium = URIRef("https://schema.org/Aquarium")
    gender = URIRef("https://schema.org/gender")
    Photograph = URIRef("https://schema.org/Photograph")
    videoQuality = URIRef("https://schema.org/videoQuality")
    LegislationObject = URIRef("https://schema.org/LegislationObject")
    AdultOrientedEnumeration = URIRef("https://schema.org/AdultOrientedEnumeration")
    datasetTimeInterval = URIRef("https://schema.org/datasetTimeInterval")
    orderQuantity = URIRef("https://schema.org/orderQuantity")
    bookFormat = URIRef("https://schema.org/bookFormat")
    interactionStatistic = URIRef("https://schema.org/interactionStatistic")
    Courthouse = URIRef("https://schema.org/Courthouse")
    cvdNumBedsOcc = URIRef("https://schema.org/cvdNumBedsOcc")
    MedicalOrganization = URIRef("https://schema.org/MedicalOrganization")
    realEstateAgent = URIRef("https://schema.org/realEstateAgent")
    UnincorporatedAssociationCharity = URIRef("https://schema.org/UnincorporatedAssociationCharity")
    associatedAnatomy = URIRef("https://schema.org/associatedAnatomy")
    totalTime = URIRef("https://schema.org/totalTime")
    publishedBy = URIRef("https://schema.org/publishedBy")
    FinancialService = URIRef("https://schema.org/FinancialService")
    CheckoutPage = URIRef("https://schema.org/CheckoutPage")
    adverseOutcome = URIRef("https://schema.org/adverseOutcome")
    memoryRequirements = URIRef("https://schema.org/memoryRequirements")
    elevation = URIRef("https://schema.org/elevation")
    RecyclingCenter = URIRef("https://schema.org/RecyclingCenter")
    UKNonprofitType = URIRef("https://schema.org/UKNonprofitType")
    transitTimeLabel = URIRef("https://schema.org/transitTimeLabel")
    Episode = URIRef("https://schema.org/Episode")
    TireShop = URIRef("https://schema.org/TireShop")
    occupationLocation = URIRef("https://schema.org/occupationLocation")
    mpn = URIRef("https://schema.org/mpn")
    claimInterpreter = URIRef("https://schema.org/claimInterpreter")
    TaxiVehicleUsage = URIRef("https://schema.org/TaxiVehicleUsage")
    encodingType = URIRef("https://schema.org/encodingType")
    SportsTeam = URIRef("https://schema.org/SportsTeam")
    homeTeam = URIRef("https://schema.org/homeTeam")
    carrier = URIRef("https://schema.org/carrier")
    datePosted = URIRef("https://schema.org/datePosted")
    arrivalBoatTerminal = URIRef("https://schema.org/arrivalBoatTerminal")
    EffectivenessHealthAspect = URIRef("https://schema.org/EffectivenessHealthAspect")
    sensoryUnit = URIRef("https://schema.org/sensoryUnit")
    EngineSpecification = URIRef("https://schema.org/EngineSpecification")
    MeasurementTypeEnumeration = URIRef("https://schema.org/MeasurementTypeEnumeration")
    acceptsReservations = URIRef("https://schema.org/acceptsReservations")
    stageAsNumber = URIRef("https://schema.org/stageAsNumber")
    MotorizedBicycle = URIRef("https://schema.org/MotorizedBicycle")
    blogPost = URIRef("https://schema.org/blogPost")
    additionalName = URIRef("https://schema.org/additionalName")
    inPlaylist = URIRef("https://schema.org/inPlaylist")
    liveBlogUpdate = URIRef("https://schema.org/liveBlogUpdate")
    BuddhistTemple = URIRef("https://schema.org/BuddhistTemple")
    EnergyConsumptionDetails = URIRef("https://schema.org/EnergyConsumptionDetails")
    material = URIRef("https://schema.org/material")
    estimatedSalary = URIRef("https://schema.org/estimatedSalary")
    ViewAction = URIRef("https://schema.org/ViewAction")
    musicalKey = URIRef("https://schema.org/musicalKey")
    WearableMeasurementSleeve = URIRef("https://schema.org/WearableMeasurementSleeve")
    validThrough = URIRef("https://schema.org/validThrough")
    LoseAction = URIRef("https://schema.org/LoseAction")
    encoding = URIRef("https://schema.org/encoding")
    dependencies = URIRef("https://schema.org/dependencies")
    numberOfAvailableAccommodationUnits = URIRef("https://schema.org/numberOfAvailableAccommodationUnits")
    query = URIRef("https://schema.org/query")
    MedicalTest = URIRef("https://schema.org/MedicalTest")
    ReturnFeesEnumeration = URIRef("https://schema.org/ReturnFeesEnumeration")
    readBy = URIRef("https://schema.org/readBy")
    acquiredFrom = URIRef("https://schema.org/acquiredFrom")
    occupationalCategory = URIRef("https://schema.org/occupationalCategory")
    alternativeHeadline = URIRef("https://schema.org/alternativeHeadline")
    Artery = URIRef("https://schema.org/Artery")
    WearableSizeSystemContinental = URIRef("https://schema.org/WearableSizeSystemContinental")
    HealthAspectEnumeration = URIRef("https://schema.org/HealthAspectEnumeration")
    PublicToilet = URIRef("https://schema.org/PublicToilet")
    WearableMeasurementOutsideLeg = URIRef("https://schema.org/WearableMeasurementOutsideLeg")
    WearableMeasurementLength = URIRef("https://schema.org/WearableMeasurementLength")
    relatedStructure = URIRef("https://schema.org/relatedStructure")
    priceSpecification = URIRef("https://schema.org/priceSpecification")
    inLanguage = URIRef("https://schema.org/inLanguage")
    programmingModel = URIRef("https://schema.org/programmingModel")
    ProductModel = URIRef("https://schema.org/ProductModel")
    healthPlanCoinsuranceRate = URIRef("https://schema.org/healthPlanCoinsuranceRate")
    MonetaryGrant = URIRef("https://schema.org/MonetaryGrant")
    auditDate = URIRef("https://schema.org/auditDate")
    Intangible = URIRef("https://schema.org/Intangible")
    LikeAction = URIRef("https://schema.org/LikeAction")
    teaches = URIRef("https://schema.org/teaches")
    Poster = URIRef("https://schema.org/Poster")
    itemOffered = URIRef("https://schema.org/itemOffered")
    gtin13 = URIRef("https://schema.org/gtin13")
    colleagues = URIRef("https://schema.org/colleagues")
    mediaItemAppearance = URIRef("https://schema.org/mediaItemAppearance")
    pageEnd = URIRef("https://schema.org/pageEnd")
    ParcelService = URIRef("https://schema.org/ParcelService")
    FireStation = URIRef("https://schema.org/FireStation")
    IPTCDigitalSourceEnumeration = URIRef("https://schema.org/IPTCDigitalSourceEnumeration")
    GeoCoordinates = URIRef("https://schema.org/GeoCoordinates")
    PodcastSeries = URIRef("https://schema.org/PodcastSeries")
    geoMidpoint = URIRef("https://schema.org/geoMidpoint")
    PublicSwimmingPool = URIRef("https://schema.org/PublicSwimmingPool")
    RoofingContractor = URIRef("https://schema.org/RoofingContractor")
    AlgorithmicallyEnhancedDigitalSource = URIRef("https://schema.org/AlgorithmicallyEnhancedDigitalSource")
    Nonprofit501c24 = URIRef("https://schema.org/Nonprofit501c24")
    BodyMeasurementArm = URIRef("https://schema.org/BodyMeasurementArm")
    procedureType = URIRef("https://schema.org/procedureType")
    TouristDestination = URIRef("https://schema.org/TouristDestination")
    ComedyClub = URIRef("https://schema.org/ComedyClub")
    MixtapeAlbum = URIRef("https://schema.org/MixtapeAlbum")
    endTime = URIRef("https://schema.org/endTime")
    dateSent = URIRef("https://schema.org/dateSent")
    duration = URIRef("https://schema.org/duration")
    FourWheelDriveConfiguration = URIRef("https://schema.org/FourWheelDriveConfiguration")
    geoCoveredBy = URIRef("https://schema.org/geoCoveredBy")
    targetPopulation = URIRef("https://schema.org/targetPopulation")
    BeautySalon = URIRef("https://schema.org/BeautySalon")
    LegislationObject = URIRef("https://schema.org/LegislationObject")
    paymentDueDate = URIRef("https://schema.org/paymentDueDate")
    issuedThrough = URIRef("https://schema.org/issuedThrough")
    dropoffLocation = URIRef("https://schema.org/dropoffLocation")
    Brand = URIRef("https://schema.org/Brand")
    sameAs = URIRef("https://schema.org/sameAs")
    MusicVenue = URIRef("https://schema.org/MusicVenue")
    WesternConventional = URIRef("https://schema.org/WesternConventional")
    geoCrosses = URIRef("https://schema.org/geoCrosses")
    FoodEstablishment = URIRef("https://schema.org/FoodEstablishment")
    maximumPhysicalAttendeeCapacity = URIRef("https://schema.org/maximumPhysicalAttendeeCapacity")
    AssignAction = URIRef("https://schema.org/AssignAction")
    numTracks = URIRef("https://schema.org/numTracks")
    ratingExplanation = URIRef("https://schema.org/ratingExplanation")
    directApply = URIRef("https://schema.org/directApply")
    referencesOrder = URIRef("https://schema.org/referencesOrder")
    broadcastFrequency = URIRef("https://schema.org/broadcastFrequency")
    workFeatured = URIRef("https://schema.org/workFeatured")
    ArtGallery = URIRef("https://schema.org/ArtGallery")
    InstallAction = URIRef("https://schema.org/InstallAction")
    exampleOfWork = URIRef("https://schema.org/exampleOfWork")
    sponsor = URIRef("https://schema.org/sponsor")
    numberOfAirbags = URIRef("https://schema.org/numberOfAirbags")
    PublicationEvent = URIRef("https://schema.org/PublicationEvent")
    offers = URIRef("https://schema.org/offers")
    DoseSchedule = URIRef("https://schema.org/DoseSchedule")
    catalogNumber = URIRef("https://schema.org/catalogNumber")
    accessibilityFeature = URIRef("https://schema.org/accessibilityFeature")
    WorkersUnion = URIRef("https://schema.org/WorkersUnion")
    BodyMeasurementHips = URIRef("https://schema.org/BodyMeasurementHips")
    ArriveAction = URIRef("https://schema.org/ArriveAction")
    BasicIncome = URIRef("https://schema.org/BasicIncome")
    signOrSymptom = URIRef("https://schema.org/signOrSymptom")
    Distillery = URIRef("https://schema.org/Distillery")
    speechToTextMarkup = URIRef("https://schema.org/speechToTextMarkup")
    performers = URIRef("https://schema.org/performers")
    UserLikes = URIRef("https://schema.org/UserLikes")
    producer = URIRef("https://schema.org/producer")
    announcementLocation = URIRef("https://schema.org/announcementLocation")
    episodes = URIRef("https://schema.org/episodes")
    AuthoritativeLegalValue = URIRef("https://schema.org/AuthoritativeLegalValue")
    usesHealthPlanIdStandard = URIRef("https://schema.org/usesHealthPlanIdStandard")
    productionCompany = URIRef("https://schema.org/productionCompany")
    vehicleInteriorColor = URIRef("https://schema.org/vehicleInteriorColor")
    numberOfFullBathrooms = URIRef("https://schema.org/numberOfFullBathrooms")
    CommunityHealth = URIRef("https://schema.org/CommunityHealth")
    accountOverdraftLimit = URIRef("https://schema.org/accountOverdraftLimit")
    gtin = URIRef("https://schema.org/gtin")
    HowToSupply = URIRef("https://schema.org/HowToSupply")
    DefinitiveLegalValue = URIRef("https://schema.org/DefinitiveLegalValue")
    value = URIRef("https://schema.org/value")
    smiles = URIRef("https://schema.org/smiles")
    regionsAllowed = URIRef("https://schema.org/regionsAllowed")
    includedComposition = URIRef("https://schema.org/includedComposition")
    issn = URIRef("https://schema.org/issn")
    includesAttraction = URIRef("https://schema.org/includesAttraction")
    propertyID = URIRef("https://schema.org/propertyID")
    servicePhone = URIRef("https://schema.org/servicePhone")
    relatedTo = URIRef("https://schema.org/relatedTo")
    Mass = URIRef("https://schema.org/Mass")
    ReservationStatusType = URIRef("https://schema.org/ReservationStatusType")
    inker = URIRef("https://schema.org/inker")
    masthead = URIRef("https://schema.org/masthead")
    Bone = URIRef("https://schema.org/Bone")
    Nonprofit501c1 = URIRef("https://schema.org/Nonprofit501c1")
    governmentBenefitsInfo = URIRef("https://schema.org/governmentBenefitsInfo")
    trainingSalary = URIRef("https://schema.org/trainingSalary")
    VideoGame = URIRef("https://schema.org/VideoGame")
    AggregateOffer = URIRef("https://schema.org/AggregateOffer")
    OnlineStore = URIRef("https://schema.org/OnlineStore")
    thumbnailUrl = URIRef("https://schema.org/thumbnailUrl")
    Nonprofit501c24 = URIRef("https://schema.org/Nonprofit501c24")
    ItemList = URIRef("https://schema.org/ItemList")
    postalCodePrefix = URIRef("https://schema.org/postalCodePrefix")
    DDxElement = URIRef("https://schema.org/DDxElement")
    MediaSubscription = URIRef("https://schema.org/MediaSubscription")
    byArtist = URIRef("https://schema.org/byArtist")
    fuelConsumption = URIRef("https://schema.org/fuelConsumption")
    expertConsiderations = URIRef("https://schema.org/expertConsiderations")
    issuedBy = URIRef("https://schema.org/issuedBy")
    latitude = URIRef("https://schema.org/latitude")
    returnPolicyCountry = URIRef("https://schema.org/returnPolicyCountry")
    IOSPlatform = URIRef("https://schema.org/IOSPlatform")
    locationCreated = URIRef("https://schema.org/locationCreated")
    serviceUrl = URIRef("https://schema.org/serviceUrl")
    hasOccupation = URIRef("https://schema.org/hasOccupation")
    DepositAccount = URIRef("https://schema.org/DepositAccount")
    FMRadioChannel = URIRef("https://schema.org/FMRadioChannel")
    provider = URIRef("https://schema.org/provider")
    UnclassifiedAdultConsideration = URIRef("https://schema.org/UnclassifiedAdultConsideration")
    toRecipient = URIRef("https://schema.org/toRecipient")
    PaymentPastDue = URIRef("https://schema.org/PaymentPastDue")
    Clip = URIRef("https://schema.org/Clip")
    JoinAction = URIRef("https://schema.org/JoinAction")
    typeOfBed = URIRef("https://schema.org/typeOfBed")
    WearableMeasurementCup = URIRef("https://schema.org/WearableMeasurementCup")
    priceType = URIRef("https://schema.org/priceType")
    applicationDeadline = URIRef("https://schema.org/applicationDeadline")
    BrainStructure = URIRef("https://schema.org/BrainStructure")
    children = URIRef("https://schema.org/children")
    RealEstateAgent = URIRef("https://schema.org/RealEstateAgent")
    releaseNotes = URIRef("https://schema.org/releaseNotes")
    recipeCategory = URIRef("https://schema.org/recipeCategory")
    SellAction = URIRef("https://schema.org/SellAction")
    Nonprofit501c4 = URIRef("https://schema.org/Nonprofit501c4")
    DrugPregnancyCategory = URIRef("https://schema.org/DrugPregnancyCategory")
    recipeCategory = URIRef("https://schema.org/recipeCategory")
    occupationalCredentialAwarded = URIRef("https://schema.org/occupationalCredentialAwarded")
    claimReviewed = URIRef("https://schema.org/claimReviewed")
    TextObject = URIRef("https://schema.org/TextObject")
    healthPlanNetworkTier = URIRef("https://schema.org/healthPlanNetworkTier")
    calories = URIRef("https://schema.org/calories")
    endorsers = URIRef("https://schema.org/endorsers")
    MovieSeries = URIRef("https://schema.org/MovieSeries")
    numberedPosition = URIRef("https://schema.org/numberedPosition")
    usesHealthPlanIdStandard = URIRef("https://schema.org/usesHealthPlanIdStandard")
    MedicalRiskScore = URIRef("https://schema.org/MedicalRiskScore")
    recognizingAuthority = URIRef("https://schema.org/recognizingAuthority")
    Obstetric = URIRef("https://schema.org/Obstetric")
    MortgageLoan = URIRef("https://schema.org/MortgageLoan")
    performTime = URIRef("https://schema.org/performTime")
    Menu = URIRef("https://schema.org/Menu")
    PhotographAction = URIRef("https://schema.org/PhotographAction")
    numberOfDoors = URIRef("https://schema.org/numberOfDoors")
    OverviewHealthAspect = URIRef("https://schema.org/OverviewHealthAspect")
    WearableSizeSystemMX = URIRef("https://schema.org/WearableSizeSystemMX")
    CheckInAction = URIRef("https://schema.org/CheckInAction")
    telephone = URIRef("https://schema.org/telephone")
    hasBroadcastChannel = URIRef("https://schema.org/hasBroadcastChannel")
    EventScheduled = URIRef("https://schema.org/EventScheduled")
    CompositeCaptureDigitalSource = URIRef("https://schema.org/CompositeCaptureDigitalSource")
    missionCoveragePrioritiesPolicy = URIRef("https://schema.org/missionCoveragePrioritiesPolicy")
    nerveMotor = URIRef("https://schema.org/nerveMotor")
    accessibilityFeature = URIRef("https://schema.org/accessibilityFeature")
    valueReference = URIRef("https://schema.org/valueReference")
    PhysicalActivity = URIRef("https://schema.org/PhysicalActivity")
    Ayurvedic = URIRef("https://schema.org/Ayurvedic")
    distance = URIRef("https://schema.org/distance")
    alternateName = URIRef("https://schema.org/alternateName")
    Joint = URIRef("https://schema.org/Joint")
    recordLabel = URIRef("https://schema.org/recordLabel")
    hasDriveThroughService = URIRef("https://schema.org/hasDriveThroughService")
    doesNotShip = URIRef("https://schema.org/doesNotShip")
    MonetaryGrant = URIRef("https://schema.org/MonetaryGrant")
    siblings = URIRef("https://schema.org/siblings")
    SportsActivityLocation = URIRef("https://schema.org/SportsActivityLocation")
    audience = URIRef("https://schema.org/audience")
    identifyingExam = URIRef("https://schema.org/identifyingExam")
    pattern = URIRef("https://schema.org/pattern")
    TaxiService = URIRef("https://schema.org/TaxiService")
    countryOfOrigin = URIRef("https://schema.org/countryOfOrigin")
    DayOfWeek = URIRef("https://schema.org/DayOfWeek")
    permitAudience = URIRef("https://schema.org/permitAudience")
    namedPosition = URIRef("https://schema.org/namedPosition")
    BoatReservation = URIRef("https://schema.org/BoatReservation")
    speed = URIRef("https://schema.org/speed")
    Mountain = URIRef("https://schema.org/Mountain")
    DrawAction = URIRef("https://schema.org/DrawAction")
    Number = URIRef("https://schema.org/Number")
    negativeNotes = URIRef("https://schema.org/negativeNotes")
    ScholarlyArticle = URIRef("https://schema.org/ScholarlyArticle")
    torque = URIRef("https://schema.org/torque")
    ScheduleAction = URIRef("https://schema.org/ScheduleAction")
    webCheckinTime = URIRef("https://schema.org/webCheckinTime")
    dateIssued = URIRef("https://schema.org/dateIssued")
    AnalysisNewsArticle = URIRef("https://schema.org/AnalysisNewsArticle")
    ShippingRateSettings = URIRef("https://schema.org/ShippingRateSettings")
    EducationEvent = URIRef("https://schema.org/EducationEvent")
    contactlessPayment = URIRef("https://schema.org/contactlessPayment")
    recipient = URIRef("https://schema.org/recipient")
    exerciseType = URIRef("https://schema.org/exerciseType")
    Zoo = URIRef("https://schema.org/Zoo")
    HowToDirection = URIRef("https://schema.org/HowToDirection")
    IndividualPhysician = URIRef("https://schema.org/IndividualPhysician")
    clincalPharmacology = URIRef("https://schema.org/clincalPharmacology")
    EatAction = URIRef("https://schema.org/EatAction")
    photos = URIRef("https://schema.org/photos")
    keywords = URIRef("https://schema.org/keywords")
    exerciseCourse = URIRef("https://schema.org/exerciseCourse")
    BasicIncome = URIRef("https://schema.org/BasicIncome")
    SheetMusic = URIRef("https://schema.org/SheetMusic")
    populationType = URIRef("https://schema.org/populationType")
    memberOf = URIRef("https://schema.org/memberOf")
    byMonthWeek = URIRef("https://schema.org/byMonthWeek")
    healthPlanCoinsuranceRate = URIRef("https://schema.org/healthPlanCoinsuranceRate")
    OfficialLegalValue = URIRef("https://schema.org/OfficialLegalValue")
    availableAtOrFrom = URIRef("https://schema.org/availableAtOrFrom")
    CarUsageType = URIRef("https://schema.org/CarUsageType")
    acceptsReservations = URIRef("https://schema.org/acceptsReservations")
    BoardingPolicyType = URIRef("https://schema.org/BoardingPolicyType")
    legislationJurisdiction = URIRef("https://schema.org/legislationJurisdiction")
    DataDownload = URIRef("https://schema.org/DataDownload")
    encodings = URIRef("https://schema.org/encodings")
    Skin = URIRef("https://schema.org/Skin")
    contentRating = URIRef("https://schema.org/contentRating")
    Quotation = URIRef("https://schema.org/Quotation")
    advanceBookingRequirement = URIRef("https://schema.org/advanceBookingRequirement")
    winner = URIRef("https://schema.org/winner")
    CssSelectorType = URIRef("https://schema.org/CssSelectorType")
    storageRequirements = URIRef("https://schema.org/storageRequirements")
    broadcastSubChannel = URIRef("https://schema.org/broadcastSubChannel")
    Statement = URIRef("https://schema.org/Statement")
    Urologic = URIRef("https://schema.org/Urologic")
    gtin8 = URIRef("https://schema.org/gtin8")
    vehicleSpecialUsage = URIRef("https://schema.org/vehicleSpecialUsage")
    RadioSeries = URIRef("https://schema.org/RadioSeries")
    MediaReviewItem = URIRef("https://schema.org/MediaReviewItem")
    colorSwatch = URIRef("https://schema.org/colorSwatch")
    additionalVariable = URIRef("https://schema.org/additionalVariable")
    lyricist = URIRef("https://schema.org/lyricist")
    sensoryRequirement = URIRef("https://schema.org/sensoryRequirement")
    numConstraints = URIRef("https://schema.org/numConstraints")
    Therapeutic = URIRef("https://schema.org/Therapeutic")
    TaxiVehicleUsage = URIRef("https://schema.org/TaxiVehicleUsage")
    observationAbout = URIRef("https://schema.org/observationAbout")
    lodgingUnitDescription = URIRef("https://schema.org/lodgingUnitDescription")
    MusicRecording = URIRef("https://schema.org/MusicRecording")
    auditDate = URIRef("https://schema.org/auditDate")
    hasEnergyEfficiencyCategory = URIRef("https://schema.org/hasEnergyEfficiencyCategory")
    agentInteractionStatistic = URIRef("https://schema.org/agentInteractionStatistic")
    Gene = URIRef("https://schema.org/Gene")
    correction = URIRef("https://schema.org/correction")
    MediaReviewItem = URIRef("https://schema.org/MediaReviewItem")
    OccupationalActivity = URIRef("https://schema.org/OccupationalActivity")
    gtin12 = URIRef("https://schema.org/gtin12")
    musicalKey = URIRef("https://schema.org/musicalKey")
    tripOrigin = URIRef("https://schema.org/tripOrigin")
    partOfTrip = URIRef("https://schema.org/partOfTrip")
    inLanguage = URIRef("https://schema.org/inLanguage")
    Nonprofit501c13 = URIRef("https://schema.org/Nonprofit501c13")
    legislationDate = URIRef("https://schema.org/legislationDate")
    follows = URIRef("https://schema.org/follows")
    modelDate = URIRef("https://schema.org/modelDate")
    loser = URIRef("https://schema.org/loser")
    OfficialLegalValue = URIRef("https://schema.org/OfficialLegalValue")
    legislationLegalForce = URIRef("https://schema.org/legislationLegalForce")
    LinkRole = URIRef("https://schema.org/LinkRole")
    MedicalIndication = URIRef("https://schema.org/MedicalIndication")
    BroadcastRelease = URIRef("https://schema.org/BroadcastRelease")
    differentialDiagnosis = URIRef("https://schema.org/differentialDiagnosis")
    ImageObject = URIRef("https://schema.org/ImageObject")
    thumbnailUrl = URIRef("https://schema.org/thumbnailUrl")
    ConstraintNode = URIRef("https://schema.org/ConstraintNode")
    domiciledMortgage = URIRef("https://schema.org/domiciledMortgage")
    SchoolDistrict = URIRef("https://schema.org/SchoolDistrict")
    serviceOutput = URIRef("https://schema.org/serviceOutput")
    albumRelease = URIRef("https://schema.org/albumRelease")
    lyricist = URIRef("https://schema.org/lyricist")
    productSupported = URIRef("https://schema.org/productSupported")
    inCodeSet = URIRef("https://schema.org/inCodeSet")
    legislationApplies = URIRef("https://schema.org/legislationApplies")
    OrderCancelled = URIRef("https://schema.org/OrderCancelled")
    publishedOn = URIRef("https://schema.org/publishedOn")
    recordingOf = URIRef("https://schema.org/recordingOf")
    OnSitePickup = URIRef("https://schema.org/OnSitePickup")
    CommunicateAction = URIRef("https://schema.org/CommunicateAction")
    subOrganization = URIRef("https://schema.org/subOrganization")
    educationalAlignment = URIRef("https://schema.org/educationalAlignment")
    downPayment = URIRef("https://schema.org/downPayment")
    LaboratoryScience = URIRef("https://schema.org/LaboratoryScience")
    jobLocationType = URIRef("https://schema.org/jobLocationType")
    FourWheelDriveConfiguration = URIRef("https://schema.org/FourWheelDriveConfiguration")
    recommendedIntake = URIRef("https://schema.org/recommendedIntake")
    serialNumber = URIRef("https://schema.org/serialNumber")
    Chapter = URIRef("https://schema.org/Chapter")
    costPerUnit = URIRef("https://schema.org/costPerUnit")
    OfflineEventAttendanceMode = URIRef("https://schema.org/OfflineEventAttendanceMode")
    children = URIRef("https://schema.org/children")
    SchoolDistrict = URIRef("https://schema.org/SchoolDistrict")
    timeToComplete = URIRef("https://schema.org/timeToComplete")
    RightHandDriving = URIRef("https://schema.org/RightHandDriving")
    numberOfBathroomsTotal = URIRef("https://schema.org/numberOfBathroomsTotal")
    priceSpecification = URIRef("https://schema.org/priceSpecification")
    SearchRescueOrganization = URIRef("https://schema.org/SearchRescueOrganization")
    keywords = URIRef("https://schema.org/keywords")
    geoEquals = URIRef("https://schema.org/geoEquals")
    NutritionInformation = URIRef("https://schema.org/NutritionInformation")
    floorLimit = URIRef("https://schema.org/floorLimit")
    servicePostalAddress = URIRef("https://schema.org/servicePostalAddress")
    learningResourceType = URIRef("https://schema.org/learningResourceType")
    contactPoint = URIRef("https://schema.org/contactPoint")
    departureStation = URIRef("https://schema.org/departureStation")
    depth = URIRef("https://schema.org/depth")
    areaServed = URIRef("https://schema.org/areaServed")
    EventRescheduled = URIRef("https://schema.org/EventRescheduled")
    biologicalRole = URIRef("https://schema.org/biologicalRole")
    CarUsageType = URIRef("https://schema.org/CarUsageType")
    OpinionNewsArticle = URIRef("https://schema.org/OpinionNewsArticle")
    MedicalGuideline = URIRef("https://schema.org/MedicalGuideline")
    ArtGallery = URIRef("https://schema.org/ArtGallery")
    maximumEnrollment = URIRef("https://schema.org/maximumEnrollment")
    callSign = URIRef("https://schema.org/callSign")
    associatedMedia = URIRef("https://schema.org/associatedMedia")
    spatialCoverage = URIRef("https://schema.org/spatialCoverage")
    PropertyValueSpecification = URIRef("https://schema.org/PropertyValueSpecification")
    TelevisionStation = URIRef("https://schema.org/TelevisionStation")
    occupationalCategory = URIRef("https://schema.org/occupationalCategory")
    USNonprofitType = URIRef("https://schema.org/USNonprofitType")
    studyLocation = URIRef("https://schema.org/studyLocation")
    eventSchedule = URIRef("https://schema.org/eventSchedule")
    commentCount = URIRef("https://schema.org/commentCount")
    skills = URIRef("https://schema.org/skills")
    founder = URIRef("https://schema.org/founder")
    GovernmentService = URIRef("https://schema.org/GovernmentService")
    cvdNumC19OverflowPats = URIRef("https://schema.org/cvdNumC19OverflowPats")
    Specialty = URIRef("https://schema.org/Specialty")
    contributor = URIRef("https://schema.org/contributor")
    Nonprofit501c17 = URIRef("https://schema.org/Nonprofit501c17")
    HearingImpairedSupported = URIRef("https://schema.org/HearingImpairedSupported")
    ReportageNewsArticle = URIRef("https://schema.org/ReportageNewsArticle")
    tocContinuation = URIRef("https://schema.org/tocContinuation")
    codingSystem = URIRef("https://schema.org/codingSystem")
    location = URIRef("https://schema.org/location")
    WearableSizeSystemEurope = URIRef("https://schema.org/WearableSizeSystemEurope")
    LegalValueLevel = URIRef("https://schema.org/LegalValueLevel")
    DaySpa = URIRef("https://schema.org/DaySpa")
    nerve = URIRef("https://schema.org/nerve")
    surface = URIRef("https://schema.org/surface")
    executableLibraryName = URIRef("https://schema.org/executableLibraryName")
    performers = URIRef("https://schema.org/performers")
    certificationStatus = URIRef("https://schema.org/certificationStatus")
    HyperTocEntry = URIRef("https://schema.org/HyperTocEntry")
    VirtualRecordingDigitalSource = URIRef("https://schema.org/VirtualRecordingDigitalSource")
    Audiobook = URIRef("https://schema.org/Audiobook")
    hasMerchantReturnPolicy = URIRef("https://schema.org/hasMerchantReturnPolicy")
    audio = URIRef("https://schema.org/audio")
    locationCreated = URIRef("https://schema.org/locationCreated")
    doorTime = URIRef("https://schema.org/doorTime")
    MobilePhoneStore = URIRef("https://schema.org/MobilePhoneStore")
    healthPlanDrugOption = URIRef("https://schema.org/healthPlanDrugOption")
    LeaveAction = URIRef("https://schema.org/LeaveAction")
    TaxiStand = URIRef("https://schema.org/TaxiStand")
    MerchantReturnPolicy = URIRef("https://schema.org/MerchantReturnPolicy")
    numberOfEpisodes = URIRef("https://schema.org/numberOfEpisodes")
    legislationDate = URIRef("https://schema.org/legislationDate")
    OfficialLegalValue = URIRef("https://schema.org/OfficialLegalValue")
    NonprofitANBI = URIRef("https://schema.org/NonprofitANBI")
    partOfTrip = URIRef("https://schema.org/partOfTrip")
    characterAttribute = URIRef("https://schema.org/characterAttribute")
    PreventionIndication = URIRef("https://schema.org/PreventionIndication")
    directors = URIRef("https://schema.org/directors")
    CatholicChurch = URIRef("https://schema.org/CatholicChurch")
    isPlanForApartment = URIRef("https://schema.org/isPlanForApartment")
    code = URIRef("https://schema.org/code")
    ResearchOrganization = URIRef("https://schema.org/ResearchOrganization")
    shippingOrigin = URIRef("https://schema.org/shippingOrigin")
    sdPublisher = URIRef("https://schema.org/sdPublisher")
    answerCount = URIRef("https://schema.org/answerCount")
    LiveBlogPosting = URIRef("https://schema.org/LiveBlogPosting")
    MedicalClinic = URIRef("https://schema.org/MedicalClinic")
    applicationContact = URIRef("https://schema.org/applicationContact")
    affiliation = URIRef("https://schema.org/affiliation")
    owns = URIRef("https://schema.org/owns")
    fuelCapacity = URIRef("https://schema.org/fuelCapacity")
    AskAction = URIRef("https://schema.org/AskAction")
    specialCommitments = URIRef("https://schema.org/specialCommitments")
    UnclassifiedAdultConsideration = URIRef("https://schema.org/UnclassifiedAdultConsideration")
    signOrSymptom = URIRef("https://schema.org/signOrSymptom")
    medicalSpecialty = URIRef("https://schema.org/medicalSpecialty")
    hasEnergyEfficiencyCategory = URIRef("https://schema.org/hasEnergyEfficiencyCategory")
    fuelType = URIRef("https://schema.org/fuelType")
    flightNumber = URIRef("https://schema.org/flightNumber")
    BikeStore = URIRef("https://schema.org/BikeStore")
    Nonprofit501c23 = URIRef("https://schema.org/Nonprofit501c23")
    authenticator = URIRef("https://schema.org/authenticator")
    PhysicalActivity = URIRef("https://schema.org/PhysicalActivity")
    PrependAction = URIRef("https://schema.org/PrependAction")
    gamePlatform = URIRef("https://schema.org/gamePlatform")
    sponsor = URIRef("https://schema.org/sponsor")
    sourceOrganization = URIRef("https://schema.org/sourceOrganization")
    departureGate = URIRef("https://schema.org/departureGate")
    seasons = URIRef("https://schema.org/seasons")
    relatedAnatomy = URIRef("https://schema.org/relatedAnatomy")
    Waterfall = URIRef("https://schema.org/Waterfall")
    Book = URIRef("https://schema.org/Book")
    TripleBlindedTrial = URIRef("https://schema.org/TripleBlindedTrial")
    clipNumber = URIRef("https://schema.org/clipNumber")
    ineligibleRegion = URIRef("https://schema.org/ineligibleRegion")
    ListItem = URIRef("https://schema.org/ListItem")
    UserReview = URIRef("https://schema.org/UserReview")
    hasCourseInstance = URIRef("https://schema.org/hasCourseInstance")
    contentLocation = URIRef("https://schema.org/contentLocation")
    commentText = URIRef("https://schema.org/commentText")
    copyrightHolder = URIRef("https://schema.org/copyrightHolder")
    upvoteCount = URIRef("https://schema.org/upvoteCount")
    taxonomicRange = URIRef("https://schema.org/taxonomicRange")
    Poster = URIRef("https://schema.org/Poster")
    validIn = URIRef("https://schema.org/validIn")
    NonprofitType = URIRef("https://schema.org/NonprofitType")
    ApprovedIndication = URIRef("https://schema.org/ApprovedIndication")
    amount = URIRef("https://schema.org/amount")
    UserReview = URIRef("https://schema.org/UserReview")
    timeOfDay = URIRef("https://schema.org/timeOfDay")
    members = URIRef("https://schema.org/members")
    knownVehicleDamages = URIRef("https://schema.org/knownVehicleDamages")
    suggestedMeasurement = URIRef("https://schema.org/suggestedMeasurement")
    typeOfBed = URIRef("https://schema.org/typeOfBed")
    Nonprofit501c23 = URIRef("https://schema.org/Nonprofit501c23")
    code = URIRef("https://schema.org/code")
    image = URIRef("https://schema.org/image")
    dataset = URIRef("https://schema.org/dataset")
    AutomatedTeller = URIRef("https://schema.org/AutomatedTeller")
    email = URIRef("https://schema.org/email")
    exceptDate = URIRef("https://schema.org/exceptDate")
    CategoryCode = URIRef("https://schema.org/CategoryCode")
    annualPercentageRate = URIRef("https://schema.org/annualPercentageRate")
    application = URIRef("https://schema.org/application")
    EmergencyService = URIRef("https://schema.org/EmergencyService")
    parents = URIRef("https://schema.org/parents")
    ContactPage = URIRef("https://schema.org/ContactPage")
    trailer = URIRef("https://schema.org/trailer")
    SubwayStation = URIRef("https://schema.org/SubwayStation")
    orderQuantity = URIRef("https://schema.org/orderQuantity")
    healthPlanCoinsuranceOption = URIRef("https://schema.org/healthPlanCoinsuranceOption")
    requiredGender = URIRef("https://schema.org/requiredGender")
    isAccessibleForFree = URIRef("https://schema.org/isAccessibleForFree")
    numberOfRooms = URIRef("https://schema.org/numberOfRooms")
    ResearchOrganization = URIRef("https://schema.org/ResearchOrganization")
    LegalValueLevel = URIRef("https://schema.org/LegalValueLevel")
    memoryRequirements = URIRef("https://schema.org/memoryRequirements")
    percentile75 = URIRef("https://schema.org/percentile75")
    releaseOf = URIRef("https://schema.org/releaseOf")
    requiredQuantity = URIRef("https://schema.org/requiredQuantity")
    TipAction = URIRef("https://schema.org/TipAction")
    programMembershipUsed = URIRef("https://schema.org/programMembershipUsed")
    DataCatalog = URIRef("https://schema.org/DataCatalog")
    trainingSalary = URIRef("https://schema.org/trainingSalary")
    DeliveryMethod = URIRef("https://schema.org/DeliveryMethod")
    albums = URIRef("https://schema.org/albums")
    pattern = URIRef("https://schema.org/pattern")
    isProprietary = URIRef("https://schema.org/isProprietary")
    offers = URIRef("https://schema.org/offers")
    relatedDrug = URIRef("https://schema.org/relatedDrug")
    applicableCountry = URIRef("https://schema.org/applicableCountry")
    discountCurrency = URIRef("https://schema.org/discountCurrency")
    OfflineEventAttendanceMode = URIRef("https://schema.org/OfflineEventAttendanceMode")
    Car = URIRef("https://schema.org/Car")
    numberOfItems = URIRef("https://schema.org/numberOfItems")
    numberOfEpisodes = URIRef("https://schema.org/numberOfEpisodes")
    originatesFrom = URIRef("https://schema.org/originatesFrom")
    FindAction = URIRef("https://schema.org/FindAction")
    reservedTicket = URIRef("https://schema.org/reservedTicket")
    applicationStartDate = URIRef("https://schema.org/applicationStartDate")
    downloadUrl = URIRef("https://schema.org/downloadUrl")
    elevation = URIRef("https://schema.org/elevation")
    additionalType = URIRef("https://schema.org/additionalType")
    DeleteAction = URIRef("https://schema.org/DeleteAction")
    Report = URIRef("https://schema.org/Report")
    PaidLeave = URIRef("https://schema.org/PaidLeave")
    datePublished = URIRef("https://schema.org/datePublished")
    ApprovedIndication = URIRef("https://schema.org/ApprovedIndication")
    valueName = URIRef("https://schema.org/valueName")
    Optician = URIRef("https://schema.org/Optician")
    OrderStatus = URIRef("https://schema.org/OrderStatus")
    Season = URIRef("https://schema.org/Season")
    SpreadsheetDigitalDocument = URIRef("https://schema.org/SpreadsheetDigitalDocument")
    readBy = URIRef("https://schema.org/readBy")
    CausesHealthAspect = URIRef("https://schema.org/CausesHealthAspect")
    stepValue = URIRef("https://schema.org/stepValue")
    subtitleLanguage = URIRef("https://schema.org/subtitleLanguage")
    webCheckinTime = URIRef("https://schema.org/webCheckinTime")
    CompoundPriceSpecification = URIRef("https://schema.org/CompoundPriceSpecification")
    StrengthTraining = URIRef("https://schema.org/StrengthTraining")
    amenityFeature = URIRef("https://schema.org/amenityFeature")
    archiveHeld = URIRef("https://schema.org/archiveHeld")
    domiciledMortgage = URIRef("https://schema.org/domiciledMortgage")
    locationCreated = URIRef("https://schema.org/locationCreated")
    GlutenFreeDiet = URIRef("https://schema.org/GlutenFreeDiet")
    contactPoint = URIRef("https://schema.org/contactPoint")
    PalliativeProcedure = URIRef("https://schema.org/PalliativeProcedure")
    salaryUponCompletion = URIRef("https://schema.org/salaryUponCompletion")
    hasCourse = URIRef("https://schema.org/hasCourse")
    certificationStatus = URIRef("https://schema.org/certificationStatus")
    ActionAccessSpecification = URIRef("https://schema.org/ActionAccessSpecification")
    requiredMaxAge = URIRef("https://schema.org/requiredMaxAge")
    VideoGame = URIRef("https://schema.org/VideoGame")
    requiresSubscription = URIRef("https://schema.org/requiresSubscription")
    diversityStaffingReport = URIRef("https://schema.org/diversityStaffingReport")
    Nonprofit501c10 = URIRef("https://schema.org/Nonprofit501c10")
    PodcastSeason = URIRef("https://schema.org/PodcastSeason")
    contentLocation = URIRef("https://schema.org/contentLocation")
    Museum = URIRef("https://schema.org/Museum")
    color = URIRef("https://schema.org/color")
    requiredMinAge = URIRef("https://schema.org/requiredMinAge")
    MovieTheater = URIRef("https://schema.org/MovieTheater")
    flightNumber = URIRef("https://schema.org/flightNumber")
    SearchRescueOrganization = URIRef("https://schema.org/SearchRescueOrganization")
    deliveryAddress = URIRef("https://schema.org/deliveryAddress")
    events = URIRef("https://schema.org/events")
    naturalProgression = URIRef("https://schema.org/naturalProgression")
    verificationFactCheckingPolicy = URIRef("https://schema.org/verificationFactCheckingPolicy")
    Nonprofit501c22 = URIRef("https://schema.org/Nonprofit501c22")
    MinorHumanEditsDigitalSource = URIRef("https://schema.org/MinorHumanEditsDigitalSource")
    associatedMedia = URIRef("https://schema.org/associatedMedia")
    MediaManipulationRatingEnumeration = URIRef("https://schema.org/MediaManipulationRatingEnumeration")
    trialDesign = URIRef("https://schema.org/trialDesign")
    CaseSeries = URIRef("https://schema.org/CaseSeries")
    directors = URIRef("https://schema.org/directors")
    callSign = URIRef("https://schema.org/callSign")
    isbn = URIRef("https://schema.org/isbn")
    PodcastEpisode = URIRef("https://schema.org/PodcastEpisode")
    instrument = URIRef("https://schema.org/instrument")
    numberOfBeds = URIRef("https://schema.org/numberOfBeds")
    HealthCare = URIRef("https://schema.org/HealthCare")
    RegisterAction = URIRef("https://schema.org/RegisterAction")
    Consortium = URIRef("https://schema.org/Consortium")
    partOfEpisode = URIRef("https://schema.org/partOfEpisode")
    name = URIRef("https://schema.org/name")
    includesObject = URIRef("https://schema.org/includesObject")
    InviteAction = URIRef("https://schema.org/InviteAction")
    providesBroadcastService = URIRef("https://schema.org/providesBroadcastService")
    itemOffered = URIRef("https://schema.org/itemOffered")
    alcoholWarning = URIRef("https://schema.org/alcoholWarning")
    encodingType = URIRef("https://schema.org/encodingType")
    actionableFeedbackPolicy = URIRef("https://schema.org/actionableFeedbackPolicy")
    inker = URIRef("https://schema.org/inker")
    MedicalRiskEstimator = URIRef("https://schema.org/MedicalRiskEstimator")
    subOrganization = URIRef("https://schema.org/subOrganization")
    coverageEndTime = URIRef("https://schema.org/coverageEndTime")
    applicableLocation = URIRef("https://schema.org/applicableLocation")
    ProgramMembership = URIRef("https://schema.org/ProgramMembership")
    WarrantyScope = URIRef("https://schema.org/WarrantyScope")
    numberOfSeasons = URIRef("https://schema.org/numberOfSeasons")
    partOfTVSeries = URIRef("https://schema.org/partOfTVSeries")
    inChIKey = URIRef("https://schema.org/inChIKey")
    translator = URIRef("https://schema.org/translator")
    ReturnLabelCustomerResponsibility = URIRef("https://schema.org/ReturnLabelCustomerResponsibility")
    sensoryRequirement = URIRef("https://schema.org/sensoryRequirement")
    WearableSizeGroupTall = URIRef("https://schema.org/WearableSizeGroupTall")
    pageEnd = URIRef("https://schema.org/pageEnd")
    UKNonprofitType = URIRef("https://schema.org/UKNonprofitType")
    layoutImage = URIRef("https://schema.org/layoutImage")
    speed = URIRef("https://schema.org/speed")
    GovernmentPermit = URIRef("https://schema.org/GovernmentPermit")
    comment = URIRef("https://schema.org/comment")
    SelfStorage = URIRef("https://schema.org/SelfStorage")
    SelfCareHealthAspect = URIRef("https://schema.org/SelfCareHealthAspect")
    eligibleRegion = URIRef("https://schema.org/eligibleRegion")
    ccRecipient = URIRef("https://schema.org/ccRecipient")
    WearableSizeSystemCN = URIRef("https://schema.org/WearableSizeSystemCN")
    monthlyMinimumRepaymentAmount = URIRef("https://schema.org/monthlyMinimumRepaymentAmount")
    MediaManipulationRatingEnumeration = URIRef("https://schema.org/MediaManipulationRatingEnumeration")
    dateCreated = URIRef("https://schema.org/dateCreated")
    repetitions = URIRef("https://schema.org/repetitions")
    unitCode = URIRef("https://schema.org/unitCode")
    credentialCategory = URIRef("https://schema.org/credentialCategory")
    legislationType = URIRef("https://schema.org/legislationType")
    hasRepresentation = URIRef("https://schema.org/hasRepresentation")
    Osteopathic = URIRef("https://schema.org/Osteopathic")
    AlcoholConsideration = URIRef("https://schema.org/AlcoholConsideration")
    DeliveryMethod = URIRef("https://schema.org/DeliveryMethod")
    award = URIRef("https://schema.org/award")
    estimatedSalary = URIRef("https://schema.org/estimatedSalary")
    exercisePlan = URIRef("https://schema.org/exercisePlan")
    TheaterGroup = URIRef("https://schema.org/TheaterGroup")
    event = URIRef("https://schema.org/event")
    accommodationFloorPlan = URIRef("https://schema.org/accommodationFloorPlan")
    Mass = URIRef("https://schema.org/Mass")
    TVSeries = URIRef("https://schema.org/TVSeries")
    discount = URIRef("https://schema.org/discount")
    foundingDate = URIRef("https://schema.org/foundingDate")
    legalStatus = URIRef("https://schema.org/legalStatus")
    faxNumber = URIRef("https://schema.org/faxNumber")
    MedicalResearcher = URIRef("https://schema.org/MedicalResearcher")
    MedicalAudienceType = URIRef("https://schema.org/MedicalAudienceType")
    arrivalBusStop = URIRef("https://schema.org/arrivalBusStop")
    distance = URIRef("https://schema.org/distance")
    WPFooter = URIRef("https://schema.org/WPFooter")
    measurementQualifier = URIRef("https://schema.org/measurementQualifier")
    DrugCost = URIRef("https://schema.org/DrugCost")
    hasMenuItem = URIRef("https://schema.org/hasMenuItem")
    opens = URIRef("https://schema.org/opens")
    OwnershipInfo = URIRef("https://schema.org/OwnershipInfo")
    MeasurementTypeEnumeration = URIRef("https://schema.org/MeasurementTypeEnumeration")
    RoofingContractor = URIRef("https://schema.org/RoofingContractor")
    materialExtent = URIRef("https://schema.org/materialExtent")
    supplyTo = URIRef("https://schema.org/supplyTo")
    NotYetRecruiting = URIRef("https://schema.org/NotYetRecruiting")
    workLocation = URIRef("https://schema.org/workLocation")
    isLocatedInSubcellularLocation = URIRef("https://schema.org/isLocatedInSubcellularLocation")
    OfferShippingDetails = URIRef("https://schema.org/OfferShippingDetails")
    isPartOf = URIRef("https://schema.org/isPartOf")
    size = URIRef("https://schema.org/size")
    announcementLocation = URIRef("https://schema.org/announcementLocation")
    advanceBookingRequirement = URIRef("https://schema.org/advanceBookingRequirement")
    exceptDate = URIRef("https://schema.org/exceptDate")
    hospitalAffiliation = URIRef("https://schema.org/hospitalAffiliation")
    yearBuilt = URIRef("https://schema.org/yearBuilt")
    fuelEfficiency = URIRef("https://schema.org/fuelEfficiency")
    RestrictedDiet = URIRef("https://schema.org/RestrictedDiet")
    PaymentChargeSpecification = URIRef("https://schema.org/PaymentChargeSpecification")
    geographicArea = URIRef("https://schema.org/geographicArea")
    VideoGame = URIRef("https://schema.org/VideoGame")
    starRating = URIRef("https://schema.org/starRating")
    height = URIRef("https://schema.org/height")
    sport = URIRef("https://schema.org/sport")
    MusicPlaylist = URIRef("https://schema.org/MusicPlaylist")
    alignmentType = URIRef("https://schema.org/alignmentType")
    diversityStaffingReport = URIRef("https://schema.org/diversityStaffingReport")
    title = URIRef("https://schema.org/title")
    TouristAttraction = URIRef("https://schema.org/TouristAttraction")
    dietFeatures = URIRef("https://schema.org/dietFeatures")
    globalLocationNumber = URIRef("https://schema.org/globalLocationNumber")
    interactivityType = URIRef("https://schema.org/interactivityType")
    modelDate = URIRef("https://schema.org/modelDate")
    strengthValue = URIRef("https://schema.org/strengthValue")
    Physician = URIRef("https://schema.org/Physician")
    MayTreatHealthAspect = URIRef("https://schema.org/MayTreatHealthAspect")
    warrantyScope = URIRef("https://schema.org/warrantyScope")
    postalCodeRange = URIRef("https://schema.org/postalCodeRange")
    issn = URIRef("https://schema.org/issn")
    broadcastDisplayName = URIRef("https://schema.org/broadcastDisplayName")
    cutoffTime = URIRef("https://schema.org/cutoffTime")
    query = URIRef("https://schema.org/query")
    UKNonprofitType = URIRef("https://schema.org/UKNonprofitType")
    MulticellularParasite = URIRef("https://schema.org/MulticellularParasite")
    vatID = URIRef("https://schema.org/vatID")
    PronounceableText = URIRef("https://schema.org/PronounceableText")
    WearableMeasurementTypeEnumeration = URIRef("https://schema.org/WearableMeasurementTypeEnumeration")
    vehicleSpecialUsage = URIRef("https://schema.org/vehicleSpecialUsage")
    vehicleInteriorColor = URIRef("https://schema.org/vehicleInteriorColor")
    MedicalStudy = URIRef("https://schema.org/MedicalStudy")
    hoursAvailable = URIRef("https://schema.org/hoursAvailable")
    accessCode = URIRef("https://schema.org/accessCode")
    fileSize = URIRef("https://schema.org/fileSize")
    UserLikes = URIRef("https://schema.org/UserLikes")
    exceptDate = URIRef("https://schema.org/exceptDate")
    gameAvailabilityType = URIRef("https://schema.org/gameAvailabilityType")
    reviews = URIRef("https://schema.org/reviews")
    targetPopulation = URIRef("https://schema.org/targetPopulation")
    Trip = URIRef("https://schema.org/Trip")
    PodcastSeries = URIRef("https://schema.org/PodcastSeries")
    Drawing = URIRef("https://schema.org/Drawing")
    Nonprofit501c3 = URIRef("https://schema.org/Nonprofit501c3")
    OfflineEventAttendanceMode = URIRef("https://schema.org/OfflineEventAttendanceMode")
    deliveryLeadTime = URIRef("https://schema.org/deliveryLeadTime")
    availableIn = URIRef("https://schema.org/availableIn")
    suggestedMeasurement = URIRef("https://schema.org/suggestedMeasurement")
    CertificationInactive = URIRef("https://schema.org/CertificationInactive")
    actor = URIRef("https://schema.org/actor")
    EUEnergyEfficiencyCategoryF = URIRef("https://schema.org/EUEnergyEfficiencyCategoryF")
    productionCompany = URIRef("https://schema.org/productionCompany")
    vehicleModelDate = URIRef("https://schema.org/vehicleModelDate")
    jurisdiction = URIRef("https://schema.org/jurisdiction")
    Homeopathic = URIRef("https://schema.org/Homeopathic")
    scheduledPaymentDate = URIRef("https://schema.org/scheduledPaymentDate")
    superEvent = URIRef("https://schema.org/superEvent")
    cvdFacilityCounty = URIRef("https://schema.org/cvdFacilityCounty")
    doorTime = URIRef("https://schema.org/doorTime")
    positiveNotes = URIRef("https://schema.org/positiveNotes")
    MSRP = URIRef("https://schema.org/MSRP")
    PrognosisHealthAspect = URIRef("https://schema.org/PrognosisHealthAspect")
    ChemicalSubstance = URIRef("https://schema.org/ChemicalSubstance")
    numberOfSeasons = URIRef("https://schema.org/numberOfSeasons")
    Winery = URIRef("https://schema.org/Winery")
    ratingExplanation = URIRef("https://schema.org/ratingExplanation")
    hasVariant = URIRef("https://schema.org/hasVariant")
    ListPrice = URIRef("https://schema.org/ListPrice")
    TransitMap = URIRef("https://schema.org/TransitMap")
    contraindication = URIRef("https://schema.org/contraindication")
    Nonprofit501c19 = URIRef("https://schema.org/Nonprofit501c19")
    acceptsReservations = URIRef("https://schema.org/acceptsReservations")
    MiddleSchool = URIRef("https://schema.org/MiddleSchool")
    containsSeason = URIRef("https://schema.org/containsSeason")
    broadcaster = URIRef("https://schema.org/broadcaster")
    HealthClub = URIRef("https://schema.org/HealthClub")
    EUEnergyEfficiencyCategoryF = URIRef("https://schema.org/EUEnergyEfficiencyCategoryF")
    targetName = URIRef("https://schema.org/targetName")
    healthPlanId = URIRef("https://schema.org/healthPlanId")
    WearableSizeGroupPlus = URIRef("https://schema.org/WearableSizeGroupPlus")
    PathologyTest = URIRef("https://schema.org/PathologyTest")
    measurementMethod = URIRef("https://schema.org/measurementMethod")
    episode = URIRef("https://schema.org/episode")
    isrcCode = URIRef("https://schema.org/isrcCode")
    Nonprofit501c9 = URIRef("https://schema.org/Nonprofit501c9")
    printEdition = URIRef("https://schema.org/printEdition")
    PalliativeProcedure = URIRef("https://schema.org/PalliativeProcedure")
    ContactPoint = URIRef("https://schema.org/ContactPoint")
    hasBroadcastChannel = URIRef("https://schema.org/hasBroadcastChannel")
    seller = URIRef("https://schema.org/seller")
    VoteAction = URIRef("https://schema.org/VoteAction")
    departureAirport = URIRef("https://schema.org/departureAirport")
    MulticellularParasite = URIRef("https://schema.org/MulticellularParasite")
    requirements = URIRef("https://schema.org/requirements")
    dataFeedElement = URIRef("https://schema.org/dataFeedElement")
    disambiguatingDescription = URIRef("https://schema.org/disambiguatingDescription")
    CivicStructure = URIRef("https://schema.org/CivicStructure")
    exerciseCourse = URIRef("https://schema.org/exerciseCourse")
    birthDate = URIRef("https://schema.org/birthDate")
    hospitalAffiliation = URIRef("https://schema.org/hospitalAffiliation")
    knowsLanguage = URIRef("https://schema.org/knowsLanguage")
    EducationalAudience = URIRef("https://schema.org/EducationalAudience")
    maximumPhysicalAttendeeCapacity = URIRef("https://schema.org/maximumPhysicalAttendeeCapacity")
    areaServed = URIRef("https://schema.org/areaServed")
    numberOfPlayers = URIRef("https://schema.org/numberOfPlayers")
    carbohydrateContent = URIRef("https://schema.org/carbohydrateContent")
    responsibilities = URIRef("https://schema.org/responsibilities")
    CompositeCaptureDigitalSource = URIRef("https://schema.org/CompositeCaptureDigitalSource")
    appliesToDeliveryMethod = URIRef("https://schema.org/appliesToDeliveryMethod")
    SeatingMap = URIRef("https://schema.org/SeatingMap")
    jurisdiction = URIRef("https://schema.org/jurisdiction")
    exerciseRelatedDiet = URIRef("https://schema.org/exerciseRelatedDiet")
    headline = URIRef("https://schema.org/headline")
    partOfEpisode = URIRef("https://schema.org/partOfEpisode")
    nsn = URIRef("https://schema.org/nsn")
    subtitleLanguage = URIRef("https://schema.org/subtitleLanguage")
    accountId = URIRef("https://schema.org/accountId")
    OrderReturned = URIRef("https://schema.org/OrderReturned")
    fuelCapacity = URIRef("https://schema.org/fuelCapacity")
    paymentMethod = URIRef("https://schema.org/paymentMethod")
    Podiatric = URIRef("https://schema.org/Podiatric")
    longitude = URIRef("https://schema.org/longitude")
    broadcastSubChannel = URIRef("https://schema.org/broadcastSubChannel")
    AmpStory = URIRef("https://schema.org/AmpStory")
    applicationCategory = URIRef("https://schema.org/applicationCategory")
    LearningResource = URIRef("https://schema.org/LearningResource")
    Nonprofit501c7 = URIRef("https://schema.org/Nonprofit501c7")
    CancelAction = URIRef("https://schema.org/CancelAction")
    cvdNumICUBedsOcc = URIRef("https://schema.org/cvdNumICUBedsOcc")
    ownedFrom = URIRef("https://schema.org/ownedFrom")
    subtitleLanguage = URIRef("https://schema.org/subtitleLanguage")
    differentialDiagnosis = URIRef("https://schema.org/differentialDiagnosis")
    structuralClass = URIRef("https://schema.org/structuralClass")
    occupancy = URIRef("https://schema.org/occupancy")
    seatingType = URIRef("https://schema.org/seatingType")
    reservationFor = URIRef("https://schema.org/reservationFor")
    IndividualPhysician = URIRef("https://schema.org/IndividualPhysician")
    eligibleTransactionVolume = URIRef("https://schema.org/eligibleTransactionVolume")
    knows = URIRef("https://schema.org/knows")
    MeasurementMethodEnum = URIRef("https://schema.org/MeasurementMethodEnum")
    noBylinesPolicy = URIRef("https://schema.org/noBylinesPolicy")
    fromLocation = URIRef("https://schema.org/fromLocation")
    postalCode = URIRef("https://schema.org/postalCode")
    startTime = URIRef("https://schema.org/startTime")
    MedicalClinic = URIRef("https://schema.org/MedicalClinic")
    accessModeSufficient = URIRef("https://schema.org/accessModeSufficient")
    Distillery = URIRef("https://schema.org/Distillery")
    sponsor = URIRef("https://schema.org/sponsor")
    refundType = URIRef("https://schema.org/refundType")
    structuralClass = URIRef("https://schema.org/structuralClass")
    Otolaryngologic = URIRef("https://schema.org/Otolaryngologic")
    GovernmentBuilding = URIRef("https://schema.org/GovernmentBuilding")
    eligibleRegion = URIRef("https://schema.org/eligibleRegion")
    Nonprofit501d = URIRef("https://schema.org/Nonprofit501d")
    InvestmentFund = URIRef("https://schema.org/InvestmentFund")
    ReturnFeesEnumeration = URIRef("https://schema.org/ReturnFeesEnumeration")
    refundType = URIRef("https://schema.org/refundType")
    affectedBy = URIRef("https://schema.org/affectedBy")
    FullRefund = URIRef("https://schema.org/FullRefund")
    cvdNumC19OFMechVentPats = URIRef("https://schema.org/cvdNumC19OFMechVentPats")
    EvidenceLevelC = URIRef("https://schema.org/EvidenceLevelC")
    correction = URIRef("https://schema.org/correction")
    diagnosis = URIRef("https://schema.org/diagnosis")
    partySize = URIRef("https://schema.org/partySize")
    alumni = URIRef("https://schema.org/alumni")
    MayTreatHealthAspect = URIRef("https://schema.org/MayTreatHealthAspect")
    usesHealthPlanIdStandard = URIRef("https://schema.org/usesHealthPlanIdStandard")
    geoOverlaps = URIRef("https://schema.org/geoOverlaps")
    Nonprofit501c9 = URIRef("https://schema.org/Nonprofit501c9")
    monthlyMinimumRepaymentAmount = URIRef("https://schema.org/monthlyMinimumRepaymentAmount")
    schoolClosuresInfo = URIRef("https://schema.org/schoolClosuresInfo")
    accommodationFloorPlan = URIRef("https://schema.org/accommodationFloorPlan")
    administrationRoute = URIRef("https://schema.org/administrationRoute")
    includedDataCatalog = URIRef("https://schema.org/includedDataCatalog")
    nerveMotor = URIRef("https://schema.org/nerveMotor")
    name = URIRef("https://schema.org/name")
    valueName = URIRef("https://schema.org/valueName")
    ChildCare = URIRef("https://schema.org/ChildCare")
    includesObject = URIRef("https://schema.org/includesObject")
    stepValue = URIRef("https://schema.org/stepValue")
    Winery = URIRef("https://schema.org/Winery")
    costPerUnit = URIRef("https://schema.org/costPerUnit")
    legislationTransposes = URIRef("https://schema.org/legislationTransposes")
    issn = URIRef("https://schema.org/issn")
    instructor = URIRef("https://schema.org/instructor")
    durationOfWarranty = URIRef("https://schema.org/durationOfWarranty")
    physiologicalBenefits = URIRef("https://schema.org/physiologicalBenefits")
    coverageStartTime = URIRef("https://schema.org/coverageStartTime")
    ContagiousnessHealthAspect = URIRef("https://schema.org/ContagiousnessHealthAspect")
    FourWheelDriveConfiguration = URIRef("https://schema.org/FourWheelDriveConfiguration")
    deliveryMethod = URIRef("https://schema.org/deliveryMethod")
    learningResourceType = URIRef("https://schema.org/learningResourceType")
    applicationDeadline = URIRef("https://schema.org/applicationDeadline")
    arrivalGate = URIRef("https://schema.org/arrivalGate")
    FreeReturn = URIRef("https://schema.org/FreeReturn")
    target = URIRef("https://schema.org/target")
    speed = URIRef("https://schema.org/speed")
    cvdNumC19HOPats = URIRef("https://schema.org/cvdNumC19HOPats")
    FDAcategoryD = URIRef("https://schema.org/FDAcategoryD")
    landlord = URIRef("https://schema.org/landlord")
    height = URIRef("https://schema.org/height")
    Integer = URIRef("https://schema.org/Integer")
    checkinTime = URIRef("https://schema.org/checkinTime")
    duration = URIRef("https://schema.org/duration")
    domiciledMortgage = URIRef("https://schema.org/domiciledMortgage")
    usNPI = URIRef("https://schema.org/usNPI")
    mainEntity = URIRef("https://schema.org/mainEntity")
    ShippingDeliveryTime = URIRef("https://schema.org/ShippingDeliveryTime")
    aspect = URIRef("https://schema.org/aspect")
    mathExpression = URIRef("https://schema.org/mathExpression")
    publicationType = URIRef("https://schema.org/publicationType")
    secondaryPrevention = URIRef("https://schema.org/secondaryPrevention")
    numberOfPlayers = URIRef("https://schema.org/numberOfPlayers")
    question = URIRef("https://schema.org/question")
    measurementMethod = URIRef("https://schema.org/measurementMethod")
    numAdults = URIRef("https://schema.org/numAdults")
    CassetteFormat = URIRef("https://schema.org/CassetteFormat")
    ReservationPackage = URIRef("https://schema.org/ReservationPackage")
    inDefinedTermSet = URIRef("https://schema.org/inDefinedTermSet")
    PaymentAutomaticallyApplied = URIRef("https://schema.org/PaymentAutomaticallyApplied")
    volumeNumber = URIRef("https://schema.org/volumeNumber")
    cvdNumICUBeds = URIRef("https://schema.org/cvdNumICUBeds")
    Registry = URIRef("https://schema.org/Registry")
    caption = URIRef("https://schema.org/caption")
    DJMixAlbum = URIRef("https://schema.org/DJMixAlbum")
    temporal = URIRef("https://schema.org/temporal")
    validFrom = URIRef("https://schema.org/validFrom")
    muscleAction = URIRef("https://schema.org/muscleAction")
    postalCodePrefix = URIRef("https://schema.org/postalCodePrefix")
    ExhibitionEvent = URIRef("https://schema.org/ExhibitionEvent")
    jobStartDate = URIRef("https://schema.org/jobStartDate")
    ReturnAction = URIRef("https://schema.org/ReturnAction")
    SinglePlayer = URIRef("https://schema.org/SinglePlayer")
    Thesis = URIRef("https://schema.org/Thesis")
    Distance = URIRef("https://schema.org/Distance")
    MusicAlbumReleaseType = URIRef("https://schema.org/MusicAlbumReleaseType")
    fromLocation = URIRef("https://schema.org/fromLocation")
    buyer = URIRef("https://schema.org/buyer")
    departureBoatTerminal = URIRef("https://schema.org/departureBoatTerminal")
    RecommendedDoseSchedule = URIRef("https://schema.org/RecommendedDoseSchedule")
    PodcastEpisode = URIRef("https://schema.org/PodcastEpisode")
    BusTrip = URIRef("https://schema.org/BusTrip")
    MotorcycleDealer = URIRef("https://schema.org/MotorcycleDealer")
    medicalAudience = URIRef("https://schema.org/medicalAudience")
    episode = URIRef("https://schema.org/episode")
    advanceBookingRequirement = URIRef("https://schema.org/advanceBookingRequirement")
    ActionStatusType = URIRef("https://schema.org/ActionStatusType")
    OneTimePayments = URIRef("https://schema.org/OneTimePayments")
    UnRegisterAction = URIRef("https://schema.org/UnRegisterAction")
    interactionStatistic = URIRef("https://schema.org/interactionStatistic")
    GardenStore = URIRef("https://schema.org/GardenStore")
    provider = URIRef("https://schema.org/provider")
    ReturnLabelInBox = URIRef("https://schema.org/ReturnLabelInBox")
    LegalValueLevel = URIRef("https://schema.org/LegalValueLevel")
    ProfessionalService = URIRef("https://schema.org/ProfessionalService")
    OnlineBusiness = URIRef("https://schema.org/OnlineBusiness")
    FDAcategoryX = URIRef("https://schema.org/FDAcategoryX")
    naics = URIRef("https://schema.org/naics")
    Balance = URIRef("https://schema.org/Balance")
    activeIngredient = URIRef("https://schema.org/activeIngredient")
    SafetyHealthAspect = URIRef("https://schema.org/SafetyHealthAspect")
    Mountain = URIRef("https://schema.org/Mountain")
    openingHoursSpecification = URIRef("https://schema.org/openingHoursSpecification")
    Energy = URIRef("https://schema.org/Energy")
    numberOfBedrooms = URIRef("https://schema.org/numberOfBedrooms")
    Nonprofit501e = URIRef("https://schema.org/Nonprofit501e")
    jurisdiction = URIRef("https://schema.org/jurisdiction")
    memberOf = URIRef("https://schema.org/memberOf")
    engineType = URIRef("https://schema.org/engineType")
    abstract = URIRef("https://schema.org/abstract")
    encoding = URIRef("https://schema.org/encoding")
    customer = URIRef("https://schema.org/customer")
    seriousAdverseOutcome = URIRef("https://schema.org/seriousAdverseOutcome")
    Reservation = URIRef("https://schema.org/Reservation")
    parent = URIRef("https://schema.org/parent")
    musicBy = URIRef("https://schema.org/musicBy")
    endTime = URIRef("https://schema.org/endTime")
    costOrigin = URIRef("https://schema.org/costOrigin")
    associatedDisease = URIRef("https://schema.org/associatedDisease")
    agentInteractionStatistic = URIRef("https://schema.org/agentInteractionStatistic")
    roleName = URIRef("https://schema.org/roleName")
    HairSalon = URIRef("https://schema.org/HairSalon")
    securityClearanceRequirement = URIRef("https://schema.org/securityClearanceRequirement")
    SingleRelease = URIRef("https://schema.org/SingleRelease")
    arrivalGate = URIRef("https://schema.org/arrivalGate")
    MovieTheater = URIRef("https://schema.org/MovieTheater")
    TripleBlindedTrial = URIRef("https://schema.org/TripleBlindedTrial")
    contactlessPayment = URIRef("https://schema.org/contactlessPayment")
    knowsLanguage = URIRef("https://schema.org/knowsLanguage")
    sponsor = URIRef("https://schema.org/sponsor")
    PregnancyHealthAspect = URIRef("https://schema.org/PregnancyHealthAspect")
    VegetarianDiet = URIRef("https://schema.org/VegetarianDiet")
    partOfEpisode = URIRef("https://schema.org/partOfEpisode")
    PrintDigitalSource = URIRef("https://schema.org/PrintDigitalSource")
    TheaterGroup = URIRef("https://schema.org/TheaterGroup")
    bioChemInteraction = URIRef("https://schema.org/bioChemInteraction")
    geoWithin = URIRef("https://schema.org/geoWithin")
    restockingFee = URIRef("https://schema.org/restockingFee")
    BodyMeasurementHand = URIRef("https://schema.org/BodyMeasurementHand")
    asin = URIRef("https://schema.org/asin")
    Wednesday = URIRef("https://schema.org/Wednesday")
    restockingFee = URIRef("https://schema.org/restockingFee")
    sampleType = URIRef("https://schema.org/sampleType")
    disambiguatingDescription = URIRef("https://schema.org/disambiguatingDescription")
    ticketToken = URIRef("https://schema.org/ticketToken")
    doesNotShip = URIRef("https://schema.org/doesNotShip")
    icaoCode = URIRef("https://schema.org/icaoCode")
    colleague = URIRef("https://schema.org/colleague")
    educationalProgramMode = URIRef("https://schema.org/educationalProgramMode")
    restockingFee = URIRef("https://schema.org/restockingFee")
    branch = URIRef("https://schema.org/branch")
    howPerformed = URIRef("https://schema.org/howPerformed")
    BackgroundNewsArticle = URIRef("https://schema.org/BackgroundNewsArticle")
    ExhibitionEvent = URIRef("https://schema.org/ExhibitionEvent")
    PerformanceRole = URIRef("https://schema.org/PerformanceRole")
    SexualContentConsideration = URIRef("https://schema.org/SexualContentConsideration")
    healthPlanCostSharing = URIRef("https://schema.org/healthPlanCostSharing")
    audience = URIRef("https://schema.org/audience")
    NoteDigitalDocument = URIRef("https://schema.org/NoteDigitalDocument")
    percentile90 = URIRef("https://schema.org/percentile90")
    pregnancyWarning = URIRef("https://schema.org/pregnancyWarning")
    representativeOfPage = URIRef("https://schema.org/representativeOfPage")
    Bone = URIRef("https://schema.org/Bone")
    MathSolver = URIRef("https://schema.org/MathSolver")
    isLocatedInSubcellularLocation = URIRef("https://schema.org/isLocatedInSubcellularLocation")
    bodyType = URIRef("https://schema.org/bodyType")
    BedDetails = URIRef("https://schema.org/BedDetails")
    seatingType = URIRef("https://schema.org/seatingType")
    subTrip = URIRef("https://schema.org/subTrip")
    serviceType = URIRef("https://schema.org/serviceType")
    BodyMeasurementNeck = URIRef("https://schema.org/BodyMeasurementNeck")
    availability = URIRef("https://schema.org/availability")
    associatedPathophysiology = URIRef("https://schema.org/associatedPathophysiology")
    embeddedTextCaption = URIRef("https://schema.org/embeddedTextCaption")
    foundingDate = URIRef("https://schema.org/foundingDate")
    MotorizedBicycle = URIRef("https://schema.org/MotorizedBicycle")
    awards = URIRef("https://schema.org/awards")
    TVSeries = URIRef("https://schema.org/TVSeries")
    primaryPrevention = URIRef("https://schema.org/primaryPrevention")
    relatedCondition = URIRef("https://schema.org/relatedCondition")
    PodcastSeries = URIRef("https://schema.org/PodcastSeries")
    loanPaymentAmount = URIRef("https://schema.org/loanPaymentAmount")
    ratingValue = URIRef("https://schema.org/ratingValue")
    ReturnByMail = URIRef("https://schema.org/ReturnByMail")
    ParentAudience = URIRef("https://schema.org/ParentAudience")
    LearningResource = URIRef("https://schema.org/LearningResource")
    NonprofitSBBI = URIRef("https://schema.org/NonprofitSBBI")
    amenityFeature = URIRef("https://schema.org/amenityFeature")
    Statement = URIRef("https://schema.org/Statement")
    inChI = URIRef("https://schema.org/inChI")
    TobaccoNicotineConsideration = URIRef("https://schema.org/TobaccoNicotineConsideration")
    Organization = URIRef("https://schema.org/Organization")
    membershipPointsEarned = URIRef("https://schema.org/membershipPointsEarned")
    BedAndBreakfast = URIRef("https://schema.org/BedAndBreakfast")
    BloodTest = URIRef("https://schema.org/BloodTest")
    Protein = URIRef("https://schema.org/Protein")
    LocationFeatureSpecification = URIRef("https://schema.org/LocationFeatureSpecification")
    MedicalContraindication = URIRef("https://schema.org/MedicalContraindication")
    ccRecipient = URIRef("https://schema.org/ccRecipient")
    Episode = URIRef("https://schema.org/Episode")
    SearchAction = URIRef("https://schema.org/SearchAction")
    Occupation = URIRef("https://schema.org/Occupation")
    transFatContent = URIRef("https://schema.org/transFatContent")
    hasMenu = URIRef("https://schema.org/hasMenu")
    weightTotal = URIRef("https://schema.org/weightTotal")
    EUEnergyEfficiencyCategoryB = URIRef("https://schema.org/EUEnergyEfficiencyCategoryB")
    code = URIRef("https://schema.org/code")
    eventStatus = URIRef("https://schema.org/eventStatus")
    Obstetric = URIRef("https://schema.org/Obstetric")
    diagram = URIRef("https://schema.org/diagram")
    PotentialActionStatus = URIRef("https://schema.org/PotentialActionStatus")
    ParentalSupport = URIRef("https://schema.org/ParentalSupport")
    Atlas = URIRef("https://schema.org/Atlas")
    Eye = URIRef("https://schema.org/Eye")
    DeliveryTimeSettings = URIRef("https://schema.org/DeliveryTimeSettings")
    photos = URIRef("https://schema.org/photos")
    MedicalSignOrSymptom = URIRef("https://schema.org/MedicalSignOrSymptom")
    MultiPlayer = URIRef("https://schema.org/MultiPlayer")
    printPage = URIRef("https://schema.org/printPage")
    startTime = URIRef("https://schema.org/startTime")
    AdultEntertainment = URIRef("https://schema.org/AdultEntertainment")
    CovidTestingFacility = URIRef("https://schema.org/CovidTestingFacility")
    constraintProperty = URIRef("https://schema.org/constraintProperty")
    TouristDestination = URIRef("https://schema.org/TouristDestination")
    codingSystem = URIRef("https://schema.org/codingSystem")
    TouristTrip = URIRef("https://schema.org/TouristTrip")
    jobStartDate = URIRef("https://schema.org/jobStartDate")
    tourBookingPage = URIRef("https://schema.org/tourBookingPage")
    ActiveNotRecruiting = URIRef("https://schema.org/ActiveNotRecruiting")
    PropertyValueSpecification = URIRef("https://schema.org/PropertyValueSpecification")
    bccRecipient = URIRef("https://schema.org/bccRecipient")
    ticketNumber = URIRef("https://schema.org/ticketNumber")
    responsibilities = URIRef("https://schema.org/responsibilities")
    SkiResort = URIRef("https://schema.org/SkiResort")
    BodyMeasurementHand = URIRef("https://schema.org/BodyMeasurementHand")
    countryOfLastProcessing = URIRef("https://schema.org/countryOfLastProcessing")
    WearableSizeSystemCN = URIRef("https://schema.org/WearableSizeSystemCN")
    ProductGroup = URIRef("https://schema.org/ProductGroup")
    BefriendAction = URIRef("https://schema.org/BefriendAction")
    previousItem = URIRef("https://schema.org/previousItem")
    clinicalPharmacology = URIRef("https://schema.org/clinicalPharmacology")
    cvdNumC19HospPats = URIRef("https://schema.org/cvdNumC19HospPats")
    drug = URIRef("https://schema.org/drug")
    MedicalEnumeration = URIRef("https://schema.org/MedicalEnumeration")
    potentialUse = URIRef("https://schema.org/potentialUse")
    earlyPrepaymentPenalty = URIRef("https://schema.org/earlyPrepaymentPenalty")
    departureBoatTerminal = URIRef("https://schema.org/departureBoatTerminal")
    totalHistoricalEnrollment = URIRef("https://schema.org/totalHistoricalEnrollment")
    priceComponent = URIRef("https://schema.org/priceComponent")
    AlgorithmicallyEnhancedDigitalSource = URIRef("https://schema.org/AlgorithmicallyEnhancedDigitalSource")
    DVDFormat = URIRef("https://schema.org/DVDFormat")
    SportingGoodsStore = URIRef("https://schema.org/SportingGoodsStore")
    MerchantReturnFiniteReturnWindow = URIRef("https://schema.org/MerchantReturnFiniteReturnWindow")
    programmingModel = URIRef("https://schema.org/programmingModel")
    LegalService = URIRef("https://schema.org/LegalService")
    BodyMeasurementNeck = URIRef("https://schema.org/BodyMeasurementNeck")
    creditedTo = URIRef("https://schema.org/creditedTo")
    colleagues = URIRef("https://schema.org/colleagues")
    MoneyTransfer = URIRef("https://schema.org/MoneyTransfer")
    isProprietary = URIRef("https://schema.org/isProprietary")
    EventAttendanceModeEnumeration = URIRef("https://schema.org/EventAttendanceModeEnumeration")
    ImageGallery = URIRef("https://schema.org/ImageGallery")
    Joint = URIRef("https://schema.org/Joint")
    parentOrganization = URIRef("https://schema.org/parentOrganization")
    addressRegion = URIRef("https://schema.org/addressRegion")
    typicalCreditsPerTerm = URIRef("https://schema.org/typicalCreditsPerTerm")
    drugUnit = URIRef("https://schema.org/drugUnit")
    postalCodeEnd = URIRef("https://schema.org/postalCodeEnd")
    Nursing = URIRef("https://schema.org/Nursing")
    unitText = URIRef("https://schema.org/unitText")
    reviewCount = URIRef("https://schema.org/reviewCount")
    cvdFacilityCounty = URIRef("https://schema.org/cvdFacilityCounty")
    embedUrl = URIRef("https://schema.org/embedUrl")
    Virus = URIRef("https://schema.org/Virus")
    isPlanForApartment = URIRef("https://schema.org/isPlanForApartment")
    mediaAuthenticityCategory = URIRef("https://schema.org/mediaAuthenticityCategory")
    dateModified = URIRef("https://schema.org/dateModified")
    itemCondition = URIRef("https://schema.org/itemCondition")
    WearableSizeSystemEnumeration = URIRef("https://schema.org/WearableSizeSystemEnumeration")
    SolveMathAction = URIRef("https://schema.org/SolveMathAction")
    AutomotiveBusiness = URIRef("https://schema.org/AutomotiveBusiness")
    EventRescheduled = URIRef("https://schema.org/EventRescheduled")
    transcript = URIRef("https://schema.org/transcript")
    byMonthWeek = URIRef("https://schema.org/byMonthWeek")
    WearableMeasurementBack = URIRef("https://schema.org/WearableMeasurementBack")
    LodgingReservation = URIRef("https://schema.org/LodgingReservation")
    CommunityHealth = URIRef("https://schema.org/CommunityHealth")
    startTime = URIRef("https://schema.org/startTime")
    sdLicense = URIRef("https://schema.org/sdLicense")
    OfficialLegalValue = URIRef("https://schema.org/OfficialLegalValue")
    BikeStore = URIRef("https://schema.org/BikeStore")
    keywords = URIRef("https://schema.org/keywords")
    programmingLanguage = URIRef("https://schema.org/programmingLanguage")
    gameEdition = URIRef("https://schema.org/gameEdition")
    DefenceEstablishment = URIRef("https://schema.org/DefenceEstablishment")
    SingleFamilyResidence = URIRef("https://schema.org/SingleFamilyResidence")
    phoneticText = URIRef("https://schema.org/phoneticText")
    cvdNumBeds = URIRef("https://schema.org/cvdNumBeds")
    OrderItem = URIRef("https://schema.org/OrderItem")
    legislationIdentifier = URIRef("https://schema.org/legislationIdentifier")
    penciler = URIRef("https://schema.org/penciler")
    isbn = URIRef("https://schema.org/isbn")
    LymphaticVessel = URIRef("https://schema.org/LymphaticVessel")
    costPerUnit = URIRef("https://schema.org/costPerUnit")
    streetAddress = URIRef("https://schema.org/streetAddress")
    hasMeasurement = URIRef("https://schema.org/hasMeasurement")
    location = URIRef("https://schema.org/location")
    discount = URIRef("https://schema.org/discount")
    pattern = URIRef("https://schema.org/pattern")
    PodcastEpisode = URIRef("https://schema.org/PodcastEpisode")
    sport = URIRef("https://schema.org/sport")
    taxonRank = URIRef("https://schema.org/taxonRank")
    ingredients = URIRef("https://schema.org/ingredients")
    CookAction = URIRef("https://schema.org/CookAction")
    numberOfLoanPayments = URIRef("https://schema.org/numberOfLoanPayments")
    ReturnFeesCustomerResponsibility = URIRef("https://schema.org/ReturnFeesCustomerResponsibility")
    meetsEmissionStandard = URIRef("https://schema.org/meetsEmissionStandard")
    EndorseAction = URIRef("https://schema.org/EndorseAction")
    preparation = URIRef("https://schema.org/preparation")
    ownershipFundingInfo = URIRef("https://schema.org/ownershipFundingInfo")
    WearableSizeSystemGS1 = URIRef("https://schema.org/WearableSizeSystemGS1")
    dataFeedElement = URIRef("https://schema.org/dataFeedElement")
    healthCondition = URIRef("https://schema.org/healthCondition")
    ScholarlyArticle = URIRef("https://schema.org/ScholarlyArticle")
    dateModified = URIRef("https://schema.org/dateModified")
    sender = URIRef("https://schema.org/sender")
    OrderPickupAvailable = URIRef("https://schema.org/OrderPickupAvailable")
    termsOfService = URIRef("https://schema.org/termsOfService")
    DrivingSchoolVehicleUsage = URIRef("https://schema.org/DrivingSchoolVehicleUsage")
    layoutImage = URIRef("https://schema.org/layoutImage")
    ShoeStore = URIRef("https://schema.org/ShoeStore")
    FoodEvent = URIRef("https://schema.org/FoodEvent")
    CleaningFee = URIRef("https://schema.org/CleaningFee")
    Hotel = URIRef("https://schema.org/Hotel")
    permissionType = URIRef("https://schema.org/permissionType")
    GlutenFreeDiet = URIRef("https://schema.org/GlutenFreeDiet")
    TobaccoNicotineConsideration = URIRef("https://schema.org/TobaccoNicotineConsideration")
    applicationContact = URIRef("https://schema.org/applicationContact")
    OfferShippingDetails = URIRef("https://schema.org/OfferShippingDetails")
    OriginalShippingFees = URIRef("https://schema.org/OriginalShippingFees")
    DislikeAction = URIRef("https://schema.org/DislikeAction")
    employerOverview = URIRef("https://schema.org/employerOverview")
    ItemListUnordered = URIRef("https://schema.org/ItemListUnordered")
    PriceTypeEnumeration = URIRef("https://schema.org/PriceTypeEnumeration")
    sourcedFrom = URIRef("https://schema.org/sourcedFrom")
    byArtist = URIRef("https://schema.org/byArtist")
    catalogNumber = URIRef("https://schema.org/catalogNumber")
    encoding = URIRef("https://schema.org/encoding")
    InfectiousAgentClass = URIRef("https://schema.org/InfectiousAgentClass")
    includesObject = URIRef("https://schema.org/includesObject")
    Endocrine = URIRef("https://schema.org/Endocrine")
    loanRepaymentForm = URIRef("https://schema.org/loanRepaymentForm")
    album = URIRef("https://schema.org/album")
    exampleOfWork = URIRef("https://schema.org/exampleOfWork")
    quarantineGuidelines = URIRef("https://schema.org/quarantineGuidelines")
    contactlessPayment = URIRef("https://schema.org/contactlessPayment")
    CategoryCode = URIRef("https://schema.org/CategoryCode")
    legalName = URIRef("https://schema.org/legalName")
    supersededBy = URIRef("https://schema.org/supersededBy")
    colorist = URIRef("https://schema.org/colorist")
    codeValue = URIRef("https://schema.org/codeValue")
    medicalAudience = URIRef("https://schema.org/medicalAudience")
    WebSite = URIRef("https://schema.org/WebSite")
    cheatCode = URIRef("https://schema.org/cheatCode")
    Project = URIRef("https://schema.org/Project")
    EUEnergyEfficiencyCategoryC = URIRef("https://schema.org/EUEnergyEfficiencyCategoryC")
    FDAcategoryC = URIRef("https://schema.org/FDAcategoryC")
    healthPlanNetworkId = URIRef("https://schema.org/healthPlanNetworkId")
    Nonprofit501c21 = URIRef("https://schema.org/Nonprofit501c21")
    CertificationActive = URIRef("https://schema.org/CertificationActive")
    energyEfficiencyScaleMax = URIRef("https://schema.org/energyEfficiencyScaleMax")
    Certification = URIRef("https://schema.org/Certification")
    mainEntityOfPage = URIRef("https://schema.org/mainEntityOfPage")
    nonEqual = URIRef("https://schema.org/nonEqual")
    Fungus = URIRef("https://schema.org/Fungus")
    HealthTopicContent = URIRef("https://schema.org/HealthTopicContent")
    ItemListOrderDescending = URIRef("https://schema.org/ItemListOrderDescending")
    Code = URIRef("https://schema.org/Code")
    targetProduct = URIRef("https://schema.org/targetProduct")
    median = URIRef("https://schema.org/median")
    recipient = URIRef("https://schema.org/recipient")
    procedure = URIRef("https://schema.org/procedure")
    free = URIRef("https://schema.org/free")
    numberOfDoors = URIRef("https://schema.org/numberOfDoors")
    cashBack = URIRef("https://schema.org/cashBack")
    MerchantReturnUnlimitedWindow = URIRef("https://schema.org/MerchantReturnUnlimitedWindow")
    CDCPMDRecord = URIRef("https://schema.org/CDCPMDRecord")
    MedicalTrialDesign = URIRef("https://schema.org/MedicalTrialDesign")
    founders = URIRef("https://schema.org/founders")
    includesAttraction = URIRef("https://schema.org/includesAttraction")
    rangeIncludes = URIRef("https://schema.org/rangeIncludes")
    parentItem = URIRef("https://schema.org/parentItem")
    LowCalorieDiet = URIRef("https://schema.org/LowCalorieDiet")
    actionableFeedbackPolicy = URIRef("https://schema.org/actionableFeedbackPolicy")
    MedicalGuidelineContraindication = URIRef("https://schema.org/MedicalGuidelineContraindication")
    contributor = URIRef("https://schema.org/contributor")
    isInvolvedInBiologicalProcess = URIRef("https://schema.org/isInvolvedInBiologicalProcess")
    TaxiVehicleUsage = URIRef("https://schema.org/TaxiVehicleUsage")
    artform = URIRef("https://schema.org/artform")
    serviceOutput = URIRef("https://schema.org/serviceOutput")
    AdvertiserContentArticle = URIRef("https://schema.org/AdvertiserContentArticle")
    VideoGameSeries = URIRef("https://schema.org/VideoGameSeries")
    itemOffered = URIRef("https://schema.org/itemOffered")
    MedicalGuidelineRecommendation = URIRef("https://schema.org/MedicalGuidelineRecommendation")
    Bridge = URIRef("https://schema.org/Bridge")
    PercutaneousProcedure = URIRef("https://schema.org/PercutaneousProcedure")
    pageStart = URIRef("https://schema.org/pageStart")
    amount = URIRef("https://schema.org/amount")
    requirements = URIRef("https://schema.org/requirements")
    WPAdBlock = URIRef("https://schema.org/WPAdBlock")
    salaryUponCompletion = URIRef("https://schema.org/salaryUponCompletion")
    lastReviewed = URIRef("https://schema.org/lastReviewed")
    maps = URIRef("https://schema.org/maps")
    bookFormat = URIRef("https://schema.org/bookFormat")
    totalJobOpenings = URIRef("https://schema.org/totalJobOpenings")
    activityFrequency = URIRef("https://schema.org/activityFrequency")
    contactType = URIRef("https://schema.org/contactType")
    Gastroenterologic = URIRef("https://schema.org/Gastroenterologic")
    doseUnit = URIRef("https://schema.org/doseUnit")
    relatedTherapy = URIRef("https://schema.org/relatedTherapy")
    Dentist = URIRef("https://schema.org/Dentist")
    userInteractionCount = URIRef("https://schema.org/userInteractionCount")
    datasetTimeInterval = URIRef("https://schema.org/datasetTimeInterval")
    experienceRequirements = URIRef("https://schema.org/experienceRequirements")
    RadiationTherapy = URIRef("https://schema.org/RadiationTherapy")
    DefinitiveLegalValue = URIRef("https://schema.org/DefinitiveLegalValue")
    item = URIRef("https://schema.org/item")
    geoCovers = URIRef("https://schema.org/geoCovers")
    containsSeason = URIRef("https://schema.org/containsSeason")
    numberedPosition = URIRef("https://schema.org/numberedPosition")
    MedicalTrialDesign = URIRef("https://schema.org/MedicalTrialDesign")
    knownVehicleDamages = URIRef("https://schema.org/knownVehicleDamages")
    prepTime = URIRef("https://schema.org/prepTime")
    backstory = URIRef("https://schema.org/backstory")
    estimatedCost = URIRef("https://schema.org/estimatedCost")
    applicableLocation = URIRef("https://schema.org/applicableLocation")
    worstRating = URIRef("https://schema.org/worstRating")
    GovernmentOrganization = URIRef("https://schema.org/GovernmentOrganization")
    numberOfItems = URIRef("https://schema.org/numberOfItems")
    breadcrumb = URIRef("https://schema.org/breadcrumb")
    molecularFormula = URIRef("https://schema.org/molecularFormula")
    prescriptionStatus = URIRef("https://schema.org/prescriptionStatus")
    legislationConsolidates = URIRef("https://schema.org/legislationConsolidates")
    IndividualProduct = URIRef("https://schema.org/IndividualProduct")
    lesserOrEqual = URIRef("https://schema.org/lesserOrEqual")
    Nonprofit501a = URIRef("https://schema.org/Nonprofit501a")
    inverseOf = URIRef("https://schema.org/inverseOf")
    gtin12 = URIRef("https://schema.org/gtin12")
    ComicSeries = URIRef("https://schema.org/ComicSeries")
    IngredientsHealthAspect = URIRef("https://schema.org/IngredientsHealthAspect")
    NewsArticle = URIRef("https://schema.org/NewsArticle")
    gettingTestedInfo = URIRef("https://schema.org/gettingTestedInfo")
    BodyMeasurementHips = URIRef("https://schema.org/BodyMeasurementHips")
    EUEnergyEfficiencyCategoryA2Plus = URIRef("https://schema.org/EUEnergyEfficiencyCategoryA2Plus")
    ImagingTest = URIRef("https://schema.org/ImagingTest")
    CurrencyConversionService = URIRef("https://schema.org/CurrencyConversionService")
    claimInterpreter = URIRef("https://schema.org/claimInterpreter")
    BioChemEntity = URIRef("https://schema.org/BioChemEntity")
    Nose = URIRef("https://schema.org/Nose")
    tracks = URIRef("https://schema.org/tracks")
    BodyMeasurementChest = URIRef("https://schema.org/BodyMeasurementChest")
    MulticellularParasite = URIRef("https://schema.org/MulticellularParasite")
    BusinessSupport = URIRef("https://schema.org/BusinessSupport")
    game = URIRef("https://schema.org/game")
    supportingData = URIRef("https://schema.org/supportingData")
    WearableSizeGroupWomens = URIRef("https://schema.org/WearableSizeGroupWomens")
    busName = URIRef("https://schema.org/busName")
    SeeDoctorHealthAspect = URIRef("https://schema.org/SeeDoctorHealthAspect")
    WearableSizeGroupMens = URIRef("https://schema.org/WearableSizeGroupMens")
    ProfilePage = URIRef("https://schema.org/ProfilePage")
    Property = URIRef("https://schema.org/Property")
    eligibleCustomerType = URIRef("https://schema.org/eligibleCustomerType")
    MonetaryAmount = URIRef("https://schema.org/MonetaryAmount")
    remainingAttendeeCapacity = URIRef("https://schema.org/remainingAttendeeCapacity")
    positiveNotes = URIRef("https://schema.org/positiveNotes")
    cheatCode = URIRef("https://schema.org/cheatCode")
    DisagreeAction = URIRef("https://schema.org/DisagreeAction")
    Hospital = URIRef("https://schema.org/Hospital")
    includesObject = URIRef("https://schema.org/includesObject")
    EffectivenessHealthAspect = URIRef("https://schema.org/EffectivenessHealthAspect")
    ArchiveComponent = URIRef("https://schema.org/ArchiveComponent")
    DVDFormat = URIRef("https://schema.org/DVDFormat")
    numberOfPartialBathrooms = URIRef("https://schema.org/numberOfPartialBathrooms")
    maximumEnrollment = URIRef("https://schema.org/maximumEnrollment")
    citation = URIRef("https://schema.org/citation")
    OrderAction = URIRef("https://schema.org/OrderAction")
    recourseLoan = URIRef("https://schema.org/recourseLoan")
    WearableSizeSystemJP = URIRef("https://schema.org/WearableSizeSystemJP")
    CompoundPriceSpecification = URIRef("https://schema.org/CompoundPriceSpecification")
    rangeIncludes = URIRef("https://schema.org/rangeIncludes")
    funding = URIRef("https://schema.org/funding")
    arrivalPlatform = URIRef("https://schema.org/arrivalPlatform")
    resultComment = URIRef("https://schema.org/resultComment")
    reviewedBy = URIRef("https://schema.org/reviewedBy")
    MerchantReturnPolicy = URIRef("https://schema.org/MerchantReturnPolicy")
    AdministrativeArea = URIRef("https://schema.org/AdministrativeArea")
    superEvent = URIRef("https://schema.org/superEvent")
    eligibleRegion = URIRef("https://schema.org/eligibleRegion")
    latitude = URIRef("https://schema.org/latitude")
    availabilityStarts = URIRef("https://schema.org/availabilityStarts")
    LodgingBusiness = URIRef("https://schema.org/LodgingBusiness")
    WearableSizeSystemIT = URIRef("https://schema.org/WearableSizeSystemIT")
    width = URIRef("https://schema.org/width")
    PET = URIRef("https://schema.org/PET")
    ReservationPending = URIRef("https://schema.org/ReservationPending")
    doseSchedule = URIRef("https://schema.org/doseSchedule")
    temporalCoverage = URIRef("https://schema.org/temporalCoverage")
    IndividualProduct = URIRef("https://schema.org/IndividualProduct")
    publicTransportClosuresInfo = URIRef("https://schema.org/publicTransportClosuresInfo")
    contentLocation = URIRef("https://schema.org/contentLocation")
    Patient = URIRef("https://schema.org/Patient")
    Gene = URIRef("https://schema.org/Gene")
    SolveMathAction = URIRef("https://schema.org/SolveMathAction")
    numChildren = URIRef("https://schema.org/numChildren")
    measurementMethod = URIRef("https://schema.org/measurementMethod")
    Locksmith = URIRef("https://schema.org/Locksmith")
    geographicArea = URIRef("https://schema.org/geographicArea")
    supportingData = URIRef("https://schema.org/supportingData")
    targetName = URIRef("https://schema.org/targetName")
    ContagiousnessHealthAspect = URIRef("https://schema.org/ContagiousnessHealthAspect")
    MiddleSchool = URIRef("https://schema.org/MiddleSchool")
    valueMinLength = URIRef("https://schema.org/valueMinLength")
    doseValue = URIRef("https://schema.org/doseValue")
    byDay = URIRef("https://schema.org/byDay")
    educationalLevel = URIRef("https://schema.org/educationalLevel")
    educationalUse = URIRef("https://schema.org/educationalUse")
    brand = URIRef("https://schema.org/brand")
    programmingModel = URIRef("https://schema.org/programmingModel")
    unnamedSourcesPolicy = URIRef("https://schema.org/unnamedSourcesPolicy")
    materialExtent = URIRef("https://schema.org/materialExtent")
    BodyMeasurementInsideLeg = URIRef("https://schema.org/BodyMeasurementInsideLeg")
    translationOfWork = URIRef("https://schema.org/translationOfWork")
    ReturnAtKiosk = URIRef("https://schema.org/ReturnAtKiosk")
    athlete = URIRef("https://schema.org/athlete")
    PlayAction = URIRef("https://schema.org/PlayAction")
    DefinitiveLegalValue = URIRef("https://schema.org/DefinitiveLegalValue")
    eligibilityToWorkRequirement = URIRef("https://schema.org/eligibilityToWorkRequirement")
    PhysicalActivity = URIRef("https://schema.org/PhysicalActivity")
    Flight = URIRef("https://schema.org/Flight")
    PrintDigitalSource = URIRef("https://schema.org/PrintDigitalSource")
    actor = URIRef("https://schema.org/actor")
    headline = URIRef("https://schema.org/headline")
    taxID = URIRef("https://schema.org/taxID")
    usesDevice = URIRef("https://schema.org/usesDevice")
    advanceBookingRequirement = URIRef("https://schema.org/advanceBookingRequirement")
    downPayment = URIRef("https://schema.org/downPayment")
    event = URIRef("https://schema.org/event")
    WesternConventional = URIRef("https://schema.org/WesternConventional")
    seasonNumber = URIRef("https://schema.org/seasonNumber")
    members = URIRef("https://schema.org/members")
    mainEntityOfPage = URIRef("https://schema.org/mainEntityOfPage")
    hasCategoryCode = URIRef("https://schema.org/hasCategoryCode")
    broadcaster = URIRef("https://schema.org/broadcaster")
    agent = URIRef("https://schema.org/agent")
    resultComment = URIRef("https://schema.org/resultComment")
    MusicStore = URIRef("https://schema.org/MusicStore")
    LoseAction = URIRef("https://schema.org/LoseAction")
    DefinedRegion = URIRef("https://schema.org/DefinedRegion")
    AutoBodyShop = URIRef("https://schema.org/AutoBodyShop")
    Resort = URIRef("https://schema.org/Resort")
    areaServed = URIRef("https://schema.org/areaServed")
    incentives = URIRef("https://schema.org/incentives")
    Thesis = URIRef("https://schema.org/Thesis")
    EUEnergyEfficiencyCategoryE = URIRef("https://schema.org/EUEnergyEfficiencyCategoryE")
    MonetaryGrant = URIRef("https://schema.org/MonetaryGrant")
    EffectivenessHealthAspect = URIRef("https://schema.org/EffectivenessHealthAspect")
    MediaObject = URIRef("https://schema.org/MediaObject")
    healthPlanCoinsuranceOption = URIRef("https://schema.org/healthPlanCoinsuranceOption")
    MedicalEnumeration = URIRef("https://schema.org/MedicalEnumeration")
    gtin12 = URIRef("https://schema.org/gtin12")
    maintainer = URIRef("https://schema.org/maintainer")
    floorSize = URIRef("https://schema.org/floorSize")
    spatialCoverage = URIRef("https://schema.org/spatialCoverage")
    OccupationalExperienceRequirements = URIRef("https://schema.org/OccupationalExperienceRequirements")
    free = URIRef("https://schema.org/free")
    AnalysisNewsArticle = URIRef("https://schema.org/AnalysisNewsArticle")
    acceptedPaymentMethod = URIRef("https://schema.org/acceptedPaymentMethod")
    gtin = URIRef("https://schema.org/gtin")
    geoTouches = URIRef("https://schema.org/geoTouches")
    BusinessFunction = URIRef("https://schema.org/BusinessFunction")
    bioChemInteraction = URIRef("https://schema.org/bioChemInteraction")
    requiresSubscription = URIRef("https://schema.org/requiresSubscription")
    Appearance = URIRef("https://schema.org/Appearance")
    recognizingAuthority = URIRef("https://schema.org/recognizingAuthority")
    transitTimeLabel = URIRef("https://schema.org/transitTimeLabel")
    logo = URIRef("https://schema.org/logo")
    FullGameAvailability = URIRef("https://schema.org/FullGameAvailability")
    geoRadius = URIRef("https://schema.org/geoRadius")
    SizeSpecification = URIRef("https://schema.org/SizeSpecification")
    broadcastFrequencyValue = URIRef("https://schema.org/broadcastFrequencyValue")
    LeftHandDriving = URIRef("https://schema.org/LeftHandDriving")
    accountOverdraftLimit = URIRef("https://schema.org/accountOverdraftLimit")
    Guide = URIRef("https://schema.org/Guide")
    MensClothingStore = URIRef("https://schema.org/MensClothingStore")
    PublicHolidays = URIRef("https://schema.org/PublicHolidays")
    issueNumber = URIRef("https://schema.org/issueNumber")
    gameServer = URIRef("https://schema.org/gameServer")
    relatedAnatomy = URIRef("https://schema.org/relatedAnatomy")
    object = URIRef("https://schema.org/object")
    JobPosting = URIRef("https://schema.org/JobPosting")
    priceType = URIRef("https://schema.org/priceType")
    sportsEvent = URIRef("https://schema.org/sportsEvent")
    legislationType = URIRef("https://schema.org/legislationType")
    OwnershipInfo = URIRef("https://schema.org/OwnershipInfo")
    shippingLabel = URIRef("https://schema.org/shippingLabel")
    broker = URIRef("https://schema.org/broker")
    greater = URIRef("https://schema.org/greater")
    NewsArticle = URIRef("https://schema.org/NewsArticle")
    encoding = URIRef("https://schema.org/encoding")
    SingleBlindedTrial = URIRef("https://schema.org/SingleBlindedTrial")
    ExercisePlan = URIRef("https://schema.org/ExercisePlan")
    WearableMeasurementWaist = URIRef("https://schema.org/WearableMeasurementWaist")
    TelevisionStation = URIRef("https://schema.org/TelevisionStation")
    archiveHeld = URIRef("https://schema.org/archiveHeld")
    Nonprofit501f = URIRef("https://schema.org/Nonprofit501f")
    BodyMeasurementUnderbust = URIRef("https://schema.org/BodyMeasurementUnderbust")
    Permit = URIRef("https://schema.org/Permit")
    legislationDateVersion = URIRef("https://schema.org/legislationDateVersion")
    ExchangeRefund = URIRef("https://schema.org/ExchangeRefund")
    defaultValue = URIRef("https://schema.org/defaultValue")
    participant = URIRef("https://schema.org/participant")
    permissions = URIRef("https://schema.org/permissions")
    chemicalRole = URIRef("https://schema.org/chemicalRole")
    codeValue = URIRef("https://schema.org/codeValue")
    LegislationObject = URIRef("https://schema.org/LegislationObject")
    numberOfBeds = URIRef("https://schema.org/numberOfBeds")
    runtime = URIRef("https://schema.org/runtime")
    AllocateAction = URIRef("https://schema.org/AllocateAction")
    TreatmentsHealthAspect = URIRef("https://schema.org/TreatmentsHealthAspect")
    TrainReservation = URIRef("https://schema.org/TrainReservation")
    measurementMethod = URIRef("https://schema.org/measurementMethod")
    monoisotopicMolecularWeight = URIRef("https://schema.org/monoisotopicMolecularWeight")
    ResearchProject = URIRef("https://schema.org/ResearchProject")
    Code = URIRef("https://schema.org/Code")
    Photograph = URIRef("https://schema.org/Photograph")
    freeShippingThreshold = URIRef("https://schema.org/freeShippingThreshold")
    costPerUnit = URIRef("https://schema.org/costPerUnit")
    DeliveryMethod = URIRef("https://schema.org/DeliveryMethod")
    AndroidPlatform = URIRef("https://schema.org/AndroidPlatform")
    editEIDR = URIRef("https://schema.org/editEIDR")
    maxValue = URIRef("https://schema.org/maxValue")
    HealthPlanNetwork = URIRef("https://schema.org/HealthPlanNetwork")
    WholesaleStore = URIRef("https://schema.org/WholesaleStore")
    Nonprofit501c10 = URIRef("https://schema.org/Nonprofit501c10")
    Genitourinary = URIRef("https://schema.org/Genitourinary")
    AutoPartsStore = URIRef("https://schema.org/AutoPartsStore")
    event = URIRef("https://schema.org/event")
    cvdNumTotBeds = URIRef("https://schema.org/cvdNumTotBeds")
    AudioObject = URIRef("https://schema.org/AudioObject")
    trailerWeight = URIRef("https://schema.org/trailerWeight")
    numberOfAccommodationUnits = URIRef("https://schema.org/numberOfAccommodationUnits")
    competencyRequired = URIRef("https://schema.org/competencyRequired")
    deathDate = URIRef("https://schema.org/deathDate")
    startOffset = URIRef("https://schema.org/startOffset")
    numberOfPartialBathrooms = URIRef("https://schema.org/numberOfPartialBathrooms")
    Nonprofit501c3 = URIRef("https://schema.org/Nonprofit501c3")
    readonlyValue = URIRef("https://schema.org/readonlyValue")
    globalLocationNumber = URIRef("https://schema.org/globalLocationNumber")
    regionDrained = URIRef("https://schema.org/regionDrained")
    benefits = URIRef("https://schema.org/benefits")
    Grant = URIRef("https://schema.org/Grant")
    DiagnosticLab = URIRef("https://schema.org/DiagnosticLab")
    mobileUrl = URIRef("https://schema.org/mobileUrl")
    CompositeWithTrainedAlgorithmicMediaDigitalSource = URIRef("https://schema.org/CompositeWithTrainedAlgorithmicMediaDigitalSource")
    numConstraints = URIRef("https://schema.org/numConstraints")
    WearableSizeSystemContinental = URIRef("https://schema.org/WearableSizeSystemContinental")
    minValue = URIRef("https://schema.org/minValue")
    releasedEvent = URIRef("https://schema.org/releasedEvent")
    Radiography = URIRef("https://schema.org/Radiography")
    GovernmentBenefitsType = URIRef("https://schema.org/GovernmentBenefitsType")
    VacationRental = URIRef("https://schema.org/VacationRental")
    restPeriods = URIRef("https://schema.org/restPeriods")
    numberOfFullBathrooms = URIRef("https://schema.org/numberOfFullBathrooms")
    MinorHumanEditsDigitalSource = URIRef("https://schema.org/MinorHumanEditsDigitalSource")
    trailerWeight = URIRef("https://schema.org/trailerWeight")
    shippingRate = URIRef("https://schema.org/shippingRate")
    PregnancyHealthAspect = URIRef("https://schema.org/PregnancyHealthAspect")
    CardiovascularExam = URIRef("https://schema.org/CardiovascularExam")
    SingleBlindedTrial = URIRef("https://schema.org/SingleBlindedTrial")
    courseWorkload = URIRef("https://schema.org/courseWorkload")
    broadcastDisplayName = URIRef("https://schema.org/broadcastDisplayName")
    dateVehicleFirstRegistered = URIRef("https://schema.org/dateVehicleFirstRegistered")
    cvdNumC19OverflowPats = URIRef("https://schema.org/cvdNumC19OverflowPats")
    GroceryStore = URIRef("https://schema.org/GroceryStore")
    beforeMedia = URIRef("https://schema.org/beforeMedia")
    option = URIRef("https://schema.org/option")
    Nonprofit501c21 = URIRef("https://schema.org/Nonprofit501c21")
    flightDistance = URIRef("https://schema.org/flightDistance")
    usageInfo = URIRef("https://schema.org/usageInfo")
    FDAcategoryD = URIRef("https://schema.org/FDAcategoryD")
    WearableSizeGroupPetite = URIRef("https://schema.org/WearableSizeGroupPetite")
    jobLocation = URIRef("https://schema.org/jobLocation")
    hasEnergyEfficiencyCategory = URIRef("https://schema.org/hasEnergyEfficiencyCategory")
    guidelineSubject = URIRef("https://schema.org/guidelineSubject")
    MediaEnumeration = URIRef("https://schema.org/MediaEnumeration")
    serviceUrl = URIRef("https://schema.org/serviceUrl")
    starRating = URIRef("https://schema.org/starRating")
    athlete = URIRef("https://schema.org/athlete")
    DrugLegalStatus = URIRef("https://schema.org/DrugLegalStatus")
    BoatTerminal = URIRef("https://schema.org/BoatTerminal")
    CourseInstance = URIRef("https://schema.org/CourseInstance")
    passengerSequenceNumber = URIRef("https://schema.org/passengerSequenceNumber")
    includesHealthPlanNetwork = URIRef("https://schema.org/includesHealthPlanNetwork")
    rxcui = URIRef("https://schema.org/rxcui")
    MedicalTest = URIRef("https://schema.org/MedicalTest")
    observationDate = URIRef("https://schema.org/observationDate")
    ReportageNewsArticle = URIRef("https://schema.org/ReportageNewsArticle")
    itemListElement = URIRef("https://schema.org/itemListElement")
    remainingAttendeeCapacity = URIRef("https://schema.org/remainingAttendeeCapacity")
    stageAsNumber = URIRef("https://schema.org/stageAsNumber")
    PoliceStation = URIRef("https://schema.org/PoliceStation")
    tool = URIRef("https://schema.org/tool")
    PayAction = URIRef("https://schema.org/PayAction")
    colorSwatch = URIRef("https://schema.org/colorSwatch")
    primaryImageOfPage = URIRef("https://schema.org/primaryImageOfPage")
    produces = URIRef("https://schema.org/produces")
    grantee = URIRef("https://schema.org/grantee")
    ReducedRelevanceForChildrenConsideration = URIRef("https://schema.org/ReducedRelevanceForChildrenConsideration")
    webCheckinTime = URIRef("https://schema.org/webCheckinTime")
    associatedClaimReview = URIRef("https://schema.org/associatedClaimReview")
    polygon = URIRef("https://schema.org/polygon")
    ProfessionalService = URIRef("https://schema.org/ProfessionalService")
    NoninvasiveProcedure = URIRef("https://schema.org/NoninvasiveProcedure")
    articleSection = URIRef("https://schema.org/articleSection")
    subTest = URIRef("https://schema.org/subTest")
    Volcano = URIRef("https://schema.org/Volcano")
    videoFrameSize = URIRef("https://schema.org/videoFrameSize")
    containsSeason = URIRef("https://schema.org/containsSeason")
    AboutPage = URIRef("https://schema.org/AboutPage")
    aspect = URIRef("https://schema.org/aspect")
    orderNumber = URIRef("https://schema.org/orderNumber")
    SuspendAction = URIRef("https://schema.org/SuspendAction")
    diseasePreventionInfo = URIRef("https://schema.org/diseasePreventionInfo")
    hasDigitalDocumentPermission = URIRef("https://schema.org/hasDigitalDocumentPermission")
    ItemListOrderType = URIRef("https://schema.org/ItemListOrderType")
    CharitableIncorporatedOrganization = URIRef("https://schema.org/CharitableIncorporatedOrganization")
    requiresSubscription = URIRef("https://schema.org/requiresSubscription")
    TennisComplex = URIRef("https://schema.org/TennisComplex")
    Map = URIRef("https://schema.org/Map")
    RejectAction = URIRef("https://schema.org/RejectAction")
    dateRead = URIRef("https://schema.org/dateRead")
    penciler = URIRef("https://schema.org/penciler")
    UserPlays = URIRef("https://schema.org/UserPlays")
    originalMediaContextDescription = URIRef("https://schema.org/originalMediaContextDescription")
    loanTerm = URIRef("https://schema.org/loanTerm")
    isVariantOf = URIRef("https://schema.org/isVariantOf")
    issn = URIRef("https://schema.org/issn")
    returnPolicySeasonalOverride = URIRef("https://schema.org/returnPolicySeasonalOverride")
    annualPercentageRate = URIRef("https://schema.org/annualPercentageRate")
    Organization = URIRef("https://schema.org/Organization")
    cookingMethod = URIRef("https://schema.org/cookingMethod")
    Certification = URIRef("https://schema.org/Certification")
    Osteopathic = URIRef("https://schema.org/Osteopathic")
    healthPlanCopayOption = URIRef("https://schema.org/healthPlanCopayOption")
    suitableForDiet = URIRef("https://schema.org/suitableForDiet")
    MerchantReturnPolicySeasonalOverride = URIRef("https://schema.org/MerchantReturnPolicySeasonalOverride")
    checkoutTime = URIRef("https://schema.org/checkoutTime")
    hasOfferCatalog = URIRef("https://schema.org/hasOfferCatalog")
    penciler = URIRef("https://schema.org/penciler")
    price = URIRef("https://schema.org/price")
    proficiencyLevel = URIRef("https://schema.org/proficiencyLevel")
    Nonprofit501c21 = URIRef("https://schema.org/Nonprofit501c21")
    temporalCoverage = URIRef("https://schema.org/temporalCoverage")
    valueMinLength = URIRef("https://schema.org/valueMinLength")
    dateModified = URIRef("https://schema.org/dateModified")
    ReserveAction = URIRef("https://schema.org/ReserveAction")
    DigitalDocumentPermission = URIRef("https://schema.org/DigitalDocumentPermission")
    UnemploymentSupport = URIRef("https://schema.org/UnemploymentSupport")
    recommendedIntake = URIRef("https://schema.org/recommendedIntake")
    MediaReviewItem = URIRef("https://schema.org/MediaReviewItem")
    SubwayStation = URIRef("https://schema.org/SubwayStation")
    educationalCredentialAwarded = URIRef("https://schema.org/educationalCredentialAwarded")
    legislationTransposes = URIRef("https://schema.org/legislationTransposes")
    hasPOS = URIRef("https://schema.org/hasPOS")
    subjectOf = URIRef("https://schema.org/subjectOf")
    Duration = URIRef("https://schema.org/Duration")
    sdPublisher = URIRef("https://schema.org/sdPublisher")
    ownershipFundingInfo = URIRef("https://schema.org/ownershipFundingInfo")
    specialOpeningHoursSpecification = URIRef("https://schema.org/specialOpeningHoursSpecification")
    OwnershipInfo = URIRef("https://schema.org/OwnershipInfo")
    successorOf = URIRef("https://schema.org/successorOf")
    checkinTime = URIRef("https://schema.org/checkinTime")
    identifyingExam = URIRef("https://schema.org/identifyingExam")
    Menu = URIRef("https://schema.org/Menu")
    Prion = URIRef("https://schema.org/Prion")
    PlaceboControlledTrial = URIRef("https://schema.org/PlaceboControlledTrial")
    itemDefectReturnFees = URIRef("https://schema.org/itemDefectReturnFees")
    cvdNumC19MechVentPats = URIRef("https://schema.org/cvdNumC19MechVentPats")
    cvdNumICUBedsOcc = URIRef("https://schema.org/cvdNumICUBedsOcc")
    OnlineEventAttendanceMode = URIRef("https://schema.org/OnlineEventAttendanceMode")
    DrivingSchoolVehicleUsage = URIRef("https://schema.org/DrivingSchoolVehicleUsage")
    RealEstateListing = URIRef("https://schema.org/RealEstateListing")
    SatiricalArticle = URIRef("https://schema.org/SatiricalArticle")
    holdingArchive = URIRef("https://schema.org/holdingArchive")
    drug = URIRef("https://schema.org/drug")
    ListItem = URIRef("https://schema.org/ListItem")
    Vein = URIRef("https://schema.org/Vein")
    GiveAction = URIRef("https://schema.org/GiveAction")
    financialAidEligible = URIRef("https://schema.org/financialAidEligible")
    WearableSizeSystemUK = URIRef("https://schema.org/WearableSizeSystemUK")
    CableOrSatelliteService = URIRef("https://schema.org/CableOrSatelliteService")
    RadioStation = URIRef("https://schema.org/RadioStation")
    NewsMediaOrganization = URIRef("https://schema.org/NewsMediaOrganization")
    holdingArchive = URIRef("https://schema.org/holdingArchive")
    Suite = URIRef("https://schema.org/Suite")
    FAQPage = URIRef("https://schema.org/FAQPage")
    openingHoursSpecification = URIRef("https://schema.org/openingHoursSpecification")
    BodyMeasurementChest = URIRef("https://schema.org/BodyMeasurementChest")
    serviceArea = URIRef("https://schema.org/serviceArea")
    iswcCode = URIRef("https://schema.org/iswcCode")
    status = URIRef("https://schema.org/status")
    EnergyStarCertified = URIRef("https://schema.org/EnergyStarCertified")
    loanPaymentAmount = URIRef("https://schema.org/loanPaymentAmount")
    Patient = URIRef("https://schema.org/Patient")
    memoryRequirements = URIRef("https://schema.org/memoryRequirements")
    BodyMeasurementNeck = URIRef("https://schema.org/BodyMeasurementNeck")
    CategoryCodeSet = URIRef("https://schema.org/CategoryCodeSet")
    purchaseDate = URIRef("https://schema.org/purchaseDate")
    postalCodePrefix = URIRef("https://schema.org/postalCodePrefix")
    Subscription = URIRef("https://schema.org/Subscription")
    ExerciseAction = URIRef("https://schema.org/ExerciseAction")
    numberOfAxles = URIRef("https://schema.org/numberOfAxles")
    Head = URIRef("https://schema.org/Head")
    Subscription = URIRef("https://schema.org/Subscription")
    EUEnergyEfficiencyEnumeration = URIRef("https://schema.org/EUEnergyEfficiencyEnumeration")
    FullGameAvailability = URIRef("https://schema.org/FullGameAvailability")
    courseSchedule = URIRef("https://schema.org/courseSchedule")
    ActivationFee = URIRef("https://schema.org/ActivationFee")
    hasCertification = URIRef("https://schema.org/hasCertification")
    AuthorizeAction = URIRef("https://schema.org/AuthorizeAction")
    deliveryTime = URIRef("https://schema.org/deliveryTime")
    reviewAspect = URIRef("https://schema.org/reviewAspect")
    MensClothingStore = URIRef("https://schema.org/MensClothingStore")
    inSupportOf = URIRef("https://schema.org/inSupportOf")
    Homeopathic = URIRef("https://schema.org/Homeopathic")
    executableLibraryName = URIRef("https://schema.org/executableLibraryName")
    appliesToDeliveryMethod = URIRef("https://schema.org/appliesToDeliveryMethod")
    HighSchool = URIRef("https://schema.org/HighSchool")
    experienceInPlaceOfEducation = URIRef("https://schema.org/experienceInPlaceOfEducation")
    accountablePerson = URIRef("https://schema.org/accountablePerson")
    knowsAbout = URIRef("https://schema.org/knowsAbout")
    ShippingRateSettings = URIRef("https://schema.org/ShippingRateSettings")
    modifiedTime = URIRef("https://schema.org/modifiedTime")
    dateSent = URIRef("https://schema.org/dateSent")
    image = URIRef("https://schema.org/image")
    catalog = URIRef("https://schema.org/catalog")
    materialExtent = URIRef("https://schema.org/materialExtent")
    softwareVersion = URIRef("https://schema.org/softwareVersion")
    recordLabel = URIRef("https://schema.org/recordLabel")
    BuddhistTemple = URIRef("https://schema.org/BuddhistTemple")
    mathExpression = URIRef("https://schema.org/mathExpression")
    codeValue = URIRef("https://schema.org/codeValue")
    includedRiskFactor = URIRef("https://schema.org/includedRiskFactor")
    discountCode = URIRef("https://schema.org/discountCode")
    collection = URIRef("https://schema.org/collection")
    GeospatialGeometry = URIRef("https://schema.org/GeospatialGeometry")
    algorithm = URIRef("https://schema.org/algorithm")
    firstPerformance = URIRef("https://schema.org/firstPerformance")
    targetCollection = URIRef("https://schema.org/targetCollection")
    ElementarySchool = URIRef("https://schema.org/ElementarySchool")
    candidate = URIRef("https://schema.org/candidate")
    ResearchOrganization = URIRef("https://schema.org/ResearchOrganization")
    SteeringPositionValue = URIRef("https://schema.org/SteeringPositionValue")
    CDCPMDRecord = URIRef("https://schema.org/CDCPMDRecord")
    screenshot = URIRef("https://schema.org/screenshot")
    significance = URIRef("https://schema.org/significance")
    appliesToDeliveryMethod = URIRef("https://schema.org/appliesToDeliveryMethod")
    softwareAddOn = URIRef("https://schema.org/softwareAddOn")
    petsAllowed = URIRef("https://schema.org/petsAllowed")
    alternateName = URIRef("https://schema.org/alternateName")
    PerformAction = URIRef("https://schema.org/PerformAction")
    MayTreatHealthAspect = URIRef("https://schema.org/MayTreatHealthAspect")
    acceptedOffer = URIRef("https://schema.org/acceptedOffer")
    AutoPartsStore = URIRef("https://schema.org/AutoPartsStore")
    serviceSmsNumber = URIRef("https://schema.org/serviceSmsNumber")
    WearableSizeGroupRegular = URIRef("https://schema.org/WearableSizeGroupRegular")
    CommunicateAction = URIRef("https://schema.org/CommunicateAction")
    Appearance = URIRef("https://schema.org/Appearance")
    WearableMeasurementHips = URIRef("https://schema.org/WearableMeasurementHips")
    recipient = URIRef("https://schema.org/recipient")
    postalCodeRange = URIRef("https://schema.org/postalCodeRange")
    deliveryTime = URIRef("https://schema.org/deliveryTime")
    FinancialProduct = URIRef("https://schema.org/FinancialProduct")
    yearBuilt = URIRef("https://schema.org/yearBuilt")
    SexualContentConsideration = URIRef("https://schema.org/SexualContentConsideration")
    LegalValueLevel = URIRef("https://schema.org/LegalValueLevel")
    ReservationPending = URIRef("https://schema.org/ReservationPending")
    annualPercentageRate = URIRef("https://schema.org/annualPercentageRate")
    Surgical = URIRef("https://schema.org/Surgical")
    Hackathon = URIRef("https://schema.org/Hackathon")
    applicableCountry = URIRef("https://schema.org/applicableCountry")
    Notary = URIRef("https://schema.org/Notary")
    PlaceboControlledTrial = URIRef("https://schema.org/PlaceboControlledTrial")
    Quiz = URIRef("https://schema.org/Quiz")
    runtimePlatform = URIRef("https://schema.org/runtimePlatform")
    appearance = URIRef("https://schema.org/appearance")
    HousePainter = URIRef("https://schema.org/HousePainter")
    antagonist = URIRef("https://schema.org/antagonist")
    OfferForPurchase = URIRef("https://schema.org/OfferForPurchase")
    geoCrosses = URIRef("https://schema.org/geoCrosses")
    serviceAudience = URIRef("https://schema.org/serviceAudience")
    shippingRate = URIRef("https://schema.org/shippingRate")
    sportsEvent = URIRef("https://schema.org/sportsEvent")
    CommunityHealth = URIRef("https://schema.org/CommunityHealth")
    DepartAction = URIRef("https://schema.org/DepartAction")
    studyDesign = URIRef("https://schema.org/studyDesign")
    WearableSizeGroupPlus = URIRef("https://schema.org/WearableSizeGroupPlus")
    gtin = URIRef("https://schema.org/gtin")
    ResultsNotAvailable = URIRef("https://schema.org/ResultsNotAvailable")
    naics = URIRef("https://schema.org/naics")
    requiredQuantity = URIRef("https://schema.org/requiredQuantity")
    addressLocality = URIRef("https://schema.org/addressLocality")
    containsPlace = URIRef("https://schema.org/containsPlace")
    suggestedMeasurement = URIRef("https://schema.org/suggestedMeasurement")
    maxValue = URIRef("https://schema.org/maxValue")
    hasCredential = URIRef("https://schema.org/hasCredential")
    ComicIssue = URIRef("https://schema.org/ComicIssue")
    GenericWebPlatform = URIRef("https://schema.org/GenericWebPlatform")
    GeoCoordinates = URIRef("https://schema.org/GeoCoordinates")
    PaymentStatusType = URIRef("https://schema.org/PaymentStatusType")
    cvdNumBedsOcc = URIRef("https://schema.org/cvdNumBedsOcc")
    suggestedGender = URIRef("https://schema.org/suggestedGender")
    healthPlanMarketingUrl = URIRef("https://schema.org/healthPlanMarketingUrl")
    MarryAction = URIRef("https://schema.org/MarryAction")
    returnFees = URIRef("https://schema.org/returnFees")
    childMinAge = URIRef("https://schema.org/childMinAge")
    multipleValues = URIRef("https://schema.org/multipleValues")
    repetitions = URIRef("https://schema.org/repetitions")
    productID = URIRef("https://schema.org/productID")
    exercisePlan = URIRef("https://schema.org/exercisePlan")
    purchaseDate = URIRef("https://schema.org/purchaseDate")
    sport = URIRef("https://schema.org/sport")
    geoEquals = URIRef("https://schema.org/geoEquals")
    CreditCard = URIRef("https://schema.org/CreditCard")
    hasPOS = URIRef("https://schema.org/hasPOS")
    MonetaryAmountDistribution = URIRef("https://schema.org/MonetaryAmountDistribution")
    category = URIRef("https://schema.org/category")
    hasMolecularFunction = URIRef("https://schema.org/hasMolecularFunction")
    RemixAlbum = URIRef("https://schema.org/RemixAlbum")
    lyrics = URIRef("https://schema.org/lyrics")
    prescribingInfo = URIRef("https://schema.org/prescribingInfo")
    LockerDelivery = URIRef("https://schema.org/LockerDelivery")
    WearableMeasurementChestOrBust = URIRef("https://schema.org/WearableMeasurementChestOrBust")
    MusicVenue = URIRef("https://schema.org/MusicVenue")
    hasCategoryCode = URIRef("https://schema.org/hasCategoryCode")
    SaleEvent = URIRef("https://schema.org/SaleEvent")
    area = URIRef("https://schema.org/area")
    governmentBenefitsInfo = URIRef("https://schema.org/governmentBenefitsInfo")
    relatedAnatomy = URIRef("https://schema.org/relatedAnatomy")
    mentions = URIRef("https://schema.org/mentions")
    Vessel = URIRef("https://schema.org/Vessel")
    seeks = URIRef("https://schema.org/seeks")
    unitText = URIRef("https://schema.org/unitText")
    totalPrice = URIRef("https://schema.org/totalPrice")
    mapType = URIRef("https://schema.org/mapType")
    MusicVideoObject = URIRef("https://schema.org/MusicVideoObject")
    GameAvailabilityEnumeration = URIRef("https://schema.org/GameAvailabilityEnumeration")
    billingPeriod = URIRef("https://schema.org/billingPeriod")
    healthPlanCopay = URIRef("https://schema.org/healthPlanCopay")
    telephone = URIRef("https://schema.org/telephone")
    specialty = URIRef("https://schema.org/specialty")
    printColumn = URIRef("https://schema.org/printColumn")
    Homeopathic = URIRef("https://schema.org/Homeopathic")
    AnimalShelter = URIRef("https://schema.org/AnimalShelter")
    endorsers = URIRef("https://schema.org/endorsers")
    LeisureTimeActivity = URIRef("https://schema.org/LeisureTimeActivity")
    workExample = URIRef("https://schema.org/workExample")
    Table = URIRef("https://schema.org/Table")
    hasBioPolymerSequence = URIRef("https://schema.org/hasBioPolymerSequence")
    returnMethod = URIRef("https://schema.org/returnMethod")
    SizeSystemImperial = URIRef("https://schema.org/SizeSystemImperial")
    educationalCredentialAwarded = URIRef("https://schema.org/educationalCredentialAwarded")
    alumniOf = URIRef("https://schema.org/alumniOf")
    creditText = URIRef("https://schema.org/creditText")
    trailer = URIRef("https://schema.org/trailer")
    wheelbase = URIRef("https://schema.org/wheelbase")
    tocEntry = URIRef("https://schema.org/tocEntry")
    WearableSizeSystemMX = URIRef("https://schema.org/WearableSizeSystemMX")
    manufacturer = URIRef("https://schema.org/manufacturer")
    byDay = URIRef("https://schema.org/byDay")
    DoubleBlindedTrial = URIRef("https://schema.org/DoubleBlindedTrial")
    isLocatedInSubcellularLocation = URIRef("https://schema.org/isLocatedInSubcellularLocation")
    accessibilitySummary = URIRef("https://schema.org/accessibilitySummary")
    BrainStructure = URIRef("https://schema.org/BrainStructure")
    shippingOrigin = URIRef("https://schema.org/shippingOrigin")
    eventStatus = URIRef("https://schema.org/eventStatus")
    StructuredValue = URIRef("https://schema.org/StructuredValue")
    inCodeSet = URIRef("https://schema.org/inCodeSet")
    RentAction = URIRef("https://schema.org/RentAction")
    PetStore = URIRef("https://schema.org/PetStore")
    recordedAs = URIRef("https://schema.org/recordedAs")
    MarryAction = URIRef("https://schema.org/MarryAction")
    activityDuration = URIRef("https://schema.org/activityDuration")
    duration = URIRef("https://schema.org/duration")
    isbn = URIRef("https://schema.org/isbn")
    longitude = URIRef("https://schema.org/longitude")
    TVClip = URIRef("https://schema.org/TVClip")
    followup = URIRef("https://schema.org/followup")
    cvdNumICUBeds = URIRef("https://schema.org/cvdNumICUBeds")
    numAdults = URIRef("https://schema.org/numAdults")
    VideoObjectSnapshot = URIRef("https://schema.org/VideoObjectSnapshot")
    PaymentService = URIRef("https://schema.org/PaymentService")
    Neuro = URIRef("https://schema.org/Neuro")
    departureStation = URIRef("https://schema.org/departureStation")
    administrationRoute = URIRef("https://schema.org/administrationRoute")
    GeneralContractor = URIRef("https://schema.org/GeneralContractor")
    contentSize = URIRef("https://schema.org/contentSize")
    WPHeader = URIRef("https://schema.org/WPHeader")
    totalPaymentDue = URIRef("https://schema.org/totalPaymentDue")
    applicationDeadline = URIRef("https://schema.org/applicationDeadline")
    MovingCompany = URIRef("https://schema.org/MovingCompany")
    Nonprofit501f = URIRef("https://schema.org/Nonprofit501f")
    measurementDenominator = URIRef("https://schema.org/measurementDenominator")
    PayAction = URIRef("https://schema.org/PayAction")
    slogan = URIRef("https://schema.org/slogan")
    JobPosting = URIRef("https://schema.org/JobPosting")
    includedDataCatalog = URIRef("https://schema.org/includedDataCatalog")
    Hardcover = URIRef("https://schema.org/Hardcover")
    customerRemorseReturnFees = URIRef("https://schema.org/customerRemorseReturnFees")
    FundingAgency = URIRef("https://schema.org/FundingAgency")
    Gynecologic = URIRef("https://schema.org/Gynecologic")
    newsUpdatesAndGuidelines = URIRef("https://schema.org/newsUpdatesAndGuidelines")
    DietNutrition = URIRef("https://schema.org/DietNutrition")
    offerCount = URIRef("https://schema.org/offerCount")
    expectedArrivalFrom = URIRef("https://schema.org/expectedArrivalFrom")
    publisher = URIRef("https://schema.org/publisher")
    TextDigitalDocument = URIRef("https://schema.org/TextDigitalDocument")
    Atlas = URIRef("https://schema.org/Atlas")
    ViolenceConsideration = URIRef("https://schema.org/ViolenceConsideration")
    vehicleIdentificationNumber = URIRef("https://schema.org/vehicleIdentificationNumber")
    MerchantReturnPolicySeasonalOverride = URIRef("https://schema.org/MerchantReturnPolicySeasonalOverride")
    nextItem = URIRef("https://schema.org/nextItem")
    videoFrameSize = URIRef("https://schema.org/videoFrameSize")
    repetitions = URIRef("https://schema.org/repetitions")
    mainEntity = URIRef("https://schema.org/mainEntity")
    Nonprofit501c27 = URIRef("https://schema.org/Nonprofit501c27")
    actor = URIRef("https://schema.org/actor")
    FollowAction = URIRef("https://schema.org/FollowAction")
    musicalKey = URIRef("https://schema.org/musicalKey")
    strengthValue = URIRef("https://schema.org/strengthValue")
    sizeSystem = URIRef("https://schema.org/sizeSystem")
    returnLabelSource = URIRef("https://schema.org/returnLabelSource")
    dateVehicleFirstRegistered = URIRef("https://schema.org/dateVehicleFirstRegistered")
    MedicalCondition = URIRef("https://schema.org/MedicalCondition")
    estimatedFlightDuration = URIRef("https://schema.org/estimatedFlightDuration")
    associatedMedia = URIRef("https://schema.org/associatedMedia")
    Nonprofit527 = URIRef("https://schema.org/Nonprofit527")
    department = URIRef("https://schema.org/department")
    bookingTime = URIRef("https://schema.org/bookingTime")
    ParcelDelivery = URIRef("https://schema.org/ParcelDelivery")
    ReturnFeesCustomerResponsibility = URIRef("https://schema.org/ReturnFeesCustomerResponsibility")
    serviceArea = URIRef("https://schema.org/serviceArea")
    nonProprietaryName = URIRef("https://schema.org/nonProprietaryName")
    representativeOfPage = URIRef("https://schema.org/representativeOfPage")
    positiveNotes = URIRef("https://schema.org/positiveNotes")
    feesAndCommissionsSpecification = URIRef("https://schema.org/feesAndCommissionsSpecification")
    Saturday = URIRef("https://schema.org/Saturday")
    isPartOf = URIRef("https://schema.org/isPartOf")
    vehicleEngine = URIRef("https://schema.org/vehicleEngine")
    bookingTime = URIRef("https://schema.org/bookingTime")
    IOSPlatform = URIRef("https://schema.org/IOSPlatform")
    orderItemStatus = URIRef("https://schema.org/orderItemStatus")
    validUntil = URIRef("https://schema.org/validUntil")
    TherapeuticProcedure = URIRef("https://schema.org/TherapeuticProcedure")
    copyrightNotice = URIRef("https://schema.org/copyrightNotice")
    SoftwareApplication = URIRef("https://schema.org/SoftwareApplication")
    object = URIRef("https://schema.org/object")
    accountId = URIRef("https://schema.org/accountId")
    downvoteCount = URIRef("https://schema.org/downvoteCount")
    SeekToAction = URIRef("https://schema.org/SeekToAction")
    expires = URIRef("https://schema.org/expires")
    Rating = URIRef("https://schema.org/Rating")
    StatusEnumeration = URIRef("https://schema.org/StatusEnumeration")
    downvoteCount = URIRef("https://schema.org/downvoteCount")
    MeasurementMethodEnum = URIRef("https://schema.org/MeasurementMethodEnum")
    CertificationStatusEnumeration = URIRef("https://schema.org/CertificationStatusEnumeration")
    measurementQualifier = URIRef("https://schema.org/measurementQualifier")
    TherapeuticProcedure = URIRef("https://schema.org/TherapeuticProcedure")
    Longitudinal = URIRef("https://schema.org/Longitudinal")
    WearableMeasurementInseam = URIRef("https://schema.org/WearableMeasurementInseam")
    MinimumAdvertisedPrice = URIRef("https://schema.org/MinimumAdvertisedPrice")
    inker = URIRef("https://schema.org/inker")
    Nursing = URIRef("https://schema.org/Nursing")
    mathExpression = URIRef("https://schema.org/mathExpression")
    departureTime = URIRef("https://schema.org/departureTime")
    naics = URIRef("https://schema.org/naics")
    EUEnergyEfficiencyCategoryC = URIRef("https://schema.org/EUEnergyEfficiencyCategoryC")
    WearableMeasurementSleeve = URIRef("https://schema.org/WearableMeasurementSleeve")
    loanRepaymentForm = URIRef("https://schema.org/loanRepaymentForm")
    appliesToPaymentMethod = URIRef("https://schema.org/appliesToPaymentMethod")
    isEncodedByBioChemEntity = URIRef("https://schema.org/isEncodedByBioChemEntity")
    clincalPharmacology = URIRef("https://schema.org/clincalPharmacology")
    loanType = URIRef("https://schema.org/loanType")
    geoEquals = URIRef("https://schema.org/geoEquals")
    acquiredFrom = URIRef("https://schema.org/acquiredFrom")
    hasEnergyEfficiencyCategory = URIRef("https://schema.org/hasEnergyEfficiencyCategory")
    checkoutPageURLTemplate = URIRef("https://schema.org/checkoutPageURLTemplate")
    ineligibleRegion = URIRef("https://schema.org/ineligibleRegion")
    Continent = URIRef("https://schema.org/Continent")
    MedicalStudyStatus = URIRef("https://schema.org/MedicalStudyStatus")
    sdDatePublished = URIRef("https://schema.org/sdDatePublished")
    ReplyAction = URIRef("https://schema.org/ReplyAction")
    hasCredential = URIRef("https://schema.org/hasCredential")
    NonprofitANBI = URIRef("https://schema.org/NonprofitANBI")
    taxonRank = URIRef("https://schema.org/taxonRank")
    accommodationCategory = URIRef("https://schema.org/accommodationCategory")
    usesDevice = URIRef("https://schema.org/usesDevice")
    significantLink = URIRef("https://schema.org/significantLink")
    isPartOfBioChemEntity = URIRef("https://schema.org/isPartOfBioChemEntity")
    UserPlusOnes = URIRef("https://schema.org/UserPlusOnes")
    EducationalOccupationalCredential = URIRef("https://schema.org/EducationalOccupationalCredential")
    cvdNumBeds = URIRef("https://schema.org/cvdNumBeds")
    contraindication = URIRef("https://schema.org/contraindication")
    countryOfLastProcessing = URIRef("https://schema.org/countryOfLastProcessing")
    passengerPriorityStatus = URIRef("https://schema.org/passengerPriorityStatus")
    BodyMeasurementFoot = URIRef("https://schema.org/BodyMeasurementFoot")
    SexualContentConsideration = URIRef("https://schema.org/SexualContentConsideration")
    PhysicalActivityCategory = URIRef("https://schema.org/PhysicalActivityCategory")
    MedicalSpecialty = URIRef("https://schema.org/MedicalSpecialty")
    vehicleInteriorColor = URIRef("https://schema.org/vehicleInteriorColor")
    minValue = URIRef("https://schema.org/minValue")
    EUEnergyEfficiencyCategoryC = URIRef("https://schema.org/EUEnergyEfficiencyCategoryC")
    countriesNotSupported = URIRef("https://schema.org/countriesNotSupported")
    userInteractionCount = URIRef("https://schema.org/userInteractionCount")
    availabilityStarts = URIRef("https://schema.org/availabilityStarts")
    WearableSizeGroupMisses = URIRef("https://schema.org/WearableSizeGroupMisses")
    PerformAction = URIRef("https://schema.org/PerformAction")
    Drawing = URIRef("https://schema.org/Drawing")
    CriticReview = URIRef("https://schema.org/CriticReview")
    previousItem = URIRef("https://schema.org/previousItem")
    MusicPlaylist = URIRef("https://schema.org/MusicPlaylist")
    doseSchedule = URIRef("https://schema.org/doseSchedule")
    ticketToken = URIRef("https://schema.org/ticketToken")
    DesktopWebPlatform = URIRef("https://schema.org/DesktopWebPlatform")
    director = URIRef("https://schema.org/director")
    originalMediaContextDescription = URIRef("https://schema.org/originalMediaContextDescription")
    totalHistoricalEnrollment = URIRef("https://schema.org/totalHistoricalEnrollment")
    nonprofitStatus = URIRef("https://schema.org/nonprofitStatus")
    noBylinesPolicy = URIRef("https://schema.org/noBylinesPolicy")
    geoEquals = URIRef("https://schema.org/geoEquals")
    firstAppearance = URIRef("https://schema.org/firstAppearance")
    fuelConsumption = URIRef("https://schema.org/fuelConsumption")
    validThrough = URIRef("https://schema.org/validThrough")
    partOfTrip = URIRef("https://schema.org/partOfTrip")
    hasMenu = URIRef("https://schema.org/hasMenu")
    PalliativeProcedure = URIRef("https://schema.org/PalliativeProcedure")
    subEvents = URIRef("https://schema.org/subEvents")
    Nonprofit501c8 = URIRef("https://schema.org/Nonprofit501c8")
    startTime = URIRef("https://schema.org/startTime")
    WritePermission = URIRef("https://schema.org/WritePermission")
    TransferAction = URIRef("https://schema.org/TransferAction")
    SchoolDistrict = URIRef("https://schema.org/SchoolDistrict")
    maximumVirtualAttendeeCapacity = URIRef("https://schema.org/maximumVirtualAttendeeCapacity")
    preOp = URIRef("https://schema.org/preOp")
    addOn = URIRef("https://schema.org/addOn")
    healthPlanCopayOption = URIRef("https://schema.org/healthPlanCopayOption")
    typicalTest = URIRef("https://schema.org/typicalTest")
    isRelatedTo = URIRef("https://schema.org/isRelatedTo")
    depth = URIRef("https://schema.org/depth")
    alumniOf = URIRef("https://schema.org/alumniOf")
    isSimilarTo = URIRef("https://schema.org/isSimilarTo")
    directApply = URIRef("https://schema.org/directApply")
    costCurrency = URIRef("https://schema.org/costCurrency")
    PublicHealth = URIRef("https://schema.org/PublicHealth")
    floorLimit = URIRef("https://schema.org/floorLimit")
    TaxiStand = URIRef("https://schema.org/TaxiStand")
    hasMerchantReturnPolicy = URIRef("https://schema.org/hasMerchantReturnPolicy")
    ReviewNewsArticle = URIRef("https://schema.org/ReviewNewsArticle")
    algorithm = URIRef("https://schema.org/algorithm")
    liveBlogUpdate = URIRef("https://schema.org/liveBlogUpdate")
    opens = URIRef("https://schema.org/opens")
    archivedAt = URIRef("https://schema.org/archivedAt")
    healthPlanId = URIRef("https://schema.org/healthPlanId")
    letterer = URIRef("https://schema.org/letterer")
    transitTimeLabel = URIRef("https://schema.org/transitTimeLabel")
    adverseOutcome = URIRef("https://schema.org/adverseOutcome")
    PlayGameAction = URIRef("https://schema.org/PlayGameAction")
    DatedMoneySpecification = URIRef("https://schema.org/DatedMoneySpecification")
    providerMobility = URIRef("https://schema.org/providerMobility")
    discount = URIRef("https://schema.org/discount")
    AerobicActivity = URIRef("https://schema.org/AerobicActivity")
    spatialCoverage = URIRef("https://schema.org/spatialCoverage")
    WinAction = URIRef("https://schema.org/WinAction")
    overdosage = URIRef("https://schema.org/overdosage")
    actors = URIRef("https://schema.org/actors")
    WearableMeasurementHips = URIRef("https://schema.org/WearableMeasurementHips")
    acrissCode = URIRef("https://schema.org/acrissCode")
    HealthPlanFormulary = URIRef("https://schema.org/HealthPlanFormulary")
    Manuscript = URIRef("https://schema.org/Manuscript")
    accelerationTime = URIRef("https://schema.org/accelerationTime")
    occupationalCategory = URIRef("https://schema.org/occupationalCategory")
    OrganizationRole = URIRef("https://schema.org/OrganizationRole")
    yearBuilt = URIRef("https://schema.org/yearBuilt")
    riskFactor = URIRef("https://schema.org/riskFactor")
    publication = URIRef("https://schema.org/publication")
    translationOfWork = URIRef("https://schema.org/translationOfWork")
    occupationalCategory = URIRef("https://schema.org/occupationalCategory")
    Consortium = URIRef("https://schema.org/Consortium")
    unitCode = URIRef("https://schema.org/unitCode")
    WearableSizeGroupJuniors = URIRef("https://schema.org/WearableSizeGroupJuniors")
    eventSchedule = URIRef("https://schema.org/eventSchedule")
    VenueMap = URIRef("https://schema.org/VenueMap")
    provider = URIRef("https://schema.org/provider")
    Game = URIRef("https://schema.org/Game")
    musicCompositionForm = URIRef("https://schema.org/musicCompositionForm")
    parentItem = URIRef("https://schema.org/parentItem")
    applicationContact = URIRef("https://schema.org/applicationContact")
    Manuscript = URIRef("https://schema.org/Manuscript")
    ImageObjectSnapshot = URIRef("https://schema.org/ImageObjectSnapshot")
    CreditCard = URIRef("https://schema.org/CreditCard")
    publisher = URIRef("https://schema.org/publisher")
    salaryUponCompletion = URIRef("https://schema.org/salaryUponCompletion")
    dateModified = URIRef("https://schema.org/dateModified")
    reviews = URIRef("https://schema.org/reviews")
    xpath = URIRef("https://schema.org/xpath")
    releaseDate = URIRef("https://schema.org/releaseDate")
    estimatesRiskOf = URIRef("https://schema.org/estimatesRiskOf")
    breastfeedingWarning = URIRef("https://schema.org/breastfeedingWarning")
    ratingExplanation = URIRef("https://schema.org/ratingExplanation")
    BusinessEntityType = URIRef("https://schema.org/BusinessEntityType")
    validFrom = URIRef("https://schema.org/validFrom")
    WearableSizeGroupExtraTall = URIRef("https://schema.org/WearableSizeGroupExtraTall")
    HowToStep = URIRef("https://schema.org/HowToStep")
    partOfTrip = URIRef("https://schema.org/partOfTrip")
    Reservoir = URIRef("https://schema.org/Reservoir")
    WearableSizeSystemAU = URIRef("https://schema.org/WearableSizeSystemAU")
    biomechnicalClass = URIRef("https://schema.org/biomechnicalClass")
    blogPosts = URIRef("https://schema.org/blogPosts")
    recourseLoan = URIRef("https://schema.org/recourseLoan")
    isResizable = URIRef("https://schema.org/isResizable")
    GeospatialGeometry = URIRef("https://schema.org/GeospatialGeometry")
    publisherImprint = URIRef("https://schema.org/publisherImprint")
    normalRange = URIRef("https://schema.org/normalRange")
    homeLocation = URIRef("https://schema.org/homeLocation")
    MenuItem = URIRef("https://schema.org/MenuItem")
    CreateAction = URIRef("https://schema.org/CreateAction")
    Notary = URIRef("https://schema.org/Notary")
    transcript = URIRef("https://schema.org/transcript")
    PronounceableText = URIRef("https://schema.org/PronounceableText")
    healthcareReportingData = URIRef("https://schema.org/healthcareReportingData")
    flightNumber = URIRef("https://schema.org/flightNumber")
    percentile10 = URIRef("https://schema.org/percentile10")
    location = URIRef("https://schema.org/location")
    isInvolvedInBiologicalProcess = URIRef("https://schema.org/isInvolvedInBiologicalProcess")
    inventoryLevel = URIRef("https://schema.org/inventoryLevel")
    numberOfLoanPayments = URIRef("https://schema.org/numberOfLoanPayments")
    hasDeliveryMethod = URIRef("https://schema.org/hasDeliveryMethod")
    arrivalBoatTerminal = URIRef("https://schema.org/arrivalBoatTerminal")
    refundType = URIRef("https://schema.org/refundType")
    Pediatric = URIRef("https://schema.org/Pediatric")
    numberOfBathroomsTotal = URIRef("https://schema.org/numberOfBathroomsTotal")
    totalTime = URIRef("https://schema.org/totalTime")
    seriousAdverseOutcome = URIRef("https://schema.org/seriousAdverseOutcome")
    jurisdiction = URIRef("https://schema.org/jurisdiction")
    CreditCard = URIRef("https://schema.org/CreditCard")
    alternativeOf = URIRef("https://schema.org/alternativeOf")
    SizeGroupEnumeration = URIRef("https://schema.org/SizeGroupEnumeration")
    vehicleTransmission = URIRef("https://schema.org/vehicleTransmission")
    scheduleTimezone = URIRef("https://schema.org/scheduleTimezone")
    activityDuration = URIRef("https://schema.org/activityDuration")
    bankAccountType = URIRef("https://schema.org/bankAccountType")
    pageStart = URIRef("https://schema.org/pageStart")
    result = URIRef("https://schema.org/result")
    itemOffered = URIRef("https://schema.org/itemOffered")
    ElementarySchool = URIRef("https://schema.org/ElementarySchool")
    alcoholWarning = URIRef("https://schema.org/alcoholWarning")
    LowCalorieDiet = URIRef("https://schema.org/LowCalorieDiet")
    branch = URIRef("https://schema.org/branch")
    iso6523Code = URIRef("https://schema.org/iso6523Code")
    relatedLink = URIRef("https://schema.org/relatedLink")
    item = URIRef("https://schema.org/item")
    accommodationFloorPlan = URIRef("https://schema.org/accommodationFloorPlan")
    MeasurementMethodEnum = URIRef("https://schema.org/MeasurementMethodEnum")
    floorSize = URIRef("https://schema.org/floorSize")
    SatiricalArticle = URIRef("https://schema.org/SatiricalArticle")
    gameAvailabilityType = URIRef("https://schema.org/gameAvailabilityType")
    MedicalTherapy = URIRef("https://schema.org/MedicalTherapy")
    DiscussionForumPosting = URIRef("https://schema.org/DiscussionForumPosting")
    ResultsAvailable = URIRef("https://schema.org/ResultsAvailable")
    ExhibitionEvent = URIRef("https://schema.org/ExhibitionEvent")
    inChI = URIRef("https://schema.org/inChI")
    UsageOrScheduleHealthAspect = URIRef("https://schema.org/UsageOrScheduleHealthAspect")
    replacer = URIRef("https://schema.org/replacer")
    artEdition = URIRef("https://schema.org/artEdition")
    numberOfPreviousOwners = URIRef("https://schema.org/numberOfPreviousOwners")
    bookingAgent = URIRef("https://schema.org/bookingAgent")
    WearableSizeSystemBR = URIRef("https://schema.org/WearableSizeSystemBR")
    amenityFeature = URIRef("https://schema.org/amenityFeature")
    cutoffTime = URIRef("https://schema.org/cutoffTime")
    SpreadsheetDigitalDocument = URIRef("https://schema.org/SpreadsheetDigitalDocument")
    permissions = URIRef("https://schema.org/permissions")
    reviewBody = URIRef("https://schema.org/reviewBody")
    legislationJurisdiction = URIRef("https://schema.org/legislationJurisdiction")
    permitAudience = URIRef("https://schema.org/permitAudience")
    EntryPoint = URIRef("https://schema.org/EntryPoint")
    CertificationStatusEnumeration = URIRef("https://schema.org/CertificationStatusEnumeration")
    paymentDue = URIRef("https://schema.org/paymentDue")
    Oncologic = URIRef("https://schema.org/Oncologic")
    includedInDataCatalog = URIRef("https://schema.org/includedInDataCatalog")
    beneficiaryBank = URIRef("https://schema.org/beneficiaryBank")
    safetyConsideration = URIRef("https://schema.org/safetyConsideration")
    dateline = URIRef("https://schema.org/dateline")
    valueMaxLength = URIRef("https://schema.org/valueMaxLength")
    mentions = URIRef("https://schema.org/mentions")
    availabilityStarts = URIRef("https://schema.org/availabilityStarts")
    opens = URIRef("https://schema.org/opens")
    EducationalOrganization = URIRef("https://schema.org/EducationalOrganization")
    diseaseSpreadStatistics = URIRef("https://schema.org/diseaseSpreadStatistics")
    assesses = URIRef("https://schema.org/assesses")
    AnatomicalStructure = URIRef("https://schema.org/AnatomicalStructure")
    competencyRequired = URIRef("https://schema.org/competencyRequired")
    aircraft = URIRef("https://schema.org/aircraft")
    Certification = URIRef("https://schema.org/Certification")
    actionStatus = URIRef("https://schema.org/actionStatus")
    MedicalGuidelineContraindication = URIRef("https://schema.org/MedicalGuidelineContraindication")
    RestockingFees = URIRef("https://schema.org/RestockingFees")
    homeLocation = URIRef("https://schema.org/homeLocation")
    geoTouches = URIRef("https://schema.org/geoTouches")
    validThrough = URIRef("https://schema.org/validThrough")
    FDAcategoryC = URIRef("https://schema.org/FDAcategoryC")
    productionCompany = URIRef("https://schema.org/productionCompany")
    observationAbout = URIRef("https://schema.org/observationAbout")
    GiveAction = URIRef("https://schema.org/GiveAction")
    BuyAction = URIRef("https://schema.org/BuyAction")
    practicesAt = URIRef("https://schema.org/practicesAt")
    Retail = URIRef("https://schema.org/Retail")
    WearableSizeSystemGS1 = URIRef("https://schema.org/WearableSizeSystemGS1")
    roofLoad = URIRef("https://schema.org/roofLoad")
    inChIKey = URIRef("https://schema.org/inChIKey")
    contactPoints = URIRef("https://schema.org/contactPoints")
    primaryPrevention = URIRef("https://schema.org/primaryPrevention")
    EventScheduled = URIRef("https://schema.org/EventScheduled")
    BowlingAlley = URIRef("https://schema.org/BowlingAlley")
    WearableMeasurementWidth = URIRef("https://schema.org/WearableMeasurementWidth")
    EPRelease = URIRef("https://schema.org/EPRelease")
    validUntil = URIRef("https://schema.org/validUntil")
    parentItem = URIRef("https://schema.org/parentItem")
    trainingSalary = URIRef("https://schema.org/trainingSalary")
    toLocation = URIRef("https://schema.org/toLocation")
    DigitalCaptureDigitalSource = URIRef("https://schema.org/DigitalCaptureDigitalSource")
    CompositeSyntheticDigitalSource = URIRef("https://schema.org/CompositeSyntheticDigitalSource")
    caption = URIRef("https://schema.org/caption")
    studySubject = URIRef("https://schema.org/studySubject")
    aggregateRating = URIRef("https://schema.org/aggregateRating")
    BusinessFunction = URIRef("https://schema.org/BusinessFunction")
    estimatedFlightDuration = URIRef("https://schema.org/estimatedFlightDuration")
    observationAbout = URIRef("https://schema.org/observationAbout")
    error = URIRef("https://schema.org/error")
    exerciseRelatedDiet = URIRef("https://schema.org/exerciseRelatedDiet")
    energyEfficiencyScaleMin = URIRef("https://schema.org/energyEfficiencyScaleMin")
    OwnershipInfo = URIRef("https://schema.org/OwnershipInfo")
    includesObject = URIRef("https://schema.org/includesObject")
    MedicalImagingTechnique = URIRef("https://schema.org/MedicalImagingTechnique")
    ConsumeAction = URIRef("https://schema.org/ConsumeAction")
    ComedyClub = URIRef("https://schema.org/ComedyClub")
    measurementMethod = URIRef("https://schema.org/measurementMethod")
    recordedAs = URIRef("https://schema.org/recordedAs")
    feesAndCommissionsSpecification = URIRef("https://schema.org/feesAndCommissionsSpecification")
    repetitions = URIRef("https://schema.org/repetitions")
    subOrganization = URIRef("https://schema.org/subOrganization")
    broadcastServiceTier = URIRef("https://schema.org/broadcastServiceTier")
    shippingSettingsLink = URIRef("https://schema.org/shippingSettingsLink")
    Nonprofit501a = URIRef("https://schema.org/Nonprofit501a")
    practicesAt = URIRef("https://schema.org/practicesAt")
    speakable = URIRef("https://schema.org/speakable")
    vehicleEngine = URIRef("https://schema.org/vehicleEngine")
    founders = URIRef("https://schema.org/founders")
    identifier = URIRef("https://schema.org/identifier")
    gracePeriod = URIRef("https://schema.org/gracePeriod")
    cvdNumTotBeds = URIRef("https://schema.org/cvdNumTotBeds")
    childMinAge = URIRef("https://schema.org/childMinAge")
    targetName = URIRef("https://schema.org/targetName")
    TobaccoNicotineConsideration = URIRef("https://schema.org/TobaccoNicotineConsideration")
    salaryUponCompletion = URIRef("https://schema.org/salaryUponCompletion")
    BackOrder = URIRef("https://schema.org/BackOrder")
    EducationalAudience = URIRef("https://schema.org/EducationalAudience")
    EffectivenessHealthAspect = URIRef("https://schema.org/EffectivenessHealthAspect")
    broadcastAffiliateOf = URIRef("https://schema.org/broadcastAffiliateOf")
    LendAction = URIRef("https://schema.org/LendAction")
    QuantitativeValue = URIRef("https://schema.org/QuantitativeValue")
    Grant = URIRef("https://schema.org/Grant")
    PhysicalTherapy = URIRef("https://schema.org/PhysicalTherapy")
    broadcastOfEvent = URIRef("https://schema.org/broadcastOfEvent")
    Atlas = URIRef("https://schema.org/Atlas")
    sportsTeam = URIRef("https://schema.org/sportsTeam")
    MedicineSystem = URIRef("https://schema.org/MedicineSystem")
    servicePostalAddress = URIRef("https://schema.org/servicePostalAddress")
    subReservation = URIRef("https://schema.org/subReservation")
    BodyMeasurementChest = URIRef("https://schema.org/BodyMeasurementChest")
    ReturnShippingFees = URIRef("https://schema.org/ReturnShippingFees")
    childMinAge = URIRef("https://schema.org/childMinAge")
    Casino = URIRef("https://schema.org/Casino")
    instrument = URIRef("https://schema.org/instrument")
    valueReference = URIRef("https://schema.org/valueReference")
    identifier = URIRef("https://schema.org/identifier")
    DisabilitySupport = URIRef("https://schema.org/DisabilitySupport")
    albumReleaseType = URIRef("https://schema.org/albumReleaseType")
    postalCodeBegin = URIRef("https://schema.org/postalCodeBegin")
    OfferForPurchase = URIRef("https://schema.org/OfferForPurchase")
    spatial = URIRef("https://schema.org/spatial")
    numChildren = URIRef("https://schema.org/numChildren")
    TVClip = URIRef("https://schema.org/TVClip")
    Male = URIRef("https://schema.org/Male")
    RandomizedTrial = URIRef("https://schema.org/RandomizedTrial")
    AdministrativeArea = URIRef("https://schema.org/AdministrativeArea")
    orderDelivery = URIRef("https://schema.org/orderDelivery")
    game = URIRef("https://schema.org/game")
    aggregateRating = URIRef("https://schema.org/aggregateRating")
    DataCatalog = URIRef("https://schema.org/DataCatalog")
    scheduledTime = URIRef("https://schema.org/scheduledTime")
    OrganizationRole = URIRef("https://schema.org/OrganizationRole")
    RadioSeries = URIRef("https://schema.org/RadioSeries")
    payload = URIRef("https://schema.org/payload")
    performTime = URIRef("https://schema.org/performTime")
    departureTime = URIRef("https://schema.org/departureTime")
    minValue = URIRef("https://schema.org/minValue")
    CompositeWithTrainedAlgorithmicMediaDigitalSource = URIRef("https://schema.org/CompositeWithTrainedAlgorithmicMediaDigitalSource")
    LinkRole = URIRef("https://schema.org/LinkRole")
    releasedEvent = URIRef("https://schema.org/releasedEvent")
    emissionsCO2 = URIRef("https://schema.org/emissionsCO2")
    beneficiaryBank = URIRef("https://schema.org/beneficiaryBank")
    coursePrerequisites = URIRef("https://schema.org/coursePrerequisites")
    LymphaticVessel = URIRef("https://schema.org/LymphaticVessel")
    ReservationPackage = URIRef("https://schema.org/ReservationPackage")
    OccupationalTherapy = URIRef("https://schema.org/OccupationalTherapy")
    billingStart = URIRef("https://schema.org/billingStart")
    skills = URIRef("https://schema.org/skills")
    cookingMethod = URIRef("https://schema.org/cookingMethod")
    ApartmentComplex = URIRef("https://schema.org/ApartmentComplex")
    vehicleEngine = URIRef("https://schema.org/vehicleEngine")
    IOSPlatform = URIRef("https://schema.org/IOSPlatform")
    Cemetery = URIRef("https://schema.org/Cemetery")
    AutoWash = URIRef("https://schema.org/AutoWash")
    RefurbishedCondition = URIRef("https://schema.org/RefurbishedCondition")
    layoutImage = URIRef("https://schema.org/layoutImage")
    VinylFormat = URIRef("https://schema.org/VinylFormat")
    UserTweets = URIRef("https://schema.org/UserTweets")
    itemReviewed = URIRef("https://schema.org/itemReviewed")
    nutrition = URIRef("https://schema.org/nutrition")
    SearchResultsPage = URIRef("https://schema.org/SearchResultsPage")
    PodcastEpisode = URIRef("https://schema.org/PodcastEpisode")
    CohortStudy = URIRef("https://schema.org/CohortStudy")
    blogPost = URIRef("https://schema.org/blogPost")
    uploadDate = URIRef("https://schema.org/uploadDate")
    browserRequirements = URIRef("https://schema.org/browserRequirements")
    TouristDestination = URIRef("https://schema.org/TouristDestination")
    taxID = URIRef("https://schema.org/taxID")
    OrderStatus = URIRef("https://schema.org/OrderStatus")
    warrantyPromise = URIRef("https://schema.org/warrantyPromise")
    collectionSize = URIRef("https://schema.org/collectionSize")
    infectiousAgent = URIRef("https://schema.org/infectiousAgent")
    isPlanForApartment = URIRef("https://schema.org/isPlanForApartment")
    inChI = URIRef("https://schema.org/inChI")
    MedicalProcedureType = URIRef("https://schema.org/MedicalProcedureType")
    MenuSection = URIRef("https://schema.org/MenuSection")
    applicationSuite = URIRef("https://schema.org/applicationSuite")
    acceptedAnswer = URIRef("https://schema.org/acceptedAnswer")
    gettingTestedInfo = URIRef("https://schema.org/gettingTestedInfo")
    producer = URIRef("https://schema.org/producer")
    Obstetric = URIRef("https://schema.org/Obstetric")
    estimatedCost = URIRef("https://schema.org/estimatedCost")
    estimatedFlightDuration = URIRef("https://schema.org/estimatedFlightDuration")
    inProductGroupWithID = URIRef("https://schema.org/inProductGroupWithID")
    utterances = URIRef("https://schema.org/utterances")
    expectsAcceptanceOf = URIRef("https://schema.org/expectsAcceptanceOf")
    SingleRelease = URIRef("https://schema.org/SingleRelease")
    DanceGroup = URIRef("https://schema.org/DanceGroup")
    servicePhone = URIRef("https://schema.org/servicePhone")
    WinAction = URIRef("https://schema.org/WinAction")
    AnaerobicActivity = URIRef("https://schema.org/AnaerobicActivity")
    InvestmentFund = URIRef("https://schema.org/InvestmentFund")
    PronounceableText = URIRef("https://schema.org/PronounceableText")
    membershipNumber = URIRef("https://schema.org/membershipNumber")
    loanRepaymentForm = URIRef("https://schema.org/loanRepaymentForm")
    album = URIRef("https://schema.org/album")
    knowsAbout = URIRef("https://schema.org/knowsAbout")
    legalStatus = URIRef("https://schema.org/legalStatus")
    departureBoatTerminal = URIRef("https://schema.org/departureBoatTerminal")
    FinancialService = URIRef("https://schema.org/FinancialService")
    reviewedBy = URIRef("https://schema.org/reviewedBy")
    variantCover = URIRef("https://schema.org/variantCover")
    CT = URIRef("https://schema.org/CT")
    EmergencyService = URIRef("https://schema.org/EmergencyService")
    encodesBioChemEntity = URIRef("https://schema.org/encodesBioChemEntity")
    DrugPrescriptionStatus = URIRef("https://schema.org/DrugPrescriptionStatus")
    Festival = URIRef("https://schema.org/Festival")
    LearningResource = URIRef("https://schema.org/LearningResource")
    SpeakableSpecification = URIRef("https://schema.org/SpeakableSpecification")
    director = URIRef("https://schema.org/director")
    WearableMeasurementChestOrBust = URIRef("https://schema.org/WearableMeasurementChestOrBust")
    FDAcategoryA = URIRef("https://schema.org/FDAcategoryA")
    cvdFacilityId = URIRef("https://schema.org/cvdFacilityId")
    occupationalCredentialAwarded = URIRef("https://schema.org/occupationalCredentialAwarded")
    blogPosts = URIRef("https://schema.org/blogPosts")
    diagnosis = URIRef("https://schema.org/diagnosis")
    suggestedAnswer = URIRef("https://schema.org/suggestedAnswer")
    availableLanguage = URIRef("https://schema.org/availableLanguage")
    musicReleaseFormat = URIRef("https://schema.org/musicReleaseFormat")
    result = URIRef("https://schema.org/result")
    unsaturatedFatContent = URIRef("https://schema.org/unsaturatedFatContent")
    Dentist = URIRef("https://schema.org/Dentist")
    EducationalOccupationalCredential = URIRef("https://schema.org/EducationalOccupationalCredential")
    gtin = URIRef("https://schema.org/gtin")
    Diet = URIRef("https://schema.org/Diet")
    broadcaster = URIRef("https://schema.org/broadcaster")
    vehicleSeatingCapacity = URIRef("https://schema.org/vehicleSeatingCapacity")
    teaches = URIRef("https://schema.org/teaches")
    Report = URIRef("https://schema.org/Report")
    DonateAction = URIRef("https://schema.org/DonateAction")
    colleague = URIRef("https://schema.org/colleague")
    Book = URIRef("https://schema.org/Book")
    numChildren = URIRef("https://schema.org/numChildren")
    Manuscript = URIRef("https://schema.org/Manuscript")
    DietarySupplement = URIRef("https://schema.org/DietarySupplement")
    feesAndCommissionsSpecification = URIRef("https://schema.org/feesAndCommissionsSpecification")
    creator = URIRef("https://schema.org/creator")
    BuddhistTemple = URIRef("https://schema.org/BuddhistTemple")
    ComedyClub = URIRef("https://schema.org/ComedyClub")
    GameServer = URIRef("https://schema.org/GameServer")
    EvidenceLevelC = URIRef("https://schema.org/EvidenceLevelC")
    homeTeam = URIRef("https://schema.org/homeTeam")
    competencyRequired = URIRef("https://schema.org/competencyRequired")
    acquiredFrom = URIRef("https://schema.org/acquiredFrom")
    paymentMethod = URIRef("https://schema.org/paymentMethod")
    valuePattern = URIRef("https://schema.org/valuePattern")
    musicGroupMember = URIRef("https://schema.org/musicGroupMember")
    studyDesign = URIRef("https://schema.org/studyDesign")
    TaxiReservation = URIRef("https://schema.org/TaxiReservation")
    PodcastSeries = URIRef("https://schema.org/PodcastSeries")
    recommendationStrength = URIRef("https://schema.org/recommendationStrength")
    imagingTechnique = URIRef("https://schema.org/imagingTechnique")
    Oncologic = URIRef("https://schema.org/Oncologic")
    variantCover = URIRef("https://schema.org/variantCover")
    WearableSizeGroupPetite = URIRef("https://schema.org/WearableSizeGroupPetite")
    EnergyConsumptionDetails = URIRef("https://schema.org/EnergyConsumptionDetails")
    urlTemplate = URIRef("https://schema.org/urlTemplate")
    SheetMusic = URIRef("https://schema.org/SheetMusic")
    OpeningHoursSpecification = URIRef("https://schema.org/OpeningHoursSpecification")
    additionalType = URIRef("https://schema.org/additionalType")
    mainContentOfPage = URIRef("https://schema.org/mainContentOfPage")
    isLiveBroadcast = URIRef("https://schema.org/isLiveBroadcast")
    vehicleModelDate = URIRef("https://schema.org/vehicleModelDate")
    SportsOrganization = URIRef("https://schema.org/SportsOrganization")
    HowToTool = URIRef("https://schema.org/HowToTool")
    longitude = URIRef("https://schema.org/longitude")
    arrivalGate = URIRef("https://schema.org/arrivalGate")
    EmployerAggregateRating = URIRef("https://schema.org/EmployerAggregateRating")
    polygon = URIRef("https://schema.org/polygon")
    WearableMeasurementChestOrBust = URIRef("https://schema.org/WearableMeasurementChestOrBust")
    arrivalBoatTerminal = URIRef("https://schema.org/arrivalBoatTerminal")
    measurementTechnique = URIRef("https://schema.org/measurementTechnique")
    dateReceived = URIRef("https://schema.org/dateReceived")
    executableLibraryName = URIRef("https://schema.org/executableLibraryName")
    inAlbum = URIRef("https://schema.org/inAlbum")
    HowOrWhereHealthAspect = URIRef("https://schema.org/HowOrWhereHealthAspect")
    MedicalIndication = URIRef("https://schema.org/MedicalIndication")
    isUnlabelledFallback = URIRef("https://schema.org/isUnlabelledFallback")
    iswcCode = URIRef("https://schema.org/iswcCode")
    Locksmith = URIRef("https://schema.org/Locksmith")
    BankOrCreditUnion = URIRef("https://schema.org/BankOrCreditUnion")
    cheatCode = URIRef("https://schema.org/cheatCode")
    signOrSymptom = URIRef("https://schema.org/signOrSymptom")
    legislationDateVersion = URIRef("https://schema.org/legislationDateVersion")
    priceComponentType = URIRef("https://schema.org/priceComponentType")
    archivedAt = URIRef("https://schema.org/archivedAt")
    mapType = URIRef("https://schema.org/mapType")
    taxonomicRange = URIRef("https://schema.org/taxonomicRange")
    ItemListOrderType = URIRef("https://schema.org/ItemListOrderType")
    gamePlatform = URIRef("https://schema.org/gamePlatform")
    mainEntityOfPage = URIRef("https://schema.org/mainEntityOfPage")
    medicineSystem = URIRef("https://schema.org/medicineSystem")
    ResultsAvailable = URIRef("https://schema.org/ResultsAvailable")
    returnLabelSource = URIRef("https://schema.org/returnLabelSource")
    actor = URIRef("https://schema.org/actor")
    isFamilyFriendly = URIRef("https://schema.org/isFamilyFriendly")
    vatID = URIRef("https://schema.org/vatID")
    additionalProperty = URIRef("https://schema.org/additionalProperty")
    SizeSpecification = URIRef("https://schema.org/SizeSpecification")
    workTranslation = URIRef("https://schema.org/workTranslation")
    broadcastSignalModulation = URIRef("https://schema.org/broadcastSignalModulation")
    Airport = URIRef("https://schema.org/Airport")
    legislationDate = URIRef("https://schema.org/legislationDate")
    UnincorporatedAssociationCharity = URIRef("https://schema.org/UnincorporatedAssociationCharity")
    Project = URIRef("https://schema.org/Project")
    expertConsiderations = URIRef("https://schema.org/expertConsiderations")
    CrossSectional = URIRef("https://schema.org/CrossSectional")
    MedicalSymptom = URIRef("https://schema.org/MedicalSymptom")
    Hardcover = URIRef("https://schema.org/Hardcover")
    OriginalMediaContent = URIRef("https://schema.org/OriginalMediaContent")
    InteractAction = URIRef("https://schema.org/InteractAction")
    releaseDate = URIRef("https://schema.org/releaseDate")
    AdvertiserContentArticle = URIRef("https://schema.org/AdvertiserContentArticle")
    LaserDiscFormat = URIRef("https://schema.org/LaserDiscFormat")
    ccRecipient = URIRef("https://schema.org/ccRecipient")
    inBroadcastLineup = URIRef("https://schema.org/inBroadcastLineup")
    illustrator = URIRef("https://schema.org/illustrator")
    primaryPrevention = URIRef("https://schema.org/primaryPrevention")
    MedicalContraindication = URIRef("https://schema.org/MedicalContraindication")
    UnemploymentSupport = URIRef("https://schema.org/UnemploymentSupport")
    loanPaymentFrequency = URIRef("https://schema.org/loanPaymentFrequency")
    actionPlatform = URIRef("https://schema.org/actionPlatform")
    eligibleTransactionVolume = URIRef("https://schema.org/eligibleTransactionVolume")
    SolveMathAction = URIRef("https://schema.org/SolveMathAction")
    competitor = URIRef("https://schema.org/competitor")
    usageInfo = URIRef("https://schema.org/usageInfo")
    contentRating = URIRef("https://schema.org/contentRating")
    geoIntersects = URIRef("https://schema.org/geoIntersects")
    BusinessEntityType = URIRef("https://schema.org/BusinessEntityType")
    stageAsNumber = URIRef("https://schema.org/stageAsNumber")
    childMaxAge = URIRef("https://schema.org/childMaxAge")
    GettingAccessHealthAspect = URIRef("https://schema.org/GettingAccessHealthAspect")
    Preschool = URIRef("https://schema.org/Preschool")
    ArchiveComponent = URIRef("https://schema.org/ArchiveComponent")
    aircraft = URIRef("https://schema.org/aircraft")
    CollegeOrUniversity = URIRef("https://schema.org/CollegeOrUniversity")
    WearableSizeSystemContinental = URIRef("https://schema.org/WearableSizeSystemContinental")
    paymentDue = URIRef("https://schema.org/paymentDue")
    Product = URIRef("https://schema.org/Product")
    adverseOutcome = URIRef("https://schema.org/adverseOutcome")
    PerformingArtsTheater = URIRef("https://schema.org/PerformingArtsTheater")
    billingDuration = URIRef("https://schema.org/billingDuration")
    ExerciseGym = URIRef("https://schema.org/ExerciseGym")
    MedicalAudience = URIRef("https://schema.org/MedicalAudience")
    availabilityStarts = URIRef("https://schema.org/availabilityStarts")
    populationType = URIRef("https://schema.org/populationType")
    vehicleTransmission = URIRef("https://schema.org/vehicleTransmission")
    APIReference = URIRef("https://schema.org/APIReference")
    valueRequired = URIRef("https://schema.org/valueRequired")
    diagnosis = URIRef("https://schema.org/diagnosis")
    LinkRole = URIRef("https://schema.org/LinkRole")
    diversityPolicy = URIRef("https://schema.org/diversityPolicy")
    recipeYield = URIRef("https://schema.org/recipeYield")
    broadcastServiceTier = URIRef("https://schema.org/broadcastServiceTier")
    infectiousAgentClass = URIRef("https://schema.org/infectiousAgentClass")
    DoseSchedule = URIRef("https://schema.org/DoseSchedule")
    muscleAction = URIRef("https://schema.org/muscleAction")
    WeaponConsideration = URIRef("https://schema.org/WeaponConsideration")
    ShareAction = URIRef("https://schema.org/ShareAction")
    MultiCenterTrial = URIRef("https://schema.org/MultiCenterTrial")
    Recruiting = URIRef("https://schema.org/Recruiting")
    affiliation = URIRef("https://schema.org/affiliation")
    pregnancyWarning = URIRef("https://schema.org/pregnancyWarning")
    totalJobOpenings = URIRef("https://schema.org/totalJobOpenings")
    priceCurrency = URIRef("https://schema.org/priceCurrency")
    MedicalImagingTechnique = URIRef("https://schema.org/MedicalImagingTechnique")
    MedicalRiskFactor = URIRef("https://schema.org/MedicalRiskFactor")
    Synagogue = URIRef("https://schema.org/Synagogue")
    query = URIRef("https://schema.org/query")
    connectedTo = URIRef("https://schema.org/connectedTo")
    healthPlanCostSharing = URIRef("https://schema.org/healthPlanCostSharing")
    measurementMethod = URIRef("https://schema.org/measurementMethod")
    numberOfBedrooms = URIRef("https://schema.org/numberOfBedrooms")
    HowTo = URIRef("https://schema.org/HowTo")
    driveWheelConfiguration = URIRef("https://schema.org/driveWheelConfiguration")
    TreatmentsHealthAspect = URIRef("https://schema.org/TreatmentsHealthAspect")
    correctionsPolicy = URIRef("https://schema.org/correctionsPolicy")
    Duration = URIRef("https://schema.org/Duration")
    predecessorOf = URIRef("https://schema.org/predecessorOf")
    returnShippingFeesAmount = URIRef("https://schema.org/returnShippingFeesAmount")
    energyEfficiencyScaleMax = URIRef("https://schema.org/energyEfficiencyScaleMax")
    CharitableIncorporatedOrganization = URIRef("https://schema.org/CharitableIncorporatedOrganization")
    agent = URIRef("https://schema.org/agent")
    sdDatePublished = URIRef("https://schema.org/sdDatePublished")
    currency = URIRef("https://schema.org/currency")
    SatireOrParodyContent = URIRef("https://schema.org/SatireOrParodyContent")
    bccRecipient = URIRef("https://schema.org/bccRecipient")
    PostalCodeRangeSpecification = URIRef("https://schema.org/PostalCodeRangeSpecification")
    WebContent = URIRef("https://schema.org/WebContent")
    imagingTechnique = URIRef("https://schema.org/imagingTechnique")
    hasCredential = URIRef("https://schema.org/hasCredential")
    firstPerformance = URIRef("https://schema.org/firstPerformance")
    repeatFrequency = URIRef("https://schema.org/repeatFrequency")
    cutoffTime = URIRef("https://schema.org/cutoffTime")
    recipeYield = URIRef("https://schema.org/recipeYield")
    WPSideBar = URIRef("https://schema.org/WPSideBar")
    suitableForDiet = URIRef("https://schema.org/suitableForDiet")
    PreventionIndication = URIRef("https://schema.org/PreventionIndication")
    schemaVersion = URIRef("https://schema.org/schemaVersion")
    hasMap = URIRef("https://schema.org/hasMap")
    CampingPitch = URIRef("https://schema.org/CampingPitch")
    GameServerStatus = URIRef("https://schema.org/GameServerStatus")
    alumni = URIRef("https://schema.org/alumni")
    isPartOfBioChemEntity = URIRef("https://schema.org/isPartOfBioChemEntity")
    PublicHealth = URIRef("https://schema.org/PublicHealth")
    ExampleMeasurementMethodEnum = URIRef("https://schema.org/ExampleMeasurementMethodEnum")
    cvdNumVentUse = URIRef("https://schema.org/cvdNumVentUse")
    associatedReview = URIRef("https://schema.org/associatedReview")
    legislationLegalValue = URIRef("https://schema.org/legislationLegalValue")
    hasDigitalDocumentPermission = URIRef("https://schema.org/hasDigitalDocumentPermission")
    audienceType = URIRef("https://schema.org/audienceType")
    NegativeFilmDigitalSource = URIRef("https://schema.org/NegativeFilmDigitalSource")
    earlyPrepaymentPenalty = URIRef("https://schema.org/earlyPrepaymentPenalty")
    WearableSizeGroupWomens = URIRef("https://schema.org/WearableSizeGroupWomens")
    size = URIRef("https://schema.org/size")
    DiscoverAction = URIRef("https://schema.org/DiscoverAction")
    endDate = URIRef("https://schema.org/endDate")
    ExhibitionEvent = URIRef("https://schema.org/ExhibitionEvent")
    merchant = URIRef("https://schema.org/merchant")
    containedIn = URIRef("https://schema.org/containedIn")
    parentItem = URIRef("https://schema.org/parentItem")
    width = URIRef("https://schema.org/width")
    storageRequirements = URIRef("https://schema.org/storageRequirements")
    engineType = URIRef("https://schema.org/engineType")
    cvdNumC19OverflowPats = URIRef("https://schema.org/cvdNumC19OverflowPats")
    MotorcycleDealer = URIRef("https://schema.org/MotorcycleDealer")
    Car = URIRef("https://schema.org/Car")
    suggestedAge = URIRef("https://schema.org/suggestedAge")
    isLiveBroadcast = URIRef("https://schema.org/isLiveBroadcast")
    Nonprofit501c21 = URIRef("https://schema.org/Nonprofit501c21")
    Question = URIRef("https://schema.org/Question")
    parentTaxon = URIRef("https://schema.org/parentTaxon")
    RsvpResponseYes = URIRef("https://schema.org/RsvpResponseYes")
    proteinContent = URIRef("https://schema.org/proteinContent")
    Thesis = URIRef("https://schema.org/Thesis")
    CreditCard = URIRef("https://schema.org/CreditCard")
    costCurrency = URIRef("https://schema.org/costCurrency")
    hasCourseInstance = URIRef("https://schema.org/hasCourseInstance")
    antagonist = URIRef("https://schema.org/antagonist")
    PositiveFilmDigitalSource = URIRef("https://schema.org/PositiveFilmDigitalSource")
    applicationSuite = URIRef("https://schema.org/applicationSuite")
    citation = URIRef("https://schema.org/citation")
    providerMobility = URIRef("https://schema.org/providerMobility")
    LendAction = URIRef("https://schema.org/LendAction")
    sugarContent = URIRef("https://schema.org/sugarContent")
    EntryPoint = URIRef("https://schema.org/EntryPoint")
    jobLocationType = URIRef("https://schema.org/jobLocationType")
    energyEfficiencyScaleMax = URIRef("https://schema.org/energyEfficiencyScaleMax")
    MusicVenue = URIRef("https://schema.org/MusicVenue")
    IPTCDigitalSourceEnumeration = URIRef("https://schema.org/IPTCDigitalSourceEnumeration")
    priceValidUntil = URIRef("https://schema.org/priceValidUntil")
    FDAcategoryB = URIRef("https://schema.org/FDAcategoryB")
    ReturnFeesEnumeration = URIRef("https://schema.org/ReturnFeesEnumeration")
    linkRelationship = URIRef("https://schema.org/linkRelationship")
    energyEfficiencyScaleMin = URIRef("https://schema.org/energyEfficiencyScaleMin")
    speed = URIRef("https://schema.org/speed")
    DigitalArtDigitalSource = URIRef("https://schema.org/DigitalArtDigitalSource")
    maximumIntake = URIRef("https://schema.org/maximumIntake")
    priceComponentType = URIRef("https://schema.org/priceComponentType")
    suggestedMinAge = URIRef("https://schema.org/suggestedMinAge")
    geoOverlaps = URIRef("https://schema.org/geoOverlaps")
    Enumeration = URIRef("https://schema.org/Enumeration")
    applicableCountry = URIRef("https://schema.org/applicableCountry")
    LiveBlogPosting = URIRef("https://schema.org/LiveBlogPosting")
    EUEnergyEfficiencyCategoryA2Plus = URIRef("https://schema.org/EUEnergyEfficiencyCategoryA2Plus")
    exchangeRateSpread = URIRef("https://schema.org/exchangeRateSpread")
    applicableCountry = URIRef("https://schema.org/applicableCountry")
    openingHours = URIRef("https://schema.org/openingHours")
    measurementMethod = URIRef("https://schema.org/measurementMethod")
    repeatFrequency = URIRef("https://schema.org/repeatFrequency")
    warning = URIRef("https://schema.org/warning")
    audience = URIRef("https://schema.org/audience")
    ReturnAction = URIRef("https://schema.org/ReturnAction")
    relatedTherapy = URIRef("https://schema.org/relatedTherapy")
    contactOption = URIRef("https://schema.org/contactOption")
    customerRemorseReturnFees = URIRef("https://schema.org/customerRemorseReturnFees")
    pagination = URIRef("https://schema.org/pagination")
    Product = URIRef("https://schema.org/Product")
    Gynecologic = URIRef("https://schema.org/Gynecologic")
    measurementTechnique = URIRef("https://schema.org/measurementTechnique")
    BusOrCoach = URIRef("https://schema.org/BusOrCoach")
    ArtGallery = URIRef("https://schema.org/ArtGallery")
    hasHealthAspect = URIRef("https://schema.org/hasHealthAspect")
    legislationDate = URIRef("https://schema.org/legislationDate")
    serviceLocation = URIRef("https://schema.org/serviceLocation")
    geoMidpoint = URIRef("https://schema.org/geoMidpoint")
    ComputerLanguage = URIRef("https://schema.org/ComputerLanguage")
    drug = URIRef("https://schema.org/drug")
    artist = URIRef("https://schema.org/artist")
    includesObject = URIRef("https://schema.org/includesObject")
    netWorth = URIRef("https://schema.org/netWorth")
    beneficiaryBank = URIRef("https://schema.org/beneficiaryBank")
    cvdNumC19OverflowPats = URIRef("https://schema.org/cvdNumC19OverflowPats")
    audio = URIRef("https://schema.org/audio")
    deliveryLeadTime = URIRef("https://schema.org/deliveryLeadTime")
    agentInteractionStatistic = URIRef("https://schema.org/agentInteractionStatistic")
    PaintAction = URIRef("https://schema.org/PaintAction")
    Seat = URIRef("https://schema.org/Seat")
    confirmationNumber = URIRef("https://schema.org/confirmationNumber")
    assembly = URIRef("https://schema.org/assembly")
    accommodationCategory = URIRef("https://schema.org/accommodationCategory")
    LegislativeBuilding = URIRef("https://schema.org/LegislativeBuilding")
    albumRelease = URIRef("https://schema.org/albumRelease")
    yearlyRevenue = URIRef("https://schema.org/yearlyRevenue")
    ExampleMeasurementMethodEnum = URIRef("https://schema.org/ExampleMeasurementMethodEnum")
    WearableSizeGroupBoys = URIRef("https://schema.org/WearableSizeGroupBoys")
    startDate = URIRef("https://schema.org/startDate")
    usageInfo = URIRef("https://schema.org/usageInfo")
    hasMeasurement = URIRef("https://schema.org/hasMeasurement")
    WebApplication = URIRef("https://schema.org/WebApplication")
    PlaceboControlledTrial = URIRef("https://schema.org/PlaceboControlledTrial")
    colorSwatch = URIRef("https://schema.org/colorSwatch")
    responsibilities = URIRef("https://schema.org/responsibilities")
    reviewRating = URIRef("https://schema.org/reviewRating")
    DiscussionForumPosting = URIRef("https://schema.org/DiscussionForumPosting")
    Seat = URIRef("https://schema.org/Seat")
    repeatCount = URIRef("https://schema.org/repeatCount")
    clincalPharmacology = URIRef("https://schema.org/clincalPharmacology")
    healthPlanDrugTier = URIRef("https://schema.org/healthPlanDrugTier")
    constraintProperty = URIRef("https://schema.org/constraintProperty")
    variableMeasured = URIRef("https://schema.org/variableMeasured")
    HinduTemple = URIRef("https://schema.org/HinduTemple")
    educationalProgramMode = URIRef("https://schema.org/educationalProgramMode")
    hasMolecularFunction = URIRef("https://schema.org/hasMolecularFunction")
    restockingFee = URIRef("https://schema.org/restockingFee")
    RefundTypeEnumeration = URIRef("https://schema.org/RefundTypeEnumeration")
    vehicleModelDate = URIRef("https://schema.org/vehicleModelDate")
    warning = URIRef("https://schema.org/warning")
    benefitsSummaryUrl = URIRef("https://schema.org/benefitsSummaryUrl")
    StatisticalPopulation = URIRef("https://schema.org/StatisticalPopulation")
    httpMethod = URIRef("https://schema.org/httpMethod")
    procedure = URIRef("https://schema.org/procedure")
    MusicRecording = URIRef("https://schema.org/MusicRecording")
    participant = URIRef("https://schema.org/participant")
    category = URIRef("https://schema.org/category")
    review = URIRef("https://schema.org/review")
    LoseAction = URIRef("https://schema.org/LoseAction")
    healthPlanCoinsuranceRate = URIRef("https://schema.org/healthPlanCoinsuranceRate")
    subTrip = URIRef("https://schema.org/subTrip")
    license = URIRef("https://schema.org/license")
    LivingWithHealthAspect = URIRef("https://schema.org/LivingWithHealthAspect")
    gtin14 = URIRef("https://schema.org/gtin14")
    ChemicalSubstance = URIRef("https://schema.org/ChemicalSubstance")
    BrainStructure = URIRef("https://schema.org/BrainStructure")
    opponent = URIRef("https://schema.org/opponent")
    BroadcastRelease = URIRef("https://schema.org/BroadcastRelease")
    valueReference = URIRef("https://schema.org/valueReference")
    includesAttraction = URIRef("https://schema.org/includesAttraction")
    ProfilePage = URIRef("https://schema.org/ProfilePage")
    nonprofitStatus = URIRef("https://schema.org/nonprofitStatus")
    Bone = URIRef("https://schema.org/Bone")
    doseValue = URIRef("https://schema.org/doseValue")
    interactionType = URIRef("https://schema.org/interactionType")
    comprisedOf = URIRef("https://schema.org/comprisedOf")
    percentile75 = URIRef("https://schema.org/percentile75")
    serviceArea = URIRef("https://schema.org/serviceArea")
    isSimilarTo = URIRef("https://schema.org/isSimilarTo")
    PhysicalExam = URIRef("https://schema.org/PhysicalExam")
    episodes = URIRef("https://schema.org/episodes")
    blogPost = URIRef("https://schema.org/blogPost")
    CommunicateAction = URIRef("https://schema.org/CommunicateAction")
    molecularFormula = URIRef("https://schema.org/molecularFormula")
    AlgorithmicMediaDigitalSource = URIRef("https://schema.org/AlgorithmicMediaDigitalSource")
    collection = URIRef("https://schema.org/collection")
    map = URIRef("https://schema.org/map")
    WearableMeasurementHeight = URIRef("https://schema.org/WearableMeasurementHeight")
    Lung = URIRef("https://schema.org/Lung")
    Pond = URIRef("https://schema.org/Pond")
    MaximumDoseSchedule = URIRef("https://schema.org/MaximumDoseSchedule")
    discussionUrl = URIRef("https://schema.org/discussionUrl")
    VideoGallery = URIRef("https://schema.org/VideoGallery")
    Nonprofit501k = URIRef("https://schema.org/Nonprofit501k")
    mechanismOfAction = URIRef("https://schema.org/mechanismOfAction")
    LowFatDiet = URIRef("https://schema.org/LowFatDiet")
    WebAPI = URIRef("https://schema.org/WebAPI")
    partOfOrder = URIRef("https://schema.org/partOfOrder")
    defaultValue = URIRef("https://schema.org/defaultValue")
    runtimePlatform = URIRef("https://schema.org/runtimePlatform")
    EducationalOccupationalProgram = URIRef("https://schema.org/EducationalOccupationalProgram")
    includesHealthPlanFormulary = URIRef("https://schema.org/includesHealthPlanFormulary")
    LivingWithHealthAspect = URIRef("https://schema.org/LivingWithHealthAspect")
    MedicalTest = URIRef("https://schema.org/MedicalTest")
    ReportedDoseSchedule = URIRef("https://schema.org/ReportedDoseSchedule")
    eligibleTransactionVolume = URIRef("https://schema.org/eligibleTransactionVolume")
    steps = URIRef("https://schema.org/steps")
    issueNumber = URIRef("https://schema.org/issueNumber")
    BioChemEntity = URIRef("https://schema.org/BioChemEntity")
    PlayAction = URIRef("https://schema.org/PlayAction")
    loanType = URIRef("https://schema.org/loanType")
    securityScreening = URIRef("https://schema.org/securityScreening")
    textValue = URIRef("https://schema.org/textValue")
    warrantyPromise = URIRef("https://schema.org/warrantyPromise")
    validThrough = URIRef("https://schema.org/validThrough")
    albumProductionType = URIRef("https://schema.org/albumProductionType")
    RsvpResponseMaybe = URIRef("https://schema.org/RsvpResponseMaybe")
    membershipPointsEarned = URIRef("https://schema.org/membershipPointsEarned")
    costCurrency = URIRef("https://schema.org/costCurrency")
    gtin = URIRef("https://schema.org/gtin")
    RestockingFees = URIRef("https://schema.org/RestockingFees")
    customerRemorseReturnLabelSource = URIRef("https://schema.org/customerRemorseReturnLabelSource")
    operatingSystem = URIRef("https://schema.org/operatingSystem")
    holdingArchive = URIRef("https://schema.org/holdingArchive")
    claimInterpreter = URIRef("https://schema.org/claimInterpreter")
    SizeSystemMetric = URIRef("https://schema.org/SizeSystemMetric")
    requirements = URIRef("https://schema.org/requirements")
    addressRegion = URIRef("https://schema.org/addressRegion")
    editor = URIRef("https://schema.org/editor")
    Head = URIRef("https://schema.org/Head")
    missionCoveragePrioritiesPolicy = URIRef("https://schema.org/missionCoveragePrioritiesPolicy")
    hasOccupation = URIRef("https://schema.org/hasOccupation")
    articleBody = URIRef("https://schema.org/articleBody")
    InForce = URIRef("https://schema.org/InForce")
    refundType = URIRef("https://schema.org/refundType")
    muscleAction = URIRef("https://schema.org/muscleAction")
    AdultOrientedEnumeration = URIRef("https://schema.org/AdultOrientedEnumeration")
    Place = URIRef("https://schema.org/Place")
    Residence = URIRef("https://schema.org/Residence")
    Neck = URIRef("https://schema.org/Neck")
    ReducedRelevanceForChildrenConsideration = URIRef("https://schema.org/ReducedRelevanceForChildrenConsideration")
    jobLocationType = URIRef("https://schema.org/jobLocationType")
    availableAtOrFrom = URIRef("https://schema.org/availableAtOrFrom")
    WearableSizeSystemCN = URIRef("https://schema.org/WearableSizeSystemCN")
    legislationConsolidates = URIRef("https://schema.org/legislationConsolidates")
    startOffset = URIRef("https://schema.org/startOffset")
    actors = URIRef("https://schema.org/actors")
    originalMediaLink = URIRef("https://schema.org/originalMediaLink")
    numberOfAccommodationUnits = URIRef("https://schema.org/numberOfAccommodationUnits")
    acquireLicensePage = URIRef("https://schema.org/acquireLicensePage")
    subTrip = URIRef("https://schema.org/subTrip")
    sha256 = URIRef("https://schema.org/sha256")
    PublicToilet = URIRef("https://schema.org/PublicToilet")
    postalCodeRange = URIRef("https://schema.org/postalCodeRange")
    artEdition = URIRef("https://schema.org/artEdition")
    codingSystem = URIRef("https://schema.org/codingSystem")
    embeddedTextCaption = URIRef("https://schema.org/embeddedTextCaption")
    AudioObjectSnapshot = URIRef("https://schema.org/AudioObjectSnapshot")
    RealEstateListing = URIRef("https://schema.org/RealEstateListing")
    CancelAction = URIRef("https://schema.org/CancelAction")
    payload = URIRef("https://schema.org/payload")
    funding = URIRef("https://schema.org/funding")
    includesAttraction = URIRef("https://schema.org/includesAttraction")
    value = URIRef("https://schema.org/value")
    cvdFacilityCounty = URIRef("https://schema.org/cvdFacilityCounty")
    yearsInOperation = URIRef("https://schema.org/yearsInOperation")
    SizeGroupEnumeration = URIRef("https://schema.org/SizeGroupEnumeration")
    TrainTrip = URIRef("https://schema.org/TrainTrip")
    Legislation = URIRef("https://schema.org/Legislation")
    videoQuality = URIRef("https://schema.org/videoQuality")
    PsychologicalTreatment = URIRef("https://schema.org/PsychologicalTreatment")
    exerciseType = URIRef("https://schema.org/exerciseType")
    OverviewHealthAspect = URIRef("https://schema.org/OverviewHealthAspect")
    jobStartDate = URIRef("https://schema.org/jobStartDate")
    WarrantyScope = URIRef("https://schema.org/WarrantyScope")
    industry = URIRef("https://schema.org/industry")
    exampleOfWork = URIRef("https://schema.org/exampleOfWork")
    loanMortgageMandateAmount = URIRef("https://schema.org/loanMortgageMandateAmount")
    arrivalGate = URIRef("https://schema.org/arrivalGate")
    Reservation = URIRef("https://schema.org/Reservation")
    duns = URIRef("https://schema.org/duns")
    mainContentOfPage = URIRef("https://schema.org/mainContentOfPage")
    nsn = URIRef("https://schema.org/nsn")
    dateline = URIRef("https://schema.org/dateline")
    CorrectionComment = URIRef("https://schema.org/CorrectionComment")
    dataFeedElement = URIRef("https://schema.org/dataFeedElement")
    cvdNumBedsOcc = URIRef("https://schema.org/cvdNumBedsOcc")
    EnergyConsumptionDetails = URIRef("https://schema.org/EnergyConsumptionDetails")
    maximumVirtualAttendeeCapacity = URIRef("https://schema.org/maximumVirtualAttendeeCapacity")
    OverviewHealthAspect = URIRef("https://schema.org/OverviewHealthAspect")
    estimatedSalary = URIRef("https://schema.org/estimatedSalary")
    applicantLocationRequirements = URIRef("https://schema.org/applicantLocationRequirements")
    Recommendation = URIRef("https://schema.org/Recommendation")
    HinduDiet = URIRef("https://schema.org/HinduDiet")
    TaxiStand = URIRef("https://schema.org/TaxiStand")
    video = URIRef("https://schema.org/video")
    measurementMethod = URIRef("https://schema.org/measurementMethod")
    inDefinedTermSet = URIRef("https://schema.org/inDefinedTermSet")
    HowToTool = URIRef("https://schema.org/HowToTool")
    Diet = URIRef("https://schema.org/Diet")
    postOp = URIRef("https://schema.org/postOp")
    clinicalPharmacology = URIRef("https://schema.org/clinicalPharmacology")
    additionalVariable = URIRef("https://schema.org/additionalVariable")
    numberOfBedrooms = URIRef("https://schema.org/numberOfBedrooms")
    syllabusSections = URIRef("https://schema.org/syllabusSections")
    legislationResponsible = URIRef("https://schema.org/legislationResponsible")
    jobLocationType = URIRef("https://schema.org/jobLocationType")
    trailer = URIRef("https://schema.org/trailer")
    CorrectionComment = URIRef("https://schema.org/CorrectionComment")
    childTaxon = URIRef("https://schema.org/childTaxon")
    handlingTime = URIRef("https://schema.org/handlingTime")
    containedInPlace = URIRef("https://schema.org/containedInPlace")
    Airport = URIRef("https://schema.org/Airport")
    associatedArticle = URIRef("https://schema.org/associatedArticle")
    bccRecipient = URIRef("https://schema.org/bccRecipient")
    Motel = URIRef("https://schema.org/Motel")
    Question = URIRef("https://schema.org/Question")
    associatedDisease = URIRef("https://schema.org/associatedDisease")
    PeopleAudience = URIRef("https://schema.org/PeopleAudience")
    mediaAuthenticityCategory = URIRef("https://schema.org/mediaAuthenticityCategory")
    measurementQualifier = URIRef("https://schema.org/measurementQualifier")
    diagnosis = URIRef("https://schema.org/diagnosis")
    Barcode = URIRef("https://schema.org/Barcode")
    wordCount = URIRef("https://schema.org/wordCount")
    isInvolvedInBiologicalProcess = URIRef("https://schema.org/isInvolvedInBiologicalProcess")
    usesHealthPlanIdStandard = URIRef("https://schema.org/usesHealthPlanIdStandard")
    category = URIRef("https://schema.org/category")
    MedicalDevice = URIRef("https://schema.org/MedicalDevice")
    netWorth = URIRef("https://schema.org/netWorth")
    season = URIRef("https://schema.org/season")
    sugarContent = URIRef("https://schema.org/sugarContent")
    reviewRating = URIRef("https://schema.org/reviewRating")
    Nerve = URIRef("https://schema.org/Nerve")
    ExchangeRateSpecification = URIRef("https://schema.org/ExchangeRateSpecification")
    CheckInAction = URIRef("https://schema.org/CheckInAction")
    FundingAgency = URIRef("https://schema.org/FundingAgency")
    printPage = URIRef("https://schema.org/printPage")
    LinkRole = URIRef("https://schema.org/LinkRole")
    HowToSupply = URIRef("https://schema.org/HowToSupply")
    isFamilyFriendly = URIRef("https://schema.org/isFamilyFriendly")
    textValue = URIRef("https://schema.org/textValue")
    priceComponent = URIRef("https://schema.org/priceComponent")
    copyrightNotice = URIRef("https://schema.org/copyrightNotice")
    SizeSpecification = URIRef("https://schema.org/SizeSpecification")
    illustrator = URIRef("https://schema.org/illustrator")
    marginOfError = URIRef("https://schema.org/marginOfError")
    HealthPlanCostSharingSpecification = URIRef("https://schema.org/HealthPlanCostSharingSpecification")
    amountOfThisGood = URIRef("https://schema.org/amountOfThisGood")
    ReturnByMail = URIRef("https://schema.org/ReturnByMail")
    HowToSection = URIRef("https://schema.org/HowToSection")
    priceValidUntil = URIRef("https://schema.org/priceValidUntil")
    legislationType = URIRef("https://schema.org/legislationType")
    actors = URIRef("https://schema.org/actors")
    validFor = URIRef("https://schema.org/validFor")
    steps = URIRef("https://schema.org/steps")
    Drug = URIRef("https://schema.org/Drug")
    ProductGroup = URIRef("https://schema.org/ProductGroup")
    recipe = URIRef("https://schema.org/recipe")
    significance = URIRef("https://schema.org/significance")
    vehicleIdentificationNumber = URIRef("https://schema.org/vehicleIdentificationNumber")
    expectedArrivalFrom = URIRef("https://schema.org/expectedArrivalFrom")
    Bone = URIRef("https://schema.org/Bone")
    accessibilityHazard = URIRef("https://schema.org/accessibilityHazard")
    Church = URIRef("https://schema.org/Church")
    biomechnicalClass = URIRef("https://schema.org/biomechnicalClass")
    Time = URIRef("https://schema.org/Time")
    StatisticalPopulation = URIRef("https://schema.org/StatisticalPopulation")
    SizeSystemImperial = URIRef("https://schema.org/SizeSystemImperial")
    originAddress = URIRef("https://schema.org/originAddress")
    FilmAction = URIRef("https://schema.org/FilmAction")
    MisconceptionsHealthAspect = URIRef("https://schema.org/MisconceptionsHealthAspect")
    programType = URIRef("https://schema.org/programType")
    speakable = URIRef("https://schema.org/speakable")
    claimInterpreter = URIRef("https://schema.org/claimInterpreter")
    ToyStore = URIRef("https://schema.org/ToyStore")
    ParcelDelivery = URIRef("https://schema.org/ParcelDelivery")
    price = URIRef("https://schema.org/price")
    ProductGroup = URIRef("https://schema.org/ProductGroup")
    ReturnLabelDownloadAndPrint = URIRef("https://schema.org/ReturnLabelDownloadAndPrint")
    BoatReservation = URIRef("https://schema.org/BoatReservation")
    inChI = URIRef("https://schema.org/inChI")
    hasDigitalDocumentPermission = URIRef("https://schema.org/hasDigitalDocumentPermission")
    availableChannel = URIRef("https://schema.org/availableChannel")
    prepTime = URIRef("https://schema.org/prepTime")
    unsaturatedFatContent = URIRef("https://schema.org/unsaturatedFatContent")
    upvoteCount = URIRef("https://schema.org/upvoteCount")
    hasMeasurement = URIRef("https://schema.org/hasMeasurement")
    passengerPriorityStatus = URIRef("https://schema.org/passengerPriorityStatus")
    AdvertiserContentArticle = URIRef("https://schema.org/AdvertiserContentArticle")
    applicationCategory = URIRef("https://schema.org/applicationCategory")
    sdLicense = URIRef("https://schema.org/sdLicense")
    LowSaltDiet = URIRef("https://schema.org/LowSaltDiet")
    bankAccountType = URIRef("https://schema.org/bankAccountType")
    exifData = URIRef("https://schema.org/exifData")
    renegotiableLoan = URIRef("https://schema.org/renegotiableLoan")
    brand = URIRef("https://schema.org/brand")
    WebApplication = URIRef("https://schema.org/WebApplication")
    childTaxon = URIRef("https://schema.org/childTaxon")
    ReceiveAction = URIRef("https://schema.org/ReceiveAction")
    MinimumAdvertisedPrice = URIRef("https://schema.org/MinimumAdvertisedPrice")
    requiredCollateral = URIRef("https://schema.org/requiredCollateral")
    WearableMeasurementInseam = URIRef("https://schema.org/WearableMeasurementInseam")
    numberOfAvailableAccommodationUnits = URIRef("https://schema.org/numberOfAvailableAccommodationUnits")
    relatedTo = URIRef("https://schema.org/relatedTo")
    EUEnergyEfficiencyCategoryA1Plus = URIRef("https://schema.org/EUEnergyEfficiencyCategoryA1Plus")
    BookStore = URIRef("https://schema.org/BookStore")
    lodgingUnitType = URIRef("https://schema.org/lodgingUnitType")
    director = URIRef("https://schema.org/director")
    vehicleSpecialUsage = URIRef("https://schema.org/vehicleSpecialUsage")
    feesAndCommissionsSpecification = URIRef("https://schema.org/feesAndCommissionsSpecification")
    positiveNotes = URIRef("https://schema.org/positiveNotes")
    seatingCapacity = URIRef("https://schema.org/seatingCapacity")
    typeOfBed = URIRef("https://schema.org/typeOfBed")
    hiringOrganization = URIRef("https://schema.org/hiringOrganization")
    labelDetails = URIRef("https://schema.org/labelDetails")
    athlete = URIRef("https://schema.org/athlete")
    deliveryMethod = URIRef("https://schema.org/deliveryMethod")
    causeOf = URIRef("https://schema.org/causeOf")
    trailer = URIRef("https://schema.org/trailer")
    cutoffTime = URIRef("https://schema.org/cutoffTime")
    actors = URIRef("https://schema.org/actors")
    recipient = URIRef("https://schema.org/recipient")
    cargoVolume = URIRef("https://schema.org/cargoVolume")
    LowLactoseDiet = URIRef("https://schema.org/LowLactoseDiet")
    Nonprofit527 = URIRef("https://schema.org/Nonprofit527")
    arterialBranch = URIRef("https://schema.org/arterialBranch")
    TechArticle = URIRef("https://schema.org/TechArticle")
    UserLikes = URIRef("https://schema.org/UserLikes")
    organizer = URIRef("https://schema.org/organizer")
    sibling = URIRef("https://schema.org/sibling")
    MixedEventAttendanceMode = URIRef("https://schema.org/MixedEventAttendanceMode")
    itemDefectReturnShippingFeesAmount = URIRef("https://schema.org/itemDefectReturnShippingFeesAmount")
    name = URIRef("https://schema.org/name")
    OnSitePickup = URIRef("https://schema.org/OnSitePickup")
    HowItWorksHealthAspect = URIRef("https://schema.org/HowItWorksHealthAspect")
    longitude = URIRef("https://schema.org/longitude")
    workload = URIRef("https://schema.org/workload")
    cvdNumC19HOPats = URIRef("https://schema.org/cvdNumC19HOPats")
    deathDate = URIRef("https://schema.org/deathDate")
    MedicalSign = URIRef("https://schema.org/MedicalSign")
    BenefitsHealthAspect = URIRef("https://schema.org/BenefitsHealthAspect")
    DisagreeAction = URIRef("https://schema.org/DisagreeAction")
    courseSchedule = URIRef("https://schema.org/courseSchedule")
    gender = URIRef("https://schema.org/gender")
    departureBusStop = URIRef("https://schema.org/departureBusStop")
    PrescriptionOnly = URIRef("https://schema.org/PrescriptionOnly")
    includedInHealthInsurancePlan = URIRef("https://schema.org/includedInHealthInsurancePlan")
    epidemiology = URIRef("https://schema.org/epidemiology")
    PaymentComplete = URIRef("https://schema.org/PaymentComplete")
    FailedActionStatus = URIRef("https://schema.org/FailedActionStatus")
    bookingTime = URIRef("https://schema.org/bookingTime")
    LiquorStore = URIRef("https://schema.org/LiquorStore")
    vehicleInteriorType = URIRef("https://schema.org/vehicleInteriorType")
    originalMediaLink = URIRef("https://schema.org/originalMediaLink")
    bloodSupply = URIRef("https://schema.org/bloodSupply")
    MedicalEntity = URIRef("https://schema.org/MedicalEntity")
    deliveryStatus = URIRef("https://schema.org/deliveryStatus")
    ScheduleAction = URIRef("https://schema.org/ScheduleAction")
    trackingNumber = URIRef("https://schema.org/trackingNumber")
    potentialUse = URIRef("https://schema.org/potentialUse")
    gracePeriod = URIRef("https://schema.org/gracePeriod")
    audio = URIRef("https://schema.org/audio")
    Intangible = URIRef("https://schema.org/Intangible")
    ImagingTest = URIRef("https://schema.org/ImagingTest")
    geoContains = URIRef("https://schema.org/geoContains")
    member = URIRef("https://schema.org/member")
    namedPosition = URIRef("https://schema.org/namedPosition")
    Person = URIRef("https://schema.org/Person")
    CohortStudy = URIRef("https://schema.org/CohortStudy")
    VoteAction = URIRef("https://schema.org/VoteAction")
    diseaseSpreadStatistics = URIRef("https://schema.org/diseaseSpreadStatistics")
    programMembershipUsed = URIRef("https://schema.org/programMembershipUsed")
    datePosted = URIRef("https://schema.org/datePosted")
    BrokerageAccount = URIRef("https://schema.org/BrokerageAccount")
    sportsTeam = URIRef("https://schema.org/sportsTeam")
    datePublished = URIRef("https://schema.org/datePublished")
    device = URIRef("https://schema.org/device")
    actor = URIRef("https://schema.org/actor")
    Energy = URIRef("https://schema.org/Energy")
    trailer = URIRef("https://schema.org/trailer")
    attendee = URIRef("https://schema.org/attendee")
    legislationChanges = URIRef("https://schema.org/legislationChanges")
    SteeringPositionValue = URIRef("https://schema.org/SteeringPositionValue")
    chemicalComposition = URIRef("https://schema.org/chemicalComposition")
    geoTouches = URIRef("https://schema.org/geoTouches")
    copyrightNotice = URIRef("https://schema.org/copyrightNotice")
    priceType = URIRef("https://schema.org/priceType")
    hasDeliveryMethod = URIRef("https://schema.org/hasDeliveryMethod")
    MedicalEntity = URIRef("https://schema.org/MedicalEntity")
    teaches = URIRef("https://schema.org/teaches")
    mobileUrl = URIRef("https://schema.org/mobileUrl")
    increasesRiskOf = URIRef("https://schema.org/increasesRiskOf")
    intensity = URIRef("https://schema.org/intensity")
    EmployerReview = URIRef("https://schema.org/EmployerReview")
    birthPlace = URIRef("https://schema.org/birthPlace")
    TransformedContent = URIRef("https://schema.org/TransformedContent")
    hasMolecularFunction = URIRef("https://schema.org/hasMolecularFunction")
    Answer = URIRef("https://schema.org/Answer")
    embeddedTextCaption = URIRef("https://schema.org/embeddedTextCaption")
    freeShippingThreshold = URIRef("https://schema.org/freeShippingThreshold")
    maximumIntake = URIRef("https://schema.org/maximumIntake")
    gtin8 = URIRef("https://schema.org/gtin8")
    engineType = URIRef("https://schema.org/engineType")
    equal = URIRef("https://schema.org/equal")
    additionalType = URIRef("https://schema.org/additionalType")
    WearableMeasurementLength = URIRef("https://schema.org/WearableMeasurementLength")
    address = URIRef("https://schema.org/address")
    Protozoa = URIRef("https://schema.org/Protozoa")
    replacee = URIRef("https://schema.org/replacee")
    description = URIRef("https://schema.org/description")
    directors = URIRef("https://schema.org/directors")
    mediaItemAppearance = URIRef("https://schema.org/mediaItemAppearance")
    CafeOrCoffeeShop = URIRef("https://schema.org/CafeOrCoffeeShop")
    OfferCatalog = URIRef("https://schema.org/OfferCatalog")
    vendor = URIRef("https://schema.org/vendor")
    Manuscript = URIRef("https://schema.org/Manuscript")
    Landform = URIRef("https://schema.org/Landform")
    MedicalEnumeration = URIRef("https://schema.org/MedicalEnumeration")
    MedicalCause = URIRef("https://schema.org/MedicalCause")
    beforeMedia = URIRef("https://schema.org/beforeMedia")
    customerRemorseReturnLabelSource = URIRef("https://schema.org/customerRemorseReturnLabelSource")
    gtin13 = URIRef("https://schema.org/gtin13")
    competencyRequired = URIRef("https://schema.org/competencyRequired")
    Quotation = URIRef("https://schema.org/Quotation")
    Nonprofit501f = URIRef("https://schema.org/Nonprofit501f")
    domainIncludes = URIRef("https://schema.org/domainIncludes")
    employmentUnit = URIRef("https://schema.org/employmentUnit")
    DistanceFee = URIRef("https://schema.org/DistanceFee")
    musicGroupMember = URIRef("https://schema.org/musicGroupMember")
    orderItemStatus = URIRef("https://schema.org/orderItemStatus")
    WPAdBlock = URIRef("https://schema.org/WPAdBlock")
    Offer = URIRef("https://schema.org/Offer")
    member = URIRef("https://schema.org/member")
    arrivalBusStop = URIRef("https://schema.org/arrivalBusStop")
    broadcastChannelId = URIRef("https://schema.org/broadcastChannelId")
    PostalAddress = URIRef("https://schema.org/PostalAddress")
    usedToDiagnose = URIRef("https://schema.org/usedToDiagnose")
    hasMap = URIRef("https://schema.org/hasMap")
    seeks = URIRef("https://schema.org/seeks")
    UnofficialLegalValue = URIRef("https://schema.org/UnofficialLegalValue")
    pregnancyCategory = URIRef("https://schema.org/pregnancyCategory")
    drugClass = URIRef("https://schema.org/drugClass")
    ViolenceConsideration = URIRef("https://schema.org/ViolenceConsideration")
    geoTouches = URIRef("https://schema.org/geoTouches")
    area = URIRef("https://schema.org/area")
    IOSPlatform = URIRef("https://schema.org/IOSPlatform")
    Musculoskeletal = URIRef("https://schema.org/Musculoskeletal")
    Person = URIRef("https://schema.org/Person")
    screenshot = URIRef("https://schema.org/screenshot")
    associatedAnatomy = URIRef("https://schema.org/associatedAnatomy")
    VisualArtwork = URIRef("https://schema.org/VisualArtwork")
    measurementMethod = URIRef("https://schema.org/measurementMethod")
    OfficeEquipmentStore = URIRef("https://schema.org/OfficeEquipmentStore")
    ownedThrough = URIRef("https://schema.org/ownedThrough")
    estimatedCost = URIRef("https://schema.org/estimatedCost")
    statType = URIRef("https://schema.org/statType")
    followup = URIRef("https://schema.org/followup")
    House = URIRef("https://schema.org/House")
    memoryRequirements = URIRef("https://schema.org/memoryRequirements")
    founders = URIRef("https://schema.org/founders")
    hasPart = URIRef("https://schema.org/hasPart")
    unsaturatedFatContent = URIRef("https://schema.org/unsaturatedFatContent")
    accessibilityFeature = URIRef("https://schema.org/accessibilityFeature")
    FilmAction = URIRef("https://schema.org/FilmAction")
    lodgingUnitType = URIRef("https://schema.org/lodgingUnitType")
    TipAction = URIRef("https://schema.org/TipAction")
    ItemAvailability = URIRef("https://schema.org/ItemAvailability")
    AnimalShelter = URIRef("https://schema.org/AnimalShelter")
    lyricist = URIRef("https://schema.org/lyricist")
    interpretedAsClaim = URIRef("https://schema.org/interpretedAsClaim")
    offeredBy = URIRef("https://schema.org/offeredBy")
    publishedBy = URIRef("https://schema.org/publishedBy")
    ComicIssue = URIRef("https://schema.org/ComicIssue")
    availableOnDevice = URIRef("https://schema.org/availableOnDevice")
    geoCoveredBy = URIRef("https://schema.org/geoCoveredBy")
    surface = URIRef("https://schema.org/surface")
    director = URIRef("https://schema.org/director")
    DemoAlbum = URIRef("https://schema.org/DemoAlbum")
    seasonNumber = URIRef("https://schema.org/seasonNumber")
    recordedAt = URIRef("https://schema.org/recordedAt")
    discountCode = URIRef("https://schema.org/discountCode")
    isBasedOn = URIRef("https://schema.org/isBasedOn")
    availableThrough = URIRef("https://schema.org/availableThrough")
    composer = URIRef("https://schema.org/composer")
    Series = URIRef("https://schema.org/Series")
    cvdNumVent = URIRef("https://schema.org/cvdNumVent")
    MusicReleaseFormatType = URIRef("https://schema.org/MusicReleaseFormatType")
    fileFormat = URIRef("https://schema.org/fileFormat")
    itemLocation = URIRef("https://schema.org/itemLocation")
    itemLocation = URIRef("https://schema.org/itemLocation")
    deliveryAddress = URIRef("https://schema.org/deliveryAddress")
    cvdNumC19HOPats = URIRef("https://schema.org/cvdNumC19HOPats")
    hasBioChemEntityPart = URIRef("https://schema.org/hasBioChemEntityPart")
    PublicationIssue = URIRef("https://schema.org/PublicationIssue")
    artist = URIRef("https://schema.org/artist")
    HealthTopicContent = URIRef("https://schema.org/HealthTopicContent")
    free = URIRef("https://schema.org/free")
    seller = URIRef("https://schema.org/seller")
    PhotographAction = URIRef("https://schema.org/PhotographAction")
    Corporation = URIRef("https://schema.org/Corporation")
    cashBack = URIRef("https://schema.org/cashBack")
    dateIssued = URIRef("https://schema.org/dateIssued")
    mobileUrl = URIRef("https://schema.org/mobileUrl")
    branch = URIRef("https://schema.org/branch")
    infectiousAgentClass = URIRef("https://schema.org/infectiousAgentClass")
    GameServerStatus = URIRef("https://schema.org/GameServerStatus")
    carrier = URIRef("https://schema.org/carrier")
    applicationContact = URIRef("https://schema.org/applicationContact")
    telephone = URIRef("https://schema.org/telephone")
    legislationDateVersion = URIRef("https://schema.org/legislationDateVersion")
    broadcastAffiliateOf = URIRef("https://schema.org/broadcastAffiliateOf")
    meetsEmissionStandard = URIRef("https://schema.org/meetsEmissionStandard")
    foundingLocation = URIRef("https://schema.org/foundingLocation")
    eventAttendanceMode = URIRef("https://schema.org/eventAttendanceMode")
    TattooParlor = URIRef("https://schema.org/TattooParlor")
    workFeatured = URIRef("https://schema.org/workFeatured")
    geo = URIRef("https://schema.org/geo")
    Restaurant = URIRef("https://schema.org/Restaurant")
    reviewedBy = URIRef("https://schema.org/reviewedBy")
    Photograph = URIRef("https://schema.org/Photograph")
    accountablePerson = URIRef("https://schema.org/accountablePerson")
    mediaAuthenticityCategory = URIRef("https://schema.org/mediaAuthenticityCategory")
    PublicHolidays = URIRef("https://schema.org/PublicHolidays")
    application = URIRef("https://schema.org/application")
    Flight = URIRef("https://schema.org/Flight")
    drugClass = URIRef("https://schema.org/drugClass")
    earlyPrepaymentPenalty = URIRef("https://schema.org/earlyPrepaymentPenalty")
    molecularFormula = URIRef("https://schema.org/molecularFormula")
    TransformedContent = URIRef("https://schema.org/TransformedContent")
    interestRate = URIRef("https://schema.org/interestRate")
    insertion = URIRef("https://schema.org/insertion")
    GameServerStatus = URIRef("https://schema.org/GameServerStatus")
    titleEIDR = URIRef("https://schema.org/titleEIDR")
    holdingArchive = URIRef("https://schema.org/holdingArchive")
    playerType = URIRef("https://schema.org/playerType")
    VitalSign = URIRef("https://schema.org/VitalSign")
    seriousAdverseOutcome = URIRef("https://schema.org/seriousAdverseOutcome")
    pagination = URIRef("https://schema.org/pagination")
    SportsEvent = URIRef("https://schema.org/SportsEvent")
    WearableSizeSystemUK = URIRef("https://schema.org/WearableSizeSystemUK")
    WritePermission = URIRef("https://schema.org/WritePermission")
    TVEpisode = URIRef("https://schema.org/TVEpisode")
    flightDistance = URIRef("https://schema.org/flightDistance")
    areaServed = URIRef("https://schema.org/areaServed")
    item = URIRef("https://schema.org/item")
    seatSection = URIRef("https://schema.org/seatSection")
    Suite = URIRef("https://schema.org/Suite")
    MedicalProcedureType = URIRef("https://schema.org/MedicalProcedureType")
    OpeningHoursSpecification = URIRef("https://schema.org/OpeningHoursSpecification")
    PaymentDeclined = URIRef("https://schema.org/PaymentDeclined")
    SexualContentConsideration = URIRef("https://schema.org/SexualContentConsideration")
    makesOffer = URIRef("https://schema.org/makesOffer")
    ReturnMethodEnumeration = URIRef("https://schema.org/ReturnMethodEnumeration")
    doorTime = URIRef("https://schema.org/doorTime")
    BroadcastChannel = URIRef("https://schema.org/BroadcastChannel")
    coach = URIRef("https://schema.org/coach")
    grantee = URIRef("https://schema.org/grantee")
    eligibleTransactionVolume = URIRef("https://schema.org/eligibleTransactionVolume")
    givenName = URIRef("https://schema.org/givenName")
    returnShippingFeesAmount = URIRef("https://schema.org/returnShippingFeesAmount")
    MedicalCode = URIRef("https://schema.org/MedicalCode")
    legislationDate = URIRef("https://schema.org/legislationDate")
    BedDetails = URIRef("https://schema.org/BedDetails")
    MedicalWebPage = URIRef("https://schema.org/MedicalWebPage")
    interactionStatistic = URIRef("https://schema.org/interactionStatistic")
    BusinessAudience = URIRef("https://schema.org/BusinessAudience")
    Infectious = URIRef("https://schema.org/Infectious")
    Abdomen = URIRef("https://schema.org/Abdomen")
    JoinAction = URIRef("https://schema.org/JoinAction")
    RadioBroadcastService = URIRef("https://schema.org/RadioBroadcastService")
    DrugClass = URIRef("https://schema.org/DrugClass")
    billingIncrement = URIRef("https://schema.org/billingIncrement")
    estimatesRiskOf = URIRef("https://schema.org/estimatesRiskOf")
    OnDemandEvent = URIRef("https://schema.org/OnDemandEvent")
    serviceUrl = URIRef("https://schema.org/serviceUrl")
    accessibilityHazard = URIRef("https://schema.org/accessibilityHazard")
    DepositAccount = URIRef("https://schema.org/DepositAccount")
    BroadcastFrequencySpecification = URIRef("https://schema.org/BroadcastFrequencySpecification")
    depth = URIRef("https://schema.org/depth")
    PronounceableText = URIRef("https://schema.org/PronounceableText")
    geoCrosses = URIRef("https://schema.org/geoCrosses")
    CompleteDataFeed = URIRef("https://schema.org/CompleteDataFeed")
    musicBy = URIRef("https://schema.org/musicBy")
    digitalSourceType = URIRef("https://schema.org/digitalSourceType")
    AssessAction = URIRef("https://schema.org/AssessAction")
    shippingLabel = URIRef("https://schema.org/shippingLabel")
    medicalAudience = URIRef("https://schema.org/medicalAudience")
    TransformedContent = URIRef("https://schema.org/TransformedContent")
    hasBioPolymerSequence = URIRef("https://schema.org/hasBioPolymerSequence")
    experienceInPlaceOfEducation = URIRef("https://schema.org/experienceInPlaceOfEducation")
    MedicineSystem = URIRef("https://schema.org/MedicineSystem")
    ArtGallery = URIRef("https://schema.org/ArtGallery")
    NewsMediaOrganization = URIRef("https://schema.org/NewsMediaOrganization")
    WearableSizeGroupBoys = URIRef("https://schema.org/WearableSizeGroupBoys")
    ReturnShippingFees = URIRef("https://schema.org/ReturnShippingFees")
    recommendedIntake = URIRef("https://schema.org/recommendedIntake")
    jobTitle = URIRef("https://schema.org/jobTitle")
    funding = URIRef("https://schema.org/funding")
    orderQuantity = URIRef("https://schema.org/orderQuantity")
    Pulmonary = URIRef("https://schema.org/Pulmonary")
    Brewery = URIRef("https://schema.org/Brewery")
    DefinedTerm = URIRef("https://schema.org/DefinedTerm")
    interactionType = URIRef("https://schema.org/interactionType")
    PreOrderAction = URIRef("https://schema.org/PreOrderAction")
    dietFeatures = URIRef("https://schema.org/dietFeatures")
    ParcelDelivery = URIRef("https://schema.org/ParcelDelivery")
    colleague = URIRef("https://schema.org/colleague")
    SpokenWordAlbum = URIRef("https://schema.org/SpokenWordAlbum")
    minPrice = URIRef("https://schema.org/minPrice")
    creativeWorkStatus = URIRef("https://schema.org/creativeWorkStatus")
    includedDataCatalog = URIRef("https://schema.org/includedDataCatalog")
    salaryCurrency = URIRef("https://schema.org/salaryCurrency")
    PoliceStation = URIRef("https://schema.org/PoliceStation")
    category = URIRef("https://schema.org/category")
    termCode = URIRef("https://schema.org/termCode")
    vehicleSpecialUsage = URIRef("https://schema.org/vehicleSpecialUsage")
    Ultrasound = URIRef("https://schema.org/Ultrasound")
    predecessorOf = URIRef("https://schema.org/predecessorOf")
    WearableSizeGroupMisses = URIRef("https://schema.org/WearableSizeGroupMisses")
    Permit = URIRef("https://schema.org/Permit")
    requirements = URIRef("https://schema.org/requirements")
    attendees = URIRef("https://schema.org/attendees")
    recipe = URIRef("https://schema.org/recipe")
    isAvailableGenerically = URIRef("https://schema.org/isAvailableGenerically")
    MarryAction = URIRef("https://schema.org/MarryAction")
    TieAction = URIRef("https://schema.org/TieAction")
    StructuredValue = URIRef("https://schema.org/StructuredValue")
    addOn = URIRef("https://schema.org/addOn")
    Event = URIRef("https://schema.org/Event")
    position = URIRef("https://schema.org/position")
    datePosted = URIRef("https://schema.org/datePosted")
    geoIntersects = URIRef("https://schema.org/geoIntersects")
    BloodTest = URIRef("https://schema.org/BloodTest")
    cookTime = URIRef("https://schema.org/cookTime")
    SportsTeam = URIRef("https://schema.org/SportsTeam")
    InvestmentOrDeposit = URIRef("https://schema.org/InvestmentOrDeposit")
    strengthUnit = URIRef("https://schema.org/strengthUnit")
    legislationApplies = URIRef("https://schema.org/legislationApplies")
    reservationId = URIRef("https://schema.org/reservationId")
    exifData = URIRef("https://schema.org/exifData")
    evidenceLevel = URIRef("https://schema.org/evidenceLevel")
    healthPlanCoinsuranceOption = URIRef("https://schema.org/healthPlanCoinsuranceOption")
    TattooParlor = URIRef("https://schema.org/TattooParlor")
    propertyID = URIRef("https://schema.org/propertyID")
    UserComments = URIRef("https://schema.org/UserComments")
    orderQuantity = URIRef("https://schema.org/orderQuantity")
    DislikeAction = URIRef("https://schema.org/DislikeAction")
    subjectOf = URIRef("https://schema.org/subjectOf")
    mainEntity = URIRef("https://schema.org/mainEntity")
    transitTimeLabel = URIRef("https://schema.org/transitTimeLabel")
    vehicleIdentificationNumber = URIRef("https://schema.org/vehicleIdentificationNumber")
    EventStatusType = URIRef("https://schema.org/EventStatusType")
    countryOfOrigin = URIRef("https://schema.org/countryOfOrigin")
    advanceBookingRequirement = URIRef("https://schema.org/advanceBookingRequirement")
    reviewCount = URIRef("https://schema.org/reviewCount")
    variantCover = URIRef("https://schema.org/variantCover")
    releaseNotes = URIRef("https://schema.org/releaseNotes")
    loanRepaymentForm = URIRef("https://schema.org/loanRepaymentForm")
    mechanismOfAction = URIRef("https://schema.org/mechanismOfAction")
    DataDrivenMediaDigitalSource = URIRef("https://schema.org/DataDrivenMediaDigitalSource")
    SatiricalArticle = URIRef("https://schema.org/SatiricalArticle")
    leaseLength = URIRef("https://schema.org/leaseLength")
    ReturnLabelCustomerResponsibility = URIRef("https://schema.org/ReturnLabelCustomerResponsibility")
    globalLocationNumber = URIRef("https://schema.org/globalLocationNumber")
    inStoreReturnsOffered = URIRef("https://schema.org/inStoreReturnsOffered")
    countriesSupported = URIRef("https://schema.org/countriesSupported")
    EventVenue = URIRef("https://schema.org/EventVenue")
    leaseLength = URIRef("https://schema.org/leaseLength")
    cvdNumICUBeds = URIRef("https://schema.org/cvdNumICUBeds")
    fundedItem = URIRef("https://schema.org/fundedItem")
    ChildrensEvent = URIRef("https://schema.org/ChildrensEvent")
    ReservationConfirmed = URIRef("https://schema.org/ReservationConfirmed")
    material = URIRef("https://schema.org/material")
    produces = URIRef("https://schema.org/produces")
    noBylinesPolicy = URIRef("https://schema.org/noBylinesPolicy")
    hasCertification = URIRef("https://schema.org/hasCertification")
    albums = URIRef("https://schema.org/albums")
    qualifications = URIRef("https://schema.org/qualifications")
    inLanguage = URIRef("https://schema.org/inLanguage")
    Float = URIRef("https://schema.org/Float")
    ReturnInStore = URIRef("https://schema.org/ReturnInStore")
    courseCode = URIRef("https://schema.org/courseCode")
    measuredProperty = URIRef("https://schema.org/measuredProperty")
    cvdNumC19OFMechVentPats = URIRef("https://schema.org/cvdNumC19OFMechVentPats")
    episode = URIRef("https://schema.org/episode")
    entertainmentBusiness = URIRef("https://schema.org/entertainmentBusiness")
    foodWarning = URIRef("https://schema.org/foodWarning")
    brand = URIRef("https://schema.org/brand")
    leiCode = URIRef("https://schema.org/leiCode")
    GardenStore = URIRef("https://schema.org/GardenStore")
    WearableSizeSystemGS1 = URIRef("https://schema.org/WearableSizeSystemGS1")
    urlTemplate = URIRef("https://schema.org/urlTemplate")
    CleaningFee = URIRef("https://schema.org/CleaningFee")
    assembly = URIRef("https://schema.org/assembly")
    legislationPassedBy = URIRef("https://schema.org/legislationPassedBy")
    childTaxon = URIRef("https://schema.org/childTaxon")
    Airline = URIRef("https://schema.org/Airline")
    MotorizedBicycle = URIRef("https://schema.org/MotorizedBicycle")
    interactivityType = URIRef("https://schema.org/interactivityType")
    acceptedPaymentMethod = URIRef("https://schema.org/acceptedPaymentMethod")
    differentialDiagnosis = URIRef("https://schema.org/differentialDiagnosis")
    workPresented = URIRef("https://schema.org/workPresented")
    vehicleTransmission = URIRef("https://schema.org/vehicleTransmission")
    quarantineGuidelines = URIRef("https://schema.org/quarantineGuidelines")
    certificationStatus = URIRef("https://schema.org/certificationStatus")
    steps = URIRef("https://schema.org/steps")
    accountMinimumInflow = URIRef("https://schema.org/accountMinimumInflow")
    correctionsPolicy = URIRef("https://schema.org/correctionsPolicy")
    reviewCount = URIRef("https://schema.org/reviewCount")
    HotelRoom = URIRef("https://schema.org/HotelRoom")
    masthead = URIRef("https://schema.org/masthead")
    Nonprofit501c17 = URIRef("https://schema.org/Nonprofit501c17")
    BreadcrumbList = URIRef("https://schema.org/BreadcrumbList")
    unitText = URIRef("https://schema.org/unitText")
    financialAidEligible = URIRef("https://schema.org/financialAidEligible")
    hospitalAffiliation = URIRef("https://schema.org/hospitalAffiliation")
    learningResourceType = URIRef("https://schema.org/learningResourceType")
    MedicalAudienceType = URIRef("https://schema.org/MedicalAudienceType")
    ProductCollection = URIRef("https://schema.org/ProductCollection")
    countriesSupported = URIRef("https://schema.org/countriesSupported")
    addressLocality = URIRef("https://schema.org/addressLocality")
    OnlineBusiness = URIRef("https://schema.org/OnlineBusiness")
    cvdFacilityId = URIRef("https://schema.org/cvdFacilityId")
    LowSaltDiet = URIRef("https://schema.org/LowSaltDiet")
    ethicsPolicy = URIRef("https://schema.org/ethicsPolicy")
    ParkingFacility = URIRef("https://schema.org/ParkingFacility")
    auditDate = URIRef("https://schema.org/auditDate")
    warrantyScope = URIRef("https://schema.org/warrantyScope")
    PaymentChargeSpecification = URIRef("https://schema.org/PaymentChargeSpecification")
    caption = URIRef("https://schema.org/caption")
    ResultsNotAvailable = URIRef("https://schema.org/ResultsNotAvailable")
    jobImmediateStart = URIRef("https://schema.org/jobImmediateStart")
    TravelAction = URIRef("https://schema.org/TravelAction")
    monoisotopicMolecularWeight = URIRef("https://schema.org/monoisotopicMolecularWeight")
    partOfSeason = URIRef("https://schema.org/partOfSeason")
    competencyRequired = URIRef("https://schema.org/competencyRequired")
    measurementDenominator = URIRef("https://schema.org/measurementDenominator")
    numberOfBeds = URIRef("https://schema.org/numberOfBeds")
    recognizedBy = URIRef("https://schema.org/recognizedBy")
    acceptedAnswer = URIRef("https://schema.org/acceptedAnswer")
    AlcoholConsideration = URIRef("https://schema.org/AlcoholConsideration")
    Patient = URIRef("https://schema.org/Patient")
    numberOfItems = URIRef("https://schema.org/numberOfItems")
    itemDefectReturnFees = URIRef("https://schema.org/itemDefectReturnFees")
    ToyStore = URIRef("https://schema.org/ToyStore")
    DefinedTerm = URIRef("https://schema.org/DefinedTerm")
    resultComment = URIRef("https://schema.org/resultComment")
    ActivateAction = URIRef("https://schema.org/ActivateAction")
    measurementTechnique = URIRef("https://schema.org/measurementTechnique")
    customerRemorseReturnShippingFeesAmount = URIRef("https://schema.org/customerRemorseReturnShippingFeesAmount")
    experienceInPlaceOfEducation = URIRef("https://schema.org/experienceInPlaceOfEducation")
    AudioObjectSnapshot = URIRef("https://schema.org/AudioObjectSnapshot")
    hasCourseInstance = URIRef("https://schema.org/hasCourseInstance")
    TypeAndQuantityNode = URIRef("https://schema.org/TypeAndQuantityNode")
    partOfTVSeries = URIRef("https://schema.org/partOfTVSeries")
    WarrantyScope = URIRef("https://schema.org/WarrantyScope")
    doseValue = URIRef("https://schema.org/doseValue")
    ScreeningHealthAspect = URIRef("https://schema.org/ScreeningHealthAspect")
    givenName = URIRef("https://schema.org/givenName")
    EmployerReview = URIRef("https://schema.org/EmployerReview")
    measuredProperty = URIRef("https://schema.org/measuredProperty")
    familyName = URIRef("https://schema.org/familyName")
    isicV4 = URIRef("https://schema.org/isicV4")
    interactionStatistic = URIRef("https://schema.org/interactionStatistic")
    Ticket = URIRef("https://schema.org/Ticket")
    applicationCategory = URIRef("https://schema.org/applicationCategory")
    MediaManipulationRatingEnumeration = URIRef("https://schema.org/MediaManipulationRatingEnumeration")
    OfferForLease = URIRef("https://schema.org/OfferForLease")
    colorist = URIRef("https://schema.org/colorist")
    vehicleConfiguration = URIRef("https://schema.org/vehicleConfiguration")
    character = URIRef("https://schema.org/character")
    inCodeSet = URIRef("https://schema.org/inCodeSet")
    downPayment = URIRef("https://schema.org/downPayment")
    priceType = URIRef("https://schema.org/priceType")
    typeOfBed = URIRef("https://schema.org/typeOfBed")
    returnPolicyCategory = URIRef("https://schema.org/returnPolicyCategory")
    target = URIRef("https://schema.org/target")
    subStructure = URIRef("https://schema.org/subStructure")
    DeliveryMethod = URIRef("https://schema.org/DeliveryMethod")
    breadcrumb = URIRef("https://schema.org/breadcrumb")
    SymptomsHealthAspect = URIRef("https://schema.org/SymptomsHealthAspect")
    feesAndCommissionsSpecification = URIRef("https://schema.org/feesAndCommissionsSpecification")
    course = URIRef("https://schema.org/course")
    repeatCount = URIRef("https://schema.org/repeatCount")
    clincalPharmacology = URIRef("https://schema.org/clincalPharmacology")
    NonprofitType = URIRef("https://schema.org/NonprofitType")
    colleagues = URIRef("https://schema.org/colleagues")
    departureAirport = URIRef("https://schema.org/departureAirport")
    recourseLoan = URIRef("https://schema.org/recourseLoan")
    salaryUponCompletion = URIRef("https://schema.org/salaryUponCompletion")
    relatedDrug = URIRef("https://schema.org/relatedDrug")
    price = URIRef("https://schema.org/price")
    BoatTerminal = URIRef("https://schema.org/BoatTerminal")
    exampleOfWork = URIRef("https://schema.org/exampleOfWork")
    LegislativeBuilding = URIRef("https://schema.org/LegislativeBuilding")
    openingHours = URIRef("https://schema.org/openingHours")
    strengthValue = URIRef("https://schema.org/strengthValue")
    BoatReservation = URIRef("https://schema.org/BoatReservation")
    Rheumatologic = URIRef("https://schema.org/Rheumatologic")
    employee = URIRef("https://schema.org/employee")
    estimatedFlightDuration = URIRef("https://schema.org/estimatedFlightDuration")
    ProgramMembership = URIRef("https://schema.org/ProgramMembership")
    applicableLocation = URIRef("https://schema.org/applicableLocation")
    GeoCircle = URIRef("https://schema.org/GeoCircle")
    aspect = URIRef("https://schema.org/aspect")
    inLanguage = URIRef("https://schema.org/inLanguage")
    funder = URIRef("https://schema.org/funder")
    supplyTo = URIRef("https://schema.org/supplyTo")
    audienceType = URIRef("https://schema.org/audienceType")
    WearableSizeGroupJuniors = URIRef("https://schema.org/WearableSizeGroupJuniors")
    winner = URIRef("https://schema.org/winner")
    recipient = URIRef("https://schema.org/recipient")
    MixtapeAlbum = URIRef("https://schema.org/MixtapeAlbum")
    loanType = URIRef("https://schema.org/loanType")
    studySubject = URIRef("https://schema.org/studySubject")
    safetyConsideration = URIRef("https://schema.org/safetyConsideration")
    acquireLicensePage = URIRef("https://schema.org/acquireLicensePage")
    Continent = URIRef("https://schema.org/Continent")
    securityClearanceRequirement = URIRef("https://schema.org/securityClearanceRequirement")
    musicalKey = URIRef("https://schema.org/musicalKey")
    mpn = URIRef("https://schema.org/mpn")
    Nonprofit501c18 = URIRef("https://schema.org/Nonprofit501c18")
    partOfSeason = URIRef("https://schema.org/partOfSeason")
    differentialDiagnosis = URIRef("https://schema.org/differentialDiagnosis")
    RefundTypeEnumeration = URIRef("https://schema.org/RefundTypeEnumeration")
    printSection = URIRef("https://schema.org/printSection")
    validIn = URIRef("https://schema.org/validIn")
    byMonth = URIRef("https://schema.org/byMonth")
    dateDeleted = URIRef("https://schema.org/dateDeleted")
    hasMenuItem = URIRef("https://schema.org/hasMenuItem")
    Zoo = URIRef("https://schema.org/Zoo")
    NonprofitSBBI = URIRef("https://schema.org/NonprofitSBBI")
    healthPlanCoinsuranceOption = URIRef("https://schema.org/healthPlanCoinsuranceOption")
    permissions = URIRef("https://schema.org/permissions")
    ClaimReview = URIRef("https://schema.org/ClaimReview")
    MedicalStudyStatus = URIRef("https://schema.org/MedicalStudyStatus")
    license = URIRef("https://schema.org/license")
    frequency = URIRef("https://schema.org/frequency")
    releaseOf = URIRef("https://schema.org/releaseOf")
    featureList = URIRef("https://schema.org/featureList")
    jobStartDate = URIRef("https://schema.org/jobStartDate")
    bed = URIRef("https://schema.org/bed")
    TextObject = URIRef("https://schema.org/TextObject")
    supersededBy = URIRef("https://schema.org/supersededBy")
    interestRate = URIRef("https://schema.org/interestRate")
    validFrom = URIRef("https://schema.org/validFrom")
    MusicComposition = URIRef("https://schema.org/MusicComposition")
    homeTeam = URIRef("https://schema.org/homeTeam")
    BroadcastChannel = URIRef("https://schema.org/BroadcastChannel")
    ethicsPolicy = URIRef("https://schema.org/ethicsPolicy")
    accommodationFloorPlan = URIRef("https://schema.org/accommodationFloorPlan")
    intensity = URIRef("https://schema.org/intensity")
    CleaningFee = URIRef("https://schema.org/CleaningFee")
    contentReferenceTime = URIRef("https://schema.org/contentReferenceTime")
    contactOption = URIRef("https://schema.org/contactOption")
    endTime = URIRef("https://schema.org/endTime")
    FDAnotEvaluated = URIRef("https://schema.org/FDAnotEvaluated")
    OccupationalExperienceRequirements = URIRef("https://schema.org/OccupationalExperienceRequirements")
    Muscle = URIRef("https://schema.org/Muscle")
    WearableSizeGroupGirls = URIRef("https://schema.org/WearableSizeGroupGirls")
    ethicsPolicy = URIRef("https://schema.org/ethicsPolicy")
    recognizingAuthority = URIRef("https://schema.org/recognizingAuthority")
    WearableMeasurementBack = URIRef("https://schema.org/WearableMeasurementBack")
    CreativeWorkSeason = URIRef("https://schema.org/CreativeWorkSeason")
    tocEntry = URIRef("https://schema.org/tocEntry")
    TaxiVehicleUsage = URIRef("https://schema.org/TaxiVehicleUsage")
    SatiricalArticle = URIRef("https://schema.org/SatiricalArticle")
    educationalRole = URIRef("https://schema.org/educationalRole")
    value = URIRef("https://schema.org/value")
    FoodEvent = URIRef("https://schema.org/FoodEvent")
    costOrigin = URIRef("https://schema.org/costOrigin")
    Hackathon = URIRef("https://schema.org/Hackathon")
    AggregateOffer = URIRef("https://schema.org/AggregateOffer")
    availableStrength = URIRef("https://schema.org/availableStrength")
    yearBuilt = URIRef("https://schema.org/yearBuilt")
    Continent = URIRef("https://schema.org/Continent")
    valueReference = URIRef("https://schema.org/valueReference")
    musicGroupMember = URIRef("https://schema.org/musicGroupMember")
    mpn = URIRef("https://schema.org/mpn")
    fundedItem = URIRef("https://schema.org/fundedItem")
    RadioSeries = URIRef("https://schema.org/RadioSeries")
    eduQuestionType = URIRef("https://schema.org/eduQuestionType")
    Schedule = URIRef("https://schema.org/Schedule")
    stage = URIRef("https://schema.org/stage")
    GeoShape = URIRef("https://schema.org/GeoShape")
    cvdNumC19MechVentPats = URIRef("https://schema.org/cvdNumC19MechVentPats")
    legislationConsolidates = URIRef("https://schema.org/legislationConsolidates")
    Quotation = URIRef("https://schema.org/Quotation")
    typicalTest = URIRef("https://schema.org/typicalTest")
    reviews = URIRef("https://schema.org/reviews")
    recordingOf = URIRef("https://schema.org/recordingOf")
    containedInPlace = URIRef("https://schema.org/containedInPlace")
    playersOnline = URIRef("https://schema.org/playersOnline")
    dietFeatures = URIRef("https://schema.org/dietFeatures")
    OfferForLease = URIRef("https://schema.org/OfferForLease")
    PublicationIssue = URIRef("https://schema.org/PublicationIssue")
    hasDriveThroughService = URIRef("https://schema.org/hasDriveThroughService")
    missionCoveragePrioritiesPolicy = URIRef("https://schema.org/missionCoveragePrioritiesPolicy")
    letterer = URIRef("https://schema.org/letterer")
    childTaxon = URIRef("https://schema.org/childTaxon")
    musicBy = URIRef("https://schema.org/musicBy")
    documentation = URIRef("https://schema.org/documentation")
    businessFunction = URIRef("https://schema.org/businessFunction")
    Observation = URIRef("https://schema.org/Observation")
    supplyTo = URIRef("https://schema.org/supplyTo")
    PatientExperienceHealthAspect = URIRef("https://schema.org/PatientExperienceHealthAspect")
    featureList = URIRef("https://schema.org/featureList")
    Nonprofit501c18 = URIRef("https://schema.org/Nonprofit501c18")
    model = URIRef("https://schema.org/model")
    TVSeries = URIRef("https://schema.org/TVSeries")
    ReturnLabelSourceEnumeration = URIRef("https://schema.org/ReturnLabelSourceEnumeration")
    torque = URIRef("https://schema.org/torque")
    Quotation = URIRef("https://schema.org/Quotation")
    PriceSpecification = URIRef("https://schema.org/PriceSpecification")
    arrivalBoatTerminal = URIRef("https://schema.org/arrivalBoatTerminal")
    cargoVolume = URIRef("https://schema.org/cargoVolume")
    status = URIRef("https://schema.org/status")
    MobileWebPlatform = URIRef("https://schema.org/MobileWebPlatform")
    taxonomicRange = URIRef("https://schema.org/taxonomicRange")
    ineligibleRegion = URIRef("https://schema.org/ineligibleRegion")
    performer = URIRef("https://schema.org/performer")
    URL = URIRef("https://schema.org/URL")
    validFrom = URIRef("https://schema.org/validFrom")
    MusculoskeletalExam = URIRef("https://schema.org/MusculoskeletalExam")
    occupationLocation = URIRef("https://schema.org/occupationLocation")
    MedicalDevicePurpose = URIRef("https://schema.org/MedicalDevicePurpose")
    HousePainter = URIRef("https://schema.org/HousePainter")
    sponsor = URIRef("https://schema.org/sponsor")
    isAcceptingNewPatients = URIRef("https://schema.org/isAcceptingNewPatients")
    recordLabel = URIRef("https://schema.org/recordLabel")
    firstAppearance = URIRef("https://schema.org/firstAppearance")
    USNonprofitType = URIRef("https://schema.org/USNonprofitType")
    FDAcategoryB = URIRef("https://schema.org/FDAcategoryB")
    legislationLegalValue = URIRef("https://schema.org/legislationLegalValue")
    EntryPoint = URIRef("https://schema.org/EntryPoint")
    availableService = URIRef("https://schema.org/availableService")
    serviceType = URIRef("https://schema.org/serviceType")
    cvdFacilityCounty = URIRef("https://schema.org/cvdFacilityCounty")
    Boolean = URIRef("https://schema.org/Boolean")
    CreateAction = URIRef("https://schema.org/CreateAction")
    RsvpAction = URIRef("https://schema.org/RsvpAction")
    healthCondition = URIRef("https://schema.org/healthCondition")
    FloorPlan = URIRef("https://schema.org/FloorPlan")
    alignmentType = URIRef("https://schema.org/alignmentType")
    acquireLicensePage = URIRef("https://schema.org/acquireLicensePage")
    totalTime = URIRef("https://schema.org/totalTime")
    accessMode = URIRef("https://schema.org/accessMode")
    children = URIRef("https://schema.org/children")
    gtin8 = URIRef("https://schema.org/gtin8")
    legalStatus = URIRef("https://schema.org/legalStatus")
    ExerciseGym = URIRef("https://schema.org/ExerciseGym")
    Play = URIRef("https://schema.org/Play")
    codeSampleType = URIRef("https://schema.org/codeSampleType")
    PreSale = URIRef("https://schema.org/PreSale")
    Nonprofit501c19 = URIRef("https://schema.org/Nonprofit501c19")
    isrcCode = URIRef("https://schema.org/isrcCode")
    TherapeuticProcedure = URIRef("https://schema.org/TherapeuticProcedure")
    returnShippingFeesAmount = URIRef("https://schema.org/returnShippingFeesAmount")
    masthead = URIRef("https://schema.org/masthead")
    funder = URIRef("https://schema.org/funder")
    CardiovascularExam = URIRef("https://schema.org/CardiovascularExam")
    device = URIRef("https://schema.org/device")
    publishedBy = URIRef("https://schema.org/publishedBy")
    category = URIRef("https://schema.org/category")
    titleEIDR = URIRef("https://schema.org/titleEIDR")
    Episode = URIRef("https://schema.org/Episode")
    GettingAccessHealthAspect = URIRef("https://schema.org/GettingAccessHealthAspect")
    processingTime = URIRef("https://schema.org/processingTime")
    exerciseCourse = URIRef("https://schema.org/exerciseCourse")
    departurePlatform = URIRef("https://schema.org/departurePlatform")
    interactingDrug = URIRef("https://schema.org/interactingDrug")
    geoContains = URIRef("https://schema.org/geoContains")
    code = URIRef("https://schema.org/code")
    MusicComposition = URIRef("https://schema.org/MusicComposition")
    Thursday = URIRef("https://schema.org/Thursday")
    workPresented = URIRef("https://schema.org/workPresented")
    GenderType = URIRef("https://schema.org/GenderType")
    telephone = URIRef("https://schema.org/telephone")
    embedUrl = URIRef("https://schema.org/embedUrl")
    ActiveNotRecruiting = URIRef("https://schema.org/ActiveNotRecruiting")
    articleBody = URIRef("https://schema.org/articleBody")
    UnitPriceSpecification = URIRef("https://schema.org/UnitPriceSpecification")
    loser = URIRef("https://schema.org/loser")
    additionalVariable = URIRef("https://schema.org/additionalVariable")
    datasetTimeInterval = URIRef("https://schema.org/datasetTimeInterval")
    EvidenceLevelA = URIRef("https://schema.org/EvidenceLevelA")
    gtin14 = URIRef("https://schema.org/gtin14")
    transmissionMethod = URIRef("https://schema.org/transmissionMethod")
    deliveryTime = URIRef("https://schema.org/deliveryTime")
    pickupTime = URIRef("https://schema.org/pickupTime")
    DonateAction = URIRef("https://schema.org/DonateAction")
    TransferAction = URIRef("https://schema.org/TransferAction")
    cvdCollectionDate = URIRef("https://schema.org/cvdCollectionDate")
    valueReference = URIRef("https://schema.org/valueReference")
    Number = URIRef("https://schema.org/Number")
    NightClub = URIRef("https://schema.org/NightClub")
    spouse = URIRef("https://schema.org/spouse")
    broadcastOfEvent = URIRef("https://schema.org/broadcastOfEvent")
    sender = URIRef("https://schema.org/sender")
    tissueSample = URIRef("https://schema.org/tissueSample")
    secondaryPrevention = URIRef("https://schema.org/secondaryPrevention")
    noBylinesPolicy = URIRef("https://schema.org/noBylinesPolicy")
    subTest = URIRef("https://schema.org/subTest")
    issn = URIRef("https://schema.org/issn")
    gamePlatform = URIRef("https://schema.org/gamePlatform")
    CleaningFee = URIRef("https://schema.org/CleaningFee")
    programType = URIRef("https://schema.org/programType")
    recipient = URIRef("https://schema.org/recipient")
    applicationSubCategory = URIRef("https://schema.org/applicationSubCategory")
    recipient = URIRef("https://schema.org/recipient")
    countryOfLastProcessing = URIRef("https://schema.org/countryOfLastProcessing")
    cvdNumBedsOcc = URIRef("https://schema.org/cvdNumBedsOcc")
    Nonprofit501c24 = URIRef("https://schema.org/Nonprofit501c24")
    about = URIRef("https://schema.org/about")
    OrderProcessing = URIRef("https://schema.org/OrderProcessing")
    PlayGameAction = URIRef("https://schema.org/PlayGameAction")
    isSimilarTo = URIRef("https://schema.org/isSimilarTo")
    availableDeliveryMethod = URIRef("https://schema.org/availableDeliveryMethod")
    PalliativeProcedure = URIRef("https://schema.org/PalliativeProcedure")
    accessibilityAPI = URIRef("https://schema.org/accessibilityAPI")
    Question = URIRef("https://schema.org/Question")
    relatedTherapy = URIRef("https://schema.org/relatedTherapy")
    emissionsCO2 = URIRef("https://schema.org/emissionsCO2")
    reportNumber = URIRef("https://schema.org/reportNumber")
    TouristDestination = URIRef("https://schema.org/TouristDestination")
    follows = URIRef("https://schema.org/follows")
    biologicalRole = URIRef("https://schema.org/biologicalRole")
    strengthUnit = URIRef("https://schema.org/strengthUnit")
    includedInHealthInsurancePlan = URIRef("https://schema.org/includedInHealthInsurancePlan")
    endTime = URIRef("https://schema.org/endTime")
    iso6523Code = URIRef("https://schema.org/iso6523Code")
    beneficiaryBank = URIRef("https://schema.org/beneficiaryBank")
    recommendedIntake = URIRef("https://schema.org/recommendedIntake")
    TraditionalChinese = URIRef("https://schema.org/TraditionalChinese")
    requiredGender = URIRef("https://schema.org/requiredGender")
    DrugPregnancyCategory = URIRef("https://schema.org/DrugPregnancyCategory")
    ConstraintNode = URIRef("https://schema.org/ConstraintNode")
    SatireOrParodyContent = URIRef("https://schema.org/SatireOrParodyContent")
    ChooseAction = URIRef("https://schema.org/ChooseAction")
    FAQPage = URIRef("https://schema.org/FAQPage")
    comprisedOf = URIRef("https://schema.org/comprisedOf")
    diversityPolicy = URIRef("https://schema.org/diversityPolicy")
    cvdNumC19Died = URIRef("https://schema.org/cvdNumC19Died")
    greaterOrEqual = URIRef("https://schema.org/greaterOrEqual")
    relatedCondition = URIRef("https://schema.org/relatedCondition")
    BookSeries = URIRef("https://schema.org/BookSeries")
    actionOption = URIRef("https://schema.org/actionOption")
    directApply = URIRef("https://schema.org/directApply")
    loanMortgageMandateAmount = URIRef("https://schema.org/loanMortgageMandateAmount")
    steps = URIRef("https://schema.org/steps")
    adverseOutcome = URIRef("https://schema.org/adverseOutcome")
    employmentUnit = URIRef("https://schema.org/employmentUnit")
    guidelineDate = URIRef("https://schema.org/guidelineDate")
    Renal = URIRef("https://schema.org/Renal")
    RadioSeason = URIRef("https://schema.org/RadioSeason")
    LegislativeBuilding = URIRef("https://schema.org/LegislativeBuilding")
    BookFormatType = URIRef("https://schema.org/BookFormatType")
    hasMerchantReturnPolicy = URIRef("https://schema.org/hasMerchantReturnPolicy")
    PaymentCard = URIRef("https://schema.org/PaymentCard")
    measuredProperty = URIRef("https://schema.org/measuredProperty")
    monthsOfExperience = URIRef("https://schema.org/monthsOfExperience")
    BedType = URIRef("https://schema.org/BedType")
    HomeGoodsStore = URIRef("https://schema.org/HomeGoodsStore")
    BookSeries = URIRef("https://schema.org/BookSeries")
    relevantSpecialty = URIRef("https://schema.org/relevantSpecialty")
    supersededBy = URIRef("https://schema.org/supersededBy")
    LocationFeatureSpecification = URIRef("https://schema.org/LocationFeatureSpecification")
    Room = URIRef("https://schema.org/Room")
    EntryPoint = URIRef("https://schema.org/EntryPoint")
    MeetingRoom = URIRef("https://schema.org/MeetingRoom")
    MedicalRiskCalculator = URIRef("https://schema.org/MedicalRiskCalculator")
    significantLinks = URIRef("https://schema.org/significantLinks")
    commentText = URIRef("https://schema.org/commentText")
    hasRepresentation = URIRef("https://schema.org/hasRepresentation")
    multipleValues = URIRef("https://schema.org/multipleValues")
    DigitalCaptureDigitalSource = URIRef("https://schema.org/DigitalCaptureDigitalSource")
    MerchantReturnUnspecified = URIRef("https://schema.org/MerchantReturnUnspecified")
    isPartOfBioChemEntity = URIRef("https://schema.org/isPartOfBioChemEntity")
    Barcode = URIRef("https://schema.org/Barcode")
    workLocation = URIRef("https://schema.org/workLocation")
    legislationLegalValue = URIRef("https://schema.org/legislationLegalValue")
    TouristDestination = URIRef("https://schema.org/TouristDestination")
    Conversation = URIRef("https://schema.org/Conversation")
    dataFeedElement = URIRef("https://schema.org/dataFeedElement")
    legislationResponsible = URIRef("https://schema.org/legislationResponsible")
    numberOfRooms = URIRef("https://schema.org/numberOfRooms")
    translator = URIRef("https://schema.org/translator")
    PriceTypeEnumeration = URIRef("https://schema.org/PriceTypeEnumeration")
    ComicStory = URIRef("https://schema.org/ComicStory")
    attendee = URIRef("https://schema.org/attendee")
    value = URIRef("https://schema.org/value")
    publisherImprint = URIRef("https://schema.org/publisherImprint")
    actionStatus = URIRef("https://schema.org/actionStatus")
    WearableSizeSystemIT = URIRef("https://schema.org/WearableSizeSystemIT")
    SoftwareSourceCode = URIRef("https://schema.org/SoftwareSourceCode")
    applicationStartDate = URIRef("https://schema.org/applicationStartDate")
    offerCount = URIRef("https://schema.org/offerCount")
    Class = URIRef("https://schema.org/Class")
    ParentalSupport = URIRef("https://schema.org/ParentalSupport")
    Florist = URIRef("https://schema.org/Florist")
    NoteDigitalDocument = URIRef("https://schema.org/NoteDigitalDocument")
    measurementDenominator = URIRef("https://schema.org/measurementDenominator")
    ParkingFacility = URIRef("https://schema.org/ParkingFacility")
    gameServer = URIRef("https://schema.org/gameServer")
    alternateName = URIRef("https://schema.org/alternateName")
    Text = URIRef("https://schema.org/Text")
    typicalAgeRange = URIRef("https://schema.org/typicalAgeRange")
    verificationFactCheckingPolicy = URIRef("https://schema.org/verificationFactCheckingPolicy")
    MedicalClinic = URIRef("https://schema.org/MedicalClinic")
    ArriveAction = URIRef("https://schema.org/ArriveAction")
    deliveryAddress = URIRef("https://schema.org/deliveryAddress")
    hasMenuItem = URIRef("https://schema.org/hasMenuItem")
    restockingFee = URIRef("https://schema.org/restockingFee")
    accountMinimumInflow = URIRef("https://schema.org/accountMinimumInflow")
    ineligibleRegion = URIRef("https://schema.org/ineligibleRegion")
    vehicleSeatingCapacity = URIRef("https://schema.org/vehicleSeatingCapacity")
    actor = URIRef("https://schema.org/actor")
    structuralClass = URIRef("https://schema.org/structuralClass")
    producer = URIRef("https://schema.org/producer")
    reservationStatus = URIRef("https://schema.org/reservationStatus")
    ReadPermission = URIRef("https://schema.org/ReadPermission")
    SiteNavigationElement = URIRef("https://schema.org/SiteNavigationElement")
    suggestedMaxAge = URIRef("https://schema.org/suggestedMaxAge")
    BoatReservation = URIRef("https://schema.org/BoatReservation")
    broadcastTimezone = URIRef("https://schema.org/broadcastTimezone")
    intensity = URIRef("https://schema.org/intensity")
    vehicleConfiguration = URIRef("https://schema.org/vehicleConfiguration")
    isPartOfBioChemEntity = URIRef("https://schema.org/isPartOfBioChemEntity")
    riskFactor = URIRef("https://schema.org/riskFactor")
    departureTerminal = URIRef("https://schema.org/departureTerminal")
    healthPlanDrugTier = URIRef("https://schema.org/healthPlanDrugTier")
    SocialEvent = URIRef("https://schema.org/SocialEvent")
    WearableSizeGroupMaternity = URIRef("https://schema.org/WearableSizeGroupMaternity")
    adverseOutcome = URIRef("https://schema.org/adverseOutcome")
    TelevisionChannel = URIRef("https://schema.org/TelevisionChannel")
    position = URIRef("https://schema.org/position")
    structuralClass = URIRef("https://schema.org/structuralClass")
    courseSchedule = URIRef("https://schema.org/courseSchedule")
    Nonprofit501c26 = URIRef("https://schema.org/Nonprofit501c26")
    numberOfLoanPayments = URIRef("https://schema.org/numberOfLoanPayments")
    returnPolicyCategory = URIRef("https://schema.org/returnPolicyCategory")
    SideEffectsHealthAspect = URIRef("https://schema.org/SideEffectsHealthAspect")
    deliveryTime = URIRef("https://schema.org/deliveryTime")
    CableOrSatelliteService = URIRef("https://schema.org/CableOrSatelliteService")
    costOrigin = URIRef("https://schema.org/costOrigin")
    recipeInstructions = URIRef("https://schema.org/recipeInstructions")
    CheckInAction = URIRef("https://schema.org/CheckInAction")
    line = URIRef("https://schema.org/line")
    geoDisjoint = URIRef("https://schema.org/geoDisjoint")
    cvdCollectionDate = URIRef("https://schema.org/cvdCollectionDate")
    doseUnit = URIRef("https://schema.org/doseUnit")
    SpeechPathology = URIRef("https://schema.org/SpeechPathology")
    Thursday = URIRef("https://schema.org/Thursday")
    teaches = URIRef("https://schema.org/teaches")
    productID = URIRef("https://schema.org/productID")
    membershipNumber = URIRef("https://schema.org/membershipNumber")
    hasBioPolymerSequence = URIRef("https://schema.org/hasBioPolymerSequence")
    Quantity = URIRef("https://schema.org/Quantity")
    applicantLocationRequirements = URIRef("https://schema.org/applicantLocationRequirements")
    MediaReviewItem = URIRef("https://schema.org/MediaReviewItem")
    insertion = URIRef("https://schema.org/insertion")
    gameTip = URIRef("https://schema.org/gameTip")
    borrower = URIRef("https://schema.org/borrower")
    relatedCondition = URIRef("https://schema.org/relatedCondition")
    healthPlanCoinsuranceOption = URIRef("https://schema.org/healthPlanCoinsuranceOption")
    sdPublisher = URIRef("https://schema.org/sdPublisher")
    reservationId = URIRef("https://schema.org/reservationId")
    numberOfBathroomsTotal = URIRef("https://schema.org/numberOfBathroomsTotal")
    Hematologic = URIRef("https://schema.org/Hematologic")
    funder = URIRef("https://schema.org/funder")
    Florist = URIRef("https://schema.org/Florist")
    musicGroupMember = URIRef("https://schema.org/musicGroupMember")
    TelevisionStation = URIRef("https://schema.org/TelevisionStation")
    OccupationalActivity = URIRef("https://schema.org/OccupationalActivity")
    isRelatedTo = URIRef("https://schema.org/isRelatedTo")
    Nonprofit501c14 = URIRef("https://schema.org/Nonprofit501c14")
    mileageFromOdometer = URIRef("https://schema.org/mileageFromOdometer")
    EUEnergyEfficiencyCategoryD = URIRef("https://schema.org/EUEnergyEfficiencyCategoryD")
    MedicalIntangible = URIRef("https://schema.org/MedicalIntangible")
    UserPlays = URIRef("https://schema.org/UserPlays")
    textValue = URIRef("https://schema.org/textValue")
    significantLink = URIRef("https://schema.org/significantLink")
    hasDigitalDocumentPermission = URIRef("https://schema.org/hasDigitalDocumentPermission")
    Hardcover = URIRef("https://schema.org/Hardcover")
    CompletedActionStatus = URIRef("https://schema.org/CompletedActionStatus")
    EUEnergyEfficiencyCategoryA3Plus = URIRef("https://schema.org/EUEnergyEfficiencyCategoryA3Plus")
    arterialBranch = URIRef("https://schema.org/arterialBranch")
    WearableSizeSystemDE = URIRef("https://schema.org/WearableSizeSystemDE")
    Ultrasound = URIRef("https://schema.org/Ultrasound")
    Answer = URIRef("https://schema.org/Answer")
    dietFeatures = URIRef("https://schema.org/dietFeatures")
    IPTCDigitalSourceEnumeration = URIRef("https://schema.org/IPTCDigitalSourceEnumeration")
    seeks = URIRef("https://schema.org/seeks")
    TelevisionChannel = URIRef("https://schema.org/TelevisionChannel")
    ExerciseAction = URIRef("https://schema.org/ExerciseAction")
    Vein = URIRef("https://schema.org/Vein")
    geoIntersects = URIRef("https://schema.org/geoIntersects")
    DateTime = URIRef("https://schema.org/DateTime")
    dataset = URIRef("https://schema.org/dataset")
    broker = URIRef("https://schema.org/broker")
    availableThrough = URIRef("https://schema.org/availableThrough")
    SatireOrParodyContent = URIRef("https://schema.org/SatireOrParodyContent")
    SubwayStation = URIRef("https://schema.org/SubwayStation")
    serverStatus = URIRef("https://schema.org/serverStatus")
    TVSeason = URIRef("https://schema.org/TVSeason")
    potentialAction = URIRef("https://schema.org/potentialAction")
    OfferShippingDetails = URIRef("https://schema.org/OfferShippingDetails")
    arrivalTime = URIRef("https://schema.org/arrivalTime")
    underName = URIRef("https://schema.org/underName")
    UnofficialLegalValue = URIRef("https://schema.org/UnofficialLegalValue")
    modifiedTime = URIRef("https://schema.org/modifiedTime")
    WearableSizeGroupGirls = URIRef("https://schema.org/WearableSizeGroupGirls")
    WearableSizeGroupPetite = URIRef("https://schema.org/WearableSizeGroupPetite")
    LoanOrCredit = URIRef("https://schema.org/LoanOrCredit")
    Genetic = URIRef("https://schema.org/Genetic")
    Nonprofit501c13 = URIRef("https://schema.org/Nonprofit501c13")
    partOfSeries = URIRef("https://schema.org/partOfSeries")
    Barcode = URIRef("https://schema.org/Barcode")
    FreeReturn = URIRef("https://schema.org/FreeReturn")
    highPrice = URIRef("https://schema.org/highPrice")
    AchieveAction = URIRef("https://schema.org/AchieveAction")
    diagnosis = URIRef("https://schema.org/diagnosis")
    CategoryCode = URIRef("https://schema.org/CategoryCode")
    operatingSystem = URIRef("https://schema.org/operatingSystem")
    FullRefund = URIRef("https://schema.org/FullRefund")
    ActivationFee = URIRef("https://schema.org/ActivationFee")
    publication = URIRef("https://schema.org/publication")
    regionDrained = URIRef("https://schema.org/regionDrained")
    CheckAction = URIRef("https://schema.org/CheckAction")
    employerOverview = URIRef("https://schema.org/employerOverview")
    paymentDueDate = URIRef("https://schema.org/paymentDueDate")
    bodyLocation = URIRef("https://schema.org/bodyLocation")
    LiveAlbum = URIRef("https://schema.org/LiveAlbum")
    WearableMeasurementWidth = URIRef("https://schema.org/WearableMeasurementWidth")
    commentCount = URIRef("https://schema.org/commentCount")
    Question = URIRef("https://schema.org/Question")
    educationalLevel = URIRef("https://schema.org/educationalLevel")
    CourseInstance = URIRef("https://schema.org/CourseInstance")
    commentCount = URIRef("https://schema.org/commentCount")
    itemListOrder = URIRef("https://schema.org/itemListOrder")
    naturalProgression = URIRef("https://schema.org/naturalProgression")
    ArriveAction = URIRef("https://schema.org/ArriveAction")
    estimatesRiskOf = URIRef("https://schema.org/estimatesRiskOf")
    Dermatology = URIRef("https://schema.org/Dermatology")
    associatedClaimReview = URIRef("https://schema.org/associatedClaimReview")
    diseaseSpreadStatistics = URIRef("https://schema.org/diseaseSpreadStatistics")
    totalHistoricalEnrollment = URIRef("https://schema.org/totalHistoricalEnrollment")
    Crematorium = URIRef("https://schema.org/Crematorium")
    InStoreOnly = URIRef("https://schema.org/InStoreOnly")
    CoverArt = URIRef("https://schema.org/CoverArt")
    MusicGroup = URIRef("https://schema.org/MusicGroup")
    healthPlanNetworkTier = URIRef("https://schema.org/healthPlanNetworkTier")
    cargoVolume = URIRef("https://schema.org/cargoVolume")
    FoodEstablishmentReservation = URIRef("https://schema.org/FoodEstablishmentReservation")
    VisualArtsEvent = URIRef("https://schema.org/VisualArtsEvent")
    numberOfBeds = URIRef("https://schema.org/numberOfBeds")
    LaboratoryScience = URIRef("https://schema.org/LaboratoryScience")
    durationOfWarranty = URIRef("https://schema.org/durationOfWarranty")
    DeliveryEvent = URIRef("https://schema.org/DeliveryEvent")
    trackingUrl = URIRef("https://schema.org/trackingUrl")
    DaySpa = URIRef("https://schema.org/DaySpa")
    accommodationCategory = URIRef("https://schema.org/accommodationCategory")
    produces = URIRef("https://schema.org/produces")
    HealthInsurancePlan = URIRef("https://schema.org/HealthInsurancePlan")
    Museum = URIRef("https://schema.org/Museum")
    OneTimePayments = URIRef("https://schema.org/OneTimePayments")
    Reservoir = URIRef("https://schema.org/Reservoir")
    hasCourseInstance = URIRef("https://schema.org/hasCourseInstance")
    OnlineEventAttendanceMode = URIRef("https://schema.org/OnlineEventAttendanceMode")
    XPathType = URIRef("https://schema.org/XPathType")
    athlete = URIRef("https://schema.org/athlete")
    PropertyValue = URIRef("https://schema.org/PropertyValue")
    comment = URIRef("https://schema.org/comment")
    howPerformed = URIRef("https://schema.org/howPerformed")
    sharedContent = URIRef("https://schema.org/sharedContent")
    hasEnergyConsumptionDetails = URIRef("https://schema.org/hasEnergyConsumptionDetails")
    numberOfEmployees = URIRef("https://schema.org/numberOfEmployees")
    diet = URIRef("https://schema.org/diet")
    MedicalSignOrSymptom = URIRef("https://schema.org/MedicalSignOrSymptom")
    assembly = URIRef("https://schema.org/assembly")
    CreativeWorkSeries = URIRef("https://schema.org/CreativeWorkSeries")
    typicalCreditsPerTerm = URIRef("https://schema.org/typicalCreditsPerTerm")
    WarrantyPromise = URIRef("https://schema.org/WarrantyPromise")
    CompositeSyntheticDigitalSource = URIRef("https://schema.org/CompositeSyntheticDigitalSource")
    priceSpecification = URIRef("https://schema.org/priceSpecification")
    PriceTypeEnumeration = URIRef("https://schema.org/PriceTypeEnumeration")
    propertyID = URIRef("https://schema.org/propertyID")
    actionOption = URIRef("https://schema.org/actionOption")
    PropertyValueSpecification = URIRef("https://schema.org/PropertyValueSpecification")
    evidenceOrigin = URIRef("https://schema.org/evidenceOrigin")
    courseWorkload = URIRef("https://schema.org/courseWorkload")
    EvidenceLevelB = URIRef("https://schema.org/EvidenceLevelB")
    branchOf = URIRef("https://schema.org/branchOf")
    value = URIRef("https://schema.org/value")
    drainsTo = URIRef("https://schema.org/drainsTo")
    volumeNumber = URIRef("https://schema.org/volumeNumber")
    printSection = URIRef("https://schema.org/printSection")
    legislationLegalForce = URIRef("https://schema.org/legislationLegalForce")
    AchieveAction = URIRef("https://schema.org/AchieveAction")
    applicableLocation = URIRef("https://schema.org/applicableLocation")
    codeRepository = URIRef("https://schema.org/codeRepository")
    Motorcycle = URIRef("https://schema.org/Motorcycle")
    Nonprofit527 = URIRef("https://schema.org/Nonprofit527")
    hasPart = URIRef("https://schema.org/hasPart")
    arrivalStation = URIRef("https://schema.org/arrivalStation")
    tourBookingPage = URIRef("https://schema.org/tourBookingPage")
    UserCheckins = URIRef("https://schema.org/UserCheckins")
    language = URIRef("https://schema.org/language")
    numberOfRooms = URIRef("https://schema.org/numberOfRooms")
    jobBenefits = URIRef("https://schema.org/jobBenefits")
    artist = URIRef("https://schema.org/artist")
    SurgicalProcedure = URIRef("https://schema.org/SurgicalProcedure")
    borrower = URIRef("https://schema.org/borrower")
    RentAction = URIRef("https://schema.org/RentAction")
    Obstetric = URIRef("https://schema.org/Obstetric")
    PlasticSurgery = URIRef("https://schema.org/PlasticSurgery")
    musicArrangement = URIRef("https://schema.org/musicArrangement")
    DefinedTerm = URIRef("https://schema.org/DefinedTerm")
    numberOfRooms = URIRef("https://schema.org/numberOfRooms")
    reservationFor = URIRef("https://schema.org/reservationFor")
    numberOfAxles = URIRef("https://schema.org/numberOfAxles")
    acquiredFrom = URIRef("https://schema.org/acquiredFrom")
    BookStore = URIRef("https://schema.org/BookStore")
    Chiropractic = URIRef("https://schema.org/Chiropractic")
    programmingLanguage = URIRef("https://schema.org/programmingLanguage")
    tracks = URIRef("https://schema.org/tracks")
    HomeAndConstructionBusiness = URIRef("https://schema.org/HomeAndConstructionBusiness")
    HealthcareConsideration = URIRef("https://schema.org/HealthcareConsideration")
    infectiousAgentClass = URIRef("https://schema.org/infectiousAgentClass")
    actors = URIRef("https://schema.org/actors")
    Nonprofit501c1 = URIRef("https://schema.org/Nonprofit501c1")
    variableMeasured = URIRef("https://schema.org/variableMeasured")
    starRating = URIRef("https://schema.org/starRating")
    Therapeutic = URIRef("https://schema.org/Therapeutic")
    ActionAccessSpecification = URIRef("https://schema.org/ActionAccessSpecification")
    Diet = URIRef("https://schema.org/Diet")
    Nonprofit501c27 = URIRef("https://schema.org/Nonprofit501c27")
    availableFrom = URIRef("https://schema.org/availableFrom")
    cssSelector = URIRef("https://schema.org/cssSelector")
    totalJobOpenings = URIRef("https://schema.org/totalJobOpenings")
    TrainedAlgorithmicMediaDigitalSource = URIRef("https://schema.org/TrainedAlgorithmicMediaDigitalSource")
    isPlanForApartment = URIRef("https://schema.org/isPlanForApartment")
    BodyOfWater = URIRef("https://schema.org/BodyOfWater")
    encodesBioChemEntity = URIRef("https://schema.org/encodesBioChemEntity")
    Product = URIRef("https://schema.org/Product")
    diseasePreventionInfo = URIRef("https://schema.org/diseasePreventionInfo")
    episodes = URIRef("https://schema.org/episodes")
    masthead = URIRef("https://schema.org/masthead")
    endDate = URIRef("https://schema.org/endDate")
    trailer = URIRef("https://schema.org/trailer")
    recipeCategory = URIRef("https://schema.org/recipeCategory")
    numberOfFullBathrooms = URIRef("https://schema.org/numberOfFullBathrooms")
    HairSalon = URIRef("https://schema.org/HairSalon")
    SuspendAction = URIRef("https://schema.org/SuspendAction")
    ItemListOrderAscending = URIRef("https://schema.org/ItemListOrderAscending")
    accessModeSufficient = URIRef("https://schema.org/accessModeSufficient")
    Substance = URIRef("https://schema.org/Substance")
    monthlyMinimumRepaymentAmount = URIRef("https://schema.org/monthlyMinimumRepaymentAmount")
    AnatomicalSystem = URIRef("https://schema.org/AnatomicalSystem")
    aircraft = URIRef("https://schema.org/aircraft")
    AmpStory = URIRef("https://schema.org/AmpStory")
    supplyTo = URIRef("https://schema.org/supplyTo")
    ReturnMethodEnumeration = URIRef("https://schema.org/ReturnMethodEnumeration")
    requiredCollateral = URIRef("https://schema.org/requiredCollateral")
    DiagnosticProcedure = URIRef("https://schema.org/DiagnosticProcedure")
    experienceRequirements = URIRef("https://schema.org/experienceRequirements")
    emissionsCO2 = URIRef("https://schema.org/emissionsCO2")
    Taxon = URIRef("https://schema.org/Taxon")
    assesses = URIRef("https://schema.org/assesses")
    warranty = URIRef("https://schema.org/warranty")
    applicationStartDate = URIRef("https://schema.org/applicationStartDate")
    MedicalStudy = URIRef("https://schema.org/MedicalStudy")
    EntertainmentBusiness = URIRef("https://schema.org/EntertainmentBusiness")
    currentExchangeRate = URIRef("https://schema.org/currentExchangeRate")
    EducationEvent = URIRef("https://schema.org/EducationEvent")
    MenuItem = URIRef("https://schema.org/MenuItem")
    stageAsNumber = URIRef("https://schema.org/stageAsNumber")
    BodyMeasurementUnderbust = URIRef("https://schema.org/BodyMeasurementUnderbust")
    roleName = URIRef("https://schema.org/roleName")
    seatingCapacity = URIRef("https://schema.org/seatingCapacity")
    RadioEpisode = URIRef("https://schema.org/RadioEpisode")
    BoardingPolicyType = URIRef("https://schema.org/BoardingPolicyType")
    Church = URIRef("https://schema.org/Church")
    programType = URIRef("https://schema.org/programType")
    ownedFrom = URIRef("https://schema.org/ownedFrom")
    FinancialProduct = URIRef("https://schema.org/FinancialProduct")
    Renal = URIRef("https://schema.org/Renal")
    AudioObject = URIRef("https://schema.org/AudioObject")
    regionsAllowed = URIRef("https://schema.org/regionsAllowed")
    healthCondition = URIRef("https://schema.org/healthCondition")
    BarOrPub = URIRef("https://schema.org/BarOrPub")
    GovernmentBenefitsType = URIRef("https://schema.org/GovernmentBenefitsType")
    latitude = URIRef("https://schema.org/latitude")
    typicalTest = URIRef("https://schema.org/typicalTest")
    saturatedFatContent = URIRef("https://schema.org/saturatedFatContent")
    PrintDigitalSource = URIRef("https://schema.org/PrintDigitalSource")
    asin = URIRef("https://schema.org/asin")
    meetsEmissionStandard = URIRef("https://schema.org/meetsEmissionStandard")
    bookingAgent = URIRef("https://schema.org/bookingAgent")
    monoisotopicMolecularWeight = URIRef("https://schema.org/monoisotopicMolecularWeight")
    transmissionMethod = URIRef("https://schema.org/transmissionMethod")
    MusicAlbumProductionType = URIRef("https://schema.org/MusicAlbumProductionType")
    energyEfficiencyScaleMin = URIRef("https://schema.org/energyEfficiencyScaleMin")
    application = URIRef("https://schema.org/application")
    Researcher = URIRef("https://schema.org/Researcher")
    InfectiousAgentClass = URIRef("https://schema.org/InfectiousAgentClass")
    contentUrl = URIRef("https://schema.org/contentUrl")
    reviewCount = URIRef("https://schema.org/reviewCount")
    EventVenue = URIRef("https://schema.org/EventVenue")
    season = URIRef("https://schema.org/season")
    ReceiveAction = URIRef("https://schema.org/ReceiveAction")
    legislationJurisdiction = URIRef("https://schema.org/legislationJurisdiction")
    accountablePerson = URIRef("https://schema.org/accountablePerson")
    itinerary = URIRef("https://schema.org/itinerary")
    VoteAction = URIRef("https://schema.org/VoteAction")
    Service = URIRef("https://schema.org/Service")
    itemDefectReturnLabelSource = URIRef("https://schema.org/itemDefectReturnLabelSource")
    lender = URIRef("https://schema.org/lender")
    review = URIRef("https://schema.org/review")
    warranty = URIRef("https://schema.org/warranty")
    OfferForPurchase = URIRef("https://schema.org/OfferForPurchase")
    byMonthDay = URIRef("https://schema.org/byMonthDay")
    legislationDateVersion = URIRef("https://schema.org/legislationDateVersion")
    typicalCreditsPerTerm = URIRef("https://schema.org/typicalCreditsPerTerm")
    originalMediaContextDescription = URIRef("https://schema.org/originalMediaContextDescription")
    ticketNumber = URIRef("https://schema.org/ticketNumber")
    documentation = URIRef("https://schema.org/documentation")
    DrugStrength = URIRef("https://schema.org/DrugStrength")
    inProductGroupWithID = URIRef("https://schema.org/inProductGroupWithID")
    creator = URIRef("https://schema.org/creator")
    AutoRepair = URIRef("https://schema.org/AutoRepair")
    HowToSection = URIRef("https://schema.org/HowToSection")
    offers = URIRef("https://schema.org/offers")
    knows = URIRef("https://schema.org/knows")
    artworkSurface = URIRef("https://schema.org/artworkSurface")
    cvdFacilityId = URIRef("https://schema.org/cvdFacilityId")
    LodgingReservation = URIRef("https://schema.org/LodgingReservation")
    expectedArrivalUntil = URIRef("https://schema.org/expectedArrivalUntil")
    owns = URIRef("https://schema.org/owns")
    ProfilePage = URIRef("https://schema.org/ProfilePage")
    BrainStructure = URIRef("https://schema.org/BrainStructure")
    area = URIRef("https://schema.org/area")
    bed = URIRef("https://schema.org/bed")
    provider = URIRef("https://schema.org/provider")
    HyperToc = URIRef("https://schema.org/HyperToc")
    AudioObject = URIRef("https://schema.org/AudioObject")
    timeRequired = URIRef("https://schema.org/timeRequired")
    courseCode = URIRef("https://schema.org/courseCode")
    isicV4 = URIRef("https://schema.org/isicV4")
    closes = URIRef("https://schema.org/closes")
    Nose = URIRef("https://schema.org/Nose")
    quarantineGuidelines = URIRef("https://schema.org/quarantineGuidelines")
    ticketedSeat = URIRef("https://schema.org/ticketedSeat")
    suggestedMaxAge = URIRef("https://schema.org/suggestedMaxAge")
    creditText = URIRef("https://schema.org/creditText")
    TaxiService = URIRef("https://schema.org/TaxiService")
    originAddress = URIRef("https://schema.org/originAddress")
    InfectiousAgentClass = URIRef("https://schema.org/InfectiousAgentClass")
    documentation = URIRef("https://schema.org/documentation")
    drugUnit = URIRef("https://schema.org/drugUnit")
    applicationSubCategory = URIRef("https://schema.org/applicationSubCategory")
    colleague = URIRef("https://schema.org/colleague")
    Attorney = URIRef("https://schema.org/Attorney")
    seller = URIRef("https://schema.org/seller")
    departureTime = URIRef("https://schema.org/departureTime")
    musicBy = URIRef("https://schema.org/musicBy")
    manufacturer = URIRef("https://schema.org/manufacturer")
    arrivalTime = URIRef("https://schema.org/arrivalTime")
    applicationStartDate = URIRef("https://schema.org/applicationStartDate")
    Guide = URIRef("https://schema.org/Guide")
    sameAs = URIRef("https://schema.org/sameAs")
    MedicalConditionStage = URIRef("https://schema.org/MedicalConditionStage")
    vehicleSpecialUsage = URIRef("https://schema.org/vehicleSpecialUsage")
    MedicalWebPage = URIRef("https://schema.org/MedicalWebPage")
    printPage = URIRef("https://schema.org/printPage")
    multipleValues = URIRef("https://schema.org/multipleValues")
    MedicalRiskFactor = URIRef("https://schema.org/MedicalRiskFactor")
    startOffset = URIRef("https://schema.org/startOffset")
    iso6523Code = URIRef("https://schema.org/iso6523Code")
    sensoryRequirement = URIRef("https://schema.org/sensoryRequirement")
    Statement = URIRef("https://schema.org/Statement")
    cookTime = URIRef("https://schema.org/cookTime")
    AutomatedTeller = URIRef("https://schema.org/AutomatedTeller")
    position = URIRef("https://schema.org/position")
    playerType = URIRef("https://schema.org/playerType")
    WearableSizeSystemDE = URIRef("https://schema.org/WearableSizeSystemDE")
    publishingPrinciples = URIRef("https://schema.org/publishingPrinciples")
    box = URIRef("https://schema.org/box")
    WearableSizeSystemBR = URIRef("https://schema.org/WearableSizeSystemBR")
    petsAllowed = URIRef("https://schema.org/petsAllowed")
    proprietaryName = URIRef("https://schema.org/proprietaryName")
    stage = URIRef("https://schema.org/stage")
    serviceAudience = URIRef("https://schema.org/serviceAudience")
    cvdNumVent = URIRef("https://schema.org/cvdNumVent")
    BroadcastFrequencySpecification = URIRef("https://schema.org/BroadcastFrequencySpecification")
    WarrantyScope = URIRef("https://schema.org/WarrantyScope")
    legislationTransposes = URIRef("https://schema.org/legislationTransposes")
    eventSchedule = URIRef("https://schema.org/eventSchedule")
    featureList = URIRef("https://schema.org/featureList")
    availableFrom = URIRef("https://schema.org/availableFrom")
    MultiPlayer = URIRef("https://schema.org/MultiPlayer")
    suitableForDiet = URIRef("https://schema.org/suitableForDiet")
    EventVenue = URIRef("https://schema.org/EventVenue")
    copyrightHolder = URIRef("https://schema.org/copyrightHolder")
    Date = URIRef("https://schema.org/Date")
    director = URIRef("https://schema.org/director")
    layoutImage = URIRef("https://schema.org/layoutImage")
    AmpStory = URIRef("https://schema.org/AmpStory")
    softwareRequirements = URIRef("https://schema.org/softwareRequirements")
    NotInForce = URIRef("https://schema.org/NotInForce")
    MonetaryGrant = URIRef("https://schema.org/MonetaryGrant")
    identifier = URIRef("https://schema.org/identifier")
    nonProprietaryName = URIRef("https://schema.org/nonProprietaryName")
    UserComments = URIRef("https://schema.org/UserComments")
    EventReservation = URIRef("https://schema.org/EventReservation")
    workHours = URIRef("https://schema.org/workHours")
    ServiceChannel = URIRef("https://schema.org/ServiceChannel")
    events = URIRef("https://schema.org/events")
    certificationIdentification = URIRef("https://schema.org/certificationIdentification")
    Gastroenterologic = URIRef("https://schema.org/Gastroenterologic")
    DeliveryMethod = URIRef("https://schema.org/DeliveryMethod")
    Nonprofit501c5 = URIRef("https://schema.org/Nonprofit501c5")
    MedicalCode = URIRef("https://schema.org/MedicalCode")
    EBook = URIRef("https://schema.org/EBook")
    greater = URIRef("https://schema.org/greater")
    productGroupID = URIRef("https://schema.org/productGroupID")
    loser = URIRef("https://schema.org/loser")
    UserPageVisits = URIRef("https://schema.org/UserPageVisits")
    PhysicalActivityCategory = URIRef("https://schema.org/PhysicalActivityCategory")
    awards = URIRef("https://schema.org/awards")
    MerchantReturnFiniteReturnWindow = URIRef("https://schema.org/MerchantReturnFiniteReturnWindow")
    SportsClub = URIRef("https://schema.org/SportsClub")
    EvidenceLevelB = URIRef("https://schema.org/EvidenceLevelB")
    CheckOutAction = URIRef("https://schema.org/CheckOutAction")
    numberOfDoors = URIRef("https://schema.org/numberOfDoors")
    isResizable = URIRef("https://schema.org/isResizable")
    Nonprofit501c3 = URIRef("https://schema.org/Nonprofit501c3")
    editEIDR = URIRef("https://schema.org/editEIDR")
    CurrencyConversionService = URIRef("https://schema.org/CurrencyConversionService")
    ConvenienceStore = URIRef("https://schema.org/ConvenienceStore")
    PaymentPastDue = URIRef("https://schema.org/PaymentPastDue")
    ExchangeRateSpecification = URIRef("https://schema.org/ExchangeRateSpecification")
    PaymentChargeSpecification = URIRef("https://schema.org/PaymentChargeSpecification")
    Quiz = URIRef("https://schema.org/Quiz")
    isPartOfBioChemEntity = URIRef("https://schema.org/isPartOfBioChemEntity")
    numberOfBedrooms = URIRef("https://schema.org/numberOfBedrooms")
    sportsTeam = URIRef("https://schema.org/sportsTeam")
    keywords = URIRef("https://schema.org/keywords")
    closes = URIRef("https://schema.org/closes")
    associatedMediaReview = URIRef("https://schema.org/associatedMediaReview")
    subTrip = URIRef("https://schema.org/subTrip")
    BrokerageAccount = URIRef("https://schema.org/BrokerageAccount")
    ccRecipient = URIRef("https://schema.org/ccRecipient")
    variesBy = URIRef("https://schema.org/variesBy")
    ingredients = URIRef("https://schema.org/ingredients")
    circle = URIRef("https://schema.org/circle")
    ReservationStatusType = URIRef("https://schema.org/ReservationStatusType")
    signDetected = URIRef("https://schema.org/signDetected")
    BlogPosting = URIRef("https://schema.org/BlogPosting")
    directors = URIRef("https://schema.org/directors")
    DrugClass = URIRef("https://schema.org/DrugClass")
    code = URIRef("https://schema.org/code")
    experienceRequirements = URIRef("https://schema.org/experienceRequirements")
    availableChannel = URIRef("https://schema.org/availableChannel")
    transFatContent = URIRef("https://schema.org/transFatContent")
    expectsAcceptanceOf = URIRef("https://schema.org/expectsAcceptanceOf")
    gameTip = URIRef("https://schema.org/gameTip")
    mpn = URIRef("https://schema.org/mpn")
    Mosque = URIRef("https://schema.org/Mosque")
    refundType = URIRef("https://schema.org/refundType")
    parentService = URIRef("https://schema.org/parentService")
    review = URIRef("https://schema.org/review")
    TravelAgency = URIRef("https://schema.org/TravelAgency")
    WearableSizeSystemAU = URIRef("https://schema.org/WearableSizeSystemAU")
    actionOption = URIRef("https://schema.org/actionOption")
    containedInPlace = URIRef("https://schema.org/containedInPlace")
    Nonprofit501c14 = URIRef("https://schema.org/Nonprofit501c14")
    inLanguage = URIRef("https://schema.org/inLanguage")
    taxonomicRange = URIRef("https://schema.org/taxonomicRange")
    specialCommitments = URIRef("https://schema.org/specialCommitments")
    NewsArticle = URIRef("https://schema.org/NewsArticle")
    CheckoutPage = URIRef("https://schema.org/CheckoutPage")
    departurePlatform = URIRef("https://schema.org/departurePlatform")
    unitCode = URIRef("https://schema.org/unitCode")
    BedDetails = URIRef("https://schema.org/BedDetails")
    eligibilityToWorkRequirement = URIRef("https://schema.org/eligibilityToWorkRequirement")
    PositiveFilmDigitalSource = URIRef("https://schema.org/PositiveFilmDigitalSource")
    ratingValue = URIRef("https://schema.org/ratingValue")
    legislationTransposes = URIRef("https://schema.org/legislationTransposes")
    memberOf = URIRef("https://schema.org/memberOf")
    suggestedAnswer = URIRef("https://schema.org/suggestedAnswer")
    algorithm = URIRef("https://schema.org/algorithm")
    NonprofitANBI = URIRef("https://schema.org/NonprofitANBI")
    SubwayStation = URIRef("https://schema.org/SubwayStation")
    medicalSpecialty = URIRef("https://schema.org/medicalSpecialty")
    SurgicalProcedure = URIRef("https://schema.org/SurgicalProcedure")
    referenceQuantity = URIRef("https://schema.org/referenceQuantity")
    NegativeFilmDigitalSource = URIRef("https://schema.org/NegativeFilmDigitalSource")
    landlord = URIRef("https://schema.org/landlord")
    isVariantOf = URIRef("https://schema.org/isVariantOf")
    itemDefectReturnFees = URIRef("https://schema.org/itemDefectReturnFees")
    AdvertiserContentArticle = URIRef("https://schema.org/AdvertiserContentArticle")
    sport = URIRef("https://schema.org/sport")
    priceComponentType = URIRef("https://schema.org/priceComponentType")
    distribution = URIRef("https://schema.org/distribution")
    RisksOrComplicationsHealthAspect = URIRef("https://schema.org/RisksOrComplicationsHealthAspect")
    recipeCuisine = URIRef("https://schema.org/recipeCuisine")
    benefitsSummaryUrl = URIRef("https://schema.org/benefitsSummaryUrl")
    BodyMeasurementHips = URIRef("https://schema.org/BodyMeasurementHips")
    thumbnailUrl = URIRef("https://schema.org/thumbnailUrl")
    carrier = URIRef("https://schema.org/carrier")
    NutritionInformation = URIRef("https://schema.org/NutritionInformation")
    hasVariant = URIRef("https://schema.org/hasVariant")
    associatedAnatomy = URIRef("https://schema.org/associatedAnatomy")
    endorsee = URIRef("https://schema.org/endorsee")
    activityDuration = URIRef("https://schema.org/activityDuration")
    sender = URIRef("https://schema.org/sender")
    BedAndBreakfast = URIRef("https://schema.org/BedAndBreakfast")
    MapCategoryType = URIRef("https://schema.org/MapCategoryType")
    EventSeries = URIRef("https://schema.org/EventSeries")
    flightDistance = URIRef("https://schema.org/flightDistance")
    Motel = URIRef("https://schema.org/Motel")
    Thesis = URIRef("https://schema.org/Thesis")
    DangerousGoodConsideration = URIRef("https://schema.org/DangerousGoodConsideration")
    parent = URIRef("https://schema.org/parent")
    HyperTocEntry = URIRef("https://schema.org/HyperTocEntry")
    GenericWebPlatform = URIRef("https://schema.org/GenericWebPlatform")
    regionsAllowed = URIRef("https://schema.org/regionsAllowed")
    DataFeed = URIRef("https://schema.org/DataFeed")
    ImageObjectSnapshot = URIRef("https://schema.org/ImageObjectSnapshot")
    MediaSubscription = URIRef("https://schema.org/MediaSubscription")
    RestockingFees = URIRef("https://schema.org/RestockingFees")
    OrderDelivered = URIRef("https://schema.org/OrderDelivered")
    fatContent = URIRef("https://schema.org/fatContent")
    GraphicNovel = URIRef("https://schema.org/GraphicNovel")
    procedureType = URIRef("https://schema.org/procedureType")
    DigitalDocumentPermission = URIRef("https://schema.org/DigitalDocumentPermission")
    qualifications = URIRef("https://schema.org/qualifications")
    PronounceableText = URIRef("https://schema.org/PronounceableText")
    Order = URIRef("https://schema.org/Order")
    loanPaymentFrequency = URIRef("https://schema.org/loanPaymentFrequency")
    musicBy = URIRef("https://schema.org/musicBy")
    functionalClass = URIRef("https://schema.org/functionalClass")
    GovernmentPermit = URIRef("https://schema.org/GovernmentPermit")
    expectsAcceptanceOf = URIRef("https://schema.org/expectsAcceptanceOf")
    hasHealthAspect = URIRef("https://schema.org/hasHealthAspect")
    iataCode = URIRef("https://schema.org/iataCode")
    menuAddOn = URIRef("https://schema.org/menuAddOn")
    maxValue = URIRef("https://schema.org/maxValue")
    tool = URIRef("https://schema.org/tool")
    SoundtrackAlbum = URIRef("https://schema.org/SoundtrackAlbum")
    buyer = URIRef("https://schema.org/buyer")
    AllWheelDriveConfiguration = URIRef("https://schema.org/AllWheelDriveConfiguration")
    TollFree = URIRef("https://schema.org/TollFree")
    audience = URIRef("https://schema.org/audience")
    DistanceFee = URIRef("https://schema.org/DistanceFee")
    MovieSeries = URIRef("https://schema.org/MovieSeries")
    artform = URIRef("https://schema.org/artform")
    preparation = URIRef("https://schema.org/preparation")
    requiredMaxAge = URIRef("https://schema.org/requiredMaxAge")
    cvdNumBeds = URIRef("https://schema.org/cvdNumBeds")
    UnemploymentSupport = URIRef("https://schema.org/UnemploymentSupport")
    totalJobOpenings = URIRef("https://schema.org/totalJobOpenings")
    inSupportOf = URIRef("https://schema.org/inSupportOf")
    tongueWeight = URIRef("https://schema.org/tongueWeight")
    LeisureTimeActivity = URIRef("https://schema.org/LeisureTimeActivity")
    exchangeRateSpread = URIRef("https://schema.org/exchangeRateSpread")
    DigitalArtDigitalSource = URIRef("https://schema.org/DigitalArtDigitalSource")
    CategoryCodeSet = URIRef("https://schema.org/CategoryCodeSet")
    doseValue = URIRef("https://schema.org/doseValue")
    deliveryMethod = URIRef("https://schema.org/deliveryMethod")
    winner = URIRef("https://schema.org/winner")
    realEstateAgent = URIRef("https://schema.org/realEstateAgent")
    populationType = URIRef("https://schema.org/populationType")
    SubscribeAction = URIRef("https://schema.org/SubscribeAction")
    usNPI = URIRef("https://schema.org/usNPI")
    isPlanForApartment = URIRef("https://schema.org/isPlanForApartment")
    VirtualLocation = URIRef("https://schema.org/VirtualLocation")
    VideoObjectSnapshot = URIRef("https://schema.org/VideoObjectSnapshot")
    feesAndCommissionsSpecification = URIRef("https://schema.org/feesAndCommissionsSpecification")
    Nonprofit501c14 = URIRef("https://schema.org/Nonprofit501c14")
    PositiveFilmDigitalSource = URIRef("https://schema.org/PositiveFilmDigitalSource")
    CheckoutPage = URIRef("https://schema.org/CheckoutPage")
    sdLicense = URIRef("https://schema.org/sdLicense")
    ExchangeRefund = URIRef("https://schema.org/ExchangeRefund")
    InformAction = URIRef("https://schema.org/InformAction")
    Nonprofit501c9 = URIRef("https://schema.org/Nonprofit501c9")
    height = URIRef("https://schema.org/height")
    sizeGroup = URIRef("https://schema.org/sizeGroup")
    NotInForce = URIRef("https://schema.org/NotInForce")
    AnalysisNewsArticle = URIRef("https://schema.org/AnalysisNewsArticle")
    encodesBioChemEntity = URIRef("https://schema.org/encodesBioChemEntity")
    BankAccount = URIRef("https://schema.org/BankAccount")
    DepositAccount = URIRef("https://schema.org/DepositAccount")
    trainName = URIRef("https://schema.org/trainName")
    WearableSizeGroupWomens = URIRef("https://schema.org/WearableSizeGroupWomens")
    Class = URIRef("https://schema.org/Class")
    option = URIRef("https://schema.org/option")
    Role = URIRef("https://schema.org/Role")
    ContactPage = URIRef("https://schema.org/ContactPage")
    characterAttribute = URIRef("https://schema.org/characterAttribute")
    valueReference = URIRef("https://schema.org/valueReference")
    Action = URIRef("https://schema.org/Action")
    MedicineSystem = URIRef("https://schema.org/MedicineSystem")
    PhysicalExam = URIRef("https://schema.org/PhysicalExam")
    frequency = URIRef("https://schema.org/frequency")
    CreativeWork = URIRef("https://schema.org/CreativeWork")
    LeaveAction = URIRef("https://schema.org/LeaveAction")
    availableAtOrFrom = URIRef("https://schema.org/availableAtOrFrom")
    BankOrCreditUnion = URIRef("https://schema.org/BankOrCreditUnion")
    BedType = URIRef("https://schema.org/BedType")
    GroceryStore = URIRef("https://schema.org/GroceryStore")
    diagram = URIRef("https://schema.org/diagram")
    cvdNumICUBedsOcc = URIRef("https://schema.org/cvdNumICUBedsOcc")
    Table = URIRef("https://schema.org/Table")
    musicCompositionForm = URIRef("https://schema.org/musicCompositionForm")
    linkRelationship = URIRef("https://schema.org/linkRelationship")
    sponsor = URIRef("https://schema.org/sponsor")
    datePosted = URIRef("https://schema.org/datePosted")
    ownershipFundingInfo = URIRef("https://schema.org/ownershipFundingInfo")
    maintainer = URIRef("https://schema.org/maintainer")
    FundingScheme = URIRef("https://schema.org/FundingScheme")
    releasedEvent = URIRef("https://schema.org/releasedEvent")
    startDate = URIRef("https://schema.org/startDate")
    FAQPage = URIRef("https://schema.org/FAQPage")
    Substance = URIRef("https://schema.org/Substance")
    WebContent = URIRef("https://schema.org/WebContent")
    application = URIRef("https://schema.org/application")
    temporal = URIRef("https://schema.org/temporal")
    JewelryStore = URIRef("https://schema.org/JewelryStore")
    sensoryUnit = URIRef("https://schema.org/sensoryUnit")
    isProprietary = URIRef("https://schema.org/isProprietary")
    infectiousAgent = URIRef("https://schema.org/infectiousAgent")
    Physiotherapy = URIRef("https://schema.org/Physiotherapy")
    director = URIRef("https://schema.org/director")
    recipeInstructions = URIRef("https://schema.org/recipeInstructions")
    editEIDR = URIRef("https://schema.org/editEIDR")
    OrderProblem = URIRef("https://schema.org/OrderProblem")
    MedicalTestPanel = URIRef("https://schema.org/MedicalTestPanel")
    WearableSizeSystemEnumeration = URIRef("https://schema.org/WearableSizeSystemEnumeration")
    EventSeries = URIRef("https://schema.org/EventSeries")
    numberOfAvailableAccommodationUnits = URIRef("https://schema.org/numberOfAvailableAccommodationUnits")
    InvestmentFund = URIRef("https://schema.org/InvestmentFund")
    audience = URIRef("https://schema.org/audience")
    editEIDR = URIRef("https://schema.org/editEIDR")
    DiagnosticProcedure = URIRef("https://schema.org/DiagnosticProcedure")
    BoatTrip = URIRef("https://schema.org/BoatTrip")
    serviceAudience = URIRef("https://schema.org/serviceAudience")
    musicReleaseFormat = URIRef("https://schema.org/musicReleaseFormat")
    RightHandDriving = URIRef("https://schema.org/RightHandDriving")
    SheetMusic = URIRef("https://schema.org/SheetMusic")
    creditText = URIRef("https://schema.org/creditText")
    nerve = URIRef("https://schema.org/nerve")
    Nonprofit501c28 = URIRef("https://schema.org/Nonprofit501c28")
    validIn = URIRef("https://schema.org/validIn")
    expressedIn = URIRef("https://schema.org/expressedIn")
    LivingWithHealthAspect = URIRef("https://schema.org/LivingWithHealthAspect")
    EnergyStarEnergyEfficiencyEnumeration = URIRef("https://schema.org/EnergyStarEnergyEfficiencyEnumeration")
    publishedOn = URIRef("https://schema.org/publishedOn")
    CivicStructure = URIRef("https://schema.org/CivicStructure")
    merchantReturnDays = URIRef("https://schema.org/merchantReturnDays")
    funding = URIRef("https://schema.org/funding")
    dateline = URIRef("https://schema.org/dateline")
    distance = URIRef("https://schema.org/distance")
    CssSelectorType = URIRef("https://schema.org/CssSelectorType")
    Dentist = URIRef("https://schema.org/Dentist")
    coursePrerequisites = URIRef("https://schema.org/coursePrerequisites")
    HotelRoom = URIRef("https://schema.org/HotelRoom")
    episode = URIRef("https://schema.org/episode")
    WearableMeasurementBack = URIRef("https://schema.org/WearableMeasurementBack")
    WearAction = URIRef("https://schema.org/WearAction")
    temporalCoverage = URIRef("https://schema.org/temporalCoverage")
    OfferForPurchase = URIRef("https://schema.org/OfferForPurchase")
    tissueSample = URIRef("https://schema.org/tissueSample")
    recognizingAuthority = URIRef("https://schema.org/recognizingAuthority")
    financialAidEligible = URIRef("https://schema.org/financialAidEligible")
    isAcceptingNewPatients = URIRef("https://schema.org/isAcceptingNewPatients")
    ccRecipient = URIRef("https://schema.org/ccRecipient")
    labelDetails = URIRef("https://schema.org/labelDetails")
    antagonist = URIRef("https://schema.org/antagonist")
    smokingAllowed = URIRef("https://schema.org/smokingAllowed")
    isLiveBroadcast = URIRef("https://schema.org/isLiveBroadcast")
    isLocatedInSubcellularLocation = URIRef("https://schema.org/isLocatedInSubcellularLocation")
    referenceQuantity = URIRef("https://schema.org/referenceQuantity")
    paymentMethod = URIRef("https://schema.org/paymentMethod")
    homeTeam = URIRef("https://schema.org/homeTeam")
    Corporation = URIRef("https://schema.org/Corporation")
    Mosque = URIRef("https://schema.org/Mosque")
    AudioObject = URIRef("https://schema.org/AudioObject")
    targetUrl = URIRef("https://schema.org/targetUrl")
    referenceQuantity = URIRef("https://schema.org/referenceQuantity")
    TouristAttraction = URIRef("https://schema.org/TouristAttraction")
    Neuro = URIRef("https://schema.org/Neuro")
    keywords = URIRef("https://schema.org/keywords")
    reviewRating = URIRef("https://schema.org/reviewRating")
    ActionStatusType = URIRef("https://schema.org/ActionStatusType")
    CommentAction = URIRef("https://schema.org/CommentAction")
    workFeatured = URIRef("https://schema.org/workFeatured")
    FurnitureStore = URIRef("https://schema.org/FurnitureStore")
    openingHours = URIRef("https://schema.org/openingHours")
    SizeSystemMetric = URIRef("https://schema.org/SizeSystemMetric")
    arrivalPlatform = URIRef("https://schema.org/arrivalPlatform")
    offeredBy = URIRef("https://schema.org/offeredBy")
    Pediatric = URIRef("https://schema.org/Pediatric")
    beneficiaryBank = URIRef("https://schema.org/beneficiaryBank")
    OfferForPurchase = URIRef("https://schema.org/OfferForPurchase")
    rsvpResponse = URIRef("https://schema.org/rsvpResponse")
    cvdCollectionDate = URIRef("https://schema.org/cvdCollectionDate")
    gamePlatform = URIRef("https://schema.org/gamePlatform")
    arrivalTime = URIRef("https://schema.org/arrivalTime")
    CommentAction = URIRef("https://schema.org/CommentAction")
    discount = URIRef("https://schema.org/discount")
    flightDistance = URIRef("https://schema.org/flightDistance")
    value = URIRef("https://schema.org/value")
    legalStatus = URIRef("https://schema.org/legalStatus")
    FloorPlan = URIRef("https://schema.org/FloorPlan")
    relatedTherapy = URIRef("https://schema.org/relatedTherapy")
    prepTime = URIRef("https://schema.org/prepTime")
    AnatomicalSystem = URIRef("https://schema.org/AnatomicalSystem")
    fuelType = URIRef("https://schema.org/fuelType")
    Ayurvedic = URIRef("https://schema.org/Ayurvedic")
    BodyMeasurementHeight = URIRef("https://schema.org/BodyMeasurementHeight")
    guideline = URIRef("https://schema.org/guideline")
    negativeNotes = URIRef("https://schema.org/negativeNotes")
    workLocation = URIRef("https://schema.org/workLocation")
    includesAttraction = URIRef("https://schema.org/includesAttraction")
    ClaimReview = URIRef("https://schema.org/ClaimReview")
    isUnlabelledFallback = URIRef("https://schema.org/isUnlabelledFallback")
    Throat = URIRef("https://schema.org/Throat")
    recipeCuisine = URIRef("https://schema.org/recipeCuisine")
    WebPageElement = URIRef("https://schema.org/WebPageElement")
    RisksOrComplicationsHealthAspect = URIRef("https://schema.org/RisksOrComplicationsHealthAspect")
    TheaterEvent = URIRef("https://schema.org/TheaterEvent")
    PET = URIRef("https://schema.org/PET")
    Optometric = URIRef("https://schema.org/Optometric")
    transmissionMethod = URIRef("https://schema.org/transmissionMethod")
    duns = URIRef("https://schema.org/duns")
    ShareAction = URIRef("https://schema.org/ShareAction")
    tourBookingPage = URIRef("https://schema.org/tourBookingPage")
    vendor = URIRef("https://schema.org/vendor")
    Artery = URIRef("https://schema.org/Artery")
    geoOverlaps = URIRef("https://schema.org/geoOverlaps")
    alumniOf = URIRef("https://schema.org/alumniOf")
    Hostel = URIRef("https://schema.org/Hostel")
    School = URIRef("https://schema.org/School")
    HowOrWhereHealthAspect = URIRef("https://schema.org/HowOrWhereHealthAspect")
    isRelatedTo = URIRef("https://schema.org/isRelatedTo")
    AutoRental = URIRef("https://schema.org/AutoRental")
    LocationFeatureSpecification = URIRef("https://schema.org/LocationFeatureSpecification")
    WearableMeasurementCollar = URIRef("https://schema.org/WearableMeasurementCollar")
    primaryPrevention = URIRef("https://schema.org/primaryPrevention")
    isSimilarTo = URIRef("https://schema.org/isSimilarTo")
    depth = URIRef("https://schema.org/depth")
    DistanceFee = URIRef("https://schema.org/DistanceFee")
    isAccessoryOrSparePartFor = URIRef("https://schema.org/isAccessoryOrSparePartFor")
    isAccessibleForFree = URIRef("https://schema.org/isAccessibleForFree")
    gtin14 = URIRef("https://schema.org/gtin14")
    Language = URIRef("https://schema.org/Language")
    PercutaneousProcedure = URIRef("https://schema.org/PercutaneousProcedure")
    productSupported = URIRef("https://schema.org/productSupported")
    termsPerYear = URIRef("https://schema.org/termsPerYear")
    recipeCategory = URIRef("https://schema.org/recipeCategory")
    shippingLabel = URIRef("https://schema.org/shippingLabel")
    signDetected = URIRef("https://schema.org/signDetected")
    ParcelService = URIRef("https://schema.org/ParcelService")
    openingHoursSpecification = URIRef("https://schema.org/openingHoursSpecification")
    iso6523Code = URIRef("https://schema.org/iso6523Code")
    previousStartDate = URIRef("https://schema.org/previousStartDate")
    proprietaryName = URIRef("https://schema.org/proprietaryName")
    StagesHealthAspect = URIRef("https://schema.org/StagesHealthAspect")
    loanPaymentFrequency = URIRef("https://schema.org/loanPaymentFrequency")
    vehicleSpecialUsage = URIRef("https://schema.org/vehicleSpecialUsage")
    handlingTime = URIRef("https://schema.org/handlingTime")
    result = URIRef("https://schema.org/result")
    MeasurementTypeEnumeration = URIRef("https://schema.org/MeasurementTypeEnumeration")
    ImageObjectSnapshot = URIRef("https://schema.org/ImageObjectSnapshot")
    elevation = URIRef("https://schema.org/elevation")
    floorLevel = URIRef("https://schema.org/floorLevel")
    MedicalEnumeration = URIRef("https://schema.org/MedicalEnumeration")
    correctionsPolicy = URIRef("https://schema.org/correctionsPolicy")
    deliveryMethod = URIRef("https://schema.org/deliveryMethod")
    SocialEvent = URIRef("https://schema.org/SocialEvent")
    sportsTeam = URIRef("https://schema.org/sportsTeam")
    StructuredValue = URIRef("https://schema.org/StructuredValue")
    worstRating = URIRef("https://schema.org/worstRating")
    materialExtent = URIRef("https://schema.org/materialExtent")
    cvdNumC19OFMechVentPats = URIRef("https://schema.org/cvdNumC19OFMechVentPats")
    DigitalCaptureDigitalSource = URIRef("https://schema.org/DigitalCaptureDigitalSource")
    busName = URIRef("https://schema.org/busName")
    eligibleQuantity = URIRef("https://schema.org/eligibleQuantity")
    event = URIRef("https://schema.org/event")
    dateIssued = URIRef("https://schema.org/dateIssued")
    FDAcategoryD = URIRef("https://schema.org/FDAcategoryD")
    serviceUrl = URIRef("https://schema.org/serviceUrl")
    amount = URIRef("https://schema.org/amount")
    numberOfAccommodationUnits = URIRef("https://schema.org/numberOfAccommodationUnits")
    startTime = URIRef("https://schema.org/startTime")
    MerchantReturnPolicy = URIRef("https://schema.org/MerchantReturnPolicy")
    numberOfLoanPayments = URIRef("https://schema.org/numberOfLoanPayments")
    jobStartDate = URIRef("https://schema.org/jobStartDate")
    productionDate = URIRef("https://schema.org/productionDate")
    UKTrust = URIRef("https://schema.org/UKTrust")
    sensoryRequirement = URIRef("https://schema.org/sensoryRequirement")
    specialOpeningHoursSpecification = URIRef("https://schema.org/specialOpeningHoursSpecification")
    SRP = URIRef("https://schema.org/SRP")
    PET = URIRef("https://schema.org/PET")
    XRay = URIRef("https://schema.org/XRay")
    abridged = URIRef("https://schema.org/abridged")
    GeoShape = URIRef("https://schema.org/GeoShape")
    PublicationEvent = URIRef("https://schema.org/PublicationEvent")
    roofLoad = URIRef("https://schema.org/roofLoad")
    location = URIRef("https://schema.org/location")
    datePosted = URIRef("https://schema.org/datePosted")
    ratingExplanation = URIRef("https://schema.org/ratingExplanation")
    requiresSubscription = URIRef("https://schema.org/requiresSubscription")
    SeekToAction = URIRef("https://schema.org/SeekToAction")
    AllergiesHealthAspect = URIRef("https://schema.org/AllergiesHealthAspect")
    publicTransportClosuresInfo = URIRef("https://schema.org/publicTransportClosuresInfo")
    aspect = URIRef("https://schema.org/aspect")
    artworkSurface = URIRef("https://schema.org/artworkSurface")
    measurementDenominator = URIRef("https://schema.org/measurementDenominator")
    HearingImpairedSupported = URIRef("https://schema.org/HearingImpairedSupported")
    AggregateRating = URIRef("https://schema.org/AggregateRating")
    faxNumber = URIRef("https://schema.org/faxNumber")
    Role = URIRef("https://schema.org/Role")
    shippingRate = URIRef("https://schema.org/shippingRate")
    subjectOf = URIRef("https://schema.org/subjectOf")
    Emergency = URIRef("https://schema.org/Emergency")
    sizeSystem = URIRef("https://schema.org/sizeSystem")
    Nerve = URIRef("https://schema.org/Nerve")
    ContactPointOption = URIRef("https://schema.org/ContactPointOption")
    hasMolecularFunction = URIRef("https://schema.org/hasMolecularFunction")
    messageAttachment = URIRef("https://schema.org/messageAttachment")
    availableLanguage = URIRef("https://schema.org/availableLanguage")
    sku = URIRef("https://schema.org/sku")
    Periodical = URIRef("https://schema.org/Periodical")
    MediaEnumeration = URIRef("https://schema.org/MediaEnumeration")
    measurementQualifier = URIRef("https://schema.org/measurementQualifier")
    hasBroadcastChannel = URIRef("https://schema.org/hasBroadcastChannel")
    isbn = URIRef("https://schema.org/isbn")
    frequency = URIRef("https://schema.org/frequency")
    requiredQuantity = URIRef("https://schema.org/requiredQuantity")
    foodEstablishment = URIRef("https://schema.org/foodEstablishment")
    permissionType = URIRef("https://schema.org/permissionType")
    serviceType = URIRef("https://schema.org/serviceType")
    expectedArrivalUntil = URIRef("https://schema.org/expectedArrivalUntil")
    trainNumber = URIRef("https://schema.org/trainNumber")
    recommendedIntake = URIRef("https://schema.org/recommendedIntake")
    Grant = URIRef("https://schema.org/Grant")
    AnaerobicActivity = URIRef("https://schema.org/AnaerobicActivity")
    AmusementPark = URIRef("https://schema.org/AmusementPark")
    PeopleAudience = URIRef("https://schema.org/PeopleAudience")
    isProprietary = URIRef("https://schema.org/isProprietary")
    SoldOut = URIRef("https://schema.org/SoldOut")
    rangeIncludes = URIRef("https://schema.org/rangeIncludes")
    itemLocation = URIRef("https://schema.org/itemLocation")
    schemaVersion = URIRef("https://schema.org/schemaVersion")
    Synagogue = URIRef("https://schema.org/Synagogue")
    passengerPriorityStatus = URIRef("https://schema.org/passengerPriorityStatus")
    LibrarySystem = URIRef("https://schema.org/LibrarySystem")
    videoQuality = URIRef("https://schema.org/videoQuality")
    TradeAction = URIRef("https://schema.org/TradeAction")
    availabilityEnds = URIRef("https://schema.org/availabilityEnds")
    WearableSizeSystemEnumeration = URIRef("https://schema.org/WearableSizeSystemEnumeration")
    InstallAction = URIRef("https://schema.org/InstallAction")
    timeRequired = URIRef("https://schema.org/timeRequired")
    sensoryUnit = URIRef("https://schema.org/sensoryUnit")
    isbn = URIRef("https://schema.org/isbn")
    costCategory = URIRef("https://schema.org/costCategory")
    itemCondition = URIRef("https://schema.org/itemCondition")
    toRecipient = URIRef("https://schema.org/toRecipient")
    BreadcrumbList = URIRef("https://schema.org/BreadcrumbList")
    Saturday = URIRef("https://schema.org/Saturday")
    WearableSizeSystemCN = URIRef("https://schema.org/WearableSizeSystemCN")
    jobTitle = URIRef("https://schema.org/jobTitle")
    MedicalRiskEstimator = URIRef("https://schema.org/MedicalRiskEstimator")
    trailer = URIRef("https://schema.org/trailer")
    WearableMeasurementHeight = URIRef("https://schema.org/WearableMeasurementHeight")
    featureList = URIRef("https://schema.org/featureList")
    durationOfWarranty = URIRef("https://schema.org/durationOfWarranty")
    healthcareReportingData = URIRef("https://schema.org/healthcareReportingData")
    datasetTimeInterval = URIRef("https://schema.org/datasetTimeInterval")
    option = URIRef("https://schema.org/option")
    serviceOperator = URIRef("https://schema.org/serviceOperator")
    accelerationTime = URIRef("https://schema.org/accelerationTime")
    Winery = URIRef("https://schema.org/Winery")
    recipeIngredient = URIRef("https://schema.org/recipeIngredient")
    WearableSizeGroupRegular = URIRef("https://schema.org/WearableSizeGroupRegular")
    seasons = URIRef("https://schema.org/seasons")
    MusicPlaylist = URIRef("https://schema.org/MusicPlaylist")
    rxcui = URIRef("https://schema.org/rxcui")
    UpdateAction = URIRef("https://schema.org/UpdateAction")
    legislationConsolidates = URIRef("https://schema.org/legislationConsolidates")
    pathophysiology = URIRef("https://schema.org/pathophysiology")
    geoContains = URIRef("https://schema.org/geoContains")
    vehicleSeatingCapacity = URIRef("https://schema.org/vehicleSeatingCapacity")
    merchantReturnLink = URIRef("https://schema.org/merchantReturnLink")
    unnamedSourcesPolicy = URIRef("https://schema.org/unnamedSourcesPolicy")
    requiredMaxAge = URIRef("https://schema.org/requiredMaxAge")
    payload = URIRef("https://schema.org/payload")
    FDAnotEvaluated = URIRef("https://schema.org/FDAnotEvaluated")
    torque = URIRef("https://schema.org/torque")
    WebPage = URIRef("https://schema.org/WebPage")
    dropoffTime = URIRef("https://schema.org/dropoffTime")
    WearableSizeGroupPlus = URIRef("https://schema.org/WearableSizeGroupPlus")
    BusStation = URIRef("https://schema.org/BusStation")
    reviewRating = URIRef("https://schema.org/reviewRating")
    MedicalSpecialty = URIRef("https://schema.org/MedicalSpecialty")
    legislationType = URIRef("https://schema.org/legislationType")
    dissolutionDate = URIRef("https://schema.org/dissolutionDate")
    SearchAction = URIRef("https://schema.org/SearchAction")
    accessCode = URIRef("https://schema.org/accessCode")
    siblings = URIRef("https://schema.org/siblings")
    EmergencyService = URIRef("https://schema.org/EmergencyService")
    skills = URIRef("https://schema.org/skills")
    MeasurementMethodEnum = URIRef("https://schema.org/MeasurementMethodEnum")
    expires = URIRef("https://schema.org/expires")
    RadioClip = URIRef("https://schema.org/RadioClip")
    amount = URIRef("https://schema.org/amount")
    ComicCoverArt = URIRef("https://schema.org/ComicCoverArt")
    productSupported = URIRef("https://schema.org/productSupported")
    gtin12 = URIRef("https://schema.org/gtin12")
    validFrom = URIRef("https://schema.org/validFrom")
    RadiationTherapy = URIRef("https://schema.org/RadiationTherapy")
    deliveryStatus = URIRef("https://schema.org/deliveryStatus")
    legislationJurisdiction = URIRef("https://schema.org/legislationJurisdiction")
    dropoffLocation = URIRef("https://schema.org/dropoffLocation")
    agentInteractionStatistic = URIRef("https://schema.org/agentInteractionStatistic")
    MedicalTrial = URIRef("https://schema.org/MedicalTrial")
    Virus = URIRef("https://schema.org/Virus")
    cvdNumBeds = URIRef("https://schema.org/cvdNumBeds")
    TrainReservation = URIRef("https://schema.org/TrainReservation")
    Vessel = URIRef("https://schema.org/Vessel")
    EventCancelled = URIRef("https://schema.org/EventCancelled")
    reviewAspect = URIRef("https://schema.org/reviewAspect")
    bloodSupply = URIRef("https://schema.org/bloodSupply")
    workPerformed = URIRef("https://schema.org/workPerformed")
    DemoGameAvailability = URIRef("https://schema.org/DemoGameAvailability")
    MediaManipulationRatingEnumeration = URIRef("https://schema.org/MediaManipulationRatingEnumeration")
    GroupBoardingPolicy = URIRef("https://schema.org/GroupBoardingPolicy")
    printColumn = URIRef("https://schema.org/printColumn")
    paymentMethodId = URIRef("https://schema.org/paymentMethodId")
    seatSection = URIRef("https://schema.org/seatSection")
    PropertyValue = URIRef("https://schema.org/PropertyValue")
    availableOnDevice = URIRef("https://schema.org/availableOnDevice")
    programName = URIRef("https://schema.org/programName")
    totalPaymentDue = URIRef("https://schema.org/totalPaymentDue")
    numberOfAxles = URIRef("https://schema.org/numberOfAxles")
    Project = URIRef("https://schema.org/Project")
    exceptDate = URIRef("https://schema.org/exceptDate")
    gameAvailabilityType = URIRef("https://schema.org/gameAvailabilityType")
    costPerUnit = URIRef("https://schema.org/costPerUnit")
    inLanguage = URIRef("https://schema.org/inLanguage")
    Series = URIRef("https://schema.org/Series")
    WearableMeasurementCup = URIRef("https://schema.org/WearableMeasurementCup")
    FDAcategoryB = URIRef("https://schema.org/FDAcategoryB")
    utterances = URIRef("https://schema.org/utterances")
    legislationLegalValue = URIRef("https://schema.org/legislationLegalValue")
    WearableSizeGroupInfants = URIRef("https://schema.org/WearableSizeGroupInfants")
    healthPlanMarketingUrl = URIRef("https://schema.org/healthPlanMarketingUrl")
    BorrowAction = URIRef("https://schema.org/BorrowAction")
    eligibleQuantity = URIRef("https://schema.org/eligibleQuantity")
    softwareAddOn = URIRef("https://schema.org/softwareAddOn")
    broadcastFrequencyValue = URIRef("https://schema.org/broadcastFrequencyValue")
    EnergyEfficiencyEnumeration = URIRef("https://schema.org/EnergyEfficiencyEnumeration")
    hasMeasurement = URIRef("https://schema.org/hasMeasurement")
    parentService = URIRef("https://schema.org/parentService")
    geo = URIRef("https://schema.org/geo")
    creditedTo = URIRef("https://schema.org/creditedTo")
    GenericWebPlatform = URIRef("https://schema.org/GenericWebPlatform")
    DataDrivenMediaDigitalSource = URIRef("https://schema.org/DataDrivenMediaDigitalSource")
    Room = URIRef("https://schema.org/Room")
    valuePattern = URIRef("https://schema.org/valuePattern")
    carrier = URIRef("https://schema.org/carrier")
    healthPlanCopayOption = URIRef("https://schema.org/healthPlanCopayOption")
    KeepProduct = URIRef("https://schema.org/KeepProduct")
    bookingAgent = URIRef("https://schema.org/bookingAgent")
    menu = URIRef("https://schema.org/menu")
    carbohydrateContent = URIRef("https://schema.org/carbohydrateContent")
    endDate = URIRef("https://schema.org/endDate")
    MRI = URIRef("https://schema.org/MRI")
    diversityPolicy = URIRef("https://schema.org/diversityPolicy")
    availableTest = URIRef("https://schema.org/availableTest")
    PaymentService = URIRef("https://schema.org/PaymentService")
    partOfSeries = URIRef("https://schema.org/partOfSeries")
    actor = URIRef("https://schema.org/actor")
    HealthCare = URIRef("https://schema.org/HealthCare")
    PublicationVolume = URIRef("https://schema.org/PublicationVolume")
    linkRelationship = URIRef("https://schema.org/linkRelationship")
    offers = URIRef("https://schema.org/offers")
    coverageStartTime = URIRef("https://schema.org/coverageStartTime")
    PodcastEpisode = URIRef("https://schema.org/PodcastEpisode")
    workTranslation = URIRef("https://schema.org/workTranslation")
    warrantyPromise = URIRef("https://schema.org/warrantyPromise")
    endorsers = URIRef("https://schema.org/endorsers")
    study = URIRef("https://schema.org/study")
    validFrom = URIRef("https://schema.org/validFrom")
    bestRating = URIRef("https://schema.org/bestRating")
    AlignmentObject = URIRef("https://schema.org/AlignmentObject")
    softwareVersion = URIRef("https://schema.org/softwareVersion")
    contactPoint = URIRef("https://schema.org/contactPoint")
    Optician = URIRef("https://schema.org/Optician")
    programmingModel = URIRef("https://schema.org/programmingModel")
    Protein = URIRef("https://schema.org/Protein")
    FDAcategoryC = URIRef("https://schema.org/FDAcategoryC")
    arrivalBoatTerminal = URIRef("https://schema.org/arrivalBoatTerminal")
    WearableSizeSystemUK = URIRef("https://schema.org/WearableSizeSystemUK")
    trackingNumber = URIRef("https://schema.org/trackingNumber")
    percentile10 = URIRef("https://schema.org/percentile10")
    billingDuration = URIRef("https://schema.org/billingDuration")
    Blog = URIRef("https://schema.org/Blog")
    agent = URIRef("https://schema.org/agent")
    ineligibleRegion = URIRef("https://schema.org/ineligibleRegion")
    educationalFramework = URIRef("https://schema.org/educationalFramework")
    legislationJurisdiction = URIRef("https://schema.org/legislationJurisdiction")
    carbohydrateContent = URIRef("https://schema.org/carbohydrateContent")
    landlord = URIRef("https://schema.org/landlord")
    ComputerLanguage = URIRef("https://schema.org/ComputerLanguage")
    vehicleEngine = URIRef("https://schema.org/vehicleEngine")
    orderNumber = URIRef("https://schema.org/orderNumber")
    broadcastDisplayName = URIRef("https://schema.org/broadcastDisplayName")
    priceType = URIRef("https://schema.org/priceType")
    Nonprofit501c12 = URIRef("https://schema.org/Nonprofit501c12")
    XPathType = URIRef("https://schema.org/XPathType")
    amount = URIRef("https://schema.org/amount")
    Nonprofit501e = URIRef("https://schema.org/Nonprofit501e")
    endOffset = URIRef("https://schema.org/endOffset")
    fromLocation = URIRef("https://schema.org/fromLocation")
    PodcastSeries = URIRef("https://schema.org/PodcastSeries")
    EUEnergyEfficiencyCategoryB = URIRef("https://schema.org/EUEnergyEfficiencyCategoryB")
    InvestmentOrDeposit = URIRef("https://schema.org/InvestmentOrDeposit")
    legislationType = URIRef("https://schema.org/legislationType")
    minValue = URIRef("https://schema.org/minValue")
    bankAccountType = URIRef("https://schema.org/bankAccountType")
    winner = URIRef("https://schema.org/winner")
    agent = URIRef("https://schema.org/agent")
    MovieRentalStore = URIRef("https://schema.org/MovieRentalStore")
    RespiratoryTherapy = URIRef("https://schema.org/RespiratoryTherapy")
    discountCurrency = URIRef("https://schema.org/discountCurrency")
    BarOrPub = URIRef("https://schema.org/BarOrPub")
    ShoppingCenter = URIRef("https://schema.org/ShoppingCenter")
    contactPoints = URIRef("https://schema.org/contactPoints")
    PawnShop = URIRef("https://schema.org/PawnShop")
    lowPrice = URIRef("https://schema.org/lowPrice")
    accommodationCategory = URIRef("https://schema.org/accommodationCategory")
    interpretedAsClaim = URIRef("https://schema.org/interpretedAsClaim")
    interactionStatistic = URIRef("https://schema.org/interactionStatistic")
    PoliticalParty = URIRef("https://schema.org/PoliticalParty")
    Synagogue = URIRef("https://schema.org/Synagogue")
    usNPI = URIRef("https://schema.org/usNPI")
    programPrerequisites = URIRef("https://schema.org/programPrerequisites")
    ContagiousnessHealthAspect = URIRef("https://schema.org/ContagiousnessHealthAspect")
    ActionAccessSpecification = URIRef("https://schema.org/ActionAccessSpecification")
    toLocation = URIRef("https://schema.org/toLocation")
    WearableMeasurementWaist = URIRef("https://schema.org/WearableMeasurementWaist")
    defaultValue = URIRef("https://schema.org/defaultValue")
    PostOffice = URIRef("https://schema.org/PostOffice")
    maximumEnrollment = URIRef("https://schema.org/maximumEnrollment")
    MedicalTherapy = URIRef("https://schema.org/MedicalTherapy")
    UnclassifiedAdultConsideration = URIRef("https://schema.org/UnclassifiedAdultConsideration")
    PhysicalExam = URIRef("https://schema.org/PhysicalExam")
    legislationLegalValue = URIRef("https://schema.org/legislationLegalValue")
    geoCoveredBy = URIRef("https://schema.org/geoCoveredBy")
    noBylinesPolicy = URIRef("https://schema.org/noBylinesPolicy")
    relatedStructure = URIRef("https://schema.org/relatedStructure")
    Claim = URIRef("https://schema.org/Claim")
    GroceryStore = URIRef("https://schema.org/GroceryStore")
    bestRating = URIRef("https://schema.org/bestRating")
    commentCount = URIRef("https://schema.org/commentCount")
    Nonprofit501c6 = URIRef("https://schema.org/Nonprofit501c6")
    Urologic = URIRef("https://schema.org/Urologic")
    workTranslation = URIRef("https://schema.org/workTranslation")
    assembly = URIRef("https://schema.org/assembly")
    includedInDataCatalog = URIRef("https://schema.org/includedInDataCatalog")
    hasCategoryCode = URIRef("https://schema.org/hasCategoryCode")
    Landform = URIRef("https://schema.org/Landform")
    Article = URIRef("https://schema.org/Article")
    aspect = URIRef("https://schema.org/aspect")
    LodgingReservation = URIRef("https://schema.org/LodgingReservation")
    qualifications = URIRef("https://schema.org/qualifications")
    warning = URIRef("https://schema.org/warning")
    availabilityEnds = URIRef("https://schema.org/availabilityEnds")
    Balance = URIRef("https://schema.org/Balance")
    productionCompany = URIRef("https://schema.org/productionCompany")
    dependencies = URIRef("https://schema.org/dependencies")
    polygon = URIRef("https://schema.org/polygon")
    NarcoticConsideration = URIRef("https://schema.org/NarcoticConsideration")
    Audiobook = URIRef("https://schema.org/Audiobook")
    PreventionHealthAspect = URIRef("https://schema.org/PreventionHealthAspect")
    MisconceptionsHealthAspect = URIRef("https://schema.org/MisconceptionsHealthAspect")
    funding = URIRef("https://schema.org/funding")
    availableIn = URIRef("https://schema.org/availableIn")
    tongueWeight = URIRef("https://schema.org/tongueWeight")
    itemDefectReturnShippingFeesAmount = URIRef("https://schema.org/itemDefectReturnShippingFeesAmount")
    AerobicActivity = URIRef("https://schema.org/AerobicActivity")
    globalLocationNumber = URIRef("https://schema.org/globalLocationNumber")
    orderStatus = URIRef("https://schema.org/orderStatus")
    associatedMedia = URIRef("https://schema.org/associatedMedia")
    WorkersUnion = URIRef("https://schema.org/WorkersUnion")
    exifData = URIRef("https://schema.org/exifData")
    Answer = URIRef("https://schema.org/Answer")
    ImageGallery = URIRef("https://schema.org/ImageGallery")
    practicesAt = URIRef("https://schema.org/practicesAt")
    geoCovers = URIRef("https://schema.org/geoCovers")
    geoIntersects = URIRef("https://schema.org/geoIntersects")
    namedPosition = URIRef("https://schema.org/namedPosition")
    MeasurementMethodEnum = URIRef("https://schema.org/MeasurementMethodEnum")
    DefinedRegion = URIRef("https://schema.org/DefinedRegion")
    maximumVirtualAttendeeCapacity = URIRef("https://schema.org/maximumVirtualAttendeeCapacity")
    gtin14 = URIRef("https://schema.org/gtin14")
    seasonNumber = URIRef("https://schema.org/seasonNumber")
    reportNumber = URIRef("https://schema.org/reportNumber")
    PublicToilet = URIRef("https://schema.org/PublicToilet")
    volumeNumber = URIRef("https://schema.org/volumeNumber")
    MedicalProcedureType = URIRef("https://schema.org/MedicalProcedureType")
    closes = URIRef("https://schema.org/closes")
    EUEnergyEfficiencyEnumeration = URIRef("https://schema.org/EUEnergyEfficiencyEnumeration")
    ingredients = URIRef("https://schema.org/ingredients")
    recourseLoan = URIRef("https://schema.org/recourseLoan")
    CDCPMDRecord = URIRef("https://schema.org/CDCPMDRecord")
    orderNumber = URIRef("https://schema.org/orderNumber")
    RadioEpisode = URIRef("https://schema.org/RadioEpisode")
    actionableFeedbackPolicy = URIRef("https://schema.org/actionableFeedbackPolicy")
    shippingDetails = URIRef("https://schema.org/shippingDetails")
    costPerUnit = URIRef("https://schema.org/costPerUnit")
    PostalAddress = URIRef("https://schema.org/PostalAddress")
    billingDuration = URIRef("https://schema.org/billingDuration")
    softwareHelp = URIRef("https://schema.org/softwareHelp")
    recordedIn = URIRef("https://schema.org/recordedIn")
    PropertyValue = URIRef("https://schema.org/PropertyValue")
    orderDelivery = URIRef("https://schema.org/orderDelivery")
    toRecipient = URIRef("https://schema.org/toRecipient")
    smiles = URIRef("https://schema.org/smiles")
    Brand = URIRef("https://schema.org/Brand")
    InvestmentFund = URIRef("https://schema.org/InvestmentFund")
    fundedItem = URIRef("https://schema.org/fundedItem")
    actionableFeedbackPolicy = URIRef("https://schema.org/actionableFeedbackPolicy")
    width = URIRef("https://schema.org/width")
    transitTimeLabel = URIRef("https://schema.org/transitTimeLabel")
    scheduleTimezone = URIRef("https://schema.org/scheduleTimezone")
    carrier = URIRef("https://schema.org/carrier")
    actionAccessibilityRequirement = URIRef("https://schema.org/actionAccessibilityRequirement")
    abstract = URIRef("https://schema.org/abstract")
    countryOfAssembly = URIRef("https://schema.org/countryOfAssembly")
    EndorsementRating = URIRef("https://schema.org/EndorsementRating")
    actor = URIRef("https://schema.org/actor")
    BroadcastEvent = URIRef("https://schema.org/BroadcastEvent")
    legislationChanges = URIRef("https://schema.org/legislationChanges")
    employmentUnit = URIRef("https://schema.org/employmentUnit")
    legislationIdentifier = URIRef("https://schema.org/legislationIdentifier")
    HowToTip = URIRef("https://schema.org/HowToTip")
    encodingFormat = URIRef("https://schema.org/encodingFormat")
    byMonthWeek = URIRef("https://schema.org/byMonthWeek")
    GovernmentBenefitsType = URIRef("https://schema.org/GovernmentBenefitsType")
    ShippingDeliveryTime = URIRef("https://schema.org/ShippingDeliveryTime")
    associatedPathophysiology = URIRef("https://schema.org/associatedPathophysiology")
    WearableSizeGroupGirls = URIRef("https://schema.org/WearableSizeGroupGirls")
    provider = URIRef("https://schema.org/provider")
    TradeAction = URIRef("https://schema.org/TradeAction")
    diet = URIRef("https://schema.org/diet")
    hasVariant = URIRef("https://schema.org/hasVariant")
    referenceQuantity = URIRef("https://schema.org/referenceQuantity")
    geoCovers = URIRef("https://schema.org/geoCovers")
    totalJobOpenings = URIRef("https://schema.org/totalJobOpenings")
    termsOfService = URIRef("https://schema.org/termsOfService")
    quest = URIRef("https://schema.org/quest")
    MedicalEntity = URIRef("https://schema.org/MedicalEntity")
    itemDefectReturnShippingFeesAmount = URIRef("https://schema.org/itemDefectReturnShippingFeesAmount")
    foodWarning = URIRef("https://schema.org/foodWarning")
    starRating = URIRef("https://schema.org/starRating")
    longitude = URIRef("https://schema.org/longitude")
    inProductGroupWithID = URIRef("https://schema.org/inProductGroupWithID")
    sodiumContent = URIRef("https://schema.org/sodiumContent")
    OfflinePermanently = URIRef("https://schema.org/OfflinePermanently")
    creditedTo = URIRef("https://schema.org/creditedTo")
    LegislationObject = URIRef("https://schema.org/LegislationObject")
    Courthouse = URIRef("https://schema.org/Courthouse")
    runtime = URIRef("https://schema.org/runtime")
    MenuSection = URIRef("https://schema.org/MenuSection")
    APIReference = URIRef("https://schema.org/APIReference")
    Residence = URIRef("https://schema.org/Residence")
    suitableForDiet = URIRef("https://schema.org/suitableForDiet")
    domainIncludes = URIRef("https://schema.org/domainIncludes")
    RVPark = URIRef("https://schema.org/RVPark")
    SafetyHealthAspect = URIRef("https://schema.org/SafetyHealthAspect")
    readBy = URIRef("https://schema.org/readBy")
    loanPaymentAmount = URIRef("https://schema.org/loanPaymentAmount")
    isEncodedByBioChemEntity = URIRef("https://schema.org/isEncodedByBioChemEntity")
    healthPlanId = URIRef("https://schema.org/healthPlanId")
    boardingGroup = URIRef("https://schema.org/boardingGroup")
    HowToTip = URIRef("https://schema.org/HowToTip")
    TravelAction = URIRef("https://schema.org/TravelAction")
    driveWheelConfiguration = URIRef("https://schema.org/driveWheelConfiguration")
    evidenceLevel = URIRef("https://schema.org/evidenceLevel")
    ArchiveOrganization = URIRef("https://schema.org/ArchiveOrganization")
    DepartAction = URIRef("https://schema.org/DepartAction")
    mathExpression = URIRef("https://schema.org/mathExpression")
    legislationIdentifier = URIRef("https://schema.org/legislationIdentifier")
    hasOfferCatalog = URIRef("https://schema.org/hasOfferCatalog")
    Demand = URIRef("https://schema.org/Demand")
    ActionStatusType = URIRef("https://schema.org/ActionStatusType")
    seller = URIRef("https://schema.org/seller")
    menu = URIRef("https://schema.org/menu")
    AdultOrientedEnumeration = URIRef("https://schema.org/AdultOrientedEnumeration")
    remainingAttendeeCapacity = URIRef("https://schema.org/remainingAttendeeCapacity")
    acquireLicensePage = URIRef("https://schema.org/acquireLicensePage")
    availableThrough = URIRef("https://schema.org/availableThrough")
    chemicalRole = URIRef("https://schema.org/chemicalRole")
    isGift = URIRef("https://schema.org/isGift")
    numberOfRooms = URIRef("https://schema.org/numberOfRooms")
    speechToTextMarkup = URIRef("https://schema.org/speechToTextMarkup")
    pagination = URIRef("https://schema.org/pagination")
    DiagnosticProcedure = URIRef("https://schema.org/DiagnosticProcedure")
    recordedAs = URIRef("https://schema.org/recordedAs")
    riskFactor = URIRef("https://schema.org/riskFactor")
    ExchangeRateSpecification = URIRef("https://schema.org/ExchangeRateSpecification")
    OverviewHealthAspect = URIRef("https://schema.org/OverviewHealthAspect")
    sizeSystem = URIRef("https://schema.org/sizeSystem")
    risks = URIRef("https://schema.org/risks")
    educationalRole = URIRef("https://schema.org/educationalRole")
    sensoryRequirement = URIRef("https://schema.org/sensoryRequirement")
    MovieTheater = URIRef("https://schema.org/MovieTheater")
    storageRequirements = URIRef("https://schema.org/storageRequirements")
    measurementTechnique = URIRef("https://schema.org/measurementTechnique")
    OrganizationRole = URIRef("https://schema.org/OrganizationRole")
    BioChemEntity = URIRef("https://schema.org/BioChemEntity")
    MRI = URIRef("https://schema.org/MRI")
    LodgingBusiness = URIRef("https://schema.org/LodgingBusiness")
    MerchantReturnFiniteReturnWindow = URIRef("https://schema.org/MerchantReturnFiniteReturnWindow")
    DoubleBlindedTrial = URIRef("https://schema.org/DoubleBlindedTrial")
    streetAddress = URIRef("https://schema.org/streetAddress")
    suggestedGender = URIRef("https://schema.org/suggestedGender")
    loanTerm = URIRef("https://schema.org/loanTerm")
    statType = URIRef("https://schema.org/statType")
    Poster = URIRef("https://schema.org/Poster")
    Guide = URIRef("https://schema.org/Guide")
    awayTeam = URIRef("https://schema.org/awayTeam")
    seatRow = URIRef("https://schema.org/seatRow")
    doseSchedule = URIRef("https://schema.org/doseSchedule")
    taxonRank = URIRef("https://schema.org/taxonRank")
    Class = URIRef("https://schema.org/Class")
    validFor = URIRef("https://schema.org/validFor")
    shippingRate = URIRef("https://schema.org/shippingRate")
    iupacName = URIRef("https://schema.org/iupacName")
    Restaurant = URIRef("https://schema.org/Restaurant")
    cvdNumTotBeds = URIRef("https://schema.org/cvdNumTotBeds")
    areaServed = URIRef("https://schema.org/areaServed")
    MediaGallery = URIRef("https://schema.org/MediaGallery")
    MedicalTest = URIRef("https://schema.org/MedicalTest")
    DrawAction = URIRef("https://schema.org/DrawAction")
    MedicalSign = URIRef("https://schema.org/MedicalSign")
    originAddress = URIRef("https://schema.org/originAddress")
    activeIngredient = URIRef("https://schema.org/activeIngredient")
    ElementarySchool = URIRef("https://schema.org/ElementarySchool")
    expires = URIRef("https://schema.org/expires")
    material = URIRef("https://schema.org/material")
    model = URIRef("https://schema.org/model")
    EvidenceLevelC = URIRef("https://schema.org/EvidenceLevelC")
    WearableSizeSystemEnumeration = URIRef("https://schema.org/WearableSizeSystemEnumeration")
    alternativeOf = URIRef("https://schema.org/alternativeOf")
    productGroupID = URIRef("https://schema.org/productGroupID")
    healthCondition = URIRef("https://schema.org/healthCondition")
    DisabilitySupport = URIRef("https://schema.org/DisabilitySupport")
    Dataset = URIRef("https://schema.org/Dataset")
    hasPOS = URIRef("https://schema.org/hasPOS")
    ProductGroup = URIRef("https://schema.org/ProductGroup")
    DataFeed = URIRef("https://schema.org/DataFeed")
    StadiumOrArena = URIRef("https://schema.org/StadiumOrArena")
    about = URIRef("https://schema.org/about")
    Offer = URIRef("https://schema.org/Offer")
    codeRepository = URIRef("https://schema.org/codeRepository")
    DriveWheelConfigurationValue = URIRef("https://schema.org/DriveWheelConfigurationValue")
    eligibleDuration = URIRef("https://schema.org/eligibleDuration")
    processingTime = URIRef("https://schema.org/processingTime")
    weight = URIRef("https://schema.org/weight")
    EnergyEfficiencyEnumeration = URIRef("https://schema.org/EnergyEfficiencyEnumeration")
    VideoGameSeries = URIRef("https://schema.org/VideoGameSeries")
    MedicalProcedureType = URIRef("https://schema.org/MedicalProcedureType")
    eligibleRegion = URIRef("https://schema.org/eligibleRegion")
    publicationType = URIRef("https://schema.org/publicationType")
    latitude = URIRef("https://schema.org/latitude")
    resultComment = URIRef("https://schema.org/resultComment")
    healthPlanCostSharing = URIRef("https://schema.org/healthPlanCostSharing")
    parents = URIRef("https://schema.org/parents")
    Nonprofit501c21 = URIRef("https://schema.org/Nonprofit501c21")
    legislationDateVersion = URIRef("https://schema.org/legislationDateVersion")
    resultReview = URIRef("https://schema.org/resultReview")
    VirtualLocation = URIRef("https://schema.org/VirtualLocation")
    CDCPMDRecord = URIRef("https://schema.org/CDCPMDRecord")
    Urologic = URIRef("https://schema.org/Urologic")
    epidemiology = URIRef("https://schema.org/epidemiology")
    activeIngredient = URIRef("https://schema.org/activeIngredient")
    recordedAs = URIRef("https://schema.org/recordedAs")
    brand = URIRef("https://schema.org/brand")
    temporal = URIRef("https://schema.org/temporal")
    floorLevel = URIRef("https://schema.org/floorLevel")
    codingSystem = URIRef("https://schema.org/codingSystem")
    RiverBodyOfWater = URIRef("https://schema.org/RiverBodyOfWater")
    releasedEvent = URIRef("https://schema.org/releasedEvent")
    productionDate = URIRef("https://schema.org/productionDate")
    legislationChanges = URIRef("https://schema.org/legislationChanges")
    AggregateRating = URIRef("https://schema.org/AggregateRating")
    foodEvent = URIRef("https://schema.org/foodEvent")
    pageStart = URIRef("https://schema.org/pageStart")
    workExample = URIRef("https://schema.org/workExample")
    Time = URIRef("https://schema.org/Time")
    vehicleInteriorType = URIRef("https://schema.org/vehicleInteriorType")
    UnofficialLegalValue = URIRef("https://schema.org/UnofficialLegalValue")
    MediaGallery = URIRef("https://schema.org/MediaGallery")
    mediaAuthenticityCategory = URIRef("https://schema.org/mediaAuthenticityCategory")
    identifyingTest = URIRef("https://schema.org/identifyingTest")
    risks = URIRef("https://schema.org/risks")
    maxPrice = URIRef("https://schema.org/maxPrice")
    subtitleLanguage = URIRef("https://schema.org/subtitleLanguage")
    tributary = URIRef("https://schema.org/tributary")
    Gynecologic = URIRef("https://schema.org/Gynecologic")
    OfflinePermanently = URIRef("https://schema.org/OfflinePermanently")
    PhotographAction = URIRef("https://schema.org/PhotographAction")
    itinerary = URIRef("https://schema.org/itinerary")
    customerRemorseReturnFees = URIRef("https://schema.org/customerRemorseReturnFees")
    eventAttendanceMode = URIRef("https://schema.org/eventAttendanceMode")
    naics = URIRef("https://schema.org/naics")
    BenefitsHealthAspect = URIRef("https://schema.org/BenefitsHealthAspect")
    salaryCurrency = URIRef("https://schema.org/salaryCurrency")
    relatedCondition = URIRef("https://schema.org/relatedCondition")
    RespiratoryTherapy = URIRef("https://schema.org/RespiratoryTherapy")
    MoveAction = URIRef("https://schema.org/MoveAction")
    WearableSizeGroupShort = URIRef("https://schema.org/WearableSizeGroupShort")
    SomeProducts = URIRef("https://schema.org/SomeProducts")
    AlgorithmicMediaDigitalSource = URIRef("https://schema.org/AlgorithmicMediaDigitalSource")
    educationalLevel = URIRef("https://schema.org/educationalLevel")
    WarrantyScope = URIRef("https://schema.org/WarrantyScope")
    sportsEvent = URIRef("https://schema.org/sportsEvent")
    expectsAcceptanceOf = URIRef("https://schema.org/expectsAcceptanceOf")
    returnPolicySeasonalOverride = URIRef("https://schema.org/returnPolicySeasonalOverride")
    weightTotal = URIRef("https://schema.org/weightTotal")
    ingredients = URIRef("https://schema.org/ingredients")
    Clinician = URIRef("https://schema.org/Clinician")
    spokenByCharacter = URIRef("https://schema.org/spokenByCharacter")
    percentile25 = URIRef("https://schema.org/percentile25")
    pageEnd = URIRef("https://schema.org/pageEnd")
    DDxElement = URIRef("https://schema.org/DDxElement")
    Quotation = URIRef("https://schema.org/Quotation")
    highPrice = URIRef("https://schema.org/highPrice")
    EducationalOccupationalProgram = URIRef("https://schema.org/EducationalOccupationalProgram")
    returnPolicyCategory = URIRef("https://schema.org/returnPolicyCategory")
    ratingCount = URIRef("https://schema.org/ratingCount")
    CommentPermission = URIRef("https://schema.org/CommentPermission")
    FoodEstablishmentReservation = URIRef("https://schema.org/FoodEstablishmentReservation")
    gameLocation = URIRef("https://schema.org/gameLocation")
    arrivalBoatTerminal = URIRef("https://schema.org/arrivalBoatTerminal")
    LegalService = URIRef("https://schema.org/LegalService")
    mealService = URIRef("https://schema.org/mealService")
    CategoryCode = URIRef("https://schema.org/CategoryCode")
    totalPaymentDue = URIRef("https://schema.org/totalPaymentDue")
    offeredBy = URIRef("https://schema.org/offeredBy")
    WearableSizeSystemFR = URIRef("https://schema.org/WearableSizeSystemFR")
    amount = URIRef("https://schema.org/amount")
    CertificationInactive = URIRef("https://schema.org/CertificationInactive")
    Suspended = URIRef("https://schema.org/Suspended")
    Article = URIRef("https://schema.org/Article")
    subTest = URIRef("https://schema.org/subTest")
    artEdition = URIRef("https://schema.org/artEdition")
    bookEdition = URIRef("https://schema.org/bookEdition")
    contactType = URIRef("https://schema.org/contactType")
    WearableMeasurementCup = URIRef("https://schema.org/WearableMeasurementCup")
    DataFeedItem = URIRef("https://schema.org/DataFeedItem")
    CommunityHealth = URIRef("https://schema.org/CommunityHealth")
    endorsers = URIRef("https://schema.org/endorsers")
    affiliation = URIRef("https://schema.org/affiliation")
    OpenTrial = URIRef("https://schema.org/OpenTrial")
    servicePostalAddress = URIRef("https://schema.org/servicePostalAddress")
    orderItemNumber = URIRef("https://schema.org/orderItemNumber")
    isSimilarTo = URIRef("https://schema.org/isSimilarTo")
    subjectOf = URIRef("https://schema.org/subjectOf")
    toLocation = URIRef("https://schema.org/toLocation")
    SeatingMap = URIRef("https://schema.org/SeatingMap")
    character = URIRef("https://schema.org/character")
    percentile10 = URIRef("https://schema.org/percentile10")
    MathSolver = URIRef("https://schema.org/MathSolver")
    Reservation = URIRef("https://schema.org/Reservation")
    Hostel = URIRef("https://schema.org/Hostel")
    numberOfAccommodationUnits = URIRef("https://schema.org/numberOfAccommodationUnits")
    height = URIRef("https://schema.org/height")
    titleEIDR = URIRef("https://schema.org/titleEIDR")
    masthead = URIRef("https://schema.org/masthead")
    claimReviewed = URIRef("https://schema.org/claimReviewed")
    warning = URIRef("https://schema.org/warning")
    addressLocality = URIRef("https://schema.org/addressLocality")
    interactionService = URIRef("https://schema.org/interactionService")
    ticketToken = URIRef("https://schema.org/ticketToken")
    HowToStep = URIRef("https://schema.org/HowToStep")
    RegisterAction = URIRef("https://schema.org/RegisterAction")
    cvdFacilityId = URIRef("https://schema.org/cvdFacilityId")
    associatedReview = URIRef("https://schema.org/associatedReview")
    EmailMessage = URIRef("https://schema.org/EmailMessage")
    PotentialActionStatus = URIRef("https://schema.org/PotentialActionStatus")
    fuelType = URIRef("https://schema.org/fuelType")
    ReturnLabelDownloadAndPrint = URIRef("https://schema.org/ReturnLabelDownloadAndPrint")
    season = URIRef("https://schema.org/season")
    CivicStructure = URIRef("https://schema.org/CivicStructure")
    suggestedGender = URIRef("https://schema.org/suggestedGender")
    abstract = URIRef("https://schema.org/abstract")
    Language = URIRef("https://schema.org/Language")
    runsTo = URIRef("https://schema.org/runsTo")
    programName = URIRef("https://schema.org/programName")
    mileageFromOdometer = URIRef("https://schema.org/mileageFromOdometer")
    deliveryMethod = URIRef("https://schema.org/deliveryMethod")
    inAlbum = URIRef("https://schema.org/inAlbum")
    includedInHealthInsurancePlan = URIRef("https://schema.org/includedInHealthInsurancePlan")
    containedIn = URIRef("https://schema.org/containedIn")
    merchantReturnDays = URIRef("https://schema.org/merchantReturnDays")
    suggestedMeasurement = URIRef("https://schema.org/suggestedMeasurement")
    AutoBodyShop = URIRef("https://schema.org/AutoBodyShop")
    Review = URIRef("https://schema.org/Review")
    cvdNumC19MechVentPats = URIRef("https://schema.org/cvdNumC19MechVentPats")
    IgnoreAction = URIRef("https://schema.org/IgnoreAction")
    lender = URIRef("https://schema.org/lender")
    WebSite = URIRef("https://schema.org/WebSite")
    loanRepaymentForm = URIRef("https://schema.org/loanRepaymentForm")
    buyer = URIRef("https://schema.org/buyer")
    MusicVideoObject = URIRef("https://schema.org/MusicVideoObject")
    medicalSpecialty = URIRef("https://schema.org/medicalSpecialty")
    WearableMeasurementCollar = URIRef("https://schema.org/WearableMeasurementCollar")
    sender = URIRef("https://schema.org/sender")
    GovernmentPermit = URIRef("https://schema.org/GovernmentPermit")
    Library = URIRef("https://schema.org/Library")
    Anesthesia = URIRef("https://schema.org/Anesthesia")
    businessFunction = URIRef("https://schema.org/businessFunction")
    trialDesign = URIRef("https://schema.org/trialDesign")
    deathDate = URIRef("https://schema.org/deathDate")
    Online = URIRef("https://schema.org/Online")
    encodingType = URIRef("https://schema.org/encodingType")
    review = URIRef("https://schema.org/review")
    legislationType = URIRef("https://schema.org/legislationType")
    funder = URIRef("https://schema.org/funder")
    multipleValues = URIRef("https://schema.org/multipleValues")
    award = URIRef("https://schema.org/award")
    measuredProperty = URIRef("https://schema.org/measuredProperty")
    url = URIRef("https://schema.org/url")
    byArtist = URIRef("https://schema.org/byArtist")
    discussionUrl = URIRef("https://schema.org/discussionUrl")
    ScreeningHealthAspect = URIRef("https://schema.org/ScreeningHealthAspect")
    yearlyRevenue = URIRef("https://schema.org/yearlyRevenue")
    UserInteraction = URIRef("https://schema.org/UserInteraction")
    labelDetails = URIRef("https://schema.org/labelDetails")
    ApprovedIndication = URIRef("https://schema.org/ApprovedIndication")
    returnPolicySeasonalOverride = URIRef("https://schema.org/returnPolicySeasonalOverride")
    releaseDate = URIRef("https://schema.org/releaseDate")
    MedicalCause = URIRef("https://schema.org/MedicalCause")
    downPayment = URIRef("https://schema.org/downPayment")
    exampleOfWork = URIRef("https://schema.org/exampleOfWork")
    OriginalShippingFees = URIRef("https://schema.org/OriginalShippingFees")
    JewelryStore = URIRef("https://schema.org/JewelryStore")
    preparation = URIRef("https://schema.org/preparation")
    gameServer = URIRef("https://schema.org/gameServer")
    MovingCompany = URIRef("https://schema.org/MovingCompany")
    duns = URIRef("https://schema.org/duns")
    EducationalAudience = URIRef("https://schema.org/EducationalAudience")
    DeleteAction = URIRef("https://schema.org/DeleteAction")
    ReturnFeesEnumeration = URIRef("https://schema.org/ReturnFeesEnumeration")
    postalCodeRange = URIRef("https://schema.org/postalCodeRange")
    permittedUsage = URIRef("https://schema.org/permittedUsage")
    applicationSubCategory = URIRef("https://schema.org/applicationSubCategory")
    ineligibleRegion = URIRef("https://schema.org/ineligibleRegion")
    InternationalTrial = URIRef("https://schema.org/InternationalTrial")
    ItemPage = URIRef("https://schema.org/ItemPage")
    geoCoveredBy = URIRef("https://schema.org/geoCoveredBy")
    CompoundPriceSpecification = URIRef("https://schema.org/CompoundPriceSpecification")
    WearableMeasurementWaist = URIRef("https://schema.org/WearableMeasurementWaist")
    nationality = URIRef("https://schema.org/nationality")
    Time = URIRef("https://schema.org/Time")
    seatingCapacity = URIRef("https://schema.org/seatingCapacity")
    deathDate = URIRef("https://schema.org/deathDate")
    event = URIRef("https://schema.org/event")
    ticketNumber = URIRef("https://schema.org/ticketNumber")
    PrimaryCare = URIRef("https://schema.org/PrimaryCare")
    EUEnergyEfficiencyCategoryA = URIRef("https://schema.org/EUEnergyEfficiencyCategoryA")
    pageEnd = URIRef("https://schema.org/pageEnd")
    increasesRiskOf = URIRef("https://schema.org/increasesRiskOf")
    applicableCountry = URIRef("https://schema.org/applicableCountry")
    gameServer = URIRef("https://schema.org/gameServer")
    applicableLocation = URIRef("https://schema.org/applicableLocation")
    ResearchOrganization = URIRef("https://schema.org/ResearchOrganization")
    subjectOf = URIRef("https://schema.org/subjectOf")
    seasons = URIRef("https://schema.org/seasons")
    Quiz = URIRef("https://schema.org/Quiz")
    LocalBusiness = URIRef("https://schema.org/LocalBusiness")
    RisksOrComplicationsHealthAspect = URIRef("https://schema.org/RisksOrComplicationsHealthAspect")
    WPSideBar = URIRef("https://schema.org/WPSideBar")
    bodyLocation = URIRef("https://schema.org/bodyLocation")
    pregnancyWarning = URIRef("https://schema.org/pregnancyWarning")
    honorificSuffix = URIRef("https://schema.org/honorificSuffix")
    actors = URIRef("https://schema.org/actors")
    eligibleTransactionVolume = URIRef("https://schema.org/eligibleTransactionVolume")
    recordedIn = URIRef("https://schema.org/recordedIn")
    associatedClaimReview = URIRef("https://schema.org/associatedClaimReview")
    broadcastFrequencyValue = URIRef("https://schema.org/broadcastFrequencyValue")
    eligibleCustomerType = URIRef("https://schema.org/eligibleCustomerType")
    engineDisplacement = URIRef("https://schema.org/engineDisplacement")
    arrivalStation = URIRef("https://schema.org/arrivalStation")
    WearableSizeGroupRegular = URIRef("https://schema.org/WearableSizeGroupRegular")
    publication = URIRef("https://schema.org/publication")
    mainContentOfPage = URIRef("https://schema.org/mainContentOfPage")
    shippingOrigin = URIRef("https://schema.org/shippingOrigin")
    trainNumber = URIRef("https://schema.org/trainNumber")
    membershipPointsEarned = URIRef("https://schema.org/membershipPointsEarned")
    availabilityEnds = URIRef("https://schema.org/availabilityEnds")
    sourcedFrom = URIRef("https://schema.org/sourcedFrom")
    director = URIRef("https://schema.org/director")
    ComicIssue = URIRef("https://schema.org/ComicIssue")
    associatedArticle = URIRef("https://schema.org/associatedArticle")
    PaymentComplete = URIRef("https://schema.org/PaymentComplete")
    CssSelectorType = URIRef("https://schema.org/CssSelectorType")
    CardiovascularExam = URIRef("https://schema.org/CardiovascularExam")
    incentiveCompensation = URIRef("https://schema.org/incentiveCompensation")
    educationalProgramMode = URIRef("https://schema.org/educationalProgramMode")
    availabilityEnds = URIRef("https://schema.org/availabilityEnds")
    CausesHealthAspect = URIRef("https://schema.org/CausesHealthAspect")
    areaServed = URIRef("https://schema.org/areaServed")
    biologicalRole = URIRef("https://schema.org/biologicalRole")
    hasCredential = URIRef("https://schema.org/hasCredential")
    DesktopWebPlatform = URIRef("https://schema.org/DesktopWebPlatform")
    Nonprofit501c26 = URIRef("https://schema.org/Nonprofit501c26")
    WearableSizeSystemEN13402 = URIRef("https://schema.org/WearableSizeSystemEN13402")
    UserComments = URIRef("https://schema.org/UserComments")
    CertificationInactive = URIRef("https://schema.org/CertificationInactive")
    evidenceOrigin = URIRef("https://schema.org/evidenceOrigin")
    OpeningHoursSpecification = URIRef("https://schema.org/OpeningHoursSpecification")
    MusicComposition = URIRef("https://schema.org/MusicComposition")
    InternetCafe = URIRef("https://schema.org/InternetCafe")
    monoisotopicMolecularWeight = URIRef("https://schema.org/monoisotopicMolecularWeight")
    numberedPosition = URIRef("https://schema.org/numberedPosition")
    endDate = URIRef("https://schema.org/endDate")
    cvdNumC19Died = URIRef("https://schema.org/cvdNumC19Died")
    KosherDiet = URIRef("https://schema.org/KosherDiet")
    Grant = URIRef("https://schema.org/Grant")
    DrugClass = URIRef("https://schema.org/DrugClass")
    NLNonprofitType = URIRef("https://schema.org/NLNonprofitType")
    originalMediaContextDescription = URIRef("https://schema.org/originalMediaContextDescription")
    DoseSchedule = URIRef("https://schema.org/DoseSchedule")
    broadcastOfEvent = URIRef("https://schema.org/broadcastOfEvent")
    AmpStory = URIRef("https://schema.org/AmpStory")
    ReturnLabelInBox = URIRef("https://schema.org/ReturnLabelInBox")
    cookingMethod = URIRef("https://schema.org/cookingMethod")
    subEvents = URIRef("https://schema.org/subEvents")
    Nonprofit501c27 = URIRef("https://schema.org/Nonprofit501c27")
    Distillery = URIRef("https://schema.org/Distillery")
    acceptedPaymentMethod = URIRef("https://schema.org/acceptedPaymentMethod")
    loanMortgageMandateAmount = URIRef("https://schema.org/loanMortgageMandateAmount")
    gtin12 = URIRef("https://schema.org/gtin12")
    transitTime = URIRef("https://schema.org/transitTime")
    fileFormat = URIRef("https://schema.org/fileFormat")
    tracks = URIRef("https://schema.org/tracks")
    language = URIRef("https://schema.org/language")
    OnlineStore = URIRef("https://schema.org/OnlineStore")
    ConsumeAction = URIRef("https://schema.org/ConsumeAction")
    returnPolicyCountry = URIRef("https://schema.org/returnPolicyCountry")
    ExercisePlan = URIRef("https://schema.org/ExercisePlan")
    RVPark = URIRef("https://schema.org/RVPark")
    Nursing = URIRef("https://schema.org/Nursing")
    recourseLoan = URIRef("https://schema.org/recourseLoan")
    hoursAvailable = URIRef("https://schema.org/hoursAvailable")
    Hospital = URIRef("https://schema.org/Hospital")
    screenshot = URIRef("https://schema.org/screenshot")
    numberedPosition = URIRef("https://schema.org/numberedPosition")
    availableStrength = URIRef("https://schema.org/availableStrength")
    hasBioChemEntityPart = URIRef("https://schema.org/hasBioChemEntityPart")
    Nonprofit527 = URIRef("https://schema.org/Nonprofit527")
    assesses = URIRef("https://schema.org/assesses")
    proprietaryName = URIRef("https://schema.org/proprietaryName")
    TraditionalChinese = URIRef("https://schema.org/TraditionalChinese")
    diseaseSpreadStatistics = URIRef("https://schema.org/diseaseSpreadStatistics")
    healthPlanCopay = URIRef("https://schema.org/healthPlanCopay")
    shippingDestination = URIRef("https://schema.org/shippingDestination")
    quarantineGuidelines = URIRef("https://schema.org/quarantineGuidelines")
    touristType = URIRef("https://schema.org/touristType")
    gameAvailabilityType = URIRef("https://schema.org/gameAvailabilityType")
    NoninvasiveProcedure = URIRef("https://schema.org/NoninvasiveProcedure")
    SchoolDistrict = URIRef("https://schema.org/SchoolDistrict")
    GeospatialGeometry = URIRef("https://schema.org/GeospatialGeometry")
    MedicalRiskEstimator = URIRef("https://schema.org/MedicalRiskEstimator")
    PhysiciansOffice = URIRef("https://schema.org/PhysiciansOffice")
    knowsAbout = URIRef("https://schema.org/knowsAbout")
    VacationRental = URIRef("https://schema.org/VacationRental")
    ReturnAtKiosk = URIRef("https://schema.org/ReturnAtKiosk")
    Restaurant = URIRef("https://schema.org/Restaurant")
    cvdNumC19HOPats = URIRef("https://schema.org/cvdNumC19HOPats")
    medicalSpecialty = URIRef("https://schema.org/medicalSpecialty")
    OnlineEventAttendanceMode = URIRef("https://schema.org/OnlineEventAttendanceMode")
    TouristDestination = URIRef("https://schema.org/TouristDestination")
    latitude = URIRef("https://schema.org/latitude")
    percentile10 = URIRef("https://schema.org/percentile10")
    directors = URIRef("https://schema.org/directors")
    unnamedSourcesPolicy = URIRef("https://schema.org/unnamedSourcesPolicy")
    departureBoatTerminal = URIRef("https://schema.org/departureBoatTerminal")
    hasDriveThroughService = URIRef("https://schema.org/hasDriveThroughService")
    TransformedContent = URIRef("https://schema.org/TransformedContent")
    directors = URIRef("https://schema.org/directors")
    programPrerequisites = URIRef("https://schema.org/programPrerequisites")
    RecyclingCenter = URIRef("https://schema.org/RecyclingCenter")
    PostalCodeRangeSpecification = URIRef("https://schema.org/PostalCodeRangeSpecification")
    eligibleRegion = URIRef("https://schema.org/eligibleRegion")
    Ayurvedic = URIRef("https://schema.org/Ayurvedic")
    hasCourse = URIRef("https://schema.org/hasCourse")
    observationAbout = URIRef("https://schema.org/observationAbout")
    geoTouches = URIRef("https://schema.org/geoTouches")
    SportsClub = URIRef("https://schema.org/SportsClub")
    GroupBoardingPolicy = URIRef("https://schema.org/GroupBoardingPolicy")
    Country = URIRef("https://schema.org/Country")
    relatedTo = URIRef("https://schema.org/relatedTo")
    UserReview = URIRef("https://schema.org/UserReview")
    MediaGallery = URIRef("https://schema.org/MediaGallery")
    incentives = URIRef("https://schema.org/incentives")
    serviceAudience = URIRef("https://schema.org/serviceAudience")
    FoodEstablishment = URIRef("https://schema.org/FoodEstablishment")
    AnaerobicActivity = URIRef("https://schema.org/AnaerobicActivity")
    Blog = URIRef("https://schema.org/Blog")
    MedicalResearcher = URIRef("https://schema.org/MedicalResearcher")
    appearance = URIRef("https://schema.org/appearance")
    DiagnosticLab = URIRef("https://schema.org/DiagnosticLab")
    floorLevel = URIRef("https://schema.org/floorLevel")
    previousStartDate = URIRef("https://schema.org/previousStartDate")
    isicV4 = URIRef("https://schema.org/isicV4")
    signDetected = URIRef("https://schema.org/signDetected")
    albumReleaseType = URIRef("https://schema.org/albumReleaseType")
    greaterOrEqual = URIRef("https://schema.org/greaterOrEqual")
    broadcastChannelId = URIRef("https://schema.org/broadcastChannelId")
    competencyRequired = URIRef("https://schema.org/competencyRequired")
    musicReleaseFormat = URIRef("https://schema.org/musicReleaseFormat")
    deliveryTime = URIRef("https://schema.org/deliveryTime")
    weight = URIRef("https://schema.org/weight")
    Tuesday = URIRef("https://schema.org/Tuesday")
    seasons = URIRef("https://schema.org/seasons")
    BodyMeasurementBust = URIRef("https://schema.org/BodyMeasurementBust")
    RearWheelDriveConfiguration = URIRef("https://schema.org/RearWheelDriveConfiguration")
    comprisedOf = URIRef("https://schema.org/comprisedOf")
    NotInForce = URIRef("https://schema.org/NotInForce")
    broker = URIRef("https://schema.org/broker")
    arrivalStation = URIRef("https://schema.org/arrivalStation")
    Recommendation = URIRef("https://schema.org/Recommendation")
    Observation = URIRef("https://schema.org/Observation")
    PlanAction = URIRef("https://schema.org/PlanAction")
    messageAttachment = URIRef("https://schema.org/messageAttachment")
    CollectionPage = URIRef("https://schema.org/CollectionPage")
    additionalType = URIRef("https://schema.org/additionalType")
    bccRecipient = URIRef("https://schema.org/bccRecipient")
    accommodationFloorPlan = URIRef("https://schema.org/accommodationFloorPlan")
    potentialUse = URIRef("https://schema.org/potentialUse")
    CompleteDataFeed = URIRef("https://schema.org/CompleteDataFeed")
    WebAPI = URIRef("https://schema.org/WebAPI")
    AmpStory = URIRef("https://schema.org/AmpStory")
    accommodationCategory = URIRef("https://schema.org/accommodationCategory")
    recipeInstructions = URIRef("https://schema.org/recipeInstructions")
    ReturnLabelDownloadAndPrint = URIRef("https://schema.org/ReturnLabelDownloadAndPrint")
    Geriatric = URIRef("https://schema.org/Geriatric")
    MusicStore = URIRef("https://schema.org/MusicStore")
    seriousAdverseOutcome = URIRef("https://schema.org/seriousAdverseOutcome")
    Observation = URIRef("https://schema.org/Observation")
    follows = URIRef("https://schema.org/follows")
    TouristTrip = URIRef("https://schema.org/TouristTrip")
    availableTest = URIRef("https://schema.org/availableTest")
    gameItem = URIRef("https://schema.org/gameItem")
    contactOption = URIRef("https://schema.org/contactOption")
    MedicalBusiness = URIRef("https://schema.org/MedicalBusiness")
    version = URIRef("https://schema.org/version")
    repeatCount = URIRef("https://schema.org/repeatCount")
    sodiumContent = URIRef("https://schema.org/sodiumContent")
    representativeOfPage = URIRef("https://schema.org/representativeOfPage")
    isRelatedTo = URIRef("https://schema.org/isRelatedTo")
    MusicReleaseFormatType = URIRef("https://schema.org/MusicReleaseFormatType")
    SpeakableSpecification = URIRef("https://schema.org/SpeakableSpecification")
    WearableSizeGroupJuniors = URIRef("https://schema.org/WearableSizeGroupJuniors")
    SizeGroupEnumeration = URIRef("https://schema.org/SizeGroupEnumeration")
    costCurrency = URIRef("https://schema.org/costCurrency")
    lastReviewed = URIRef("https://schema.org/lastReviewed")
    PlanAction = URIRef("https://schema.org/PlanAction")
    hasMenu = URIRef("https://schema.org/hasMenu")
    CreditCard = URIRef("https://schema.org/CreditCard")
    webFeed = URIRef("https://schema.org/webFeed")
    itemDefectReturnFees = URIRef("https://schema.org/itemDefectReturnFees")
    containedInPlace = URIRef("https://schema.org/containedInPlace")
    award = URIRef("https://schema.org/award")
    codeValue = URIRef("https://schema.org/codeValue")
    epidemiology = URIRef("https://schema.org/epidemiology")
    legislationApplies = URIRef("https://schema.org/legislationApplies")
    WearableMeasurementTypeEnumeration = URIRef("https://schema.org/WearableMeasurementTypeEnumeration")
    foundingDate = URIRef("https://schema.org/foundingDate")
    clipNumber = URIRef("https://schema.org/clipNumber")
    Eye = URIRef("https://schema.org/Eye")
    bodyType = URIRef("https://schema.org/bodyType")
    Quiz = URIRef("https://schema.org/Quiz")
    BodyMeasurementHand = URIRef("https://schema.org/BodyMeasurementHand")
    inDefinedTermSet = URIRef("https://schema.org/inDefinedTermSet")
    Gastroenterologic = URIRef("https://schema.org/Gastroenterologic")
    educationalRole = URIRef("https://schema.org/educationalRole")
    salaryCurrency = URIRef("https://schema.org/salaryCurrency")
    seriousAdverseOutcome = URIRef("https://schema.org/seriousAdverseOutcome")
    DepartmentStore = URIRef("https://schema.org/DepartmentStore")
    alumni = URIRef("https://schema.org/alumni")
    ResearchOrganization = URIRef("https://schema.org/ResearchOrganization")
    recordLabel = URIRef("https://schema.org/recordLabel")
    MotorcycleRepair = URIRef("https://schema.org/MotorcycleRepair")
    DJMixAlbum = URIRef("https://schema.org/DJMixAlbum")
    fundedItem = URIRef("https://schema.org/fundedItem")
    startDate = URIRef("https://schema.org/startDate")
    educationRequirements = URIRef("https://schema.org/educationRequirements")
    videoFormat = URIRef("https://schema.org/videoFormat")
    median = URIRef("https://schema.org/median")
    ReturnLabelDownloadAndPrint = URIRef("https://schema.org/ReturnLabelDownloadAndPrint")
    Nonprofit501c11 = URIRef("https://schema.org/Nonprofit501c11")
    ItemList = URIRef("https://schema.org/ItemList")
    FDAnotEvaluated = URIRef("https://schema.org/FDAnotEvaluated")
    deliveryLeadTime = URIRef("https://schema.org/deliveryLeadTime")
    unnamedSourcesPolicy = URIRef("https://schema.org/unnamedSourcesPolicy")
    Nonprofit501n = URIRef("https://schema.org/Nonprofit501n")
    primaryPrevention = URIRef("https://schema.org/primaryPrevention")
    paymentDueDate = URIRef("https://schema.org/paymentDueDate")
    EntertainmentBusiness = URIRef("https://schema.org/EntertainmentBusiness")
    eligibleDuration = URIRef("https://schema.org/eligibleDuration")
    contentRating = URIRef("https://schema.org/contentRating")
    WearAction = URIRef("https://schema.org/WearAction")
    actionPlatform = URIRef("https://schema.org/actionPlatform")
    OccupationalTherapy = URIRef("https://schema.org/OccupationalTherapy")
    Country = URIRef("https://schema.org/Country")
    BasicIncome = URIRef("https://schema.org/BasicIncome")
    HowToSection = URIRef("https://schema.org/HowToSection")
    DepositAccount = URIRef("https://schema.org/DepositAccount")
    MedicalRiskFactor = URIRef("https://schema.org/MedicalRiskFactor")
    OrderPickupAvailable = URIRef("https://schema.org/OrderPickupAvailable")
    educationalLevel = URIRef("https://schema.org/educationalLevel")
    musicCompositionForm = URIRef("https://schema.org/musicCompositionForm")
    servesCuisine = URIRef("https://schema.org/servesCuisine")
    BedDetails = URIRef("https://schema.org/BedDetails")
    supersededBy = URIRef("https://schema.org/supersededBy")
    itemShipped = URIRef("https://schema.org/itemShipped")
    annualPercentageRate = URIRef("https://schema.org/annualPercentageRate")
    carrierRequirements = URIRef("https://schema.org/carrierRequirements")
    insertion = URIRef("https://schema.org/insertion")
    character = URIRef("https://schema.org/character")
    gender = URIRef("https://schema.org/gender")
    suggestedGender = URIRef("https://schema.org/suggestedGender")
    numberOfPartialBathrooms = URIRef("https://schema.org/numberOfPartialBathrooms")
    deliveryAddress = URIRef("https://schema.org/deliveryAddress")
    musicBy = URIRef("https://schema.org/musicBy")
    postalCode = URIRef("https://schema.org/postalCode")
    Mountain = URIRef("https://schema.org/Mountain")
    isVariantOf = URIRef("https://schema.org/isVariantOf")
    legislationLegalForce = URIRef("https://schema.org/legislationLegalForce")
    Poster = URIRef("https://schema.org/Poster")
    GeospatialGeometry = URIRef("https://schema.org/GeospatialGeometry")
    cvdNumVentUse = URIRef("https://schema.org/cvdNumVentUse")
    AlcoholConsideration = URIRef("https://schema.org/AlcoholConsideration")
    HealthPlanNetwork = URIRef("https://schema.org/HealthPlanNetwork")
    actionPlatform = URIRef("https://schema.org/actionPlatform")
    map = URIRef("https://schema.org/map")
    SkiResort = URIRef("https://schema.org/SkiResort")
    actionStatus = URIRef("https://schema.org/actionStatus")
    additionalName = URIRef("https://schema.org/additionalName")
    AlgorithmicallyEnhancedDigitalSource = URIRef("https://schema.org/AlgorithmicallyEnhancedDigitalSource")
    hasBioPolymerSequence = URIRef("https://schema.org/hasBioPolymerSequence")
    polygon = URIRef("https://schema.org/polygon")
    MedicalProcedure = URIRef("https://schema.org/MedicalProcedure")
    DoseSchedule = URIRef("https://schema.org/DoseSchedule")
    NutritionInformation = URIRef("https://schema.org/NutritionInformation")
    isBasedOn = URIRef("https://schema.org/isBasedOn")
    hasDriveThroughService = URIRef("https://schema.org/hasDriveThroughService")
    accessibilityControl = URIRef("https://schema.org/accessibilityControl")
    merchantReturnLink = URIRef("https://schema.org/merchantReturnLink")
    baseSalary = URIRef("https://schema.org/baseSalary")
    fuelType = URIRef("https://schema.org/fuelType")
    VeterinaryCare = URIRef("https://schema.org/VeterinaryCare")
    TakeAction = URIRef("https://schema.org/TakeAction")
    LibrarySystem = URIRef("https://schema.org/LibrarySystem")
    Nonprofit501c8 = URIRef("https://schema.org/Nonprofit501c8")
    hasAdultConsideration = URIRef("https://schema.org/hasAdultConsideration")
    Hotel = URIRef("https://schema.org/Hotel")
    Monday = URIRef("https://schema.org/Monday")
    TextDigitalDocument = URIRef("https://schema.org/TextDigitalDocument")
    schoolClosuresInfo = URIRef("https://schema.org/schoolClosuresInfo")
    parentService = URIRef("https://schema.org/parentService")
    Online = URIRef("https://schema.org/Online")
    nsn = URIRef("https://schema.org/nsn")
    MaximumDoseSchedule = URIRef("https://schema.org/MaximumDoseSchedule")
    MolecularEntity = URIRef("https://schema.org/MolecularEntity")
    dietFeatures = URIRef("https://schema.org/dietFeatures")
    marginOfError = URIRef("https://schema.org/marginOfError")
    legislationResponsible = URIRef("https://schema.org/legislationResponsible")
    eligibleRegion = URIRef("https://schema.org/eligibleRegion")
    Muscle = URIRef("https://schema.org/Muscle")
    Optician = URIRef("https://schema.org/Optician")
    attendees = URIRef("https://schema.org/attendees")
    offers = URIRef("https://schema.org/offers")
    Suspended = URIRef("https://schema.org/Suspended")
    unitText = URIRef("https://schema.org/unitText")
    identifyingExam = URIRef("https://schema.org/identifyingExam")
    prescribingInfo = URIRef("https://schema.org/prescribingInfo")
    addressLocality = URIRef("https://schema.org/addressLocality")
    programType = URIRef("https://schema.org/programType")
    OfferItemCondition = URIRef("https://schema.org/OfferItemCondition")
    referencesOrder = URIRef("https://schema.org/referencesOrder")
    OriginalMediaContent = URIRef("https://schema.org/OriginalMediaContent")
    Cemetery = URIRef("https://schema.org/Cemetery")
    PreventionIndication = URIRef("https://schema.org/PreventionIndication")
    sizeGroup = URIRef("https://schema.org/sizeGroup")
    programPrerequisites = URIRef("https://schema.org/programPrerequisites")
    partOfTrip = URIRef("https://schema.org/partOfTrip")
    WearableSizeSystemEurope = URIRef("https://schema.org/WearableSizeSystemEurope")
    MedicalRiskCalculator = URIRef("https://schema.org/MedicalRiskCalculator")
    includesHealthPlanNetwork = URIRef("https://schema.org/includesHealthPlanNetwork")
    spatial = URIRef("https://schema.org/spatial")
    width = URIRef("https://schema.org/width")
    amenityFeature = URIRef("https://schema.org/amenityFeature")
    numberOfPartialBathrooms = URIRef("https://schema.org/numberOfPartialBathrooms")
    ReportedDoseSchedule = URIRef("https://schema.org/ReportedDoseSchedule")
    ActionStatusType = URIRef("https://schema.org/ActionStatusType")
    maximumVirtualAttendeeCapacity = URIRef("https://schema.org/maximumVirtualAttendeeCapacity")
    BodyMeasurementWeight = URIRef("https://schema.org/BodyMeasurementWeight")
    broadcastFrequency = URIRef("https://schema.org/broadcastFrequency")
    isBasedOnUrl = URIRef("https://schema.org/isBasedOnUrl")
    AnalysisNewsArticle = URIRef("https://schema.org/AnalysisNewsArticle")
    WearableSizeGroupTall = URIRef("https://schema.org/WearableSizeGroupTall")
    offersPrescriptionByMail = URIRef("https://schema.org/offersPrescriptionByMail")
    Joint = URIRef("https://schema.org/Joint")
    GovernmentOffice = URIRef("https://schema.org/GovernmentOffice")
    Wednesday = URIRef("https://schema.org/Wednesday")
    HotelRoom = URIRef("https://schema.org/HotelRoom")
    Accommodation = URIRef("https://schema.org/Accommodation")
    volumeNumber = URIRef("https://schema.org/volumeNumber")
    healthPlanCostSharing = URIRef("https://schema.org/healthPlanCostSharing")
    maxValue = URIRef("https://schema.org/maxValue")
    operatingSystem = URIRef("https://schema.org/operatingSystem")
    InvoicePrice = URIRef("https://schema.org/InvoicePrice")
    RsvpResponseType = URIRef("https://schema.org/RsvpResponseType")
    DeactivateAction = URIRef("https://schema.org/DeactivateAction")
    SpecialAnnouncement = URIRef("https://schema.org/SpecialAnnouncement")
    duration = URIRef("https://schema.org/duration")
    screenCount = URIRef("https://schema.org/screenCount")
    dateRead = URIRef("https://schema.org/dateRead")
    OceanBodyOfWater = URIRef("https://schema.org/OceanBodyOfWater")
    VitalSign = URIRef("https://schema.org/VitalSign")
    occupationalCredentialAwarded = URIRef("https://schema.org/occupationalCredentialAwarded")
    partOfOrder = URIRef("https://schema.org/partOfOrder")
    associatedMediaReview = URIRef("https://schema.org/associatedMediaReview")
    nonEqual = URIRef("https://schema.org/nonEqual")
    eventAttendanceMode = URIRef("https://schema.org/eventAttendanceMode")
    educationRequirements = URIRef("https://schema.org/educationRequirements")
    Osteopathic = URIRef("https://schema.org/Osteopathic")
    InForce = URIRef("https://schema.org/InForce")
    printEdition = URIRef("https://schema.org/printEdition")
    MerchantReturnPolicySeasonalOverride = URIRef("https://schema.org/MerchantReturnPolicySeasonalOverride")
    LowFatDiet = URIRef("https://schema.org/LowFatDiet")
    businessDays = URIRef("https://schema.org/businessDays")
    TaxiReservation = URIRef("https://schema.org/TaxiReservation")
    FoodService = URIRef("https://schema.org/FoodService")
    EventStatusType = URIRef("https://schema.org/EventStatusType")

    _NS = Namespace("https://qudt.org/vocab/unit/")