from rdflib.namespace import DefinedNamespace, Namespace
from rdflib.term import URIRef


class QUDT_KIND(DefinedNamespace):
    # Generated with namespacelib version 0.3.0
    _fail = True
    TemperatureDifference = URIRef("http://qudt.org/vocab/quantitykind/TemperatureDifference")
    ElectricCurrentPhasor = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPhasor")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    Reflectance = URIRef("http://qudt.org/vocab/quantitykind/Reflectance")
    ThermodynamicCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicCriticalMagneticFluxDensity")
    LogarithmicMedianInformationFlow_SourceToBase10 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicMedianInformationFlow_SourceToBase10")
    SurfaceActivityDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceActivityDensity")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    SoundPowerLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPowerLevel")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    PlanckFunction = URIRef("http://qudt.org/vocab/quantitykind/PlanckFunction")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    MolarAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAbsorptionCoefficient")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    Permittivity = URIRef("http://qudt.org/vocab/quantitykind/Permittivity")
    MassRatioOfWaterToDryMatter = URIRef("http://qudt.org/vocab/quantitykind/MassRatioOfWaterToDryMatter")
    MassPerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerAreaTime")
    MassPerEnergy = URIRef("http://qudt.org/vocab/quantitykind/MassPerEnergy")
    MolarOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/MolarOpticalRotatoryPower")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    Temperature = URIRef("http://qudt.org/vocab/quantitykind/Temperature")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    DebyeAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularFrequency")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    SecondStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SecondStageMassRatio")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    LengthRatio = URIRef("http://qudt.org/vocab/quantitykind/LengthRatio")
    FlightPathAngle = URIRef("http://qudt.org/vocab/quantitykind/FlightPathAngle")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    SpecificHeatCapacityAtSaturation = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtSaturation")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    LengthTemperature = URIRef("http://qudt.org/vocab/quantitykind/LengthTemperature")
    Circulation = URIRef("http://qudt.org/vocab/quantitykind/Circulation")
    SoilAdsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SoilAdsorptionCoefficient")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    TimeRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRatio")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    InverseSquareTime = URIRef("http://qudt.org/vocab/quantitykind/InverseSquareTime")
    MolarConductivity = URIRef("http://qudt.org/vocab/quantitykind/MolarConductivity")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    NeutralRatio = URIRef("http://qudt.org/vocab/quantitykind/NeutralRatio")
    DynamicFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DynamicFrictionCoefficient")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    Exposure = URIRef("http://qudt.org/vocab/quantitykind/Exposure")
    InverseVolume = URIRef("http://qudt.org/vocab/quantitykind/InverseVolume")
    Luminance = URIRef("http://qudt.org/vocab/quantitykind/Luminance")
    LinearElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrentDensity")
    EvaporativeHeatTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/EvaporativeHeatTransferCoefficient")
    DiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficient")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    Voltage = URIRef("http://qudt.org/vocab/quantitykind/Voltage")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    Capacitance = URIRef("http://qudt.org/vocab/quantitykind/Capacitance")
    PhotonLuminance = URIRef("http://qudt.org/vocab/quantitykind/PhotonLuminance")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    InverseSquareEnergy = URIRef("http://qudt.org/vocab/quantitykind/InverseSquareEnergy")
    CatalyticActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivityConcentration")
    PackingFraction = URIRef("http://qudt.org/vocab/quantitykind/PackingFraction")
    EnergyPerArea = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerArea")
    VaporPermeability = URIRef("http://qudt.org/vocab/quantitykind/VaporPermeability")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    OrbitalAngularMomentumPerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/OrbitalAngularMomentumPerUnitMass")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    TemperatureRelatedVolume = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRelatedVolume")
    SpecificHelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificHelmholtzEnergy")
    MassRelatedElectricalCurrent = URIRef("http://qudt.org/vocab/quantitykind/MassRelatedElectricalCurrent")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    MolarDensity = URIRef("http://qudt.org/vocab/quantitykind/MolarDensity")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    ElectricCurrentPhasor = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPhasor")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    FissionFuelUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionFuelUtilizationFactor")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    TemperatureBasedMass = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedMass")
    PhotonIntensity = URIRef("http://qudt.org/vocab/quantitykind/PhotonIntensity")
    StaticPressure = URIRef("http://qudt.org/vocab/quantitykind/StaticPressure")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    AcceptorDensity = URIRef("http://qudt.org/vocab/quantitykind/AcceptorDensity")
    AuxillaryMagneticField = URIRef("http://qudt.org/vocab/quantitykind/AuxillaryMagneticField")
    CurrencyPerFlight = URIRef("http://qudt.org/vocab/quantitykind/CurrencyPerFlight")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    Speed = URIRef("http://qudt.org/vocab/quantitykind/Speed")
    GeneralizedForce = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedForce")
    AngularReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/AngularReciprocalLatticeVector")
    Slowing_DownDensity = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownDensity")
    RateOfChangeOfTemperature = URIRef("http://qudt.org/vocab/quantitykind/RateOfChangeOfTemperature")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    PoyntingVector = URIRef("http://qudt.org/vocab/quantitykind/PoyntingVector")
    BandwidthLengthProduct = URIRef("http://qudt.org/vocab/quantitykind/BandwidthLengthProduct")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    AuditoryThresholds = URIRef("http://qudt.org/vocab/quantitykind/AuditoryThresholds")
    SpecificSurfaceArea = URIRef("http://qudt.org/vocab/quantitykind/SpecificSurfaceArea")
    Asset = URIRef("http://qudt.org/vocab/quantitykind/Asset")
    LineicMass = URIRef("http://qudt.org/vocab/quantitykind/LineicMass")
    SurfaceRelatedVolumeFlow = URIRef("http://qudt.org/vocab/quantitykind/SurfaceRelatedVolumeFlow")
    DebyeAngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularWavenumber")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    MassPerTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerTime")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    BloodGlucoseLevel = URIRef("http://qudt.org/vocab/quantitykind/BloodGlucoseLevel")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    MOMENT_OF_INERTIA_Y = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Y")
    MassConcentration = URIRef("http://qudt.org/vocab/quantitykind/MassConcentration")
    Admittance = URIRef("http://qudt.org/vocab/quantitykind/Admittance")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    PhotosyntheticPhotonFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/PhotosyntheticPhotonFluxDensity")
    Incidence = URIRef("http://qudt.org/vocab/quantitykind/Incidence")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    SoundParticleVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleVelocity")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    PRODUCT_OF_INERTIA_X = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA_X")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    Radiosity = URIRef("http://qudt.org/vocab/quantitykind/Radiosity")
    LinearIonization = URIRef("http://qudt.org/vocab/quantitykind/LinearIonization")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    BloodGlucoseLevel_Mass = URIRef("http://qudt.org/vocab/quantitykind/BloodGlucoseLevel_Mass")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    Impedance = URIRef("http://qudt.org/vocab/quantitykind/Impedance")
    MeltingPoint = URIRef("http://qudt.org/vocab/quantitykind/MeltingPoint")
    NeelTemperature = URIRef("http://qudt.org/vocab/quantitykind/NeelTemperature")
    EvaporativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/EvaporativeHeatTransfer")
    Turbidity = URIRef("http://qudt.org/vocab/quantitykind/Turbidity")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    HeatFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/HeatFluxDensity")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    EnergyDensityOfStates = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensityOfStates")
    Fluidity = URIRef("http://qudt.org/vocab/quantitykind/Fluidity")
    StoichiometricNumber = URIRef("http://qudt.org/vocab/quantitykind/StoichiometricNumber")
    TotalLinearStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalLinearStoppingPower")
    MagneticFluxPerUnitLength = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxPerUnitLength")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    AreaPerPower = URIRef("http://qudt.org/vocab/quantitykind/AreaPerPower")
    AngleOfAttack = URIRef("http://qudt.org/vocab/quantitykind/AngleOfAttack")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    MassFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MassFluxDensity")
    ElectricDisplacement = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacement")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    SecondStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SecondStageMassRatio")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    AcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/AcousticImpedance")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    MagneticPolarization = URIRef("http://qudt.org/vocab/quantitykind/MagneticPolarization")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    OsmoticPressure = URIRef("http://qudt.org/vocab/quantitykind/OsmoticPressure")
    SoundExposureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundExposureLevel")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    InverseMagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/InverseMagneticFlux")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    SurgeImpedanceOfTheMedium = URIRef("http://qudt.org/vocab/quantitykind/SurgeImpedanceOfTheMedium")
    DimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/DimensionlessRatio")
    LinearAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAttenuationCoefficient")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    ElectricChargeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeDensity")
    Speed = URIRef("http://qudt.org/vocab/quantitykind/Speed")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    MobilityRatio = URIRef("http://qudt.org/vocab/quantitykind/MobilityRatio")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    LogarithmicFrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyInterval")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    MassRatioOfWaterToDryMatter = URIRef("http://qudt.org/vocab/quantitykind/MassRatioOfWaterToDryMatter")
    StaticFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StaticFrictionCoefficient")
    SpecificPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificPower")
    Non_LeakageProbability = URIRef("http://qudt.org/vocab/quantitykind/Non-LeakageProbability")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    SpecificHeatPressure = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatPressure")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    CouplingFactor = URIRef("http://qudt.org/vocab/quantitykind/CouplingFactor")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    FermiTemperature = URIRef("http://qudt.org/vocab/quantitykind/FermiTemperature")
    ResonanceEscapeProbability = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbability")
    NumberOfParticles = URIRef("http://qudt.org/vocab/quantitykind/NumberOfParticles")
    ElectronDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectronDensity")
    AtmosphericPressure = URIRef("http://qudt.org/vocab/quantitykind/AtmosphericPressure")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    ThermalCoefficientOfLinearExpansion = URIRef("http://qudt.org/vocab/quantitykind/ThermalCoefficientOfLinearExpansion")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    LuminousFluxPerArea = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxPerArea")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    SoundParticleVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleVelocity")
    SpectralConcentrationOfRadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SpectralConcentrationOfRadiantEnergyDensity")
    OsmoticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/OsmoticCoefficient")
    AverageLogarithmicEnergyDecrement = URIRef("http://qudt.org/vocab/quantitykind/AverageLogarithmicEnergyDecrement")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    LinearResistance = URIRef("http://qudt.org/vocab/quantitykind/LinearResistance")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    Radiance = URIRef("http://qudt.org/vocab/quantitykind/Radiance")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    LossFactor = URIRef("http://qudt.org/vocab/quantitykind/LossFactor")
    ExchangeIntegral = URIRef("http://qudt.org/vocab/quantitykind/ExchangeIntegral")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    PolarizationField = URIRef("http://qudt.org/vocab/quantitykind/PolarizationField")
    Landau_GinzburgNumber = URIRef("http://qudt.org/vocab/quantitykind/Landau-GinzburgNumber")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    WarmReceptorThreshold = URIRef("http://qudt.org/vocab/quantitykind/WarmReceptorThreshold")
    InverseVolume = URIRef("http://qudt.org/vocab/quantitykind/InverseVolume")
    NeutronDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionCoefficient")
    ResistancePercentage = URIRef("http://qudt.org/vocab/quantitykind/ResistancePercentage")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    ModulusOfAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfAdmittance")
    CharacteristicAcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicAcousticImpedance")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    AtmosphericPressure = URIRef("http://qudt.org/vocab/quantitykind/AtmosphericPressure")
    EnergyPerSquareMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerSquareMagneticFluxDensity")
    ForceConstant = URIRef("http://qudt.org/vocab/quantitykind/ForceConstant")
    ElectromagneticPermeability = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeability")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    SpecificElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/SpecificElectricCurrent")
    MadelungConstant = URIRef("http://qudt.org/vocab/quantitykind/MadelungConstant")
    DegreeOfDissociation = URIRef("http://qudt.org/vocab/quantitykind/DegreeOfDissociation")
    NeutronYieldPerAbsorption = URIRef("http://qudt.org/vocab/quantitykind/NeutronYieldPerAbsorption")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    Permeance = URIRef("http://qudt.org/vocab/quantitykind/Permeance")
    EnergyPerMagneticFluxDensity_Squared = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerMagneticFluxDensity_Squared")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    FissionFuelUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionFuelUtilizationFactor")
    MassPerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerAreaTime")
    Dimensionless = URIRef("http://qudt.org/vocab/quantitykind/Dimensionless")
    TotalLinearStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalLinearStoppingPower")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    MassAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAttenuationCoefficient")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    FlashPoint = URIRef("http://qudt.org/vocab/quantitykind/FlashPoint")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    RespiratoryRate = URIRef("http://qudt.org/vocab/quantitykind/RespiratoryRate")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    ActionTime = URIRef("http://qudt.org/vocab/quantitykind/ActionTime")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    PressurePercentage = URIRef("http://qudt.org/vocab/quantitykind/PressurePercentage")
    Half_Life = URIRef("http://qudt.org/vocab/quantitykind/Half-Life")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    ScalarMagneticPotential = URIRef("http://qudt.org/vocab/quantitykind/ScalarMagneticPotential")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    Solubility_Water = URIRef("http://qudt.org/vocab/quantitykind/Solubility_Water")
    Adaptation = URIRef("http://qudt.org/vocab/quantitykind/Adaptation")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    DegreeOfDissociation = URIRef("http://qudt.org/vocab/quantitykind/DegreeOfDissociation")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    IntinsicCarrierDensity = URIRef("http://qudt.org/vocab/quantitykind/IntinsicCarrierDensity")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    TorquePerAngle = URIRef("http://qudt.org/vocab/quantitykind/TorquePerAngle")
    WaterVaporDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/WaterVaporDiffusionCoefficient")
    LinearStiffness = URIRef("http://qudt.org/vocab/quantitykind/LinearStiffness")
    PowerPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/PowerPerElectricCharge")
    ElectricalConductance = URIRef("http://qudt.org/vocab/quantitykind/ElectricalConductance")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    FissionMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionMultiplicationFactor")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    AtomicStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/AtomicStoppingPower")
    ForcePerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ForcePerElectricCharge")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    LinearEnergyTransfer = URIRef("http://qudt.org/vocab/quantitykind/LinearEnergyTransfer")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    SpecificHeatCapacityAtConstantVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantVolume")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    PressureGradient = URIRef("http://qudt.org/vocab/quantitykind/PressureGradient")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    PRODUCT_OF_INERTIA_Y = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA_Y")
    NeutronYieldPerAbsorption = URIRef("http://qudt.org/vocab/quantitykind/NeutronYieldPerAbsorption")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    InversePressure = URIRef("http://qudt.org/vocab/quantitykind/InversePressure")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    GruneisenParameter = URIRef("http://qudt.org/vocab/quantitykind/GruneisenParameter")
    VoltagePhasor = URIRef("http://qudt.org/vocab/quantitykind/VoltagePhasor")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    MassicPower = URIRef("http://qudt.org/vocab/quantitykind/MassicPower")
    NeelTemperature = URIRef("http://qudt.org/vocab/quantitykind/NeelTemperature")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    ThermalConductance = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductance")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    CharacteristicNumber = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicNumber")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    PhotosyntheticPhotonFlux = URIRef("http://qudt.org/vocab/quantitykind/PhotosyntheticPhotonFlux")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    DoseEquivalentQualityFactor = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalentQualityFactor")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    InverseSquareEnergy = URIRef("http://qudt.org/vocab/quantitykind/InverseSquareEnergy")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    ExchangeIntegral = URIRef("http://qudt.org/vocab/quantitykind/ExchangeIntegral")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    InverseMass_Squared = URIRef("http://qudt.org/vocab/quantitykind/InverseMass_Squared")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    SpecificHeatCapacityAtConstantPressure = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantPressure")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    MolarRefractivity = URIRef("http://qudt.org/vocab/quantitykind/MolarRefractivity")
    AngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/AngularCrossSection")
    AcceptorDensity = URIRef("http://qudt.org/vocab/quantitykind/AcceptorDensity")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    PlanckFunction = URIRef("http://qudt.org/vocab/quantitykind/PlanckFunction")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    ParticleNumberDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleNumberDensity")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    Luminance = URIRef("http://qudt.org/vocab/quantitykind/Luminance")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    AngularDistance = URIRef("http://qudt.org/vocab/quantitykind/AngularDistance")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    SoundParticleAcceleration = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleAcceleration")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    TotalPressure = URIRef("http://qudt.org/vocab/quantitykind/TotalPressure")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    Permittivity = URIRef("http://qudt.org/vocab/quantitykind/Permittivity")
    LinearForce = URIRef("http://qudt.org/vocab/quantitykind/LinearForce")
    Period = URIRef("http://qudt.org/vocab/quantitykind/Period")
    Reflectance = URIRef("http://qudt.org/vocab/quantitykind/Reflectance")
    Half_Life = URIRef("http://qudt.org/vocab/quantitykind/Half-Life")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    SoundPressure = URIRef("http://qudt.org/vocab/quantitykind/SoundPressure")
    PhotosyntheticPhotonFlux = URIRef("http://qudt.org/vocab/quantitykind/PhotosyntheticPhotonFlux")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    LogarithmicFrequencyIntervalToBase10 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyIntervalToBase10")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    OrderOfReflection = URIRef("http://qudt.org/vocab/quantitykind/OrderOfReflection")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    ParticleFluence = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluence")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    CostPerUnitEnergy = URIRef("http://qudt.org/vocab/quantitykind/CostPerUnitEnergy")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    LinearAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAttenuationCoefficient")
    HeatFlowRatePerUnitArea = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRatePerUnitArea")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    AverageLogarithmicEnergyDecrement = URIRef("http://qudt.org/vocab/quantitykind/AverageLogarithmicEnergyDecrement")
    MorbidityRate = URIRef("http://qudt.org/vocab/quantitykind/MorbidityRate")
    RichardsonConstant = URIRef("http://qudt.org/vocab/quantitykind/RichardsonConstant")
    LengthPerUnitElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/LengthPerUnitElectricCurrent")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    ElectricQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricQuadrupoleMoment")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    SpectralAngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralAngularCrossSection")
    InverseLength = URIRef("http://qudt.org/vocab/quantitykind/InverseLength")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    CombustionChamberTemperature = URIRef("http://qudt.org/vocab/quantitykind/CombustionChamberTemperature")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    TemperaturePerTime = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    PropellantBurnRate = URIRef("http://qudt.org/vocab/quantitykind/PropellantBurnRate")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    LinearMomentum = URIRef("http://qudt.org/vocab/quantitykind/LinearMomentum")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    EnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensity")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    Lethargy = URIRef("http://qudt.org/vocab/quantitykind/Lethargy")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    EquilibriumConstantOnPressureBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnPressureBasis")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    Voltage = URIRef("http://qudt.org/vocab/quantitykind/Voltage")
    RankineTemperature = URIRef("http://qudt.org/vocab/quantitykind/RankineTemperature")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    ElectricCurrentPhasor = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPhasor")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    FlashPoint = URIRef("http://qudt.org/vocab/quantitykind/FlashPoint")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    ThermodynamicEntropy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEntropy")
    RotationalMass = URIRef("http://qudt.org/vocab/quantitykind/RotationalMass")
    TrafficIntensity = URIRef("http://qudt.org/vocab/quantitykind/TrafficIntensity")
    TemperatureBasedMassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedMassFlowRate")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    SpectralLuminousEfficiency = URIRef("http://qudt.org/vocab/quantitykind/SpectralLuminousEfficiency")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    AmountOfSubstancePerUnitVolume = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitVolume")
    OrderOfReflection = URIRef("http://qudt.org/vocab/quantitykind/OrderOfReflection")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    RelativeLuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/RelativeLuminousFlux")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    Conductance = URIRef("http://qudt.org/vocab/quantitykind/Conductance")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    NumberDensity = URIRef("http://qudt.org/vocab/quantitykind/NumberDensity")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    NonActivePower = URIRef("http://qudt.org/vocab/quantitykind/NonActivePower")
    SerumOrPlasmaLevel = URIRef("http://qudt.org/vocab/quantitykind/SerumOrPlasmaLevel")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    AngularDistance = URIRef("http://qudt.org/vocab/quantitykind/AngularDistance")
    Rotary_TranslatoryMotionConversion = URIRef("http://qudt.org/vocab/quantitykind/Rotary-TranslatoryMotionConversion")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    TemporalSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/TemporalSummationFunction")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    AreaPerLength = URIRef("http://qudt.org/vocab/quantitykind/AreaPerLength")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    ForcePerAngle = URIRef("http://qudt.org/vocab/quantitykind/ForcePerAngle")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    SpecificHeatsRatio = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatsRatio")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    TimeRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRatio")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    FishBiotransformationHalfLife = URIRef("http://qudt.org/vocab/quantitykind/FishBiotransformationHalfLife")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    ForcePerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ForcePerElectricCharge")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    ForcePerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/ForcePerAreaTime")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    ThermalConductance = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductance")
    LiquidVolume = URIRef("http://qudt.org/vocab/quantitykind/LiquidVolume")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    SoundEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SoundEnergyDensity")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    MutualInductance = URIRef("http://qudt.org/vocab/quantitykind/MutualInductance")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    SpecificHeatVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatVolume")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    EnergyPerAreaElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerAreaElectricCharge")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    Constringence = URIRef("http://qudt.org/vocab/quantitykind/Constringence")
    NuclearQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/NuclearQuadrupoleMoment")
    MassPerLength = URIRef("http://qudt.org/vocab/quantitykind/MassPerLength")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    PressureBasedDynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedDynamicViscosity")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    MagneticTension = URIRef("http://qudt.org/vocab/quantitykind/MagneticTension")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    SoundExposureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundExposureLevel")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    OrbitalAngularMomentumPerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/OrbitalAngularMomentumPerUnitMass")
    AreaMass = URIRef("http://qudt.org/vocab/quantitykind/AreaMass")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    SurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceDensity")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    StandardChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/StandardChemicalPotential")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    DiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficient")
    VolumicDataQuantity = URIRef("http://qudt.org/vocab/quantitykind/VolumicDataQuantity")
    BandwidthDistanceProduct = URIRef("http://qudt.org/vocab/quantitykind/BandwidthDistanceProduct")
    Long_RangeOrderParameter = URIRef("http://qudt.org/vocab/quantitykind/Long-RangeOrderParameter")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    MagneticTension = URIRef("http://qudt.org/vocab/quantitykind/MagneticTension")
    MassConcentrationOfWater = URIRef("http://qudt.org/vocab/quantitykind/MassConcentrationOfWater")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    Circulation = URIRef("http://qudt.org/vocab/quantitykind/Circulation")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    InverseVolume = URIRef("http://qudt.org/vocab/quantitykind/InverseVolume")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    Conductance = URIRef("http://qudt.org/vocab/quantitykind/Conductance")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    ThermodynamicCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicCriticalMagneticFluxDensity")
    MechanicalTension = URIRef("http://qudt.org/vocab/quantitykind/MechanicalTension")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    VoltageRatio = URIRef("http://qudt.org/vocab/quantitykind/VoltageRatio")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    LogarithmicMedianInformationFlow_SourceToBase10 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicMedianInformationFlow_SourceToBase10")
    UpperCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/UpperCriticalMagneticFluxDensity")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    InverseEnergy = URIRef("http://qudt.org/vocab/quantitykind/InverseEnergy")
    LengthPercentage = URIRef("http://qudt.org/vocab/quantitykind/LengthPercentage")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    ModulusOfLinearSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfLinearSubgradeReaction")
    VolumeFlowRate_SurfaceRelated = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate_SurfaceRelated")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    EffectiveMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMultiplicationFactor")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    SpecificOpticalRotationalAbility = URIRef("http://qudt.org/vocab/quantitykind/SpecificOpticalRotationalAbility")
    DebyeAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularFrequency")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    SpecificInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificInternalEnergy")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    MASS_PROPERTY_UNCERTAINTY = URIRef("http://qudt.org/vocab/quantitykind/MASS-PROPERTY-UNCERTAINTY")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    PoissonRatio = URIRef("http://qudt.org/vocab/quantitykind/PoissonRatio")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    CombustionChamberTemperature = URIRef("http://qudt.org/vocab/quantitykind/CombustionChamberTemperature")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    ModulusOfImpedance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfImpedance")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    PartialPressure = URIRef("http://qudt.org/vocab/quantitykind/PartialPressure")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    SignalStrength = URIRef("http://qudt.org/vocab/quantitykind/SignalStrength")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    LogOctanolAirPartitionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LogOctanolAirPartitionCoefficient")
    Mobility = URIRef("http://qudt.org/vocab/quantitykind/Mobility")
    SourceVoltage = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltage")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    AngleOfAttack = URIRef("http://qudt.org/vocab/quantitykind/AngleOfAttack")
    PressureBasedMassFlow = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedMassFlow")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    ExposureRate = URIRef("http://qudt.org/vocab/quantitykind/ExposureRate")
    MassFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MassFluxDensity")
    VoltagePhasor = URIRef("http://qudt.org/vocab/quantitykind/VoltagePhasor")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    VoltagePercentage = URIRef("http://qudt.org/vocab/quantitykind/VoltagePercentage")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    StandardAbsoluteActivity = URIRef("http://qudt.org/vocab/quantitykind/StandardAbsoluteActivity")
    AccelerationOfGravity = URIRef("http://qudt.org/vocab/quantitykind/AccelerationOfGravity")
    ModulusOfImpedance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfImpedance")
    ElectricChargePerArea = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerArea")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    SectionModulus = URIRef("http://qudt.org/vocab/quantitykind/SectionModulus")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    AmountOfSubstancePerUnitVolume = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitVolume")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    MassConcentrationOfWater = URIRef("http://qudt.org/vocab/quantitykind/MassConcentrationOfWater")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    LiftCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LiftCoefficient")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    StandardAbsoluteActivity = URIRef("http://qudt.org/vocab/quantitykind/StandardAbsoluteActivity")
    MolarThermalCapacity = URIRef("http://qudt.org/vocab/quantitykind/MolarThermalCapacity")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    Turbidity = URIRef("http://qudt.org/vocab/quantitykind/Turbidity")
    ElectricChargeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeDensity")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    DynamicFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DynamicFrictionCoefficient")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    RadiantIntensity = URIRef("http://qudt.org/vocab/quantitykind/RadiantIntensity")
    Prevalence = URIRef("http://qudt.org/vocab/quantitykind/Prevalence")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    HamiltonFunction = URIRef("http://qudt.org/vocab/quantitykind/HamiltonFunction")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    SpecificImpulse = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulse")
    LandeGFactor = URIRef("http://qudt.org/vocab/quantitykind/LandeGFactor")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    LossFactor = URIRef("http://qudt.org/vocab/quantitykind/LossFactor")
    PressureBasedDynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedDynamicViscosity")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    PressureInRelationToVolumeFlow = URIRef("http://qudt.org/vocab/quantitykind/PressureInRelationToVolumeFlow")
    WarpingMoment = URIRef("http://qudt.org/vocab/quantitykind/WarpingMoment")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    KineticOrThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticOrThermalEnergy")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    FundamentalReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalReciprocalLatticeVector")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    ThomsonCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThomsonCoefficient")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    MassicActivity = URIRef("http://qudt.org/vocab/quantitykind/MassicActivity")
    RelativeMassRatioOfVapour = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassRatioOfVapour")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    DimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/DimensionlessRatio")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    SpecificModulus = URIRef("http://qudt.org/vocab/quantitykind/SpecificModulus")
    NormalizedDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/NormalizedDimensionlessRatio")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    CostPerArea = URIRef("http://qudt.org/vocab/quantitykind/CostPerArea")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    TimePercentage = URIRef("http://qudt.org/vocab/quantitykind/TimePercentage")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    DewPointTemperature = URIRef("http://qudt.org/vocab/quantitykind/DewPointTemperature")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    ThermalResistivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistivity")
    AngleOfAttack = URIRef("http://qudt.org/vocab/quantitykind/AngleOfAttack")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    SpecificVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificVolume")
    SecondAxialMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondAxialMomentOfArea")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    MolarEntropy = URIRef("http://qudt.org/vocab/quantitykind/MolarEntropy")
    MassPerLength = URIRef("http://qudt.org/vocab/quantitykind/MassPerLength")
    DebyeAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularFrequency")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    ElectromagneticWavePhaseSpeed = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticWavePhaseSpeed")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    ThermalInsulation = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulation")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    BitDataVolume = URIRef("http://qudt.org/vocab/quantitykind/BitDataVolume")
    MeltingPoint = URIRef("http://qudt.org/vocab/quantitykind/MeltingPoint")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    RelativeLuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/RelativeLuminousFlux")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    SoilAdsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SoilAdsorptionCoefficient")
    ConvectiveHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/ConvectiveHeatTransfer")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    AcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/AcousticImpedance")
    Non_LeakageProbability = URIRef("http://qudt.org/vocab/quantitykind/Non-LeakageProbability")
    IsothermalMoistureCapacity = URIRef("http://qudt.org/vocab/quantitykind/IsothermalMoistureCapacity")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    DebyeAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularFrequency")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    Population = URIRef("http://qudt.org/vocab/quantitykind/Population")
    Reflectance = URIRef("http://qudt.org/vocab/quantitykind/Reflectance")
    Coercivity = URIRef("http://qudt.org/vocab/quantitykind/Coercivity")
    ThermalUtilizationFactorForFission = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactorForFission")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    Circulation = URIRef("http://qudt.org/vocab/quantitykind/Circulation")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    ElectricConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectricConductivity")
    PoyntingVector = URIRef("http://qudt.org/vocab/quantitykind/PoyntingVector")
    KinematicViscosityOrDiffusionConstantOrThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosityOrDiffusionConstantOrThermalDiffusivity")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    IonicStrength = URIRef("http://qudt.org/vocab/quantitykind/IonicStrength")
    LengthTemperature = URIRef("http://qudt.org/vocab/quantitykind/LengthTemperature")
    MassConcentrationOfWater = URIRef("http://qudt.org/vocab/quantitykind/MassConcentrationOfWater")
    ThermalUtilizationFactorForFission = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactorForFission")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    PressureBurningRateConstant = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateConstant")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    Kerma = URIRef("http://qudt.org/vocab/quantitykind/Kerma")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    CharacteristicNumber = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicNumber")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    PictureElement = URIRef("http://qudt.org/vocab/quantitykind/PictureElement")
    Fluidity = URIRef("http://qudt.org/vocab/quantitykind/Fluidity")
    GFactorOfNucleus = URIRef("http://qudt.org/vocab/quantitykind/GFactorOfNucleus")
    TotalAngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentum")
    HeatFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/HeatFluxDensity")
    GruneisenParameter = URIRef("http://qudt.org/vocab/quantitykind/GruneisenParameter")
    MutualInductance = URIRef("http://qudt.org/vocab/quantitykind/MutualInductance")
    TemperatureGradient = URIRef("http://qudt.org/vocab/quantitykind/TemperatureGradient")
    ElectricCurrentPerAngle = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerAngle")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    InfiniteMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/InfiniteMultiplicationFactor")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    EinsteinTransitionProbabilityForSpontaneousOrInducedEmissionAndAbsorption = URIRef("http://qudt.org/vocab/quantitykind/EinsteinTransitionProbabilityForSpontaneousOrInducedEmissionAndAbsorption")
    LinearElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrentDensity")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    HoleDensity = URIRef("http://qudt.org/vocab/quantitykind/HoleDensity")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    VolumicElectromagneticEnergy = URIRef("http://qudt.org/vocab/quantitykind/VolumicElectromagneticEnergy")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    MotorConstant = URIRef("http://qudt.org/vocab/quantitykind/MotorConstant")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    NumberOfParticles = URIRef("http://qudt.org/vocab/quantitykind/NumberOfParticles")
    SecondMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondMomentOfArea")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    FUEL_BIAS = URIRef("http://qudt.org/vocab/quantitykind/FUEL-BIAS")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    Permittivity = URIRef("http://qudt.org/vocab/quantitykind/Permittivity")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    ThermalCoefficientOfLinearExpansion = URIRef("http://qudt.org/vocab/quantitykind/ThermalCoefficientOfLinearExpansion")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    StrainEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/StrainEnergyDensity")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    PlanckFunction = URIRef("http://qudt.org/vocab/quantitykind/PlanckFunction")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    TemperatureBasedMassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedMassFlowRate")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    InverseLength = URIRef("http://qudt.org/vocab/quantitykind/InverseLength")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    Compressibility = URIRef("http://qudt.org/vocab/quantitykind/Compressibility")
    ElectricDipoleMoment_CubicPerEnergy_Squared = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment_CubicPerEnergy_Squared")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    MolarHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MolarHeatCapacity")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    PressureBurningRateConstant = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateConstant")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    MassPerEnergy = URIRef("http://qudt.org/vocab/quantitykind/MassPerEnergy")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    LengthPercentage = URIRef("http://qudt.org/vocab/quantitykind/LengthPercentage")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    FissionMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionMultiplicationFactor")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    DoseEquivalent = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalent")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    AngularDistance = URIRef("http://qudt.org/vocab/quantitykind/AngularDistance")
    AreaBitDensity = URIRef("http://qudt.org/vocab/quantitykind/AreaBitDensity")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    Susceptance = URIRef("http://qudt.org/vocab/quantitykind/Susceptance")
    MagneticDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMoment")
    AbsoluteActivity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteActivity")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    VolumeThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/VolumeThermalExpansion")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    AreaChargeDensity = URIRef("http://qudt.org/vocab/quantitykind/AreaChargeDensity")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    AngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentum")
    ExitPlaneTemperature = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneTemperature")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    LuminousExitance = URIRef("http://qudt.org/vocab/quantitykind/LuminousExitance")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    Polarizability = URIRef("http://qudt.org/vocab/quantitykind/Polarizability")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    MortalityRate = URIRef("http://qudt.org/vocab/quantitykind/MortalityRate")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    MeanMassRange = URIRef("http://qudt.org/vocab/quantitykind/MeanMassRange")
    VolumicAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/VolumicAmountOfSubstance")
    DryVolume = URIRef("http://qudt.org/vocab/quantitykind/DryVolume")
    EnergyPerMassAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerMassAmountOfSubstance")
    ReciprocalPlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalPlaneAngle")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    BloodGlucoseLevel = URIRef("http://qudt.org/vocab/quantitykind/BloodGlucoseLevel")
    MassConcentrationOfWater = URIRef("http://qudt.org/vocab/quantitykind/MassConcentrationOfWater")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    RelativeMassDensity = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDensity")
    ActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/ActivityConcentration")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    LowerCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/LowerCriticalMagneticFluxDensity")
    FermiTemperature = URIRef("http://qudt.org/vocab/quantitykind/FermiTemperature")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    BucklingFactor = URIRef("http://qudt.org/vocab/quantitykind/BucklingFactor")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    DewPointTemperature = URIRef("http://qudt.org/vocab/quantitykind/DewPointTemperature")
    Voltage = URIRef("http://qudt.org/vocab/quantitykind/Voltage")
    EnergyPerArea = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerArea")
    SecondPolarMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondPolarMomentOfArea")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    SoundPowerLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPowerLevel")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    AngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/AngularCrossSection")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    SoundParticleVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleVelocity")
    WaterVapourPermeability = URIRef("http://qudt.org/vocab/quantitykind/WaterVapourPermeability")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    SuperconductionTransitionTemperature = URIRef("http://qudt.org/vocab/quantitykind/SuperconductionTransitionTemperature")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    InverseMass = URIRef("http://qudt.org/vocab/quantitykind/InverseMass")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    PowerPerAreaAngle = URIRef("http://qudt.org/vocab/quantitykind/PowerPerAreaAngle")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    StateDensityAsExpressionOfAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/StateDensityAsExpressionOfAngularFrequency")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    Log10Ratio = URIRef("http://qudt.org/vocab/quantitykind/Log10Ratio")
    EvaporativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/EvaporativeHeatTransfer")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    ElectricConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectricConductivity")
    DynamicPressure = URIRef("http://qudt.org/vocab/quantitykind/DynamicPressure")
    EquilibriumConstantBasedOnPressure = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantBasedOnPressure")
    ElectricQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricQuadrupoleMoment")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    DebyeAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularFrequency")
    PressureBasedElectricVoltage = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedElectricVoltage")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    MassFractionOfWater = URIRef("http://qudt.org/vocab/quantitykind/MassFractionOfWater")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    ThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusivity")
    VoltagePhasor = URIRef("http://qudt.org/vocab/quantitykind/VoltagePhasor")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    ThermalAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalAdmittance")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    AuditoryThresholds = URIRef("http://qudt.org/vocab/quantitykind/AuditoryThresholds")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    Compressibility = URIRef("http://qudt.org/vocab/quantitykind/Compressibility")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    DensityOfStates = URIRef("http://qudt.org/vocab/quantitykind/DensityOfStates")
    CorrelatedColorTemperature = URIRef("http://qudt.org/vocab/quantitykind/CorrelatedColorTemperature")
    IsothermalMoistureCapacity = URIRef("http://qudt.org/vocab/quantitykind/IsothermalMoistureCapacity")
    PressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PressureCoefficient")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    MutualInductance = URIRef("http://qudt.org/vocab/quantitykind/MutualInductance")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    Absorptance = URIRef("http://qudt.org/vocab/quantitykind/Absorptance")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    RotaryShock = URIRef("http://qudt.org/vocab/quantitykind/RotaryShock")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    ComplexPower = URIRef("http://qudt.org/vocab/quantitykind/ComplexPower")
    TemperaturePerTime = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime")
    MassAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/MassAmountOfSubstance")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    LiquidVolume = URIRef("http://qudt.org/vocab/quantitykind/LiquidVolume")
    AngularMomentumPerAngle = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentumPerAngle")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    MassFraction = URIRef("http://qudt.org/vocab/quantitykind/MassFraction")
    InverseTimeTemperature = URIRef("http://qudt.org/vocab/quantitykind/InverseTimeTemperature")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    PropellantMeanBulkTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantMeanBulkTemperature")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    PhotonRadiance = URIRef("http://qudt.org/vocab/quantitykind/PhotonRadiance")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    VoltageRatio = URIRef("http://qudt.org/vocab/quantitykind/VoltageRatio")
    IonCurrent = URIRef("http://qudt.org/vocab/quantitykind/IonCurrent")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    RatioOfSpecificHeatCapacities = URIRef("http://qudt.org/vocab/quantitykind/RatioOfSpecificHeatCapacities")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    AreicDataVolume = URIRef("http://qudt.org/vocab/quantitykind/AreicDataVolume")
    ElectricChargeSurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeSurfaceDensity")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    SecondAxialMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondAxialMomentOfArea")
    SecondStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SecondStageMassRatio")
    FermiTemperature = URIRef("http://qudt.org/vocab/quantitykind/FermiTemperature")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    CatalyticActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivityConcentration")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    RelativeMassExcess = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassExcess")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    PressureBurningRateConstant = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateConstant")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    MassFraction = URIRef("http://qudt.org/vocab/quantitykind/MassFraction")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    Dimensionless = URIRef("http://qudt.org/vocab/quantitykind/Dimensionless")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    MolalityOfSolute = URIRef("http://qudt.org/vocab/quantitykind/MolalityOfSolute")
    EnergyContent = URIRef("http://qudt.org/vocab/quantitykind/EnergyContent")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    Coercivity = URIRef("http://qudt.org/vocab/quantitykind/Coercivity")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    RankineTemperature = URIRef("http://qudt.org/vocab/quantitykind/RankineTemperature")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    FermiTemperature = URIRef("http://qudt.org/vocab/quantitykind/FermiTemperature")
    TemperatureRateOfChange = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRateOfChange")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    VentilationRatePerFloorArea = URIRef("http://qudt.org/vocab/quantitykind/VentilationRatePerFloorArea")
    Absorptance = URIRef("http://qudt.org/vocab/quantitykind/Absorptance")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    Viscosity = URIRef("http://qudt.org/vocab/quantitykind/Viscosity")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    AverageHeadEndPressure = URIRef("http://qudt.org/vocab/quantitykind/AverageHeadEndPressure")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    Reluctance = URIRef("http://qudt.org/vocab/quantitykind/Reluctance")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    PowerConstant = URIRef("http://qudt.org/vocab/quantitykind/PowerConstant")
    MolarFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MolarFlowRate")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    SoundReductionIndex = URIRef("http://qudt.org/vocab/quantitykind/SoundReductionIndex")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    AngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentum")
    Polarizability = URIRef("http://qudt.org/vocab/quantitykind/Polarizability")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    MagneticTension = URIRef("http://qudt.org/vocab/quantitykind/MagneticTension")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    FissionFuelUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionFuelUtilizationFactor")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    BucklingFactor = URIRef("http://qudt.org/vocab/quantitykind/BucklingFactor")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    CombinedNonEvaporativeHeatTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CombinedNonEvaporativeHeatTransferCoefficient")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    PressureBurningRateIndex = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateIndex")
    CurrentLinkage = URIRef("http://qudt.org/vocab/quantitykind/CurrentLinkage")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    SpecificHelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificHelmholtzEnergy")
    HenrysLawVolatilityConstant = URIRef("http://qudt.org/vocab/quantitykind/HenrysLawVolatilityConstant")
    ParticleCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrentDensity")
    SpecificHelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificHelmholtzEnergy")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    LiquidVolume = URIRef("http://qudt.org/vocab/quantitykind/LiquidVolume")
    ElectricDisplacementField = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacementField")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    ThrustToWeightRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToWeightRatio")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    LuminousFluxPerArea = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxPerArea")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    FloatingPointCalculationCapability = URIRef("http://qudt.org/vocab/quantitykind/FloatingPointCalculationCapability")
    IonicStrength = URIRef("http://qudt.org/vocab/quantitykind/IonicStrength")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    AbsoluteActivity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteActivity")
    EvaporativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/EvaporativeHeatTransfer")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    ParticleFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluenceRate")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    DragCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DragCoefficient")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    MechanicalTension = URIRef("http://qudt.org/vocab/quantitykind/MechanicalTension")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    ExitPlaneTemperature = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneTemperature")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    ElectronDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectronDensity")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    ForceConstant = URIRef("http://qudt.org/vocab/quantitykind/ForceConstant")
    ExchangeIntegral = URIRef("http://qudt.org/vocab/quantitykind/ExchangeIntegral")
    ElectricCurrentPerAngle = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerAngle")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    TemperatureRateOfChange = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRateOfChange")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    AccelerationOfGravity = URIRef("http://qudt.org/vocab/quantitykind/AccelerationOfGravity")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    RotationalMass = URIRef("http://qudt.org/vocab/quantitykind/RotationalMass")
    ElectromagneticPermeabilityRatio = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeabilityRatio")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    DegreeOfDissociation = URIRef("http://qudt.org/vocab/quantitykind/DegreeOfDissociation")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    OsmoticPressure = URIRef("http://qudt.org/vocab/quantitykind/OsmoticPressure")
    SymbolTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/SymbolTransmissionRate")
    SpecificEnthalpy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnthalpy")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    PositiveDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/PositiveDimensionlessRatio")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    MassPerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerAreaTime")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    SoundExposure = URIRef("http://qudt.org/vocab/quantitykind/SoundExposure")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    FlightPathAngle = URIRef("http://qudt.org/vocab/quantitykind/FlightPathAngle")
    SecondAxialMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondAxialMomentOfArea")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    PositivePlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PositivePlaneAngle")
    Exposure = URIRef("http://qudt.org/vocab/quantitykind/Exposure")
    AcceptorDensity = URIRef("http://qudt.org/vocab/quantitykind/AcceptorDensity")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    EnergyPerTemperature = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerTemperature")
    PhaseSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/PhaseSpeedOfSound")
    AuxillaryMagneticField = URIRef("http://qudt.org/vocab/quantitykind/AuxillaryMagneticField")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    CostPerArea = URIRef("http://qudt.org/vocab/quantitykind/CostPerArea")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    SpecificOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificOpticalRotatoryPower")
    Emissivity = URIRef("http://qudt.org/vocab/quantitykind/Emissivity")
    PhaseCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PhaseCoefficient")
    AngularDistance = URIRef("http://qudt.org/vocab/quantitykind/AngularDistance")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    LuminousEmittance = URIRef("http://qudt.org/vocab/quantitykind/LuminousEmittance")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    SoilAdsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SoilAdsorptionCoefficient")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    RadiantIntensity = URIRef("http://qudt.org/vocab/quantitykind/RadiantIntensity")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    AttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AttenuationCoefficient")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    AngularDistance = URIRef("http://qudt.org/vocab/quantitykind/AngularDistance")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    PoyntingVector = URIRef("http://qudt.org/vocab/quantitykind/PoyntingVector")
    LengthByForce = URIRef("http://qudt.org/vocab/quantitykind/LengthByForce")
    ThermalDiffusionRatio = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionRatio")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    NeutronDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionCoefficient")
    DebyeTemperature = URIRef("http://qudt.org/vocab/quantitykind/DebyeTemperature")
    SecondAxialMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondAxialMomentOfArea")
    SpecificWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificWeight")
    TouchThresholds = URIRef("http://qudt.org/vocab/quantitykind/TouchThresholds")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    AreaTime = URIRef("http://qudt.org/vocab/quantitykind/AreaTime")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    NozzleThroatPressure = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatPressure")
    WaterVaporDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/WaterVaporDiffusionCoefficient")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    HyperfineStructureQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/HyperfineStructureQuantumNumber")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    EnergyDensityOfStates = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensityOfStates")
    MagneticSusceptability = URIRef("http://qudt.org/vocab/quantitykind/MagneticSusceptability")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    Viscosity = URIRef("http://qudt.org/vocab/quantitykind/Viscosity")
    SpectralLuminousEfficiency = URIRef("http://qudt.org/vocab/quantitykind/SpectralLuminousEfficiency")
    MaximumExpectedOperatingPressure = URIRef("http://qudt.org/vocab/quantitykind/MaximumExpectedOperatingPressure")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    ElectricCurrentPerUnitTemperature = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerUnitTemperature")
    ElectromagneticWavePhaseSpeed = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticWavePhaseSpeed")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    CombinedNonEvaporativeHeatTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CombinedNonEvaporativeHeatTransferCoefficient")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    TimeConstant_Inductance = URIRef("http://qudt.org/vocab/quantitykind/TimeConstant_Inductance")
    LengthEnergy = URIRef("http://qudt.org/vocab/quantitykind/LengthEnergy")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    IonConcentration = URIRef("http://qudt.org/vocab/quantitykind/IonConcentration")
    AbsoluteActivity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteActivity")
    ThermalDiffusionFactor = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionFactor")
    ThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusivity")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    AmountOfSubstancePerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMass")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    CharacteristicAcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicAcousticImpedance")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    Capacitance = URIRef("http://qudt.org/vocab/quantitykind/Capacitance")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    RichardsonConstant = URIRef("http://qudt.org/vocab/quantitykind/RichardsonConstant")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    Reactivity = URIRef("http://qudt.org/vocab/quantitykind/Reactivity")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    ElectricChargeSurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeSurfaceDensity")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    SoundParticleVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleVelocity")
    ParticleSourceDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleSourceDensity")
    PayloadRatio = URIRef("http://qudt.org/vocab/quantitykind/PayloadRatio")
    EarthquakeMagnitude = URIRef("http://qudt.org/vocab/quantitykind/EarthquakeMagnitude")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    TorsionalSpringConstant = URIRef("http://qudt.org/vocab/quantitykind/TorsionalSpringConstant")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    MassRatio = URIRef("http://qudt.org/vocab/quantitykind/MassRatio")
    StrainEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/StrainEnergyDensity")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    AbsorbedDoseRate = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDoseRate")
    PositivePlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PositivePlaneAngle")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    HeatFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/HeatFluxDensity")
    MassFractionOfWater = URIRef("http://qudt.org/vocab/quantitykind/MassFractionOfWater")
    SpecificEnthalpy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnthalpy")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    MolarFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MolarFlowRate")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    ExitPlaneTemperature = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneTemperature")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    TemperatureBasedDensity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedDensity")
    TotalAngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentum")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    Coercivity = URIRef("http://qudt.org/vocab/quantitykind/Coercivity")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    Curvature = URIRef("http://qudt.org/vocab/quantitykind/Curvature")
    CanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/CanonicalPartitionFunction")
    RelativePressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/RelativePressureCoefficient")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    TemperatureBasedKinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedKinematicViscosity")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    SoundPressure = URIRef("http://qudt.org/vocab/quantitykind/SoundPressure")
    RespiratoryRate = URIRef("http://qudt.org/vocab/quantitykind/RespiratoryRate")
    ExpansionRatio = URIRef("http://qudt.org/vocab/quantitykind/ExpansionRatio")
    AcceptorDensity = URIRef("http://qudt.org/vocab/quantitykind/AcceptorDensity")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    PropagationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PropagationCoefficient")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    KineticOrThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticOrThermalEnergy")
    Radiance = URIRef("http://qudt.org/vocab/quantitykind/Radiance")
    SoundParticleVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleVelocity")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    SurfaceRelatedVolumeFlow = URIRef("http://qudt.org/vocab/quantitykind/SurfaceRelatedVolumeFlow")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    EvaporativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/EvaporativeHeatTransfer")
    TransmissionRatioBetweenRotationAndTranslation = URIRef("http://qudt.org/vocab/quantitykind/TransmissionRatioBetweenRotationAndTranslation")
    ThermalCapacitance = URIRef("http://qudt.org/vocab/quantitykind/ThermalCapacitance")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    EffectiveExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/EffectiveExhaustVelocity")
    SecondStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SecondStageMassRatio")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    EnergyPerArea = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerArea")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    TotalLinearStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalLinearStoppingPower")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    CostPerUnitEnergy = URIRef("http://qudt.org/vocab/quantitykind/CostPerUnitEnergy")
    HamiltonFunction = URIRef("http://qudt.org/vocab/quantitykind/HamiltonFunction")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    SoundReductionIndex = URIRef("http://qudt.org/vocab/quantitykind/SoundReductionIndex")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    ByteDataVolume = URIRef("http://qudt.org/vocab/quantitykind/ByteDataVolume")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    MassConcentrationOfWaterVapour = URIRef("http://qudt.org/vocab/quantitykind/MassConcentrationOfWaterVapour")
    DigitRate = URIRef("http://qudt.org/vocab/quantitykind/DigitRate")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    TemperatureBasedMass = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedMass")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    ThermalInsulance = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulance")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    PropellantTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantTemperature")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    ParticleNumberDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleNumberDensity")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    RelativeMassExcess = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassExcess")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    MassConcentrationOfWater = URIRef("http://qudt.org/vocab/quantitykind/MassConcentrationOfWater")
    Action = URIRef("http://qudt.org/vocab/quantitykind/Action")
    PropellantMeanBulkTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantMeanBulkTemperature")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    MechanicalMobility = URIRef("http://qudt.org/vocab/quantitykind/MechanicalMobility")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    GyromagneticRatio = URIRef("http://qudt.org/vocab/quantitykind/GyromagneticRatio")
    MassicElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/MassicElectricCurrent")
    HeadEndPressure = URIRef("http://qudt.org/vocab/quantitykind/HeadEndPressure")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    AmountOfSubstanceFractionOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFractionOfB")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    SpecificWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificWeight")
    IonCurrent = URIRef("http://qudt.org/vocab/quantitykind/IonCurrent")
    LengthTemperature = URIRef("http://qudt.org/vocab/quantitykind/LengthTemperature")
    ThrustToMassRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToMassRatio")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    MolecularConcentration = URIRef("http://qudt.org/vocab/quantitykind/MolecularConcentration")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    TorqueConstant = URIRef("http://qudt.org/vocab/quantitykind/TorqueConstant")
    ParticleFluence = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluence")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    SoundEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SoundEnergyDensity")
    AreicChargeDensityOrElectricFluxDensityOrElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/AreicChargeDensityOrElectricFluxDensityOrElectricPolarization")
    ParticleCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrentDensity")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    OsmoticPressure = URIRef("http://qudt.org/vocab/quantitykind/OsmoticPressure")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    TimePercentage = URIRef("http://qudt.org/vocab/quantitykind/TimePercentage")
    DiastolicBloodPressure = URIRef("http://qudt.org/vocab/quantitykind/DiastolicBloodPressure")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    AmountOfSubstancePerUnitVolume = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitVolume")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    FundamentalReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalReciprocalLatticeVector")
    CyclotronAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/CyclotronAngularFrequency")
    Reactivity = URIRef("http://qudt.org/vocab/quantitykind/Reactivity")
    TotalAngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentum")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    FlightPathAngle = URIRef("http://qudt.org/vocab/quantitykind/FlightPathAngle")
    PhotonIntensity = URIRef("http://qudt.org/vocab/quantitykind/PhotonIntensity")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    RelativePartialPressure = URIRef("http://qudt.org/vocab/quantitykind/RelativePartialPressure")
    TemperaturePerTime = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime")
    ActivityThresholds = URIRef("http://qudt.org/vocab/quantitykind/ActivityThresholds")
    AtomicNumber = URIRef("http://qudt.org/vocab/quantitykind/AtomicNumber")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    DecayConstant = URIRef("http://qudt.org/vocab/quantitykind/DecayConstant")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    GruneisenParameter = URIRef("http://qudt.org/vocab/quantitykind/GruneisenParameter")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    ExposureRateOfIonizingRadiation = URIRef("http://qudt.org/vocab/quantitykind/ExposureRateOfIonizingRadiation")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    MassConcentration = URIRef("http://qudt.org/vocab/quantitykind/MassConcentration")
    Voltage = URIRef("http://qudt.org/vocab/quantitykind/Voltage")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    AngleOfOpticalRotation = URIRef("http://qudt.org/vocab/quantitykind/AngleOfOpticalRotation")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    LinkedFlux = URIRef("http://qudt.org/vocab/quantitykind/LinkedFlux")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    ElectricDisplacement = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacement")
    DisplacementCurrent = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrent")
    PositiveDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/PositiveDimensionlessRatio")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    SpecificOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificOpticalRotatoryPower")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    Compressibility = URIRef("http://qudt.org/vocab/quantitykind/Compressibility")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    InverseSquareMass = URIRef("http://qudt.org/vocab/quantitykind/InverseSquareMass")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    LorenzCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LorenzCoefficient")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    TotalMassStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalMassStoppingPower")
    VentilationRatePerFloorArea = URIRef("http://qudt.org/vocab/quantitykind/VentilationRatePerFloorArea")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    TemperatureRelatedMolarMass = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRelatedMolarMass")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    AmountOfSubstanceFractionOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFractionOfB")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    TemperaturePerMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerMagneticFluxDensity")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    Speed = URIRef("http://qudt.org/vocab/quantitykind/Speed")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    Lethargy = URIRef("http://qudt.org/vocab/quantitykind/Lethargy")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    ForcePerLength = URIRef("http://qudt.org/vocab/quantitykind/ForcePerLength")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    Resistivity = URIRef("http://qudt.org/vocab/quantitykind/Resistivity")
    SecondMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondMomentOfArea")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    TemperatureBasedVolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedVolumeFlowRate")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    CharacteristicAcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicAcousticImpedance")
    ThermalDiffusionFactor = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionFactor")
    AmountOfSubstanceFraction = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFraction")
    LoudnessLevel = URIRef("http://qudt.org/vocab/quantitykind/LoudnessLevel")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    Dimensionless = URIRef("http://qudt.org/vocab/quantitykind/Dimensionless")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    RelativePartialPressure = URIRef("http://qudt.org/vocab/quantitykind/RelativePartialPressure")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    MOMENT_OF_INERTIA_Z = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Z")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    MechanicalImpedance = URIRef("http://qudt.org/vocab/quantitykind/MechanicalImpedance")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    GeneralizedCoordinate = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedCoordinate")
    DatasetOfBits = URIRef("http://qudt.org/vocab/quantitykind/DatasetOfBits")
    Landau_GinzburgNumber = URIRef("http://qudt.org/vocab/quantitykind/Landau-GinzburgNumber")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    GeneFamilyAbundance = URIRef("http://qudt.org/vocab/quantitykind/GeneFamilyAbundance")
    ExhaustGasMeanMolecularWeight = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasMeanMolecularWeight")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    ThrustCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThrustCoefficient")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    MassNumber = URIRef("http://qudt.org/vocab/quantitykind/MassNumber")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    PrincipalQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/PrincipalQuantumNumber")
    LinearDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearDensity")
    TotalCurrent = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrent")
    StressOpticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StressOpticCoefficient")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    LengthRatio = URIRef("http://qudt.org/vocab/quantitykind/LengthRatio")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    IncidenceProportion = URIRef("http://qudt.org/vocab/quantitykind/IncidenceProportion")
    ElectromagneticPermeability = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeability")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    IonCurrent = URIRef("http://qudt.org/vocab/quantitykind/IonCurrent")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    ParticleFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluenceRate")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    PRODUCT_OF_INERTIA_Z = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA_Z")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    DimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/DimensionlessRatio")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    MassicTorque = URIRef("http://qudt.org/vocab/quantitykind/MassicTorque")
    SpecificVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificVolume")
    CurrentOfTheAmountOfSubtance = URIRef("http://qudt.org/vocab/quantitykind/CurrentOfTheAmountOfSubtance")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    ColdReceptorThreshold = URIRef("http://qudt.org/vocab/quantitykind/ColdReceptorThreshold")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    ElectronDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectronDensity")
    Incidence = URIRef("http://qudt.org/vocab/quantitykind/Incidence")
    MobilityRatio = URIRef("http://qudt.org/vocab/quantitykind/MobilityRatio")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    ConvectiveHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/ConvectiveHeatTransfer")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    EnergyDensityOfStates = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensityOfStates")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    MassicElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/MassicElectricCurrent")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    MassConcentrationOfWaterVapour = URIRef("http://qudt.org/vocab/quantitykind/MassConcentrationOfWaterVapour")
    ModulusOfRotationalSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfRotationalSubgradeReaction")
    MassRelatedElectricalCurrent = URIRef("http://qudt.org/vocab/quantitykind/MassRelatedElectricalCurrent")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    LinearMass = URIRef("http://qudt.org/vocab/quantitykind/LinearMass")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    SpecificElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/SpecificElectricCharge")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    AuxillaryMagneticField = URIRef("http://qudt.org/vocab/quantitykind/AuxillaryMagneticField")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    BitDataVolume = URIRef("http://qudt.org/vocab/quantitykind/BitDataVolume")
    MortalityRate = URIRef("http://qudt.org/vocab/quantitykind/MortalityRate")
    PhotosyntheticPhotonFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/PhotosyntheticPhotonFluxDensity")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    DisplacementCurrent = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrent")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    Permittivity = URIRef("http://qudt.org/vocab/quantitykind/Permittivity")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    DryVolume = URIRef("http://qudt.org/vocab/quantitykind/DryVolume")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    SecondRadiationConstant = URIRef("http://qudt.org/vocab/quantitykind/SecondRadiationConstant")
    AreaTimeTemperature = URIRef("http://qudt.org/vocab/quantitykind/AreaTimeTemperature")
    SymbolTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/SymbolTransmissionRate")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    PolarMomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/PolarMomentOfInertia")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    Permittivity = URIRef("http://qudt.org/vocab/quantitykind/Permittivity")
    TorqueConstant = URIRef("http://qudt.org/vocab/quantitykind/TorqueConstant")
    KinematicViscosityOrDiffusionConstantOrThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosityOrDiffusionConstantOrThermalDiffusivity")
    GruneisenParameter = URIRef("http://qudt.org/vocab/quantitykind/GruneisenParameter")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    TotalCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrentDensity")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    MolecularViscosity = URIRef("http://qudt.org/vocab/quantitykind/MolecularViscosity")
    AcceptorDensity = URIRef("http://qudt.org/vocab/quantitykind/AcceptorDensity")
    Slowing_DownDensity = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownDensity")
    SpecificPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificPower")
    MassRatioOfWaterVapourToDryGas = URIRef("http://qudt.org/vocab/quantitykind/MassRatioOfWaterVapourToDryGas")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    Polarizability = URIRef("http://qudt.org/vocab/quantitykind/Polarizability")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    ElectricChargePerArea = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerArea")
    FloatingPointCalculationCapability = URIRef("http://qudt.org/vocab/quantitykind/FloatingPointCalculationCapability")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    StoichiometricNumber = URIRef("http://qudt.org/vocab/quantitykind/StoichiometricNumber")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    MeltingPoint = URIRef("http://qudt.org/vocab/quantitykind/MeltingPoint")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    AcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/AcousticImpedance")
    Resistivity = URIRef("http://qudt.org/vocab/quantitykind/Resistivity")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    ActivityCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ActivityCoefficient")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    TransmissionRatioBetweenRotationAndTranslation = URIRef("http://qudt.org/vocab/quantitykind/TransmissionRatioBetweenRotationAndTranslation")
    PoyntingVector = URIRef("http://qudt.org/vocab/quantitykind/PoyntingVector")
    ResonanceEscapeProbabilityForFission = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbabilityForFission")
    LinearAcceleration = URIRef("http://qudt.org/vocab/quantitykind/LinearAcceleration")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    Exposure = URIRef("http://qudt.org/vocab/quantitykind/Exposure")
    ElectricDisplacementField = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacementField")
    PositivePlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PositivePlaneAngle")
    ExitPlanePressure = URIRef("http://qudt.org/vocab/quantitykind/ExitPlanePressure")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    TemperaturePerTime = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    PRODUCT_OF_INERTIA_X = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA_X")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    DimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/DimensionlessRatio")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    HyperfineStructureQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/HyperfineStructureQuantumNumber")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    CharacteristicNumber = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicNumber")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    NeutronYieldPerAbsorption = URIRef("http://qudt.org/vocab/quantitykind/NeutronYieldPerAbsorption")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    Impedance = URIRef("http://qudt.org/vocab/quantitykind/Impedance")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    BloodGlucoseLevel_Mass = URIRef("http://qudt.org/vocab/quantitykind/BloodGlucoseLevel_Mass")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    FermiTemperature = URIRef("http://qudt.org/vocab/quantitykind/FermiTemperature")
    PoyntingVector = URIRef("http://qudt.org/vocab/quantitykind/PoyntingVector")
    MassicPower = URIRef("http://qudt.org/vocab/quantitykind/MassicPower")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    LuminousEfficacy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEfficacy")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    AbsorbedDose = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDose")
    ElectricalPowerToMassRatio = URIRef("http://qudt.org/vocab/quantitykind/ElectricalPowerToMassRatio")
    MolalityOfSolute = URIRef("http://qudt.org/vocab/quantitykind/MolalityOfSolute")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    ExposureRateOfIonizingRadiation = URIRef("http://qudt.org/vocab/quantitykind/ExposureRateOfIonizingRadiation")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    GeneralizedMomentum = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedMomentum")
    MagneticQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/MagneticQuantumNumber")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    PositivePlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PositivePlaneAngle")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    ForcePerLength = URIRef("http://qudt.org/vocab/quantitykind/ForcePerLength")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    SoundExposure = URIRef("http://qudt.org/vocab/quantitykind/SoundExposure")
    ThrusterPowerToThrustEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThrusterPowerToThrustEfficiency")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    GustatoryThreshold = URIRef("http://qudt.org/vocab/quantitykind/GustatoryThreshold")
    PressurePercentage = URIRef("http://qudt.org/vocab/quantitykind/PressurePercentage")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    InverseTemperature = URIRef("http://qudt.org/vocab/quantitykind/InverseTemperature")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    PartialPressure = URIRef("http://qudt.org/vocab/quantitykind/PartialPressure")
    ElectromagneticEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticEnergyDensity")
    Time_Squared = URIRef("http://qudt.org/vocab/quantitykind/Time_Squared")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    Duv = URIRef("http://qudt.org/vocab/quantitykind/Duv")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    RecombinationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/RecombinationCoefficient")
    MassieuFunction = URIRef("http://qudt.org/vocab/quantitykind/MassieuFunction")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    PeltierCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PeltierCoefficient")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    ParticleFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluenceRate")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    ComplexFrequency_Real = URIRef("http://qudt.org/vocab/quantitykind/ComplexFrequency_Real")
    PressureBasedElectricVoltage = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedElectricVoltage")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    ComplexFrequency_Real = URIRef("http://qudt.org/vocab/quantitykind/ComplexFrequency_Real")
    LogarithmicFrequencyIntervalToBase10 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyIntervalToBase10")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    InverseAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/InverseAmountOfSubstance")
    MOMENT_OF_INERTIA_Y = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Y")
    DoseEquivalent = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalent")
    ElectricChargeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeDensity")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    NeutralRatio = URIRef("http://qudt.org/vocab/quantitykind/NeutralRatio")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    SoundExposure = URIRef("http://qudt.org/vocab/quantitykind/SoundExposure")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    ElectromagneticEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticEnergyDensity")
    SpecificHeatVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatVolume")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    TemperatureBasedLength = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedLength")
    AbsorbedDose = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDose")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    VoltagePercentage = URIRef("http://qudt.org/vocab/quantitykind/VoltagePercentage")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    SpecificEnthalpy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnthalpy")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    MassPerTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerTime")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    DebyeTemperature = URIRef("http://qudt.org/vocab/quantitykind/DebyeTemperature")
    UpperCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/UpperCriticalMagneticFluxDensity")
    LinearPower = URIRef("http://qudt.org/vocab/quantitykind/LinearPower")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    AngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentum")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    PressureBurningRateIndex = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateIndex")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    ResidualResistivity = URIRef("http://qudt.org/vocab/quantitykind/ResidualResistivity")
    MutualInductance = URIRef("http://qudt.org/vocab/quantitykind/MutualInductance")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    SecondMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondMomentOfArea")
    DebyeAngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularWavenumber")
    ThermalInsulance = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulance")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    CanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/CanonicalPartitionFunction")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    Mobility = URIRef("http://qudt.org/vocab/quantitykind/Mobility")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    SoundPressure = URIRef("http://qudt.org/vocab/quantitykind/SoundPressure")
    LinearPower = URIRef("http://qudt.org/vocab/quantitykind/LinearPower")
    ExhaustGasesSpecificHeat = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasesSpecificHeat")
    RelativeMassConcentrationOfVapour = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassConcentrationOfVapour")
    LossFactor = URIRef("http://qudt.org/vocab/quantitykind/LossFactor")
    ByteDataVolume = URIRef("http://qudt.org/vocab/quantitykind/ByteDataVolume")
    SpecificEntropy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEntropy")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    ColdReceptorThreshold = URIRef("http://qudt.org/vocab/quantitykind/ColdReceptorThreshold")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    GFactorOfNucleus = URIRef("http://qudt.org/vocab/quantitykind/GFactorOfNucleus")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    LowerCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/LowerCriticalMagneticFluxDensity")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    GroupSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/GroupSpeedOfSound")
    MolarThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarThermodynamicEnergy")
    RatioOfSpecificHeatCapacities = URIRef("http://qudt.org/vocab/quantitykind/RatioOfSpecificHeatCapacities")
    VolumetricFlux = URIRef("http://qudt.org/vocab/quantitykind/VolumetricFlux")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    MassNumber = URIRef("http://qudt.org/vocab/quantitykind/MassNumber")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    IonDensity = URIRef("http://qudt.org/vocab/quantitykind/IonDensity")
    NonActivePower = URIRef("http://qudt.org/vocab/quantitykind/NonActivePower")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    MassPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/MassPerElectricCharge")
    SpecificHeatCapacityAtConstantVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantVolume")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    NonActivePower = URIRef("http://qudt.org/vocab/quantitykind/NonActivePower")
    WaterVaporDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/WaterVaporDiffusionCoefficient")
    ActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/ActivityConcentration")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    LinearIonization = URIRef("http://qudt.org/vocab/quantitykind/LinearIonization")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    MassTemperature = URIRef("http://qudt.org/vocab/quantitykind/MassTemperature")
    LinearMomentum = URIRef("http://qudt.org/vocab/quantitykind/LinearMomentum")
    ComplexPower = URIRef("http://qudt.org/vocab/quantitykind/ComplexPower")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    MASS_PROPERTY_UNCERTAINTY = URIRef("http://qudt.org/vocab/quantitykind/MASS-PROPERTY-UNCERTAINTY")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    Radiance = URIRef("http://qudt.org/vocab/quantitykind/Radiance")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    DensityOfStates = URIRef("http://qudt.org/vocab/quantitykind/DensityOfStates")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    AngleOfAttack = URIRef("http://qudt.org/vocab/quantitykind/AngleOfAttack")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    EquivalenceDoseOutput = URIRef("http://qudt.org/vocab/quantitykind/EquivalenceDoseOutput")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    TemperatureRateOfChange = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRateOfChange")
    Exposure = URIRef("http://qudt.org/vocab/quantitykind/Exposure")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    Long_RangeOrderParameter = URIRef("http://qudt.org/vocab/quantitykind/Long-RangeOrderParameter")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    IncidenceRate = URIRef("http://qudt.org/vocab/quantitykind/IncidenceRate")
    PressureBurningRateConstant = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateConstant")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    LuminousEnergy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEnergy")
    RichardsonConstant = URIRef("http://qudt.org/vocab/quantitykind/RichardsonConstant")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    StateDensity = URIRef("http://qudt.org/vocab/quantitykind/StateDensity")
    FissionMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionMultiplicationFactor")
    IonCurrent = URIRef("http://qudt.org/vocab/quantitykind/IonCurrent")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    GrandCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/GrandCanonicalPartitionFunction")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    SystolicBloodPressure = URIRef("http://qudt.org/vocab/quantitykind/SystolicBloodPressure")
    AngleOfAttack = URIRef("http://qudt.org/vocab/quantitykind/AngleOfAttack")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    GeneralizedMomentum = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedMomentum")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    NormalizedDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/NormalizedDimensionlessRatio")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    PressureBasedDynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedDynamicViscosity")
    Count = URIRef("http://qudt.org/vocab/quantitykind/Count")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    Impulse = URIRef("http://qudt.org/vocab/quantitykind/Impulse")
    AuditoryThresholds = URIRef("http://qudt.org/vocab/quantitykind/AuditoryThresholds")
    PhotonRadiance = URIRef("http://qudt.org/vocab/quantitykind/PhotonRadiance")
    HeadEndPressure = URIRef("http://qudt.org/vocab/quantitykind/HeadEndPressure")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    WarpingMoment = URIRef("http://qudt.org/vocab/quantitykind/WarpingMoment")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    SpectralCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralCrossSection")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    Luminance = URIRef("http://qudt.org/vocab/quantitykind/Luminance")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    InformationContent = URIRef("http://qudt.org/vocab/quantitykind/InformationContent")
    MassFraction = URIRef("http://qudt.org/vocab/quantitykind/MassFraction")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    BodyMassIndex = URIRef("http://qudt.org/vocab/quantitykind/BodyMassIndex")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    TotalAtomicStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalAtomicStoppingPower")
    PressureRatio = URIRef("http://qudt.org/vocab/quantitykind/PressureRatio")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    AngleOfAttack = URIRef("http://qudt.org/vocab/quantitykind/AngleOfAttack")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    RelativeMassDensity = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDensity")
    ElectricChargePerArea = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerArea")
    LowerCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/LowerCriticalMagneticFluxDensity")
    ElectromagneticPermeability = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeability")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    SpecificEnthalpy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnthalpy")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    ThermalAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalAdmittance")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    AtmosphericHydroxylationRate = URIRef("http://qudt.org/vocab/quantitykind/AtmosphericHydroxylationRate")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    Reactance = URIRef("http://qudt.org/vocab/quantitykind/Reactance")
    AreicChargeDensityOrElectricFluxDensityOrElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/AreicChargeDensityOrElectricFluxDensityOrElectricPolarization")
    SoundPressure = URIRef("http://qudt.org/vocab/quantitykind/SoundPressure")
    PositiveDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/PositiveDimensionlessRatio")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    MASS_PROPERTY_UNCERTAINTY = URIRef("http://qudt.org/vocab/quantitykind/MASS-PROPERTY-UNCERTAINTY")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    Absorptance = URIRef("http://qudt.org/vocab/quantitykind/Absorptance")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    LinearMomentum = URIRef("http://qudt.org/vocab/quantitykind/LinearMomentum")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    ExtentOfReaction = URIRef("http://qudt.org/vocab/quantitykind/ExtentOfReaction")
    RotationalStiffness = URIRef("http://qudt.org/vocab/quantitykind/RotationalStiffness")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    LengthTemperatureTime = URIRef("http://qudt.org/vocab/quantitykind/LengthTemperatureTime")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    ElectricChargeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeDensity")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    SecondMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondMomentOfArea")
    MolarConductivity = URIRef("http://qudt.org/vocab/quantitykind/MolarConductivity")
    LogarithmRatioToBase10 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmRatioToBase10")
    Mobility = URIRef("http://qudt.org/vocab/quantitykind/Mobility")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    MechanicalImpedance = URIRef("http://qudt.org/vocab/quantitykind/MechanicalImpedance")
    ScalarMagneticPotential = URIRef("http://qudt.org/vocab/quantitykind/ScalarMagneticPotential")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    AtomScatteringFactor = URIRef("http://qudt.org/vocab/quantitykind/AtomScatteringFactor")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    PoyntingVector = URIRef("http://qudt.org/vocab/quantitykind/PoyntingVector")
    Loudness = URIRef("http://qudt.org/vocab/quantitykind/Loudness")
    AreaPerTime = URIRef("http://qudt.org/vocab/quantitykind/AreaPerTime")
    HeadEndPressure = URIRef("http://qudt.org/vocab/quantitykind/HeadEndPressure")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    FirstStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/FirstStageMassRatio")
    Non_LeakageProbability = URIRef("http://qudt.org/vocab/quantitykind/Non-LeakageProbability")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    HoleDensity = URIRef("http://qudt.org/vocab/quantitykind/HoleDensity")
    Radioactivity = URIRef("http://qudt.org/vocab/quantitykind/Radioactivity")
    RotationalStiffness = URIRef("http://qudt.org/vocab/quantitykind/RotationalStiffness")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    SpecificHeatCapacityAtSaturation = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtSaturation")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    InformationFlowRate = URIRef("http://qudt.org/vocab/quantitykind/InformationFlowRate")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    RiseOfOffStateVoltage = URIRef("http://qudt.org/vocab/quantitykind/RiseOfOffStateVoltage")
    ThrustCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThrustCoefficient")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    TrafficIntensity = URIRef("http://qudt.org/vocab/quantitykind/TrafficIntensity")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    RecombinationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/RecombinationCoefficient")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    LandeGFactor = URIRef("http://qudt.org/vocab/quantitykind/LandeGFactor")
    CatalyticActivity = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivity")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    Luminance = URIRef("http://qudt.org/vocab/quantitykind/Luminance")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    SpecificAcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/SpecificAcousticImpedance")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    PowerPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/PowerPerElectricCharge")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    ElectromagneticWavePhaseSpeed = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticWavePhaseSpeed")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    VolumetricEntityDensity = URIRef("http://qudt.org/vocab/quantitykind/VolumetricEntityDensity")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    MassAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAbsorptionCoefficient")
    OsmoticPressure = URIRef("http://qudt.org/vocab/quantitykind/OsmoticPressure")
    Angle = URIRef("http://qudt.org/vocab/quantitykind/Angle")
    TemperatureDifference = URIRef("http://qudt.org/vocab/quantitykind/TemperatureDifference")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    SecondPolarMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondPolarMomentOfArea")
    RelativeMassDensity = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDensity")
    LuminousIntensityDistribution = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensityDistribution")
    PhaseSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/PhaseSpeedOfSound")
    ElectricChargeLinearDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeLinearDensity")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    MolecularConcentration = URIRef("http://qudt.org/vocab/quantitykind/MolecularConcentration")
    Half_Life = URIRef("http://qudt.org/vocab/quantitykind/Half-Life")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    StandardGravitationalParameter = URIRef("http://qudt.org/vocab/quantitykind/StandardGravitationalParameter")
    FlashPoint = URIRef("http://qudt.org/vocab/quantitykind/FlashPoint")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    BatteryCapacity = URIRef("http://qudt.org/vocab/quantitykind/BatteryCapacity")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    CurvatureFromRadius = URIRef("http://qudt.org/vocab/quantitykind/CurvatureFromRadius")
    IonConcentration = URIRef("http://qudt.org/vocab/quantitykind/IonConcentration")
    NapierianAbsorbance = URIRef("http://qudt.org/vocab/quantitykind/NapierianAbsorbance")
    MolarHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MolarHeatCapacity")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    ParticleNumberDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleNumberDensity")
    SpecificEntropy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEntropy")
    AngularDistance = URIRef("http://qudt.org/vocab/quantitykind/AngularDistance")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    RichardsonConstant = URIRef("http://qudt.org/vocab/quantitykind/RichardsonConstant")
    TemperatureRateOfChange = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRateOfChange")
    Exposure = URIRef("http://qudt.org/vocab/quantitykind/Exposure")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    TemperatureBasedAmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedAmountOfSubstanceConcentration")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    CoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/CoefficientOfHeatTransfer")
    Permeance = URIRef("http://qudt.org/vocab/quantitykind/Permeance")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    SecondStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SecondStageMassRatio")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    IonicStrength = URIRef("http://qudt.org/vocab/quantitykind/IonicStrength")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    SurgeImpedanceOfTheMedium = URIRef("http://qudt.org/vocab/quantitykind/SurgeImpedanceOfTheMedium")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    LuminousIntensityDistribution = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensityDistribution")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    TimeSquared = URIRef("http://qudt.org/vocab/quantitykind/TimeSquared")
    MolecularMass = URIRef("http://qudt.org/vocab/quantitykind/MolecularMass")
    VoltageRatio = URIRef("http://qudt.org/vocab/quantitykind/VoltageRatio")
    RelativeMassExcess = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassExcess")
    NozzleThroatPressure = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatPressure")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    SoilAdsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SoilAdsorptionCoefficient")
    AtomScatteringFactor = URIRef("http://qudt.org/vocab/quantitykind/AtomScatteringFactor")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    AngularDistance = URIRef("http://qudt.org/vocab/quantitykind/AngularDistance")
    SpecificOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificOpticalRotatoryPower")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    ThermalDiffusionFactor = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionFactor")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    SpecificEntropy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEntropy")
    DebyeTemperature = URIRef("http://qudt.org/vocab/quantitykind/DebyeTemperature")
    AbsoluteActivity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteActivity")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    GrandCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/GrandCanonicalPartitionFunction")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    LowerCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/LowerCriticalMagneticFluxDensity")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    LinearElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrentDensity")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    AngularDistance = URIRef("http://qudt.org/vocab/quantitykind/AngularDistance")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    VolumetricBitDensity = URIRef("http://qudt.org/vocab/quantitykind/VolumetricBitDensity")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    PeltierCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PeltierCoefficient")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    GasLeakRate = URIRef("http://qudt.org/vocab/quantitykind/GasLeakRate")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    ResistanceRatio = URIRef("http://qudt.org/vocab/quantitykind/ResistanceRatio")
    MassPerLength = URIRef("http://qudt.org/vocab/quantitykind/MassPerLength")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    MorbidityRate = URIRef("http://qudt.org/vocab/quantitykind/MorbidityRate")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    PictureElement = URIRef("http://qudt.org/vocab/quantitykind/PictureElement")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    HeatFlowRatePerUnitArea = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRatePerUnitArea")
    Permeability = URIRef("http://qudt.org/vocab/quantitykind/Permeability")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    QuantityOfLight = URIRef("http://qudt.org/vocab/quantitykind/QuantityOfLight")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    AbsorbedDoseRate = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDoseRate")
    SpectralLuminousEfficiency = URIRef("http://qudt.org/vocab/quantitykind/SpectralLuminousEfficiency")
    Turbidity = URIRef("http://qudt.org/vocab/quantitykind/Turbidity")
    ExitPlanePressure = URIRef("http://qudt.org/vocab/quantitykind/ExitPlanePressure")
    MolarRefractivity = URIRef("http://qudt.org/vocab/quantitykind/MolarRefractivity")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    AccelerationOfGravity = URIRef("http://qudt.org/vocab/quantitykind/AccelerationOfGravity")
    SpecificGibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificGibbsEnergy")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    PositiveDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/PositiveDimensionlessRatio")
    SoundParticleVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleVelocity")
    Impedance = URIRef("http://qudt.org/vocab/quantitykind/Impedance")
    ThermalUtilizationFactorForFission = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactorForFission")
    SoundExposureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundExposureLevel")
    Capacitance = URIRef("http://qudt.org/vocab/quantitykind/Capacitance")
    ElectronDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectronDensity")
    MaximumExpectedOperatingPressure = URIRef("http://qudt.org/vocab/quantitykind/MaximumExpectedOperatingPressure")
    ThermalInsulance = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulance")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    MOMENT_OF_INERTIA_Y = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Y")
    ModulusOfAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfAdmittance")
    InverseMagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/InverseMagneticFlux")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    Compressibility = URIRef("http://qudt.org/vocab/quantitykind/Compressibility")
    MagnetomotiveForce = URIRef("http://qudt.org/vocab/quantitykind/MagnetomotiveForce")
    ElectromagneticPermeability = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeability")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    ModulusOfAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfAdmittance")
    Resistivity = URIRef("http://qudt.org/vocab/quantitykind/Resistivity")
    AttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AttenuationCoefficient")
    MeanMassRange = URIRef("http://qudt.org/vocab/quantitykind/MeanMassRange")
    ThermalUtilizationFactorForFission = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactorForFission")
    Half_Life = URIRef("http://qudt.org/vocab/quantitykind/Half-Life")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    PoyntingVector = URIRef("http://qudt.org/vocab/quantitykind/PoyntingVector")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    LuminousEfficacy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEfficacy")
    LinearAcceleration = URIRef("http://qudt.org/vocab/quantitykind/LinearAcceleration")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    HamiltonFunction = URIRef("http://qudt.org/vocab/quantitykind/HamiltonFunction")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    MotorConstant = URIRef("http://qudt.org/vocab/quantitykind/MotorConstant")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    MomentumPerAngle = URIRef("http://qudt.org/vocab/quantitykind/MomentumPerAngle")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    AreaThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/AreaThermalExpansion")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    DigitRate = URIRef("http://qudt.org/vocab/quantitykind/DigitRate")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    BitTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/BitTransmissionRate")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    SpecificGibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificGibbsEnergy")
    CouplingFactor = URIRef("http://qudt.org/vocab/quantitykind/CouplingFactor")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    TemperatureBasedVelocity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedVelocity")
    ComplexPower = URIRef("http://qudt.org/vocab/quantitykind/ComplexPower")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    Impulse = URIRef("http://qudt.org/vocab/quantitykind/Impulse")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    PhotosyntheticPhotonFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/PhotosyntheticPhotonFluxDensity")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    LeakageFactor = URIRef("http://qudt.org/vocab/quantitykind/LeakageFactor")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    ThermalConductance = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductance")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    PH = URIRef("http://qudt.org/vocab/quantitykind/PH")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    TimeTemperature = URIRef("http://qudt.org/vocab/quantitykind/TimeTemperature")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    Permeance = URIRef("http://qudt.org/vocab/quantitykind/Permeance")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    MassEnergyTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassEnergyTransferCoefficient")
    ExposureRate = URIRef("http://qudt.org/vocab/quantitykind/ExposureRate")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    LeakageFactor = URIRef("http://qudt.org/vocab/quantitykind/LeakageFactor")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    ElectricCurrentPerAngle = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerAngle")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    PressureBasedVolumeFlow = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedVolumeFlow")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    LinearElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrent")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    GeneralizedMomentum = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedMomentum")
    ResistanceRatio = URIRef("http://qudt.org/vocab/quantitykind/ResistanceRatio")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    Permittivity = URIRef("http://qudt.org/vocab/quantitykind/Permittivity")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    EvaporativeHeatTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/EvaporativeHeatTransferCoefficient")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    TorquePerAngle = URIRef("http://qudt.org/vocab/quantitykind/TorquePerAngle")
    LuminousExitance = URIRef("http://qudt.org/vocab/quantitykind/LuminousExitance")
    DatasetOfBits = URIRef("http://qudt.org/vocab/quantitykind/DatasetOfBits")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    LiftCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LiftCoefficient")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    LinearBitDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearBitDensity")
    EnergyPerArea = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerArea")
    MagneticQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/MagneticQuantumNumber")
    NormalizedDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/NormalizedDimensionlessRatio")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    ExposureOfIonizingRadiation = URIRef("http://qudt.org/vocab/quantitykind/ExposureOfIonizingRadiation")
    TemperatureBasedMassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedMassFlowRate")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    MassicPower = URIRef("http://qudt.org/vocab/quantitykind/MassicPower")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    PhaseCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PhaseCoefficient")
    PressureBasedMassFlow = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedMassFlow")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    FlashPoint = URIRef("http://qudt.org/vocab/quantitykind/FlashPoint")
    MassieuFunction = URIRef("http://qudt.org/vocab/quantitykind/MassieuFunction")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    Radiance = URIRef("http://qudt.org/vocab/quantitykind/Radiance")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    ElectricDisplacementField = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacementField")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    PressureBasedElectricVoltage = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedElectricVoltage")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    PressureBasedVelocity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedVelocity")
    Capacitance = URIRef("http://qudt.org/vocab/quantitykind/Capacitance")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    MomentumPerAngle = URIRef("http://qudt.org/vocab/quantitykind/MomentumPerAngle")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    IncidenceRate = URIRef("http://qudt.org/vocab/quantitykind/IncidenceRate")
    Vorticity = URIRef("http://qudt.org/vocab/quantitykind/Vorticity")
    ThermalUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactor")
    GeneralizedCoordinate = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedCoordinate")
    RecombinationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/RecombinationCoefficient")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    Acidity = URIRef("http://qudt.org/vocab/quantitykind/Acidity")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    TimeConstant_Inductance = URIRef("http://qudt.org/vocab/quantitykind/TimeConstant_Inductance")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    MassAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAbsorptionCoefficient")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    SystolicBloodPressure = URIRef("http://qudt.org/vocab/quantitykind/SystolicBloodPressure")
    Flux = URIRef("http://qudt.org/vocab/quantitykind/Flux")
    PhaseSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/PhaseSpeedOfSound")
    LineicQuantity = URIRef("http://qudt.org/vocab/quantitykind/LineicQuantity")
    BulkModulus = URIRef("http://qudt.org/vocab/quantitykind/BulkModulus")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    StructuralEfficiency = URIRef("http://qudt.org/vocab/quantitykind/StructuralEfficiency")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    BevelGearPitchAngle = URIRef("http://qudt.org/vocab/quantitykind/BevelGearPitchAngle")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    BevelGearPitchAngle = URIRef("http://qudt.org/vocab/quantitykind/BevelGearPitchAngle")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    EnergyPerArea = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerArea")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    HeartRate = URIRef("http://qudt.org/vocab/quantitykind/HeartRate")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    ActivityRelatedByMass = URIRef("http://qudt.org/vocab/quantitykind/ActivityRelatedByMass")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    LinearAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAttenuationCoefficient")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    MolarHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MolarHeatCapacity")
    ThermalAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalAdmittance")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    MicroCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/MicroCanonicalPartitionFunction")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    KinematicViscosityOrDiffusionConstantOrThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosityOrDiffusionConstantOrThermalDiffusivity")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    MassAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAbsorptionCoefficient")
    LineicPower = URIRef("http://qudt.org/vocab/quantitykind/LineicPower")
    VoltageRatio = URIRef("http://qudt.org/vocab/quantitykind/VoltageRatio")
    ElectricChargeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeDensity")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    MagneticQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/MagneticQuantumNumber")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    AtmosphericHydroxylationRate = URIRef("http://qudt.org/vocab/quantitykind/AtmosphericHydroxylationRate")
    RelativeMassRatioOfVapour = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassRatioOfVapour")
    ElectromagneticWavePhaseSpeed = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticWavePhaseSpeed")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    ThrustToMassRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToMassRatio")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    SystolicBloodPressure = URIRef("http://qudt.org/vocab/quantitykind/SystolicBloodPressure")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    InverseMagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/InverseMagneticFlux")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    Half_Life = URIRef("http://qudt.org/vocab/quantitykind/Half-Life")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    EvaporativeHeatTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/EvaporativeHeatTransferCoefficient")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    ExhaustGasesSpecificHeat = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasesSpecificHeat")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    NuclearQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/NuclearQuadrupoleMoment")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    RF_Power = URIRef("http://qudt.org/vocab/quantitykind/RF-Power")
    ThermalResistivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistivity")
    ThermalCoefficientOfLinearExpansion = URIRef("http://qudt.org/vocab/quantitykind/ThermalCoefficientOfLinearExpansion")
    RelativePartialPressure = URIRef("http://qudt.org/vocab/quantitykind/RelativePartialPressure")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    TemperatureBasedDynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedDynamicViscosity")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    MolarThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarThermodynamicEnergy")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    TorqueConstant = URIRef("http://qudt.org/vocab/quantitykind/TorqueConstant")
    Mobility = URIRef("http://qudt.org/vocab/quantitykind/Mobility")
    HallCoefficient = URIRef("http://qudt.org/vocab/quantitykind/HallCoefficient")
    AreaTime = URIRef("http://qudt.org/vocab/quantitykind/AreaTime")
    AmountOfSubstancePerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMass")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    FahrenheitTemperature = URIRef("http://qudt.org/vocab/quantitykind/FahrenheitTemperature")
    SurfaceActivityDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceActivityDensity")
    SourceVoltageBetweenSubstances = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltageBetweenSubstances")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    DebyeAngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularWavenumber")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    PositiveDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/PositiveDimensionlessRatio")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    Capacitance = URIRef("http://qudt.org/vocab/quantitykind/Capacitance")
    TotalCurrent = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrent")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    PhotosyntheticPhotonFlux = URIRef("http://qudt.org/vocab/quantitykind/PhotosyntheticPhotonFlux")
    TotalCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrentDensity")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    Half_Life = URIRef("http://qudt.org/vocab/quantitykind/Half-Life")
    Solubility_Water = URIRef("http://qudt.org/vocab/quantitykind/Solubility_Water")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    PhaseSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/PhaseSpeedOfSound")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    StressIntensityFactor = URIRef("http://qudt.org/vocab/quantitykind/StressIntensityFactor")
    ActionTime = URIRef("http://qudt.org/vocab/quantitykind/ActionTime")
    LinkedFlux = URIRef("http://qudt.org/vocab/quantitykind/LinkedFlux")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    DoseEquivalentRate = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalentRate")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    DataRate = URIRef("http://qudt.org/vocab/quantitykind/DataRate")
    ExposureRateOfIonizingRadiation = URIRef("http://qudt.org/vocab/quantitykind/ExposureRateOfIonizingRadiation")
    SourceVoltageBetweenSubstances = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltageBetweenSubstances")
    ThermalAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalAdmittance")
    ResidualResistivity = URIRef("http://qudt.org/vocab/quantitykind/ResidualResistivity")
    StressOpticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StressOpticCoefficient")
    MOMENT_OF_INERTIA_Z = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Z")
    TotalAngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentum")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    StatisticalWeight = URIRef("http://qudt.org/vocab/quantitykind/StatisticalWeight")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    CatalyticActivity = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivity")
    InverseVolume = URIRef("http://qudt.org/vocab/quantitykind/InverseVolume")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    AttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AttenuationCoefficient")
    StrainEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/StrainEnergyDensity")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    CoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/CoefficientOfHeatTransfer")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    HoleDensity = URIRef("http://qudt.org/vocab/quantitykind/HoleDensity")
    ExtentOfReaction = URIRef("http://qudt.org/vocab/quantitykind/ExtentOfReaction")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    OsmoticPressure = URIRef("http://qudt.org/vocab/quantitykind/OsmoticPressure")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    PermeabilityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermeabilityRatio")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    ConvectiveHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/ConvectiveHeatTransfer")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    MassicTorque = URIRef("http://qudt.org/vocab/quantitykind/MassicTorque")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    Gravity_API = URIRef("http://qudt.org/vocab/quantitykind/Gravity_API")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    AreicMass = URIRef("http://qudt.org/vocab/quantitykind/AreicMass")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    CurrencyPerFlight = URIRef("http://qudt.org/vocab/quantitykind/CurrencyPerFlight")
    TemperatureGradient = URIRef("http://qudt.org/vocab/quantitykind/TemperatureGradient")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    PositiveDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/PositiveDimensionlessRatio")
    PRODUCT_OF_INERTIA_X = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA_X")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    Kerma = URIRef("http://qudt.org/vocab/quantitykind/Kerma")
    ModulusOfRotationalSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfRotationalSubgradeReaction")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    RadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergyDensity")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    Landau_GinzburgNumber = URIRef("http://qudt.org/vocab/quantitykind/Landau-GinzburgNumber")
    MassicTorque = URIRef("http://qudt.org/vocab/quantitykind/MassicTorque")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    RadianceFactor = URIRef("http://qudt.org/vocab/quantitykind/RadianceFactor")
    FahrenheitTemperature = URIRef("http://qudt.org/vocab/quantitykind/FahrenheitTemperature")
    TotalLinearStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalLinearStoppingPower")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    DonorDensity = URIRef("http://qudt.org/vocab/quantitykind/DonorDensity")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    InverseVolume = URIRef("http://qudt.org/vocab/quantitykind/InverseVolume")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    MassAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAttenuationCoefficient")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    AreaPerPower = URIRef("http://qudt.org/vocab/quantitykind/AreaPerPower")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    ExtentOfReaction = URIRef("http://qudt.org/vocab/quantitykind/ExtentOfReaction")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    ThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusivity")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    AbsorbedDoseRate = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDoseRate")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    CouplingFactor = URIRef("http://qudt.org/vocab/quantitykind/CouplingFactor")
    EnergyPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerElectricCharge")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    PressureBasedElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedElectricCurrent")
    MassRatio = URIRef("http://qudt.org/vocab/quantitykind/MassRatio")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    FissionCoreRadiusToHeightRatio = URIRef("http://qudt.org/vocab/quantitykind/FissionCoreRadiusToHeightRatio")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    ChemicalConsumptionPerMass = URIRef("http://qudt.org/vocab/quantitykind/ChemicalConsumptionPerMass")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    CurrentLinkage = URIRef("http://qudt.org/vocab/quantitykind/CurrentLinkage")
    ModulusOfLinearSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfLinearSubgradeReaction")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    Half_Life = URIRef("http://qudt.org/vocab/quantitykind/Half-Life")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    PRODUCT_OF_INERTIA_Y = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA_Y")
    StressIntensityFactor = URIRef("http://qudt.org/vocab/quantitykind/StressIntensityFactor")
    StoichiometricNumber = URIRef("http://qudt.org/vocab/quantitykind/StoichiometricNumber")
    SourceVoltage = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltage")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    LinearIonization = URIRef("http://qudt.org/vocab/quantitykind/LinearIonization")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    FUEL_BIAS = URIRef("http://qudt.org/vocab/quantitykind/FUEL-BIAS")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    ThermodynamicCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicCriticalMagneticFluxDensity")
    TorquePerAngle = URIRef("http://qudt.org/vocab/quantitykind/TorquePerAngle")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    ThermalDiffusionFactor = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionFactor")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    SpecificImpulse = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulse")
    CoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/CoefficientOfHeatTransfer")
    LengthRatio = URIRef("http://qudt.org/vocab/quantitykind/LengthRatio")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    TemperaturePerTime = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    Susceptance = URIRef("http://qudt.org/vocab/quantitykind/Susceptance")
    IonicStrength = URIRef("http://qudt.org/vocab/quantitykind/IonicStrength")
    RelativeHumidity = URIRef("http://qudt.org/vocab/quantitykind/RelativeHumidity")
    SpectralCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralCrossSection")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    RelativePressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/RelativePressureCoefficient")
    ResonanceEscapeProbabilityForFission = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbabilityForFission")
    PressureBasedElectricVoltage = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedElectricVoltage")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    HeadEndPressure = URIRef("http://qudt.org/vocab/quantitykind/HeadEndPressure")
    Capacitance = URIRef("http://qudt.org/vocab/quantitykind/Capacitance")
    PowerAreaPerSolidAngle = URIRef("http://qudt.org/vocab/quantitykind/PowerAreaPerSolidAngle")
    LogarithmRatioToBaseE = URIRef("http://qudt.org/vocab/quantitykind/LogarithmRatioToBaseE")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    VaporPermeability = URIRef("http://qudt.org/vocab/quantitykind/VaporPermeability")
    SphericalIlluminance = URIRef("http://qudt.org/vocab/quantitykind/SphericalIlluminance")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    ByteTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/ByteTransmissionRate")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    PropellantTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantTemperature")
    TotalCurrent = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrent")
    ThermalUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactor")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    Circulation = URIRef("http://qudt.org/vocab/quantitykind/Circulation")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    Exposure = URIRef("http://qudt.org/vocab/quantitykind/Exposure")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    CurrentLinkage = URIRef("http://qudt.org/vocab/quantitykind/CurrentLinkage")
    SpecificHeatCapacityAtConstantPressure = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantPressure")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    DoseEquivalent = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalent")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    NapierianAbsorbance = URIRef("http://qudt.org/vocab/quantitykind/NapierianAbsorbance")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    EnergyPerMassAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerMassAmountOfSubstance")
    ExhaustGasMeanMolecularWeight = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasMeanMolecularWeight")
    SpecificHeatCapacityAtSaturation = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtSaturation")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    DynamicPressure = URIRef("http://qudt.org/vocab/quantitykind/DynamicPressure")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    LinearDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearDensity")
    PressureBasedKinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedKinematicViscosity")
    Angle = URIRef("http://qudt.org/vocab/quantitykind/Angle")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    RadiantFluence = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluence")
    Long_RangeOrderParameter = URIRef("http://qudt.org/vocab/quantitykind/Long-RangeOrderParameter")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    ReciprocalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalEnergy")
    GrandCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/GrandCanonicalPartitionFunction")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    SoundReductionIndex = URIRef("http://qudt.org/vocab/quantitykind/SoundReductionIndex")
    LogarithmicMedianInformationFlow_SourceToBase10 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicMedianInformationFlow_SourceToBase10")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    BucklingFactor = URIRef("http://qudt.org/vocab/quantitykind/BucklingFactor")
    SphericalIlluminance = URIRef("http://qudt.org/vocab/quantitykind/SphericalIlluminance")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    Chromaticity = URIRef("http://qudt.org/vocab/quantitykind/Chromaticity")
    DebyeAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularFrequency")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    TemperatureRateOfChange = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRateOfChange")
    Log10Ratio = URIRef("http://qudt.org/vocab/quantitykind/Log10Ratio")
    FUEL_BIAS = URIRef("http://qudt.org/vocab/quantitykind/FUEL-BIAS")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    AmountOfSubstancePerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMass")
    PictureElement = URIRef("http://qudt.org/vocab/quantitykind/PictureElement")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    SoundExposureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundExposureLevel")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    TemperatureRatio = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRatio")
    InverseMagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/InverseMagneticFlux")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    Vorticity = URIRef("http://qudt.org/vocab/quantitykind/Vorticity")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    EffectiveExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/EffectiveExhaustVelocity")
    VolumicElectromagneticEnergy = URIRef("http://qudt.org/vocab/quantitykind/VolumicElectromagneticEnergy")
    ElectricDisplacementField = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacementField")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    LiquidVolume = URIRef("http://qudt.org/vocab/quantitykind/LiquidVolume")
    IntinsicCarrierDensity = URIRef("http://qudt.org/vocab/quantitykind/IntinsicCarrierDensity")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    IonDensity = URIRef("http://qudt.org/vocab/quantitykind/IonDensity")
    ElectricConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectricConductivity")
    MassAmountOfSubstanceTemperature = URIRef("http://qudt.org/vocab/quantitykind/MassAmountOfSubstanceTemperature")
    DynamicPressure = URIRef("http://qudt.org/vocab/quantitykind/DynamicPressure")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    IonicStrength = URIRef("http://qudt.org/vocab/quantitykind/IonicStrength")
    AuditoryThresholds = URIRef("http://qudt.org/vocab/quantitykind/AuditoryThresholds")
    Luminance = URIRef("http://qudt.org/vocab/quantitykind/Luminance")
    ElectricChargePerArea = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerArea")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    ElectricChargePerMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerMass")
    MagneticFluxPerUnitLength = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxPerUnitLength")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    PartialPressure = URIRef("http://qudt.org/vocab/quantitykind/PartialPressure")
    Impulse = URIRef("http://qudt.org/vocab/quantitykind/Impulse")
    SpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/SpinQuantumNumber")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    ElectricChargeSurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeSurfaceDensity")
    LogarithmicFrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyInterval")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    GeneralizedForce = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedForce")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    MagneticDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMoment")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    SpecificEntropy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEntropy")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    EccentricityOfOrbit = URIRef("http://qudt.org/vocab/quantitykind/EccentricityOfOrbit")
    TemperatureBasedVelocity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedVelocity")
    ParticleFluence = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluence")
    NumberOfParticles = URIRef("http://qudt.org/vocab/quantitykind/NumberOfParticles")
    Permeability = URIRef("http://qudt.org/vocab/quantitykind/Permeability")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    Polarizability = URIRef("http://qudt.org/vocab/quantitykind/Polarizability")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    InformationContent = URIRef("http://qudt.org/vocab/quantitykind/InformationContent")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    CatalyticActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivityConcentration")
    IonTransportNumber = URIRef("http://qudt.org/vocab/quantitykind/IonTransportNumber")
    LinearMass = URIRef("http://qudt.org/vocab/quantitykind/LinearMass")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    ElectricConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectricConductivity")
    Temperature = URIRef("http://qudt.org/vocab/quantitykind/Temperature")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    ElectricChargeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeDensity")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    InverseEnergy = URIRef("http://qudt.org/vocab/quantitykind/InverseEnergy")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    Acidity = URIRef("http://qudt.org/vocab/quantitykind/Acidity")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    ThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusivity")
    SpecificActivity = URIRef("http://qudt.org/vocab/quantitykind/SpecificActivity")
    VolumicElectromagneticEnergy = URIRef("http://qudt.org/vocab/quantitykind/VolumicElectromagneticEnergy")
    CanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/CanonicalPartitionFunction")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    SpectralConcentrationOfVibrationalModes = URIRef("http://qudt.org/vocab/quantitykind/SpectralConcentrationOfVibrationalModes")
    TimePercentage = URIRef("http://qudt.org/vocab/quantitykind/TimePercentage")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    SpecificSurfaceArea = URIRef("http://qudt.org/vocab/quantitykind/SpecificSurfaceArea")
    ActivityCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ActivityCoefficient")
    MassRatioOfWaterToDryMatter = URIRef("http://qudt.org/vocab/quantitykind/MassRatioOfWaterToDryMatter")
    VolumeThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/VolumeThermalExpansion")
    SourceVoltageBetweenSubstances = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltageBetweenSubstances")
    Action = URIRef("http://qudt.org/vocab/quantitykind/Action")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    TorsionalRigidity = URIRef("http://qudt.org/vocab/quantitykind/TorsionalRigidity")
    DebyeAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularFrequency")
    LogarithmicFrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyInterval")
    LuminousExposure = URIRef("http://qudt.org/vocab/quantitykind/LuminousExposure")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    LinearTorque = URIRef("http://qudt.org/vocab/quantitykind/LinearTorque")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    ParticleNumberDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleNumberDensity")
    ScalarMagneticPotential = URIRef("http://qudt.org/vocab/quantitykind/ScalarMagneticPotential")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    PressureBurningRateIndex = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateIndex")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    GrandCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/GrandCanonicalPartitionFunction")
    Circulation = URIRef("http://qudt.org/vocab/quantitykind/Circulation")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    MortalityRate = URIRef("http://qudt.org/vocab/quantitykind/MortalityRate")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    IonDensity = URIRef("http://qudt.org/vocab/quantitykind/IonDensity")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    CurrentOfTheAmountOfSubtance = URIRef("http://qudt.org/vocab/quantitykind/CurrentOfTheAmountOfSubtance")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    NuclearQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/NuclearQuadrupoleMoment")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    PressurePercentage = URIRef("http://qudt.org/vocab/quantitykind/PressurePercentage")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    ResonanceEscapeProbabilityForFission = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbabilityForFission")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    UpperCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/UpperCriticalMagneticFluxDensity")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    ParticleFluence = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluence")
    DynamicFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DynamicFrictionCoefficient")
    DynamicPressure = URIRef("http://qudt.org/vocab/quantitykind/DynamicPressure")
    AreaTemperature = URIRef("http://qudt.org/vocab/quantitykind/AreaTemperature")
    VolumicOutput = URIRef("http://qudt.org/vocab/quantitykind/VolumicOutput")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    PolarizationField = URIRef("http://qudt.org/vocab/quantitykind/PolarizationField")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    InverseTemperature = URIRef("http://qudt.org/vocab/quantitykind/InverseTemperature")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    CharacteristicNumber = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicNumber")
    TemperatureRelatedMolarMass = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRelatedMolarMass")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    AmountOfSubstancePerUnitMassPressure = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMassPressure")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    LossAngle = URIRef("http://qudt.org/vocab/quantitykind/LossAngle")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    ElectricChargePerAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerAmountOfSubstance")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    QuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/QuantumNumber")
    EnergyPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerElectricCharge")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    PowerConstant = URIRef("http://qudt.org/vocab/quantitykind/PowerConstant")
    Voltage = URIRef("http://qudt.org/vocab/quantitykind/Voltage")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    CombinedNonEvaporativeHeatTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CombinedNonEvaporativeHeatTransferCoefficient")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    StructureFactor = URIRef("http://qudt.org/vocab/quantitykind/StructureFactor")
    HeatFlowRatePerUnitArea = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRatePerUnitArea")
    SoundPowerLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPowerLevel")
    GroupSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/GroupSpeedOfSound")
    MassAmountOfSubstanceTemperature = URIRef("http://qudt.org/vocab/quantitykind/MassAmountOfSubstanceTemperature")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    Repetency = URIRef("http://qudt.org/vocab/quantitykind/Repetency")
    LuminousEnergy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEnergy")
    SpecificPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificPower")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    PressureBasedElectricVoltage = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedElectricVoltage")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    Prevalence = URIRef("http://qudt.org/vocab/quantitykind/Prevalence")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    AtomScatteringFactor = URIRef("http://qudt.org/vocab/quantitykind/AtomScatteringFactor")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    VideoFrameRate = URIRef("http://qudt.org/vocab/quantitykind/VideoFrameRate")
    CyclotronAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/CyclotronAngularFrequency")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    AreaMass = URIRef("http://qudt.org/vocab/quantitykind/AreaMass")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    InverseLength = URIRef("http://qudt.org/vocab/quantitykind/InverseLength")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    ThermalInsulance = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulance")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    SpecificElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/SpecificElectricCurrent")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    RadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergyDensity")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    IonCurrent = URIRef("http://qudt.org/vocab/quantitykind/IonCurrent")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    Kerma = URIRef("http://qudt.org/vocab/quantitykind/Kerma")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    TemperatureGradient = URIRef("http://qudt.org/vocab/quantitykind/TemperatureGradient")
    SuperconductionTransitionTemperature = URIRef("http://qudt.org/vocab/quantitykind/SuperconductionTransitionTemperature")
    BevelGearPitchAngle = URIRef("http://qudt.org/vocab/quantitykind/BevelGearPitchAngle")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    LinkedFlux = URIRef("http://qudt.org/vocab/quantitykind/LinkedFlux")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    NormalizedDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/NormalizedDimensionlessRatio")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    DynamicFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DynamicFrictionCoefficient")
    FermiAngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/FermiAngularWavenumber")
    MolarHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MolarHeatCapacity")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    AccelerationOfGravity = URIRef("http://qudt.org/vocab/quantitykind/AccelerationOfGravity")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    PressureBasedQuantity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedQuantity")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    Rotary_TranslatoryMotionConversion = URIRef("http://qudt.org/vocab/quantitykind/Rotary-TranslatoryMotionConversion")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    ElectricChargeSurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeSurfaceDensity")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    RankineTemperature = URIRef("http://qudt.org/vocab/quantitykind/RankineTemperature")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    ElectricChargeLineDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeLineDensity")
    MolalityOfSolute = URIRef("http://qudt.org/vocab/quantitykind/MolalityOfSolute")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    ElectricConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectricConductivity")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    PropellantTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantTemperature")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    MagneticTension = URIRef("http://qudt.org/vocab/quantitykind/MagneticTension")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    EquilibriumConstantOnConcentrationBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnConcentrationBasis")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    PrincipalQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/PrincipalQuantumNumber")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    SpecificHeatCapacityAtConstantVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantVolume")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    MagneticAreaMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticAreaMoment")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    Concentration = URIRef("http://qudt.org/vocab/quantitykind/Concentration")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    ByteDataVolume = URIRef("http://qudt.org/vocab/quantitykind/ByteDataVolume")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    InternalConversionFactor = URIRef("http://qudt.org/vocab/quantitykind/InternalConversionFactor")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    PressurePercentage = URIRef("http://qudt.org/vocab/quantitykind/PressurePercentage")
    LiquidVolume = URIRef("http://qudt.org/vocab/quantitykind/LiquidVolume")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    Viscosity = URIRef("http://qudt.org/vocab/quantitykind/Viscosity")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    RelativeMassConcentrationOfVapour = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassConcentrationOfVapour")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    Repetency = URIRef("http://qudt.org/vocab/quantitykind/Repetency")
    CouplingFactor = URIRef("http://qudt.org/vocab/quantitykind/CouplingFactor")
    ResonanceEscapeProbability = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbability")
    ModulusOfRotationalSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfRotationalSubgradeReaction")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    PlanckFunction = URIRef("http://qudt.org/vocab/quantitykind/PlanckFunction")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    GeneralizedForce = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedForce")
    FishBiotransformationHalfLife = URIRef("http://qudt.org/vocab/quantitykind/FishBiotransformationHalfLife")
    PositivePlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PositivePlaneAngle")
    CanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/CanonicalPartitionFunction")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    ReynoldsNumber = URIRef("http://qudt.org/vocab/quantitykind/ReynoldsNumber")
    RotationalStiffness = URIRef("http://qudt.org/vocab/quantitykind/RotationalStiffness")
    IonTransportNumber = URIRef("http://qudt.org/vocab/quantitykind/IonTransportNumber")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    PowerPerAreaAngle = URIRef("http://qudt.org/vocab/quantitykind/PowerPerAreaAngle")
    FissionCoreRadiusToHeightRatio = URIRef("http://qudt.org/vocab/quantitykind/FissionCoreRadiusToHeightRatio")
    NeelTemperature = URIRef("http://qudt.org/vocab/quantitykind/NeelTemperature")
    SourceVoltage = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltage")
    InverseEnergy_Squared = URIRef("http://qudt.org/vocab/quantitykind/InverseEnergy_Squared")
    SoundEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SoundEnergyDensity")
    ThermalExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalExpansionCoefficient")
    DensityInCombustionChamber = URIRef("http://qudt.org/vocab/quantitykind/DensityInCombustionChamber")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    RelativeMassExcess = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassExcess")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    MolarHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MolarHeatCapacity")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    LuminousFluxPerArea = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxPerArea")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    SpecificHeatsRatio = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatsRatio")
    PressurePercentage = URIRef("http://qudt.org/vocab/quantitykind/PressurePercentage")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    Dissipance = URIRef("http://qudt.org/vocab/quantitykind/Dissipance")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    ThermalTransmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalTransmittance")
    DebyeAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularFrequency")
    SpecificVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificVolume")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    MassicHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MassicHeatCapacity")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    ForcePerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/ForcePerAreaTime")
    ParticleFluence = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluence")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    PolarizationField = URIRef("http://qudt.org/vocab/quantitykind/PolarizationField")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    SoundEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SoundEnergyDensity")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    SpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/SpinQuantumNumber")
    CoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/CoefficientOfHeatTransfer")
    FirstStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/FirstStageMassRatio")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    SunProtectionFactorOfAProduct = URIRef("http://qudt.org/vocab/quantitykind/SunProtectionFactorOfAProduct")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    PressureBasedAmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedAmountOfSubstanceConcentration")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    MagneticFluxDensityOrMagneticPolarization = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensityOrMagneticPolarization")
    AngleOfOpticalRotation = URIRef("http://qudt.org/vocab/quantitykind/AngleOfOpticalRotation")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    IonicStrength = URIRef("http://qudt.org/vocab/quantitykind/IonicStrength")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    ResistanceRatio = URIRef("http://qudt.org/vocab/quantitykind/ResistanceRatio")
    Angle = URIRef("http://qudt.org/vocab/quantitykind/Angle")
    PressureBasedVolume = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedVolume")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    GroupSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/GroupSpeedOfSound")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    PhaseCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PhaseCoefficient")
    LagrangeFunction = URIRef("http://qudt.org/vocab/quantitykind/LagrangeFunction")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    Temperature = URIRef("http://qudt.org/vocab/quantitykind/Temperature")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    PropagationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PropagationCoefficient")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    AmountOfSubstancePerUnitVolume = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitVolume")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    LinearElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCharge")
    VolumePerArea = URIRef("http://qudt.org/vocab/quantitykind/VolumePerArea")
    IncidenceRate = URIRef("http://qudt.org/vocab/quantitykind/IncidenceRate")
    SoundPressure = URIRef("http://qudt.org/vocab/quantitykind/SoundPressure")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    AreicChargeDensityOrElectricFluxDensityOrElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/AreicChargeDensityOrElectricFluxDensityOrElectricPolarization")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    ElectricDisplacement = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacement")
    ResistancePercentage = URIRef("http://qudt.org/vocab/quantitykind/ResistancePercentage")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    CouplingFactor = URIRef("http://qudt.org/vocab/quantitykind/CouplingFactor")
    MolarThermalCapacity = URIRef("http://qudt.org/vocab/quantitykind/MolarThermalCapacity")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    PressureGradient = URIRef("http://qudt.org/vocab/quantitykind/PressureGradient")
    MutualInductance = URIRef("http://qudt.org/vocab/quantitykind/MutualInductance")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    Exposure = URIRef("http://qudt.org/vocab/quantitykind/Exposure")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    SectionAreaIntegral = URIRef("http://qudt.org/vocab/quantitykind/SectionAreaIntegral")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    Admittance = URIRef("http://qudt.org/vocab/quantitykind/Admittance")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    GruneisenParameter = URIRef("http://qudt.org/vocab/quantitykind/GruneisenParameter")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    Slowing_DownDensity = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownDensity")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    PoyntingVector = URIRef("http://qudt.org/vocab/quantitykind/PoyntingVector")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    NozzleThroatPressure = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatPressure")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    MagneticField = URIRef("http://qudt.org/vocab/quantitykind/MagneticField")
    SuperconductionTransitionTemperature = URIRef("http://qudt.org/vocab/quantitykind/SuperconductionTransitionTemperature")
    ThermalCapacitance = URIRef("http://qudt.org/vocab/quantitykind/ThermalCapacitance")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    Capacitance = URIRef("http://qudt.org/vocab/quantitykind/Capacitance")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    ThermalResistivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistivity")
    StructuralEfficiency = URIRef("http://qudt.org/vocab/quantitykind/StructuralEfficiency")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    SpectralConcentrationOfVibrationalModes = URIRef("http://qudt.org/vocab/quantitykind/SpectralConcentrationOfVibrationalModes")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    Chromaticity = URIRef("http://qudt.org/vocab/quantitykind/Chromaticity")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    ElectricConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectricConductivity")
    PH = URIRef("http://qudt.org/vocab/quantitykind/PH")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    PackingFraction = URIRef("http://qudt.org/vocab/quantitykind/PackingFraction")
    GustatoryThreshold = URIRef("http://qudt.org/vocab/quantitykind/GustatoryThreshold")
    VoltageRatio = URIRef("http://qudt.org/vocab/quantitykind/VoltageRatio")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    IsothermalMoistureCapacity = URIRef("http://qudt.org/vocab/quantitykind/IsothermalMoistureCapacity")
    Voltage = URIRef("http://qudt.org/vocab/quantitykind/Voltage")
    MassAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAttenuationCoefficient")
    DensityOfStates = URIRef("http://qudt.org/vocab/quantitykind/DensityOfStates")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    Conductance = URIRef("http://qudt.org/vocab/quantitykind/Conductance")
    MagneticReluctivity = URIRef("http://qudt.org/vocab/quantitykind/MagneticReluctivity")
    NuclearSpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/NuclearSpinQuantumNumber")
    LandeGFactor = URIRef("http://qudt.org/vocab/quantitykind/LandeGFactor")
    GeneralizedForce = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedForce")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    PolarMomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/PolarMomentOfInertia")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    AbsorbedDoseRate = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDoseRate")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    VolumetricHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/VolumetricHeatCapacity")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    LengthEnergy = URIRef("http://qudt.org/vocab/quantitykind/LengthEnergy")
    MaximumExpectedOperatingPressure = URIRef("http://qudt.org/vocab/quantitykind/MaximumExpectedOperatingPressure")
    AmountOfSubstancePerUnitVolume = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitVolume")
    Reflectance = URIRef("http://qudt.org/vocab/quantitykind/Reflectance")
    AngleOfOpticalRotation = URIRef("http://qudt.org/vocab/quantitykind/AngleOfOpticalRotation")
    MassicActivity = URIRef("http://qudt.org/vocab/quantitykind/MassicActivity")
    CurrencyPerFlight = URIRef("http://qudt.org/vocab/quantitykind/CurrencyPerFlight")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    SourceVoltageBetweenSubstances = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltageBetweenSubstances")
    SpectralConcentrationOfVibrationalModes = URIRef("http://qudt.org/vocab/quantitykind/SpectralConcentrationOfVibrationalModes")
    BandwidthDistanceProduct = URIRef("http://qudt.org/vocab/quantitykind/BandwidthDistanceProduct")
    RelativeMassDensity = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDensity")
    SourceVoltageBetweenSubstances = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltageBetweenSubstances")
    TotalPressure = URIRef("http://qudt.org/vocab/quantitykind/TotalPressure")
    AreaBitDensity = URIRef("http://qudt.org/vocab/quantitykind/AreaBitDensity")
    LogarithmicMedianInformationFlow_SourceToBase10 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicMedianInformationFlow_SourceToBase10")
    SpecificHeatsRatio = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatsRatio")
    VolumicElectromagneticEnergy = URIRef("http://qudt.org/vocab/quantitykind/VolumicElectromagneticEnergy")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    LinearEnergyTransfer = URIRef("http://qudt.org/vocab/quantitykind/LinearEnergyTransfer")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    InformationFlowRate = URIRef("http://qudt.org/vocab/quantitykind/InformationFlowRate")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    ElectricCurrentPerUnitLength = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerUnitLength")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    StatisticalWeight = URIRef("http://qudt.org/vocab/quantitykind/StatisticalWeight")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    VideoFrameRate = URIRef("http://qudt.org/vocab/quantitykind/VideoFrameRate")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    InverseSquareMass = URIRef("http://qudt.org/vocab/quantitykind/InverseSquareMass")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    EnergyPerAreaElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerAreaElectricCharge")
    BoilingPoint = URIRef("http://qudt.org/vocab/quantitykind/BoilingPoint")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    GyromagneticRatio = URIRef("http://qudt.org/vocab/quantitykind/GyromagneticRatio")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    SpecificInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificInternalEnergy")
    TemperatureRatio = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRatio")
    MolecularConcentration = URIRef("http://qudt.org/vocab/quantitykind/MolecularConcentration")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    MolarFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MolarFlowRate")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    Non_LeakageProbability = URIRef("http://qudt.org/vocab/quantitykind/Non-LeakageProbability")
    Debye_WallerFactor = URIRef("http://qudt.org/vocab/quantitykind/Debye-WallerFactor")
    TemperatureRelatedMolarMass = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRelatedMolarMass")
    ThrusterPowerToThrustEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThrusterPowerToThrustEfficiency")
    MutualInductance = URIRef("http://qudt.org/vocab/quantitykind/MutualInductance")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    MobilityRatio = URIRef("http://qudt.org/vocab/quantitykind/MobilityRatio")
    Speed = URIRef("http://qudt.org/vocab/quantitykind/Speed")
    EquilibriumConstantOnConcentrationBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnConcentrationBasis")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    AcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/AcousticImpedance")
    InternalConversionFactor = URIRef("http://qudt.org/vocab/quantitykind/InternalConversionFactor")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    InverseSquareMass = URIRef("http://qudt.org/vocab/quantitykind/InverseSquareMass")
    InternalConversionFactor = URIRef("http://qudt.org/vocab/quantitykind/InternalConversionFactor")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    SpecificHeatCapacityAtConstantVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantVolume")
    IsothermalMoistureCapacity = URIRef("http://qudt.org/vocab/quantitykind/IsothermalMoistureCapacity")
    AtomicNumber = URIRef("http://qudt.org/vocab/quantitykind/AtomicNumber")
    GrowingDegreeDay_Cereal = URIRef("http://qudt.org/vocab/quantitykind/GrowingDegreeDay_Cereal")
    Exposure = URIRef("http://qudt.org/vocab/quantitykind/Exposure")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    AngularReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/AngularReciprocalLatticeVector")
    AmountOfSubstanceConcentrationOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentrationOfB")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    DoseEquivalentQualityFactor = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalentQualityFactor")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    PolarizationField = URIRef("http://qudt.org/vocab/quantitykind/PolarizationField")
    Admittance = URIRef("http://qudt.org/vocab/quantitykind/Admittance")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    PermittivityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermittivityRatio")
    IonCurrent = URIRef("http://qudt.org/vocab/quantitykind/IonCurrent")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    MassicPower = URIRef("http://qudt.org/vocab/quantitykind/MassicPower")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    Permeability = URIRef("http://qudt.org/vocab/quantitykind/Permeability")
    TimeRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRatio")
    InfiniteMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/InfiniteMultiplicationFactor")
    MolarDensity = URIRef("http://qudt.org/vocab/quantitykind/MolarDensity")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    SourceVoltage = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltage")
    DiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficient")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    HallCoefficient = URIRef("http://qudt.org/vocab/quantitykind/HallCoefficient")
    Landau_GinzburgNumber = URIRef("http://qudt.org/vocab/quantitykind/Landau-GinzburgNumber")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    SourceVoltage = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltage")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    WarpingMoment = URIRef("http://qudt.org/vocab/quantitykind/WarpingMoment")
    AreicChargeDensityOrElectricFluxDensityOrElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/AreicChargeDensityOrElectricFluxDensityOrElectricPolarization")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    ElectricDisplacement = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacement")
    SoundPowerLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPowerLevel")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    OrderOfReflection = URIRef("http://qudt.org/vocab/quantitykind/OrderOfReflection")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    SecondMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondMomentOfArea")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    CorrelatedColorTemperature = URIRef("http://qudt.org/vocab/quantitykind/CorrelatedColorTemperature")
    ThermalCapacitance = URIRef("http://qudt.org/vocab/quantitykind/ThermalCapacitance")
    RadiantIntensity = URIRef("http://qudt.org/vocab/quantitykind/RadiantIntensity")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    MagneticFluxDensityOrMagneticPolarization = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensityOrMagneticPolarization")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    CurvatureFromRadius = URIRef("http://qudt.org/vocab/quantitykind/CurvatureFromRadius")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    TimePercentage = URIRef("http://qudt.org/vocab/quantitykind/TimePercentage")
    AmbientPressure = URIRef("http://qudt.org/vocab/quantitykind/AmbientPressure")
    NeutralRatio = URIRef("http://qudt.org/vocab/quantitykind/NeutralRatio")
    RelativeLuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/RelativeLuminousFlux")
    ThrustToWeightRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToWeightRatio")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    PhotosyntheticPhotonFlux = URIRef("http://qudt.org/vocab/quantitykind/PhotosyntheticPhotonFlux")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    LowerCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/LowerCriticalMagneticFluxDensity")
    LossAngle = URIRef("http://qudt.org/vocab/quantitykind/LossAngle")
    SoundEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SoundEnergyDensity")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    NeutronYieldPerFission = URIRef("http://qudt.org/vocab/quantitykind/NeutronYieldPerFission")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    EccentricityOfOrbit = URIRef("http://qudt.org/vocab/quantitykind/EccentricityOfOrbit")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    AreaTimeTemperature = URIRef("http://qudt.org/vocab/quantitykind/AreaTimeTemperature")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    FlightPathAngle = URIRef("http://qudt.org/vocab/quantitykind/FlightPathAngle")
    HyperfineStructureQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/HyperfineStructureQuantumNumber")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    ThermalConductance = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductance")
    LuminousIntensityDistribution = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensityDistribution")
    SpecificEnthalpy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnthalpy")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    LinkedFlux = URIRef("http://qudt.org/vocab/quantitykind/LinkedFlux")
    ReynoldsNumber = URIRef("http://qudt.org/vocab/quantitykind/ReynoldsNumber")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    IsentropicCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsentropicCompressibility")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    PositiveDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/PositiveDimensionlessRatio")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    SpecificElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/SpecificElectricCharge")
    SoundParticleAcceleration = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleAcceleration")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    MassFraction = URIRef("http://qudt.org/vocab/quantitykind/MassFraction")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    MolalityOfSolute = URIRef("http://qudt.org/vocab/quantitykind/MolalityOfSolute")
    ThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusivity")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    TemperatureBasedVolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedVolumeFlowRate")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    DiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficient")
    LineicMass = URIRef("http://qudt.org/vocab/quantitykind/LineicMass")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    SunProtectionFactorOfAProduct = URIRef("http://qudt.org/vocab/quantitykind/SunProtectionFactorOfAProduct")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    ActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/ActivityConcentration")
    PermeabilityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermeabilityRatio")
    AccelerationOfGravity = URIRef("http://qudt.org/vocab/quantitykind/AccelerationOfGravity")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    MechanicalSurfaceImpedance = URIRef("http://qudt.org/vocab/quantitykind/MechanicalSurfaceImpedance")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    IonDensity = URIRef("http://qudt.org/vocab/quantitykind/IonDensity")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    RadianceFactor = URIRef("http://qudt.org/vocab/quantitykind/RadianceFactor")
    ForceConstant = URIRef("http://qudt.org/vocab/quantitykind/ForceConstant")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    TimeTemperature = URIRef("http://qudt.org/vocab/quantitykind/TimeTemperature")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    Acidity = URIRef("http://qudt.org/vocab/quantitykind/Acidity")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    LinkedFlux = URIRef("http://qudt.org/vocab/quantitykind/LinkedFlux")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    quantitykind = URIRef("http://qudt.org/vocab/quantitykind")
    VoltageRatio = URIRef("http://qudt.org/vocab/quantitykind/VoltageRatio")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    LinearThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/LinearThermalExpansion")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    TorsionalSpringConstant = URIRef("http://qudt.org/vocab/quantitykind/TorsionalSpringConstant")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    AmountOfSubstanceConcentrationOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentrationOfB")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    LineicResistance = URIRef("http://qudt.org/vocab/quantitykind/LineicResistance")
    StateDensityAsExpressionOfAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/StateDensityAsExpressionOfAngularFrequency")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    Reactance = URIRef("http://qudt.org/vocab/quantitykind/Reactance")
    Reluctance = URIRef("http://qudt.org/vocab/quantitykind/Reluctance")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    FirstStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/FirstStageMassRatio")
    NeutronYieldPerAbsorption = URIRef("http://qudt.org/vocab/quantitykind/NeutronYieldPerAbsorption")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    SurfaceActivityDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceActivityDensity")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    PrincipalQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/PrincipalQuantumNumber")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    TemperaturePerTime = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    AngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/AngularCrossSection")
    HeatFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/HeatFluxDensity")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    PropagationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PropagationCoefficient")
    NuclearSpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/NuclearSpinQuantumNumber")
    BulkModulus = URIRef("http://qudt.org/vocab/quantitykind/BulkModulus")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    RateOfRiseOfVoltage = URIRef("http://qudt.org/vocab/quantitykind/RateOfRiseOfVoltage")
    ResistancePercentage = URIRef("http://qudt.org/vocab/quantitykind/ResistancePercentage")
    LengthPercentage = URIRef("http://qudt.org/vocab/quantitykind/LengthPercentage")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    IonCurrent = URIRef("http://qudt.org/vocab/quantitykind/IonCurrent")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    SoundReductionIndex = URIRef("http://qudt.org/vocab/quantitykind/SoundReductionIndex")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    BoilingPoint = URIRef("http://qudt.org/vocab/quantitykind/BoilingPoint")
    RadianceFactor = URIRef("http://qudt.org/vocab/quantitykind/RadianceFactor")
    VolumicElectromagneticEnergy = URIRef("http://qudt.org/vocab/quantitykind/VolumicElectromagneticEnergy")
    ThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusivity")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    SignalStrength = URIRef("http://qudt.org/vocab/quantitykind/SignalStrength")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    LengthMolarEnergy = URIRef("http://qudt.org/vocab/quantitykind/LengthMolarEnergy")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    MagneticQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/MagneticQuantumNumber")
    PositiveDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/PositiveDimensionlessRatio")
    MolarFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MolarFlowRate")
    TorsionalRigidity = URIRef("http://qudt.org/vocab/quantitykind/TorsionalRigidity")
    ComplexPower = URIRef("http://qudt.org/vocab/quantitykind/ComplexPower")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    ElectromagneticPermeability = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeability")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    RF_Power = URIRef("http://qudt.org/vocab/quantitykind/RF-Power")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    LinearThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/LinearThermalExpansion")
    OrderOfReflection = URIRef("http://qudt.org/vocab/quantitykind/OrderOfReflection")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    GeneralizedMomentum = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedMomentum")
    VideoFrameRate = URIRef("http://qudt.org/vocab/quantitykind/VideoFrameRate")
    MassPerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerAreaTime")
    Impulse = URIRef("http://qudt.org/vocab/quantitykind/Impulse")
    PowerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerArea")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    MassicHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MassicHeatCapacity")
    ParticleNumberDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleNumberDensity")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    Compressibility = URIRef("http://qudt.org/vocab/quantitykind/Compressibility")
    GeneralizedVelocity = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedVelocity")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    RichardsonConstant = URIRef("http://qudt.org/vocab/quantitykind/RichardsonConstant")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    EnergyFluence = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluence")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    RelativePartialPressure = URIRef("http://qudt.org/vocab/quantitykind/RelativePartialPressure")
    Vorticity = URIRef("http://qudt.org/vocab/quantitykind/Vorticity")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    Conductance = URIRef("http://qudt.org/vocab/quantitykind/Conductance")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    ElectromagneticPermeabilityRatio = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeabilityRatio")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    PoissonRatio = URIRef("http://qudt.org/vocab/quantitykind/PoissonRatio")
    RelativeMassRatioOfVapour = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassRatioOfVapour")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    LandeGFactor = URIRef("http://qudt.org/vocab/quantitykind/LandeGFactor")
    ModulusOfAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfAdmittance")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    PRODUCT_OF_INERTIA_Y = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA_Y")
    AbsorbedDose = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDose")
    DensityInCombustionChamber = URIRef("http://qudt.org/vocab/quantitykind/DensityInCombustionChamber")
    ElectromagneticEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticEnergyDensity")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    Compressibility = URIRef("http://qudt.org/vocab/quantitykind/Compressibility")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    Asset = URIRef("http://qudt.org/vocab/quantitykind/Asset")
    WarpingMoment = URIRef("http://qudt.org/vocab/quantitykind/WarpingMoment")
    MolarOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/MolarOpticalRotatoryPower")
    Constringence = URIRef("http://qudt.org/vocab/quantitykind/Constringence")
    FastFissionFactor = URIRef("http://qudt.org/vocab/quantitykind/FastFissionFactor")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    LinearDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearDensity")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    Dimensionless = URIRef("http://qudt.org/vocab/quantitykind/Dimensionless")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    SecondRadiationConstant = URIRef("http://qudt.org/vocab/quantitykind/SecondRadiationConstant")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    MaximumOperatingPressure = URIRef("http://qudt.org/vocab/quantitykind/MaximumOperatingPressure")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    SpecificInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificInternalEnergy")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    ElectricDisplacement = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacement")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    InverseLength = URIRef("http://qudt.org/vocab/quantitykind/InverseLength")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    ChemicalConsumptionPerMass = URIRef("http://qudt.org/vocab/quantitykind/ChemicalConsumptionPerMass")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    TemperatureRateOfChange = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRateOfChange")
    AbsorbedDoseRate = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDoseRate")
    SecondStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SecondStageMassRatio")
    TorsionalSpringConstant = URIRef("http://qudt.org/vocab/quantitykind/TorsionalSpringConstant")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    DimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/DimensionlessRatio")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    LogarithmicMedianInformationFlow_SourceToBaseE = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicMedianInformationFlow_SourceToBaseE")
    EffectiveMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMultiplicationFactor")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    Permittivity = URIRef("http://qudt.org/vocab/quantitykind/Permittivity")
    BitTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/BitTransmissionRate")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    ReynoldsNumber = URIRef("http://qudt.org/vocab/quantitykind/ReynoldsNumber")
    DigitRate = URIRef("http://qudt.org/vocab/quantitykind/DigitRate")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    ModulusOfAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfAdmittance")
    AreaChargeDensity = URIRef("http://qudt.org/vocab/quantitykind/AreaChargeDensity")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    TotalAngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentum")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    MolarRefractivity = URIRef("http://qudt.org/vocab/quantitykind/MolarRefractivity")
    CutoffCurrentRating = URIRef("http://qudt.org/vocab/quantitykind/CutoffCurrentRating")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    Mobility = URIRef("http://qudt.org/vocab/quantitykind/Mobility")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    ThrusterPowerToThrustEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThrusterPowerToThrustEfficiency")
    BoilingPoint = URIRef("http://qudt.org/vocab/quantitykind/BoilingPoint")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    Slowing_DownDensity = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownDensity")
    CoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/CoefficientOfHeatTransfer")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    PowerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerArea")
    ThrustToWeightRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToWeightRatio")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    MassFractionOfDryMatter = URIRef("http://qudt.org/vocab/quantitykind/MassFractionOfDryMatter")
    ComplexFrequency_Real = URIRef("http://qudt.org/vocab/quantitykind/ComplexFrequency_Real")
    AbsorbedDoseRate = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDoseRate")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    AtomicStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/AtomicStoppingPower")
    AreaPerLength = URIRef("http://qudt.org/vocab/quantitykind/AreaPerLength")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    VentilationRatePerFloorArea = URIRef("http://qudt.org/vocab/quantitykind/VentilationRatePerFloorArea")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    RF_Power = URIRef("http://qudt.org/vocab/quantitykind/RF-Power")
    ThrustToMassRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToMassRatio")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    FermiTemperature = URIRef("http://qudt.org/vocab/quantitykind/FermiTemperature")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    RelativePressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/RelativePressureCoefficient")
    Piece = URIRef("http://qudt.org/vocab/quantitykind/Piece")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    MassRatio = URIRef("http://qudt.org/vocab/quantitykind/MassRatio")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    BioconcentrationFactor = URIRef("http://qudt.org/vocab/quantitykind/BioconcentrationFactor")
    PressureBasedVelocity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedVelocity")
    ElectricalResistance = URIRef("http://qudt.org/vocab/quantitykind/ElectricalResistance")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    TemperatureDifference = URIRef("http://qudt.org/vocab/quantitykind/TemperatureDifference")
    PhaseCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PhaseCoefficient")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    ThermalCoefficientOfLinearExpansion = URIRef("http://qudt.org/vocab/quantitykind/ThermalCoefficientOfLinearExpansion")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    MassFraction = URIRef("http://qudt.org/vocab/quantitykind/MassFraction")
    MagnetomotiveForce = URIRef("http://qudt.org/vocab/quantitykind/MagnetomotiveForce")
    CatalyticActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivityConcentration")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    Duv = URIRef("http://qudt.org/vocab/quantitykind/Duv")
    VolumicElectromagneticEnergy = URIRef("http://qudt.org/vocab/quantitykind/VolumicElectromagneticEnergy")
    DebyeTemperature = URIRef("http://qudt.org/vocab/quantitykind/DebyeTemperature")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    HyperfineStructureQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/HyperfineStructureQuantumNumber")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    AtmosphericPressure = URIRef("http://qudt.org/vocab/quantitykind/AtmosphericPressure")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    ThermalConductance = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductance")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    RankineTemperature = URIRef("http://qudt.org/vocab/quantitykind/RankineTemperature")
    ThermalEnergyLength = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergyLength")
    PermittivityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermittivityRatio")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    PressureBasedDynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedDynamicViscosity")
    VoltagePhasor = URIRef("http://qudt.org/vocab/quantitykind/VoltagePhasor")
    Reflectance = URIRef("http://qudt.org/vocab/quantitykind/Reflectance")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    ElectrolyticConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectrolyticConductivity")
    MagneticSusceptability = URIRef("http://qudt.org/vocab/quantitykind/MagneticSusceptability")
    Permeance = URIRef("http://qudt.org/vocab/quantitykind/Permeance")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    LarmorAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/LarmorAngularFrequency")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    DiastolicBloodPressure = URIRef("http://qudt.org/vocab/quantitykind/DiastolicBloodPressure")
    OsmoticPressure = URIRef("http://qudt.org/vocab/quantitykind/OsmoticPressure")
    SoundVolumeVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundVolumeVelocity")
    GFactorOfNucleus = URIRef("http://qudt.org/vocab/quantitykind/GFactorOfNucleus")
    Absorptance = URIRef("http://qudt.org/vocab/quantitykind/Absorptance")
    RespiratoryRate = URIRef("http://qudt.org/vocab/quantitykind/RespiratoryRate")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    GrowingDegreeDay_Cereal = URIRef("http://qudt.org/vocab/quantitykind/GrowingDegreeDay_Cereal")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    ParticleFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluenceRate")
    SoundParticleAcceleration = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleAcceleration")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    LinearAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAbsorptionCoefficient")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    RelativeLuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/RelativeLuminousFlux")
    SecondAxialMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondAxialMomentOfArea")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    Prevalence = URIRef("http://qudt.org/vocab/quantitykind/Prevalence")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    VolumicElectromagneticEnergy = URIRef("http://qudt.org/vocab/quantitykind/VolumicElectromagneticEnergy")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    Luminance = URIRef("http://qudt.org/vocab/quantitykind/Luminance")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    Piece = URIRef("http://qudt.org/vocab/quantitykind/Piece")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    SpectralCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralCrossSection")
    PowerPerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerPerArea")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    MassFractionOfWater = URIRef("http://qudt.org/vocab/quantitykind/MassFractionOfWater")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    OrbitalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/OrbitalAngularMomentumQuantumNumber")
    SpecificActivity = URIRef("http://qudt.org/vocab/quantitykind/SpecificActivity")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    SecondMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondMomentOfArea")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    AmountOfSubstancePerUnitVolume = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitVolume")
    HeatFlowRatePerUnitArea = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRatePerUnitArea")
    ThermodynamicCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicCriticalMagneticFluxDensity")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    MolarEntropy = URIRef("http://qudt.org/vocab/quantitykind/MolarEntropy")
    Mobility = URIRef("http://qudt.org/vocab/quantitykind/Mobility")
    PrincipalQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/PrincipalQuantumNumber")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    TemperatureBasedLength = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedLength")
    NeutronDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionCoefficient")
    PressureBasedVolume = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedVolume")
    SpectralRadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SpectralRadiantEnergyDensity")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    Duv = URIRef("http://qudt.org/vocab/quantitykind/Duv")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    FundamentalReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalReciprocalLatticeVector")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    ThermalAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalAdmittance")
    SecondAxialMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondAxialMomentOfArea")
    PhotosyntheticPhotonFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/PhotosyntheticPhotonFluxDensity")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    AtomScatteringFactor = URIRef("http://qudt.org/vocab/quantitykind/AtomScatteringFactor")
    ExposureOfIonizingRadiation = URIRef("http://qudt.org/vocab/quantitykind/ExposureOfIonizingRadiation")
    ElectricQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricQuadrupoleMoment")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    PlanckFunction = URIRef("http://qudt.org/vocab/quantitykind/PlanckFunction")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    CoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/CoefficientOfHeatTransfer")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    MolarOpticalRotationalAbility = URIRef("http://qudt.org/vocab/quantitykind/MolarOpticalRotationalAbility")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    AreaPerTime = URIRef("http://qudt.org/vocab/quantitykind/AreaPerTime")
    SpecificEntropy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEntropy")
    MolarThermalCapacity = URIRef("http://qudt.org/vocab/quantitykind/MolarThermalCapacity")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    ElectricChargeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeDensity")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    PressureBasedMolality = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedMolality")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    LiquidVolume = URIRef("http://qudt.org/vocab/quantitykind/LiquidVolume")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    PowerPerAreaQuarticTemperature = URIRef("http://qudt.org/vocab/quantitykind/PowerPerAreaQuarticTemperature")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    SoundExposure = URIRef("http://qudt.org/vocab/quantitykind/SoundExposure")
    MassNumber = URIRef("http://qudt.org/vocab/quantitykind/MassNumber")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    MeltingPoint = URIRef("http://qudt.org/vocab/quantitykind/MeltingPoint")
    MicroCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/MicroCanonicalPartitionFunction")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    TemperatureBasedQuantity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedQuantity")
    AtmosphericHydroxylationRate = URIRef("http://qudt.org/vocab/quantitykind/AtmosphericHydroxylationRate")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    MassEnergyTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassEnergyTransferCoefficient")
    Count = URIRef("http://qudt.org/vocab/quantitykind/Count")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    Radiosity = URIRef("http://qudt.org/vocab/quantitykind/Radiosity")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    PressureInRelationToVolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/PressureInRelationToVolumeFlowRate")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    MechanicalMobility = URIRef("http://qudt.org/vocab/quantitykind/MechanicalMobility")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    PositiveDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/PositiveDimensionlessRatio")
    NormalizedDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/NormalizedDimensionlessRatio")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    MassPerTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerTime")
    KineticOrThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticOrThermalEnergy")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    InverseTime = URIRef("http://qudt.org/vocab/quantitykind/InverseTime")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    MassRatioOfWaterToDryMatter = URIRef("http://qudt.org/vocab/quantitykind/MassRatioOfWaterToDryMatter")
    ElectrolyticConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectrolyticConductivity")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    ElectricDisplacementField = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacementField")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    ReciprocalVoltage = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalVoltage")
    GeneFamilyAbundance = URIRef("http://qudt.org/vocab/quantitykind/GeneFamilyAbundance")
    ReciprocalElectricResistance = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalElectricResistance")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    FirstStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/FirstStageMassRatio")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    ParticleFluence = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluence")
    ElectricCurrentPhasor = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPhasor")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    PropellantMeanBulkTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantMeanBulkTemperature")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    ElectricFlux = URIRef("http://qudt.org/vocab/quantitykind/ElectricFlux")
    ResistanceRatio = URIRef("http://qudt.org/vocab/quantitykind/ResistanceRatio")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    EquilibriumConstantBasedOnConcentration = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantBasedOnConcentration")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    ThermalInsulance = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulance")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    AreaAngle = URIRef("http://qudt.org/vocab/quantitykind/AreaAngle")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    BevelGearPitchAngle = URIRef("http://qudt.org/vocab/quantitykind/BevelGearPitchAngle")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    ExitPlaneTemperature = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneTemperature")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    BitRate = URIRef("http://qudt.org/vocab/quantitykind/BitRate")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    MagneticField = URIRef("http://qudt.org/vocab/quantitykind/MagneticField")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    ThermalExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalExpansionCoefficient")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    Temperature = URIRef("http://qudt.org/vocab/quantitykind/Temperature")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    PermittivityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermittivityRatio")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    ElectricFlux = URIRef("http://qudt.org/vocab/quantitykind/ElectricFlux")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    StructureFactor = URIRef("http://qudt.org/vocab/quantitykind/StructureFactor")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    LinearIonization = URIRef("http://qudt.org/vocab/quantitykind/LinearIonization")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    MassNumber = URIRef("http://qudt.org/vocab/quantitykind/MassNumber")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    PermittivityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermittivityRatio")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    LuminousExposure = URIRef("http://qudt.org/vocab/quantitykind/LuminousExposure")
    MassicHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MassicHeatCapacity")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    ThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusivity")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    CatalyticActivity = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivity")
    PermittivityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermittivityRatio")
    SpecificOpticalRotationalAbility = URIRef("http://qudt.org/vocab/quantitykind/SpecificOpticalRotationalAbility")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    MolecularMass = URIRef("http://qudt.org/vocab/quantitykind/MolecularMass")
    TotalIonization = URIRef("http://qudt.org/vocab/quantitykind/TotalIonization")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    DragCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DragCoefficient")
    SecondMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondMomentOfArea")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    SurfaceRelatedVolumeFlow = URIRef("http://qudt.org/vocab/quantitykind/SurfaceRelatedVolumeFlow")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    ForcePerLength = URIRef("http://qudt.org/vocab/quantitykind/ForcePerLength")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    PressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PressureCoefficient")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    EnergyFluence = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluence")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    EnergyFluence = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluence")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    AngularReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/AngularReciprocalLatticeVector")
    BioconcentrationFactor = URIRef("http://qudt.org/vocab/quantitykind/BioconcentrationFactor")
    AreaTime = URIRef("http://qudt.org/vocab/quantitykind/AreaTime")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    CatalyticActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivityConcentration")
    VolumicElectromagneticEnergy = URIRef("http://qudt.org/vocab/quantitykind/VolumicElectromagneticEnergy")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    PermittivityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermittivityRatio")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    InverseLength = URIRef("http://qudt.org/vocab/quantitykind/InverseLength")
    LossFactor = URIRef("http://qudt.org/vocab/quantitykind/LossFactor")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    SpecificElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/SpecificElectricCharge")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    LinearEnergyTransfer = URIRef("http://qudt.org/vocab/quantitykind/LinearEnergyTransfer")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    IonDensity = URIRef("http://qudt.org/vocab/quantitykind/IonDensity")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    PressureBasedMass = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedMass")
    RadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergyDensity")
    PlanckFunction = URIRef("http://qudt.org/vocab/quantitykind/PlanckFunction")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    TemperatureBasedDynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedDynamicViscosity")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    MOMENT_OF_INERTIA_Z = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Z")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    NapierianAbsorbance = URIRef("http://qudt.org/vocab/quantitykind/NapierianAbsorbance")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    DimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/DimensionlessRatio")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    ForcePerLength = URIRef("http://qudt.org/vocab/quantitykind/ForcePerLength")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    Dissipance = URIRef("http://qudt.org/vocab/quantitykind/Dissipance")
    RadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergyDensity")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    TemperatureRateOfChange = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRateOfChange")
    TemperaturePerTime = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    MolarThermalCapacity = URIRef("http://qudt.org/vocab/quantitykind/MolarThermalCapacity")
    FermiAngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/FermiAngularWavenumber")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    LengthRatio = URIRef("http://qudt.org/vocab/quantitykind/LengthRatio")
    ElectricDisplacement = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacement")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    Dimensionless = URIRef("http://qudt.org/vocab/quantitykind/Dimensionless")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    MassieuFunction = URIRef("http://qudt.org/vocab/quantitykind/MassieuFunction")
    MolarAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAttenuationCoefficient")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    BindingFraction = URIRef("http://qudt.org/vocab/quantitykind/BindingFraction")
    SingleStageLauncherMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SingleStageLauncherMassRatio")
    FahrenheitTemperature = URIRef("http://qudt.org/vocab/quantitykind/FahrenheitTemperature")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    SoilAdsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SoilAdsorptionCoefficient")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    DotsPerInch = URIRef("http://qudt.org/vocab/quantitykind/DotsPerInch")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    LuminousExitance = URIRef("http://qudt.org/vocab/quantitykind/LuminousExitance")
    OsmoticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/OsmoticCoefficient")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    AngleOfOpticalRotation = URIRef("http://qudt.org/vocab/quantitykind/AngleOfOpticalRotation")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    Temperature = URIRef("http://qudt.org/vocab/quantitykind/Temperature")
    AngleOfAttack = URIRef("http://qudt.org/vocab/quantitykind/AngleOfAttack")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    DatasetOfBytes = URIRef("http://qudt.org/vocab/quantitykind/DatasetOfBytes")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    DebyeAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularFrequency")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    Luminance = URIRef("http://qudt.org/vocab/quantitykind/Luminance")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    TotalAngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentum")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    ActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/ActivityConcentration")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    BulkModulus = URIRef("http://qudt.org/vocab/quantitykind/BulkModulus")
    Mobility = URIRef("http://qudt.org/vocab/quantitykind/Mobility")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    DataTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/DataTransmissionRate")
    AngleOfOpticalRotation = URIRef("http://qudt.org/vocab/quantitykind/AngleOfOpticalRotation")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    AreaTemperature = URIRef("http://qudt.org/vocab/quantitykind/AreaTemperature")
    Ratio = URIRef("http://qudt.org/vocab/quantitykind/Ratio")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    EinsteinTransitionProbabilityForSpontaneousOrInducedEmissionAndAbsorption = URIRef("http://qudt.org/vocab/quantitykind/EinsteinTransitionProbabilityForSpontaneousOrInducedEmissionAndAbsorption")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    DebyeAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularFrequency")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    SpecificGibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificGibbsEnergy")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    RelativeMassDensity = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDensity")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    AuxillaryMagneticField = URIRef("http://qudt.org/vocab/quantitykind/AuxillaryMagneticField")
    Radioactivity = URIRef("http://qudt.org/vocab/quantitykind/Radioactivity")
    LinearElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrentDensity")
    StateDensityAsExpressionOfAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/StateDensityAsExpressionOfAngularFrequency")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    LinearAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAttenuationCoefficient")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    CyclotronAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/CyclotronAngularFrequency")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    DynamicPressure = URIRef("http://qudt.org/vocab/quantitykind/DynamicPressure")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    ThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusivity")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    SpecificGibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificGibbsEnergy")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    HeatFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/HeatFluxDensity")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    RateOfChangeOfTemperature = URIRef("http://qudt.org/vocab/quantitykind/RateOfChangeOfTemperature")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    AngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/AngularCrossSection")
    Curvature = URIRef("http://qudt.org/vocab/quantitykind/Curvature")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    InversePermittivity = URIRef("http://qudt.org/vocab/quantitykind/InversePermittivity")
    MassStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/MassStoppingPower")
    AreaRatio = URIRef("http://qudt.org/vocab/quantitykind/AreaRatio")
    ElectricCurrentPerUnitTemperature = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerUnitTemperature")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    AreaPerLength = URIRef("http://qudt.org/vocab/quantitykind/AreaPerLength")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    MassicActivity = URIRef("http://qudt.org/vocab/quantitykind/MassicActivity")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    SpectralDensityOfVibrationalModes = URIRef("http://qudt.org/vocab/quantitykind/SpectralDensityOfVibrationalModes")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    NonActivePower = URIRef("http://qudt.org/vocab/quantitykind/NonActivePower")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    MassPerLength = URIRef("http://qudt.org/vocab/quantitykind/MassPerLength")
    SunProtectionFactorOfAProduct = URIRef("http://qudt.org/vocab/quantitykind/SunProtectionFactorOfAProduct")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    ElectricCurrentPhasor = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPhasor")
    PermeabilityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermeabilityRatio")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    AbsorbedDose = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDose")
    InformationContentExpressedAsALogarithmToBase2 = URIRef("http://qudt.org/vocab/quantitykind/InformationContentExpressedAsALogarithmToBase2")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    VoltageRatio = URIRef("http://qudt.org/vocab/quantitykind/VoltageRatio")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    NeutronYieldPerFission = URIRef("http://qudt.org/vocab/quantitykind/NeutronYieldPerFission")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    MolarAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAbsorptionCoefficient")
    SpecificThrust = URIRef("http://qudt.org/vocab/quantitykind/SpecificThrust")
    InfiniteMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/InfiniteMultiplicationFactor")
    PayloadRatio = URIRef("http://qudt.org/vocab/quantitykind/PayloadRatio")
    LossFactor = URIRef("http://qudt.org/vocab/quantitykind/LossFactor")
    SpecificHeatCapacityAtConstantPressure = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantPressure")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    EinsteinTransitionProbability = URIRef("http://qudt.org/vocab/quantitykind/EinsteinTransitionProbability")
    SpecificPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificPower")
    VolumetricHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/VolumetricHeatCapacity")
    SoundPressure = URIRef("http://qudt.org/vocab/quantitykind/SoundPressure")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    SoundVolumeVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundVolumeVelocity")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    ResonanceEscapeProbabilityForFission = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbabilityForFission")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    SingleStageLauncherMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SingleStageLauncherMassRatio")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    AreaChargeDensity = URIRef("http://qudt.org/vocab/quantitykind/AreaChargeDensity")
    LorenzCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LorenzCoefficient")
    ThermalUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactor")
    MicroCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/MicroCanonicalPartitionFunction")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    InverseEnergy = URIRef("http://qudt.org/vocab/quantitykind/InverseEnergy")
    CubicElectricDipoleMomentPerSquareEnergy = URIRef("http://qudt.org/vocab/quantitykind/CubicElectricDipoleMomentPerSquareEnergy")
    SoundExposure = URIRef("http://qudt.org/vocab/quantitykind/SoundExposure")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    DoseEquivalent = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalent")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    GeneralizedForce = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedForce")
    CostPerArea = URIRef("http://qudt.org/vocab/quantitykind/CostPerArea")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    SpecificInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificInternalEnergy")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    MolecularConcentration = URIRef("http://qudt.org/vocab/quantitykind/MolecularConcentration")
    MortalityRate = URIRef("http://qudt.org/vocab/quantitykind/MortalityRate")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    SpecificInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificInternalEnergy")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    ReflectanceFactor = URIRef("http://qudt.org/vocab/quantitykind/ReflectanceFactor")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    StrainEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/StrainEnergyDensity")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    Mobility = URIRef("http://qudt.org/vocab/quantitykind/Mobility")
    MultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/MultiplicationFactor")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    Dimensionless = URIRef("http://qudt.org/vocab/quantitykind/Dimensionless")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    SpecificOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificOpticalRotatoryPower")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    SurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceDensity")
    EinsteinTransitionProbability = URIRef("http://qudt.org/vocab/quantitykind/EinsteinTransitionProbability")
    Resistivity = URIRef("http://qudt.org/vocab/quantitykind/Resistivity")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    LiftCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LiftCoefficient")
    Reactance = URIRef("http://qudt.org/vocab/quantitykind/Reactance")
    CoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/CoefficientOfHeatTransfer")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    TemperaturePerTime = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    KinematicViscosityOrDiffusionConstantOrThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosityOrDiffusionConstantOrThermalDiffusivity")
    LengthPercentage = URIRef("http://qudt.org/vocab/quantitykind/LengthPercentage")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    PressureRatio = URIRef("http://qudt.org/vocab/quantitykind/PressureRatio")
    StandardChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/StandardChemicalPotential")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    ModulusOfRotationalSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfRotationalSubgradeReaction")
    AtomicStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/AtomicStoppingPower")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    Basicity = URIRef("http://qudt.org/vocab/quantitykind/Basicity")
    FlightPathAngle = URIRef("http://qudt.org/vocab/quantitykind/FlightPathAngle")
    PressureBasedElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedElectricCurrent")
    PressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PressureCoefficient")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    Reactivity = URIRef("http://qudt.org/vocab/quantitykind/Reactivity")
    ScalarMagneticPotential = URIRef("http://qudt.org/vocab/quantitykind/ScalarMagneticPotential")
    NeutronYieldPerFission = URIRef("http://qudt.org/vocab/quantitykind/NeutronYieldPerFission")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    LowerCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/LowerCriticalMagneticFluxDensity")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    MassConcentration = URIRef("http://qudt.org/vocab/quantitykind/MassConcentration")
    GeneralizedCoordinate = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedCoordinate")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    AreicMass = URIRef("http://qudt.org/vocab/quantitykind/AreicMass")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    EinsteinTransitionProbability = URIRef("http://qudt.org/vocab/quantitykind/EinsteinTransitionProbability")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    LogarithmicFrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyInterval")
    SoundParticleVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleVelocity")
    DonorDensity = URIRef("http://qudt.org/vocab/quantitykind/DonorDensity")
    ExhaustGasesSpecificHeat = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasesSpecificHeat")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    Speed = URIRef("http://qudt.org/vocab/quantitykind/Speed")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    FundamentalReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalReciprocalLatticeVector")
    RF_Power = URIRef("http://qudt.org/vocab/quantitykind/RF-Power")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    VoltageRatio = URIRef("http://qudt.org/vocab/quantitykind/VoltageRatio")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    ResistancePercentage = URIRef("http://qudt.org/vocab/quantitykind/ResistancePercentage")
    MutualInductance = URIRef("http://qudt.org/vocab/quantitykind/MutualInductance")
    MadelungConstant = URIRef("http://qudt.org/vocab/quantitykind/MadelungConstant")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    EquilibriumConstantBasedOnConcentration = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantBasedOnConcentration")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    InitialExpansionRatio = URIRef("http://qudt.org/vocab/quantitykind/InitialExpansionRatio")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    AmountOfSubstancePerUnitVolume = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitVolume")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    TotalPressure = URIRef("http://qudt.org/vocab/quantitykind/TotalPressure")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    LogarithmicMedianInformationFlow_SourceToBaseE = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicMedianInformationFlow_SourceToBaseE")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    ForcePerAngle = URIRef("http://qudt.org/vocab/quantitykind/ForcePerAngle")
    Population = URIRef("http://qudt.org/vocab/quantitykind/Population")
    SignalDetectionThreshold = URIRef("http://qudt.org/vocab/quantitykind/SignalDetectionThreshold")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    SpecificEnthalpy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnthalpy")
    Conductance = URIRef("http://qudt.org/vocab/quantitykind/Conductance")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    ActivityThresholds = URIRef("http://qudt.org/vocab/quantitykind/ActivityThresholds")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    KermaRate = URIRef("http://qudt.org/vocab/quantitykind/KermaRate")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    ThermalExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalExpansionCoefficient")
    MagneticPolarization = URIRef("http://qudt.org/vocab/quantitykind/MagneticPolarization")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    MassFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MassFluxDensity")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    SpecificModulus = URIRef("http://qudt.org/vocab/quantitykind/SpecificModulus")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    SystolicBloodPressure = URIRef("http://qudt.org/vocab/quantitykind/SystolicBloodPressure")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    ThermalUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactor")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    MolarDensity = URIRef("http://qudt.org/vocab/quantitykind/MolarDensity")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    NuclearQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/NuclearQuadrupoleMoment")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    Exposure = URIRef("http://qudt.org/vocab/quantitykind/Exposure")
    LossFactor = URIRef("http://qudt.org/vocab/quantitykind/LossFactor")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    EnergyFluence = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluence")
    TotalLinearStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalLinearStoppingPower")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    HeartRate = URIRef("http://qudt.org/vocab/quantitykind/HeartRate")
    ThermalAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalAdmittance")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    VolumeThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/VolumeThermalExpansion")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    Vorticity = URIRef("http://qudt.org/vocab/quantitykind/Vorticity")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    TemperatureBasedVolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedVolumeFlowRate")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    ThermalExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalExpansionCoefficient")
    TorquePerLength = URIRef("http://qudt.org/vocab/quantitykind/TorquePerLength")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    Period = URIRef("http://qudt.org/vocab/quantitykind/Period")
    EquilibriumConstantOnPressureBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnPressureBasis")
    SecondMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondMomentOfArea")
    ByteTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/ByteTransmissionRate")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    Reactance = URIRef("http://qudt.org/vocab/quantitykind/Reactance")
    Luminance = URIRef("http://qudt.org/vocab/quantitykind/Luminance")
    MolarEntropy = URIRef("http://qudt.org/vocab/quantitykind/MolarEntropy")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    Reactance = URIRef("http://qudt.org/vocab/quantitykind/Reactance")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    AmountOfSubstanceFractionOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFractionOfB")
    Landau_GinzburgNumber = URIRef("http://qudt.org/vocab/quantitykind/Landau-GinzburgNumber")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    MassFractionOfDryMatter = URIRef("http://qudt.org/vocab/quantitykind/MassFractionOfDryMatter")
    SpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/SpinQuantumNumber")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    ByteRate = URIRef("http://qudt.org/vocab/quantitykind/ByteRate")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    TemperatureGradient = URIRef("http://qudt.org/vocab/quantitykind/TemperatureGradient")
    PressureLossPerLength = URIRef("http://qudt.org/vocab/quantitykind/PressureLossPerLength")
    ExitPlanePressure = URIRef("http://qudt.org/vocab/quantitykind/ExitPlanePressure")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    InverseLength = URIRef("http://qudt.org/vocab/quantitykind/InverseLength")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    AtomicEnergy = URIRef("http://qudt.org/vocab/quantitykind/AtomicEnergy")
    EnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensity")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    GFactorOfNucleus = URIRef("http://qudt.org/vocab/quantitykind/GFactorOfNucleus")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    AreaThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/AreaThermalExpansion")
    AngleOfAttack = URIRef("http://qudt.org/vocab/quantitykind/AngleOfAttack")
    Action = URIRef("http://qudt.org/vocab/quantitykind/Action")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    LiftCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LiftCoefficient")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    NozzleThroatPressure = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatPressure")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    NeutronYieldPerAbsorption = URIRef("http://qudt.org/vocab/quantitykind/NeutronYieldPerAbsorption")
    Loudness = URIRef("http://qudt.org/vocab/quantitykind/Loudness")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    PermeabilityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermeabilityRatio")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    MOMENT_OF_INERTIA_Y = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Y")
    ParticleSourceDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleSourceDensity")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    MassicElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/MassicElectricCurrent")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    FailureRate = URIRef("http://qudt.org/vocab/quantitykind/FailureRate")
    ElectromagneticEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticEnergyDensity")
    Curvature = URIRef("http://qudt.org/vocab/quantitykind/Curvature")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    Gravity_API = URIRef("http://qudt.org/vocab/quantitykind/Gravity_API")
    QualityFactor = URIRef("http://qudt.org/vocab/quantitykind/QualityFactor")
    ThomsonCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThomsonCoefficient")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    EnergyDensityOfStates = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensityOfStates")
    SpecificHelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificHelmholtzEnergy")
    LossAngle = URIRef("http://qudt.org/vocab/quantitykind/LossAngle")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    PermittivityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermittivityRatio")
    AcceptorDensity = URIRef("http://qudt.org/vocab/quantitykind/AcceptorDensity")
    SpectralAngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralAngularCrossSection")
    SpecificHelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificHelmholtzEnergy")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    Duv = URIRef("http://qudt.org/vocab/quantitykind/Duv")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    SurfaceActivityDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceActivityDensity")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    ForcePerLength = URIRef("http://qudt.org/vocab/quantitykind/ForcePerLength")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    LineicTorque = URIRef("http://qudt.org/vocab/quantitykind/LineicTorque")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    LinearElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrentDensity")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    PhaseSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/PhaseSpeedOfSound")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    GFactorOfNucleus = URIRef("http://qudt.org/vocab/quantitykind/GFactorOfNucleus")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    SerumOrPlasmaLevel = URIRef("http://qudt.org/vocab/quantitykind/SerumOrPlasmaLevel")
    MagneticSusceptability = URIRef("http://qudt.org/vocab/quantitykind/MagneticSusceptability")
    ElectricConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectricConductivity")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    PressureRatio = URIRef("http://qudt.org/vocab/quantitykind/PressureRatio")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    EnergyFluence = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluence")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    LossAngle = URIRef("http://qudt.org/vocab/quantitykind/LossAngle")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    DisplacementCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrentDensity")
    ElectricCurrentPerUnitTemperature = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerUnitTemperature")
    Non_LeakageProbability = URIRef("http://qudt.org/vocab/quantitykind/Non-LeakageProbability")
    ThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusivity")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    InformationContentExpressedAsALogarithmToBase10 = URIRef("http://qudt.org/vocab/quantitykind/InformationContentExpressedAsALogarithmToBase10")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    SecondOrderReactionRateConstant = URIRef("http://qudt.org/vocab/quantitykind/SecondOrderReactionRateConstant")
    LengthTemperature = URIRef("http://qudt.org/vocab/quantitykind/LengthTemperature")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    MobilityRatio = URIRef("http://qudt.org/vocab/quantitykind/MobilityRatio")
    AreaChargeDensity = URIRef("http://qudt.org/vocab/quantitykind/AreaChargeDensity")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    Resistivity = URIRef("http://qudt.org/vocab/quantitykind/Resistivity")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    Short_RangeOrderParameter = URIRef("http://qudt.org/vocab/quantitykind/Short-RangeOrderParameter")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    TorqueConstant = URIRef("http://qudt.org/vocab/quantitykind/TorqueConstant")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    Solubility_Water = URIRef("http://qudt.org/vocab/quantitykind/Solubility_Water")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    Susceptance = URIRef("http://qudt.org/vocab/quantitykind/Susceptance")
    AverageLogarithmicEnergyDecrement = URIRef("http://qudt.org/vocab/quantitykind/AverageLogarithmicEnergyDecrement")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    AccelerationOfGravity = URIRef("http://qudt.org/vocab/quantitykind/AccelerationOfGravity")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    SectionModulus = URIRef("http://qudt.org/vocab/quantitykind/SectionModulus")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    LuminousEmittance = URIRef("http://qudt.org/vocab/quantitykind/LuminousEmittance")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    VolumetricFlux = URIRef("http://qudt.org/vocab/quantitykind/VolumetricFlux")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    LinearElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCharge")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    AmountOfSubstanceFractionOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFractionOfB")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    LossAngle = URIRef("http://qudt.org/vocab/quantitykind/LossAngle")
    AuxillaryMagneticField = URIRef("http://qudt.org/vocab/quantitykind/AuxillaryMagneticField")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    DoseEquivalent = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalent")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    TimeRelatedLogarithmicRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRelatedLogarithmicRatio")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    PrincipalQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/PrincipalQuantumNumber")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    CurrencyPerFlight = URIRef("http://qudt.org/vocab/quantitykind/CurrencyPerFlight")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    BindingFraction = URIRef("http://qudt.org/vocab/quantitykind/BindingFraction")
    LinearAcceleration = URIRef("http://qudt.org/vocab/quantitykind/LinearAcceleration")
    SpecificWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificWeight")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    LogarithmicFrequencyIntervalToBase10 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyIntervalToBase10")
    SoundVolumeVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundVolumeVelocity")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    TemperatureAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/TemperatureAmountOfSubstance")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    Lethargy = URIRef("http://qudt.org/vocab/quantitykind/Lethargy")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    NuclearSpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/NuclearSpinQuantumNumber")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    ByteTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/ByteTransmissionRate")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    RelativeLuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/RelativeLuminousFlux")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    DimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/DimensionlessRatio")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    PressureBasedMass = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedMass")
    CorrelatedColorTemperature = URIRef("http://qudt.org/vocab/quantitykind/CorrelatedColorTemperature")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    AngularReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/AngularReciprocalLatticeVector")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    OlfactoryThreshold = URIRef("http://qudt.org/vocab/quantitykind/OlfactoryThreshold")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    LeakageFactor = URIRef("http://qudt.org/vocab/quantitykind/LeakageFactor")
    OlfactoryThreshold = URIRef("http://qudt.org/vocab/quantitykind/OlfactoryThreshold")
    ElectricChargeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeDensity")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    AmountOfBiologicallyActiveSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfBiologicallyActiveSubstance")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    ElectricDisplacementField = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacementField")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    LinearEnergyTransfer = URIRef("http://qudt.org/vocab/quantitykind/LinearEnergyTransfer")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    Mobility = URIRef("http://qudt.org/vocab/quantitykind/Mobility")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    ParticleFluence = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluence")
    DragForce = URIRef("http://qudt.org/vocab/quantitykind/DragForce")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    TemperatureRatio = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRatio")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    PowerPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/PowerPerElectricCharge")
    VolumetricFlux = URIRef("http://qudt.org/vocab/quantitykind/VolumetricFlux")
    SpecificHeatCapacityAtSaturation = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtSaturation")
    LevelWidth = URIRef("http://qudt.org/vocab/quantitykind/LevelWidth")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    DatasetOfBytes = URIRef("http://qudt.org/vocab/quantitykind/DatasetOfBytes")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    CostPerUnitPower = URIRef("http://qudt.org/vocab/quantitykind/CostPerUnitPower")
    TemperatureRateOfChange = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRateOfChange")
    LinearMomentum = URIRef("http://qudt.org/vocab/quantitykind/LinearMomentum")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    AccelerationOfGravity = URIRef("http://qudt.org/vocab/quantitykind/AccelerationOfGravity")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    PhotosyntheticPhotonFlux = URIRef("http://qudt.org/vocab/quantitykind/PhotosyntheticPhotonFlux")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    MutualInductance = URIRef("http://qudt.org/vocab/quantitykind/MutualInductance")
    ResistanceRatio = URIRef("http://qudt.org/vocab/quantitykind/ResistanceRatio")
    LinkedFlux = URIRef("http://qudt.org/vocab/quantitykind/LinkedFlux")
    TimePercentage = URIRef("http://qudt.org/vocab/quantitykind/TimePercentage")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    TimeConstant_Inductance = URIRef("http://qudt.org/vocab/quantitykind/TimeConstant_Inductance")
    AtomicNumber = URIRef("http://qudt.org/vocab/quantitykind/AtomicNumber")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    EquilibriumConstant = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstant")
    NumberOfParticles = URIRef("http://qudt.org/vocab/quantitykind/NumberOfParticles")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    StandardChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/StandardChemicalPotential")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    LineicResistance = URIRef("http://qudt.org/vocab/quantitykind/LineicResistance")
    ActivityRelatedByMass = URIRef("http://qudt.org/vocab/quantitykind/ActivityRelatedByMass")
    EnergyDensityOfStates = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensityOfStates")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    MassConcentrationOfWaterVapour = URIRef("http://qudt.org/vocab/quantitykind/MassConcentrationOfWaterVapour")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    PhotoThresholdOfAwarenessFunction = URIRef("http://qudt.org/vocab/quantitykind/PhotoThresholdOfAwarenessFunction")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    TorsionalSpringConstant = URIRef("http://qudt.org/vocab/quantitykind/TorsionalSpringConstant")
    RatioOfSpecificHeatCapacities = URIRef("http://qudt.org/vocab/quantitykind/RatioOfSpecificHeatCapacities")
    OsmoticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/OsmoticCoefficient")
    MassPerEnergy = URIRef("http://qudt.org/vocab/quantitykind/MassPerEnergy")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    Solubility_Water = URIRef("http://qudt.org/vocab/quantitykind/Solubility_Water")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    InformationContentExpressedAsALogarithmToBase2 = URIRef("http://qudt.org/vocab/quantitykind/InformationContentExpressedAsALogarithmToBase2")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    LarmorAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/LarmorAngularFrequency")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    FUEL_BIAS = URIRef("http://qudt.org/vocab/quantitykind/FUEL-BIAS")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    ExchangeIntegral = URIRef("http://qudt.org/vocab/quantitykind/ExchangeIntegral")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    WarmReceptorThreshold = URIRef("http://qudt.org/vocab/quantitykind/WarmReceptorThreshold")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    PlanckFunction = URIRef("http://qudt.org/vocab/quantitykind/PlanckFunction")
    ThermalConductance = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductance")
    AngularDistance = URIRef("http://qudt.org/vocab/quantitykind/AngularDistance")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    ExpansionRatio = URIRef("http://qudt.org/vocab/quantitykind/ExpansionRatio")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    ResonanceEscapeProbabilityForFission = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbabilityForFission")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    StructuralEfficiency = URIRef("http://qudt.org/vocab/quantitykind/StructuralEfficiency")
    LoudnessLevel = URIRef("http://qudt.org/vocab/quantitykind/LoudnessLevel")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    VolumetricEntityDensity = URIRef("http://qudt.org/vocab/quantitykind/VolumetricEntityDensity")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    StandardChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/StandardChemicalPotential")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    GeneralizedForce = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedForce")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    StandardGravitationalParameter = URIRef("http://qudt.org/vocab/quantitykind/StandardGravitationalParameter")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    MolarEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarEnergy")
    ElectricQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricQuadrupoleMoment")
    TimeRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRatio")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    AngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentum")
    GyromagneticRatio = URIRef("http://qudt.org/vocab/quantitykind/GyromagneticRatio")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    SpecificModulus = URIRef("http://qudt.org/vocab/quantitykind/SpecificModulus")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    LuminousFluxPerArea = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxPerArea")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    ElectricField = URIRef("http://qudt.org/vocab/quantitykind/ElectricField")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    WarpingMoment = URIRef("http://qudt.org/vocab/quantitykind/WarpingMoment")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    ThermalResistivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistivity")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    RadiantFluence = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluence")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    Fluidity = URIRef("http://qudt.org/vocab/quantitykind/Fluidity")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    Voltage = URIRef("http://qudt.org/vocab/quantitykind/Voltage")
    MagneticDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMoment")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    LagrangeFunction = URIRef("http://qudt.org/vocab/quantitykind/LagrangeFunction")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    ReynoldsNumber = URIRef("http://qudt.org/vocab/quantitykind/ReynoldsNumber")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    SoilAdsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SoilAdsorptionCoefficient")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    AreaChargeDensity = URIRef("http://qudt.org/vocab/quantitykind/AreaChargeDensity")
    SoundEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SoundEnergyDensity")
    StressOpticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StressOpticCoefficient")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    MolalityOfSolute = URIRef("http://qudt.org/vocab/quantitykind/MolalityOfSolute")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    CharacteristicVelocity = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicVelocity")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    PolarMomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/PolarMomentOfInertia")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    InformationContentExpressedAsALogarithmToBaseE = URIRef("http://qudt.org/vocab/quantitykind/InformationContentExpressedAsALogarithmToBaseE")
    Compressibility = URIRef("http://qudt.org/vocab/quantitykind/Compressibility")
    Gravity_API = URIRef("http://qudt.org/vocab/quantitykind/Gravity_API")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    BucklingFactor = URIRef("http://qudt.org/vocab/quantitykind/BucklingFactor")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    Duv = URIRef("http://qudt.org/vocab/quantitykind/Duv")
    MagneticDipoleMomentOfAMolecule = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMomentOfAMolecule")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    NapierianAbsorbance = URIRef("http://qudt.org/vocab/quantitykind/NapierianAbsorbance")
    RelativeMassDensity = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDensity")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    TotalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentumQuantumNumber")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    WaterVapourPermeability = URIRef("http://qudt.org/vocab/quantitykind/WaterVapourPermeability")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    PressureLossPerLength = URIRef("http://qudt.org/vocab/quantitykind/PressureLossPerLength")
    PhotosyntheticPhotonFlux = URIRef("http://qudt.org/vocab/quantitykind/PhotosyntheticPhotonFlux")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    AbsorbedDose = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDose")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    RatioOfSpecificHeatCapacities = URIRef("http://qudt.org/vocab/quantitykind/RatioOfSpecificHeatCapacities")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    LinearStiffness = URIRef("http://qudt.org/vocab/quantitykind/LinearStiffness")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    DragCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DragCoefficient")
    Polarizability = URIRef("http://qudt.org/vocab/quantitykind/Polarizability")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    Impedance = URIRef("http://qudt.org/vocab/quantitykind/Impedance")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    LuminousIntensityDistribution = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensityDistribution")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    Half_Life = URIRef("http://qudt.org/vocab/quantitykind/Half-Life")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    HallCoefficient = URIRef("http://qudt.org/vocab/quantitykind/HallCoefficient")
    ResonanceEscapeProbability = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbability")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    VentilationRatePerFloorArea = URIRef("http://qudt.org/vocab/quantitykind/VentilationRatePerFloorArea")
    MagneticAreaMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticAreaMoment")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    SpecificImpulse = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulse")
    ThermalDiffusionFactor = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionFactor")
    MagneticQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/MagneticQuantumNumber")
    RotationalStiffness = URIRef("http://qudt.org/vocab/quantitykind/RotationalStiffness")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    MagneticReluctivity = URIRef("http://qudt.org/vocab/quantitykind/MagneticReluctivity")
    RadioactiveDecay = URIRef("http://qudt.org/vocab/quantitykind/RadioactiveDecay")
    ChemicalConsumptionPerMass = URIRef("http://qudt.org/vocab/quantitykind/ChemicalConsumptionPerMass")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    MolarFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MolarFlowRate")
    MolarAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAttenuationCoefficient")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    InverseLength = URIRef("http://qudt.org/vocab/quantitykind/InverseLength")
    Piece = URIRef("http://qudt.org/vocab/quantitykind/Piece")
    TotalRadiance = URIRef("http://qudt.org/vocab/quantitykind/TotalRadiance")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    DensityInCombustionChamber = URIRef("http://qudt.org/vocab/quantitykind/DensityInCombustionChamber")
    Population = URIRef("http://qudt.org/vocab/quantitykind/Population")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    SpectralRadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SpectralRadiantEnergyDensity")
    PrincipalQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/PrincipalQuantumNumber")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    Mobility = URIRef("http://qudt.org/vocab/quantitykind/Mobility")
    ElectricChargePerArea = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerArea")
    IonTransportNumber = URIRef("http://qudt.org/vocab/quantitykind/IonTransportNumber")
    MassAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAttenuationCoefficient")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    PhaseSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/PhaseSpeedOfSound")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    SpectralLuminousEfficiency = URIRef("http://qudt.org/vocab/quantitykind/SpectralLuminousEfficiency")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    MagneticQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/MagneticQuantumNumber")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    BiodegredationHalfLife = URIRef("http://qudt.org/vocab/quantitykind/BiodegredationHalfLife")
    Long_RangeOrderParameter = URIRef("http://qudt.org/vocab/quantitykind/Long-RangeOrderParameter")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    ExhaustGasesSpecificHeat = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasesSpecificHeat")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    SpecificHeatPressure = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatPressure")
    NuclearSpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/NuclearSpinQuantumNumber")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    ElectricDisplacementField = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacementField")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    SpecificGibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificGibbsEnergy")
    VolumetricFlux = URIRef("http://qudt.org/vocab/quantitykind/VolumetricFlux")
    ActivityRelatedByMass = URIRef("http://qudt.org/vocab/quantitykind/ActivityRelatedByMass")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    ByteDataVolume = URIRef("http://qudt.org/vocab/quantitykind/ByteDataVolume")
    DiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficient")
    PhaseCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PhaseCoefficient")
    FissionFuelUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionFuelUtilizationFactor")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    ReciprocalElectricResistance = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalElectricResistance")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    TemperatureBasedDensity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedDensity")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    FlightPathAngle = URIRef("http://qudt.org/vocab/quantitykind/FlightPathAngle")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    MagneticField = URIRef("http://qudt.org/vocab/quantitykind/MagneticField")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    GeneralizedCoordinate = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedCoordinate")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    ActivityCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ActivityCoefficient")
    BitDataVolume = URIRef("http://qudt.org/vocab/quantitykind/BitDataVolume")
    FUEL_BIAS = URIRef("http://qudt.org/vocab/quantitykind/FUEL-BIAS")
    LinearElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrent")
    LorenzCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LorenzCoefficient")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    TransmittanceDensity = URIRef("http://qudt.org/vocab/quantitykind/TransmittanceDensity")
    ThrustCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThrustCoefficient")
    HenrysLawVolatilityConstant = URIRef("http://qudt.org/vocab/quantitykind/HenrysLawVolatilityConstant")
    PermittivityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermittivityRatio")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    FirstStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/FirstStageMassRatio")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    RadianceFactor = URIRef("http://qudt.org/vocab/quantitykind/RadianceFactor")
    PhotonIntensity = URIRef("http://qudt.org/vocab/quantitykind/PhotonIntensity")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    SecondPolarMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondPolarMomentOfArea")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    ThermodynamicCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicCriticalMagneticFluxDensity")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    SignalStrength = URIRef("http://qudt.org/vocab/quantitykind/SignalStrength")
    TotalAtomicStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalAtomicStoppingPower")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    LinearAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAbsorptionCoefficient")
    StressOpticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StressOpticCoefficient")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    ElectricChargeSurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeSurfaceDensity")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    ElectricDisplacement = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacement")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    LengthMolarEnergy = URIRef("http://qudt.org/vocab/quantitykind/LengthMolarEnergy")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    MadelungConstant = URIRef("http://qudt.org/vocab/quantitykind/MadelungConstant")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    HyperfineStructureQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/HyperfineStructureQuantumNumber")
    QualityFactor = URIRef("http://qudt.org/vocab/quantitykind/QualityFactor")
    DoseEquivalentRate = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalentRate")
    LuminousEfficacy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEfficacy")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    ElectricQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricQuadrupoleMoment")
    ElectricDipoleMoment_CubicPerEnergy_Squared = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment_CubicPerEnergy_Squared")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    Luminance = URIRef("http://qudt.org/vocab/quantitykind/Luminance")
    AmountOfSubstancePerUnitMassPressure = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMassPressure")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    EquilibriumConstant = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstant")
    SoundReductionIndex = URIRef("http://qudt.org/vocab/quantitykind/SoundReductionIndex")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    NeutronDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionCoefficient")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    TouchThresholds = URIRef("http://qudt.org/vocab/quantitykind/TouchThresholds")
    PartialPressure = URIRef("http://qudt.org/vocab/quantitykind/PartialPressure")
    VaporPermeability = URIRef("http://qudt.org/vocab/quantitykind/VaporPermeability")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    Lethargy = URIRef("http://qudt.org/vocab/quantitykind/Lethargy")
    ConductionSpeed = URIRef("http://qudt.org/vocab/quantitykind/ConductionSpeed")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    LandeGFactor = URIRef("http://qudt.org/vocab/quantitykind/LandeGFactor")
    InverseSquareTime = URIRef("http://qudt.org/vocab/quantitykind/InverseSquareTime")
    IonicStrength = URIRef("http://qudt.org/vocab/quantitykind/IonicStrength")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    BitTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/BitTransmissionRate")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    DecayConstant = URIRef("http://qudt.org/vocab/quantitykind/DecayConstant")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    LuminousEfficacy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEfficacy")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    Admittance = URIRef("http://qudt.org/vocab/quantitykind/Admittance")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    LineicPower = URIRef("http://qudt.org/vocab/quantitykind/LineicPower")
    LengthMass = URIRef("http://qudt.org/vocab/quantitykind/LengthMass")
    AtomicNumber = URIRef("http://qudt.org/vocab/quantitykind/AtomicNumber")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    OsmoticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/OsmoticCoefficient")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    NeelTemperature = URIRef("http://qudt.org/vocab/quantitykind/NeelTemperature")
    MolecularViscosity = URIRef("http://qudt.org/vocab/quantitykind/MolecularViscosity")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    LengthPercentage = URIRef("http://qudt.org/vocab/quantitykind/LengthPercentage")
    ElectricChargeVolumeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeVolumeDensity")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    SingleStageLauncherMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SingleStageLauncherMassRatio")
    InformationFlowRate = URIRef("http://qudt.org/vocab/quantitykind/InformationFlowRate")
    ReciprocalVoltage = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalVoltage")
    Reflectivity = URIRef("http://qudt.org/vocab/quantitykind/Reflectivity")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    Emissivity = URIRef("http://qudt.org/vocab/quantitykind/Emissivity")
    GFactorOfNucleus = URIRef("http://qudt.org/vocab/quantitykind/GFactorOfNucleus")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    Chromaticity = URIRef("http://qudt.org/vocab/quantitykind/Chromaticity")
    EnergyFluence = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluence")
    AtomicStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/AtomicStoppingPower")
    EnergyPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerElectricCharge")
    CanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/CanonicalPartitionFunction")
    PressureBasedDensity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedDensity")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    SphericalIlluminance = URIRef("http://qudt.org/vocab/quantitykind/SphericalIlluminance")
    NeutronDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionCoefficient")
    AreaRatio = URIRef("http://qudt.org/vocab/quantitykind/AreaRatio")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    LinearMomentum = URIRef("http://qudt.org/vocab/quantitykind/LinearMomentum")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    SpecificHeatCapacityAtSaturation = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtSaturation")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    ConductionSpeed = URIRef("http://qudt.org/vocab/quantitykind/ConductionSpeed")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    StandardGravitationalParameter = URIRef("http://qudt.org/vocab/quantitykind/StandardGravitationalParameter")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    RelativeMassConcentrationOfVapour = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassConcentrationOfVapour")
    RadioactiveDecay = URIRef("http://qudt.org/vocab/quantitykind/RadioactiveDecay")
    SpecificWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificWeight")
    DonorDensity = URIRef("http://qudt.org/vocab/quantitykind/DonorDensity")
    LineicDataVolume = URIRef("http://qudt.org/vocab/quantitykind/LineicDataVolume")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    GasLeakRate = URIRef("http://qudt.org/vocab/quantitykind/GasLeakRate")
    MassPerLength = URIRef("http://qudt.org/vocab/quantitykind/MassPerLength")
    PropellantTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantTemperature")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    FlashPoint = URIRef("http://qudt.org/vocab/quantitykind/FlashPoint")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    LogarithmRatioToBase10 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmRatioToBase10")
    AreicEnergyFlow = URIRef("http://qudt.org/vocab/quantitykind/AreicEnergyFlow")
    PayloadRatio = URIRef("http://qudt.org/vocab/quantitykind/PayloadRatio")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    PositivePlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PositivePlaneAngle")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    TemperatureRateOfChange = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRateOfChange")
    AverageSpecificImpulse = URIRef("http://qudt.org/vocab/quantitykind/AverageSpecificImpulse")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    TemperaturePerTime = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime")
    ResistanceRatio = URIRef("http://qudt.org/vocab/quantitykind/ResistanceRatio")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    CombinedNonEvaporativeHeatTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CombinedNonEvaporativeHeatTransferCoefficient")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    EnergyPerMagneticFluxDensity_Squared = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerMagneticFluxDensity_Squared")
    MolarAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAbsorptionCoefficient")
    RotaryShock = URIRef("http://qudt.org/vocab/quantitykind/RotaryShock")
    RateOfChangeOfTemperature = URIRef("http://qudt.org/vocab/quantitykind/RateOfChangeOfTemperature")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    Lethargy = URIRef("http://qudt.org/vocab/quantitykind/Lethargy")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    ChemicalConsumptionPerMass = URIRef("http://qudt.org/vocab/quantitykind/ChemicalConsumptionPerMass")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    MassRatioOfWaterToDryMatter = URIRef("http://qudt.org/vocab/quantitykind/MassRatioOfWaterToDryMatter")
    Action = URIRef("http://qudt.org/vocab/quantitykind/Action")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    ThermalTransmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalTransmittance")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    LogarithmicFrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyInterval")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    NeelTemperature = URIRef("http://qudt.org/vocab/quantitykind/NeelTemperature")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    Dimensionless = URIRef("http://qudt.org/vocab/quantitykind/Dimensionless")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    MolarRefractivity = URIRef("http://qudt.org/vocab/quantitykind/MolarRefractivity")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    Lethargy = URIRef("http://qudt.org/vocab/quantitykind/Lethargy")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    TransmissionRatioBetweenRotationAndTranslation = URIRef("http://qudt.org/vocab/quantitykind/TransmissionRatioBetweenRotationAndTranslation")
    AmountOfSubstanceFractionOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFractionOfB")
    AmountOfSubstanceFractionOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFractionOfB")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    DonorDensity = URIRef("http://qudt.org/vocab/quantitykind/DonorDensity")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    PhotoThresholdOfAwarenessFunction = URIRef("http://qudt.org/vocab/quantitykind/PhotoThresholdOfAwarenessFunction")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    PressureRatio = URIRef("http://qudt.org/vocab/quantitykind/PressureRatio")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    SpecificSurfaceArea = URIRef("http://qudt.org/vocab/quantitykind/SpecificSurfaceArea")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    BioconcentrationFactor = URIRef("http://qudt.org/vocab/quantitykind/BioconcentrationFactor")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    MagnetomotiveForce = URIRef("http://qudt.org/vocab/quantitykind/MagnetomotiveForce")
    Voltage = URIRef("http://qudt.org/vocab/quantitykind/Voltage")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    IncidenceRate = URIRef("http://qudt.org/vocab/quantitykind/IncidenceRate")
    MechanicalSurfaceImpedance = URIRef("http://qudt.org/vocab/quantitykind/MechanicalSurfaceImpedance")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    GrowingDegreeDay_Cereal = URIRef("http://qudt.org/vocab/quantitykind/GrowingDegreeDay_Cereal")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    MassAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAttenuationCoefficient")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    PressureRatio = URIRef("http://qudt.org/vocab/quantitykind/PressureRatio")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    LengthByForce = URIRef("http://qudt.org/vocab/quantitykind/LengthByForce")
    HoleDensity = URIRef("http://qudt.org/vocab/quantitykind/HoleDensity")
    TemperaturePerTime = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    CyclotronAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/CyclotronAngularFrequency")
    MolarOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/MolarOpticalRotatoryPower")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    ElectricDisplacementField = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacementField")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    PRODUCT_OF_INERTIA = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    ComplexPower = URIRef("http://qudt.org/vocab/quantitykind/ComplexPower")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    DisplacementCurrent = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrent")
    LinearAcceleration = URIRef("http://qudt.org/vocab/quantitykind/LinearAcceleration")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    PhotosyntheticPhotonFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/PhotosyntheticPhotonFluxDensity")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    PolarMomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/PolarMomentOfInertia")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    BurstFactor = URIRef("http://qudt.org/vocab/quantitykind/BurstFactor")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    Unbalance = URIRef("http://qudt.org/vocab/quantitykind/Unbalance")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    FissionMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionMultiplicationFactor")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    MassPerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerAreaTime")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    Temperature = URIRef("http://qudt.org/vocab/quantitykind/Temperature")
    Count = URIRef("http://qudt.org/vocab/quantitykind/Count")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    MolalityOfSolute = URIRef("http://qudt.org/vocab/quantitykind/MolalityOfSolute")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    NeutronYieldPerFission = URIRef("http://qudt.org/vocab/quantitykind/NeutronYieldPerFission")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    BurstFactor = URIRef("http://qudt.org/vocab/quantitykind/BurstFactor")
    ReynoldsNumber = URIRef("http://qudt.org/vocab/quantitykind/ReynoldsNumber")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    ResistanceRatio = URIRef("http://qudt.org/vocab/quantitykind/ResistanceRatio")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    PayloadRatio = URIRef("http://qudt.org/vocab/quantitykind/PayloadRatio")
    SectionModulus = URIRef("http://qudt.org/vocab/quantitykind/SectionModulus")
    MassFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MassFluxDensity")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    PayloadRatio = URIRef("http://qudt.org/vocab/quantitykind/PayloadRatio")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    ConductiveHeatTransferRate = URIRef("http://qudt.org/vocab/quantitykind/ConductiveHeatTransferRate")
    MolecularConcentration = URIRef("http://qudt.org/vocab/quantitykind/MolecularConcentration")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    LengthMass = URIRef("http://qudt.org/vocab/quantitykind/LengthMass")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    OrbitalAngularMomentumPerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/OrbitalAngularMomentumPerUnitMass")
    PH = URIRef("http://qudt.org/vocab/quantitykind/PH")
    NormalizedDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/NormalizedDimensionlessRatio")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    Debye_WallerFactor = URIRef("http://qudt.org/vocab/quantitykind/Debye-WallerFactor")
    StressOpticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StressOpticCoefficient")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    InversePermittivity = URIRef("http://qudt.org/vocab/quantitykind/InversePermittivity")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    LogarithmicMedianInformationFlow_SourceToBase10 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicMedianInformationFlow_SourceToBase10")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    SoundExposureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundExposureLevel")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    IncidenceRate = URIRef("http://qudt.org/vocab/quantitykind/IncidenceRate")
    RotationalStiffness = URIRef("http://qudt.org/vocab/quantitykind/RotationalStiffness")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    WebTimeAveragePressure = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAveragePressure")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    CatalyticActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivityConcentration")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    LinearForce = URIRef("http://qudt.org/vocab/quantitykind/LinearForce")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    ThermalInsulance = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulance")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    SpecificHelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificHelmholtzEnergy")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    DoseEquivalentQualityFactor = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalentQualityFactor")
    PeltierCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PeltierCoefficient")
    LengthMass = URIRef("http://qudt.org/vocab/quantitykind/LengthMass")
    QualityFactor = URIRef("http://qudt.org/vocab/quantitykind/QualityFactor")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    DebyeAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularFrequency")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    VolumeDensityOfCharge = URIRef("http://qudt.org/vocab/quantitykind/VolumeDensityOfCharge")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    Exposure = URIRef("http://qudt.org/vocab/quantitykind/Exposure")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    MolarHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MolarHeatCapacity")
    SecondAxialMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondAxialMomentOfArea")
    Non_LeakageProbability = URIRef("http://qudt.org/vocab/quantitykind/Non-LeakageProbability")
    SpectralRadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SpectralRadiantEnergyDensity")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    ReflectanceFactor = URIRef("http://qudt.org/vocab/quantitykind/ReflectanceFactor")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    ThomsonCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThomsonCoefficient")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    VolumetricElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/VolumetricElectricCharge")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    MorbidityRate = URIRef("http://qudt.org/vocab/quantitykind/MorbidityRate")
    CharacteristicAcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicAcousticImpedance")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    HeatFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/HeatFluxDensity")
    AngularReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/AngularReciprocalLatticeVector")
    LiquidVolume = URIRef("http://qudt.org/vocab/quantitykind/LiquidVolume")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    FlightPathAngle = URIRef("http://qudt.org/vocab/quantitykind/FlightPathAngle")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    ThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusivity")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    FlashPoint = URIRef("http://qudt.org/vocab/quantitykind/FlashPoint")
    MassPerLength = URIRef("http://qudt.org/vocab/quantitykind/MassPerLength")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    RelativeMassRatioOfVapour = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassRatioOfVapour")
    DonorDensity = URIRef("http://qudt.org/vocab/quantitykind/DonorDensity")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    StateDensityAsExpressionOfAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/StateDensityAsExpressionOfAngularFrequency")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    SpecificVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificVolume")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    ConductiveHeatTransferRate = URIRef("http://qudt.org/vocab/quantitykind/ConductiveHeatTransferRate")
    HoleDensity = URIRef("http://qudt.org/vocab/quantitykind/HoleDensity")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    ThermalDiffusionRatioCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionRatioCoefficient")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    SerumOrPlasmaLevel = URIRef("http://qudt.org/vocab/quantitykind/SerumOrPlasmaLevel")
    Time_Squared = URIRef("http://qudt.org/vocab/quantitykind/Time_Squared")
    LinearEnergyTransfer = URIRef("http://qudt.org/vocab/quantitykind/LinearEnergyTransfer")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    WarpingMoment = URIRef("http://qudt.org/vocab/quantitykind/WarpingMoment")
    TorquePerAngle = URIRef("http://qudt.org/vocab/quantitykind/TorquePerAngle")
    Radiance = URIRef("http://qudt.org/vocab/quantitykind/Radiance")
    ThrustToWeightRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToWeightRatio")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    StructureFactor = URIRef("http://qudt.org/vocab/quantitykind/StructureFactor")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    OrbitalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/OrbitalAngularMomentumQuantumNumber")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    FundamentalReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalReciprocalLatticeVector")
    InfiniteMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/InfiniteMultiplicationFactor")
    GrandCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/GrandCanonicalPartitionFunction")
    TemperatureRateOfChange = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRateOfChange")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    SpecificHeatsRatio = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatsRatio")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    PositiveDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/PositiveDimensionlessRatio")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    TouchThresholds = URIRef("http://qudt.org/vocab/quantitykind/TouchThresholds")
    SecondPolarMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondPolarMomentOfArea")
    TimeTemperature = URIRef("http://qudt.org/vocab/quantitykind/TimeTemperature")
    TemperatureGradient = URIRef("http://qudt.org/vocab/quantitykind/TemperatureGradient")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    AmountOfSubstanceFraction = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFraction")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    AcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/AcousticImpedance")
    SourceVoltageBetweenSubstances = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltageBetweenSubstances")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    ConvectiveHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/ConvectiveHeatTransfer")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    BodyMassIndex = URIRef("http://qudt.org/vocab/quantitykind/BodyMassIndex")
    SoundVolumeVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundVolumeVelocity")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    CurvatureFromRadius = URIRef("http://qudt.org/vocab/quantitykind/CurvatureFromRadius")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    DoseEquivalent = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalent")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    LiftCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LiftCoefficient")
    LinearAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAbsorptionCoefficient")
    PressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PressureCoefficient")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    DonorDensity = URIRef("http://qudt.org/vocab/quantitykind/DonorDensity")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    RadiantIntensity = URIRef("http://qudt.org/vocab/quantitykind/RadiantIntensity")
    OsmoticPressure = URIRef("http://qudt.org/vocab/quantitykind/OsmoticPressure")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    CombustionChamberTemperature = URIRef("http://qudt.org/vocab/quantitykind/CombustionChamberTemperature")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    ElectricChargePerMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerMass")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    EquilibriumConstantOnConcentrationBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnConcentrationBasis")
    StructuralEfficiency = URIRef("http://qudt.org/vocab/quantitykind/StructuralEfficiency")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    ElectricQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricQuadrupoleMoment")
    Resistivity = URIRef("http://qudt.org/vocab/quantitykind/Resistivity")
    NuclearQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/NuclearQuadrupoleMoment")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    FirstStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/FirstStageMassRatio")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    AmountOfSubstanceFraction = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFraction")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    AmountOfSubstancePerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMass")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    TimeConstant_Inductance = URIRef("http://qudt.org/vocab/quantitykind/TimeConstant_Inductance")
    LinearElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrent")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    EquilibriumConstant = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstant")
    ElectricFlux = URIRef("http://qudt.org/vocab/quantitykind/ElectricFlux")
    ActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/ActivityConcentration")
    DoseEquivalentQualityFactor = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalentQualityFactor")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    SpecificOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificOpticalRotatoryPower")
    Reactivity = URIRef("http://qudt.org/vocab/quantitykind/Reactivity")
    ChargeNumber = URIRef("http://qudt.org/vocab/quantitykind/ChargeNumber")
    SpecificEntropy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEntropy")
    TotalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentumQuantumNumber")
    AngularMomentumPerAngle = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentumPerAngle")
    SpecificHelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificHelmholtzEnergy")
    CutoffCurrentRating = URIRef("http://qudt.org/vocab/quantitykind/CutoffCurrentRating")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    FUEL_BIAS = URIRef("http://qudt.org/vocab/quantitykind/FUEL-BIAS")
    AreaThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/AreaThermalExpansion")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    PropellantTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantTemperature")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    LogarithmicFrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyInterval")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    SignalStrength = URIRef("http://qudt.org/vocab/quantitykind/SignalStrength")
    PhaseCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PhaseCoefficient")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    EvaporativeHeatTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/EvaporativeHeatTransferCoefficient")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    AuxillaryMagneticField = URIRef("http://qudt.org/vocab/quantitykind/AuxillaryMagneticField")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    LuminousEnergy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEnergy")
    AcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/AcousticImpedance")
    LinearIonization = URIRef("http://qudt.org/vocab/quantitykind/LinearIonization")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    ElectricChargeVolumeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeVolumeDensity")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    HeatFlowRatePerUnitArea = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRatePerUnitArea")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    TimePercentage = URIRef("http://qudt.org/vocab/quantitykind/TimePercentage")
    SourceVoltage = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltage")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    RadiantEnergyExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergyExposure")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    ChargeNumber = URIRef("http://qudt.org/vocab/quantitykind/ChargeNumber")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    VolumicOutput = URIRef("http://qudt.org/vocab/quantitykind/VolumicOutput")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    AreaRatio = URIRef("http://qudt.org/vocab/quantitykind/AreaRatio")
    Compressibility = URIRef("http://qudt.org/vocab/quantitykind/Compressibility")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    MechanicalSurfaceImpedance = URIRef("http://qudt.org/vocab/quantitykind/MechanicalSurfaceImpedance")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    LeakageFactor = URIRef("http://qudt.org/vocab/quantitykind/LeakageFactor")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    MolecularViscosity = URIRef("http://qudt.org/vocab/quantitykind/MolecularViscosity")
    LinearStrain = URIRef("http://qudt.org/vocab/quantitykind/LinearStrain")
    GeneFamilyAbundance = URIRef("http://qudt.org/vocab/quantitykind/GeneFamilyAbundance")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    RadiantFluence = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluence")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    MadelungConstant = URIRef("http://qudt.org/vocab/quantitykind/MadelungConstant")
    LuminousEmittance = URIRef("http://qudt.org/vocab/quantitykind/LuminousEmittance")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    RateOfRiseOfVoltage = URIRef("http://qudt.org/vocab/quantitykind/RateOfRiseOfVoltage")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    MagneticAreaMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticAreaMoment")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    SpecificThrust = URIRef("http://qudt.org/vocab/quantitykind/SpecificThrust")
    SquareEnergy = URIRef("http://qudt.org/vocab/quantitykind/SquareEnergy")
    PositivePlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PositivePlaneAngle")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    Gradient = URIRef("http://qudt.org/vocab/quantitykind/Gradient")
    EnergyPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerElectricCharge")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    AmountOfSubstanceConcentrationOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentrationOfB")
    VoltageRatio = URIRef("http://qudt.org/vocab/quantitykind/VoltageRatio")
    SurfaceCoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/SurfaceCoefficientOfHeatTransfer")
    SingleStageLauncherMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SingleStageLauncherMassRatio")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    Radioactivity = URIRef("http://qudt.org/vocab/quantitykind/Radioactivity")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    BucklingFactor = URIRef("http://qudt.org/vocab/quantitykind/BucklingFactor")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    CatalyticActivity = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivity")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    Circulation = URIRef("http://qudt.org/vocab/quantitykind/Circulation")
    TotalIonization = URIRef("http://qudt.org/vocab/quantitykind/TotalIonization")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    LinearAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAbsorptionCoefficient")
    ExtentOfReaction = URIRef("http://qudt.org/vocab/quantitykind/ExtentOfReaction")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    PhotoThresholdOfAwarenessFunction = URIRef("http://qudt.org/vocab/quantitykind/PhotoThresholdOfAwarenessFunction")
    ElectromagneticPermeability = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeability")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    InverseLength = URIRef("http://qudt.org/vocab/quantitykind/InverseLength")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    ElectromagneticPermeabilityRatio = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeabilityRatio")
    Permittivity = URIRef("http://qudt.org/vocab/quantitykind/Permittivity")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    NeutronYieldPerFission = URIRef("http://qudt.org/vocab/quantitykind/NeutronYieldPerFission")
    LagrangeFunction = URIRef("http://qudt.org/vocab/quantitykind/LagrangeFunction")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    LinearAcceleration = URIRef("http://qudt.org/vocab/quantitykind/LinearAcceleration")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    FissionCoreRadiusToHeightRatio = URIRef("http://qudt.org/vocab/quantitykind/FissionCoreRadiusToHeightRatio")
    ThermalUtilizationFactorForFission = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactorForFission")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    IsothermalMoistureCapacity = URIRef("http://qudt.org/vocab/quantitykind/IsothermalMoistureCapacity")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    BodyMassIndex = URIRef("http://qudt.org/vocab/quantitykind/BodyMassIndex")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    DiastolicBloodPressure = URIRef("http://qudt.org/vocab/quantitykind/DiastolicBloodPressure")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    LengthTemperature = URIRef("http://qudt.org/vocab/quantitykind/LengthTemperature")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    Reflectance = URIRef("http://qudt.org/vocab/quantitykind/Reflectance")
    LiftCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LiftCoefficient")
    Population = URIRef("http://qudt.org/vocab/quantitykind/Population")
    SymbolTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/SymbolTransmissionRate")
    ExchangeIntegral = URIRef("http://qudt.org/vocab/quantitykind/ExchangeIntegral")
    AmountOfSubstanceConcentrationOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentrationOfB")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    TimeSquared = URIRef("http://qudt.org/vocab/quantitykind/TimeSquared")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    SoundParticleVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleVelocity")
    ElectricChargePerArea = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerArea")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    MolecularConcentration = URIRef("http://qudt.org/vocab/quantitykind/MolecularConcentration")
    SpecificVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificVolume")
    GrandCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/GrandCanonicalPartitionFunction")
    Admittance = URIRef("http://qudt.org/vocab/quantitykind/Admittance")
    BindingFraction = URIRef("http://qudt.org/vocab/quantitykind/BindingFraction")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    SpecificHeatVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatVolume")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    PhotonLuminance = URIRef("http://qudt.org/vocab/quantitykind/PhotonLuminance")
    AngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/AngularCrossSection")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    SeebeckCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SeebeckCoefficient")
    QualityFactor = URIRef("http://qudt.org/vocab/quantitykind/QualityFactor")
    VaporPermeability = URIRef("http://qudt.org/vocab/quantitykind/VaporPermeability")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    TemperatureRelatedVolume = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRelatedVolume")
    ParticleSourceDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleSourceDensity")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    SquareEnergy = URIRef("http://qudt.org/vocab/quantitykind/SquareEnergy")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    MolarDensity = URIRef("http://qudt.org/vocab/quantitykind/MolarDensity")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    StructuralEfficiency = URIRef("http://qudt.org/vocab/quantitykind/StructuralEfficiency")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    HallCoefficient = URIRef("http://qudt.org/vocab/quantitykind/HallCoefficient")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    ElectricDisplacement = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacement")
    InverseSquareEnergy = URIRef("http://qudt.org/vocab/quantitykind/InverseSquareEnergy")
    DebyeTemperature = URIRef("http://qudt.org/vocab/quantitykind/DebyeTemperature")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    CharacteristicAcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicAcousticImpedance")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    MassFraction = URIRef("http://qudt.org/vocab/quantitykind/MassFraction")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    PropagationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PropagationCoefficient")
    SpecificAcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/SpecificAcousticImpedance")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    GeneFamilyAbundance = URIRef("http://qudt.org/vocab/quantitykind/GeneFamilyAbundance")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    Fluidity = URIRef("http://qudt.org/vocab/quantitykind/Fluidity")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    SpecificEntropy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEntropy")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    RelativeLuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/RelativeLuminousFlux")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    OsmoticPressure = URIRef("http://qudt.org/vocab/quantitykind/OsmoticPressure")
    InformationContentExpressedAsALogarithmToBaseE = URIRef("http://qudt.org/vocab/quantitykind/InformationContentExpressedAsALogarithmToBaseE")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    VolumicOutput = URIRef("http://qudt.org/vocab/quantitykind/VolumicOutput")
    AverageLogarithmicEnergyDecrement = URIRef("http://qudt.org/vocab/quantitykind/AverageLogarithmicEnergyDecrement")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    MassConcentration = URIRef("http://qudt.org/vocab/quantitykind/MassConcentration")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    InverseMass = URIRef("http://qudt.org/vocab/quantitykind/InverseMass")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    SpectralCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralCrossSection")
    EquilibriumConstantBasedOnPressure = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantBasedOnPressure")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    MolecularConcentration = URIRef("http://qudt.org/vocab/quantitykind/MolecularConcentration")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    Period = URIRef("http://qudt.org/vocab/quantitykind/Period")
    FissionMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionMultiplicationFactor")
    QuantityOfLight = URIRef("http://qudt.org/vocab/quantitykind/QuantityOfLight")
    LinkedFlux = URIRef("http://qudt.org/vocab/quantitykind/LinkedFlux")
    SpecificHeatCapacityAtConstantPressure = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantPressure")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    Chromaticity = URIRef("http://qudt.org/vocab/quantitykind/Chromaticity")
    MagneticSusceptability = URIRef("http://qudt.org/vocab/quantitykind/MagneticSusceptability")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    MagneticSusceptability = URIRef("http://qudt.org/vocab/quantitykind/MagneticSusceptability")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    ThermalDiffusionRatio = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionRatio")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    VolumicAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/VolumicAmountOfSubstance")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    EffectiveMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMultiplicationFactor")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    TemperatureBasedKinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedKinematicViscosity")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    PressureBasedMass = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedMass")
    PressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PressureCoefficient")
    MolarRefractivity = URIRef("http://qudt.org/vocab/quantitykind/MolarRefractivity")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    LengthRatio = URIRef("http://qudt.org/vocab/quantitykind/LengthRatio")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    Gravity_API = URIRef("http://qudt.org/vocab/quantitykind/Gravity_API")
    MagneticSusceptability = URIRef("http://qudt.org/vocab/quantitykind/MagneticSusceptability")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    BloodGlucoseLevel_Mass = URIRef("http://qudt.org/vocab/quantitykind/BloodGlucoseLevel_Mass")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    MolarRefractivity = URIRef("http://qudt.org/vocab/quantitykind/MolarRefractivity")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    LagrangeFunction = URIRef("http://qudt.org/vocab/quantitykind/LagrangeFunction")
    NonActivePower = URIRef("http://qudt.org/vocab/quantitykind/NonActivePower")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    CurvatureFromRadius = URIRef("http://qudt.org/vocab/quantitykind/CurvatureFromRadius")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    LinearElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrentDensity")
    AreicMass = URIRef("http://qudt.org/vocab/quantitykind/AreicMass")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    SuperconductionTransitionTemperature = URIRef("http://qudt.org/vocab/quantitykind/SuperconductionTransitionTemperature")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    EnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensity")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    ThermalTransmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalTransmittance")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    ForcePerLength = URIRef("http://qudt.org/vocab/quantitykind/ForcePerLength")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    SphericalIlluminance = URIRef("http://qudt.org/vocab/quantitykind/SphericalIlluminance")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    ExposureOfIonizingRadiation = URIRef("http://qudt.org/vocab/quantitykind/ExposureOfIonizingRadiation")
    PressureBasedDensity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedDensity")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    InverseTime = URIRef("http://qudt.org/vocab/quantitykind/InverseTime")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    AngleOfAttack = URIRef("http://qudt.org/vocab/quantitykind/AngleOfAttack")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    CouplingFactor = URIRef("http://qudt.org/vocab/quantitykind/CouplingFactor")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    PressureRatio = URIRef("http://qudt.org/vocab/quantitykind/PressureRatio")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    TotalLinearStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalLinearStoppingPower")
    VoltagePercentage = URIRef("http://qudt.org/vocab/quantitykind/VoltagePercentage")
    VisionThresholds = URIRef("http://qudt.org/vocab/quantitykind/VisionThresholds")
    GeneralizedMomentum = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedMomentum")
    MagneticSusceptability = URIRef("http://qudt.org/vocab/quantitykind/MagneticSusceptability")
    StatisticalWeight = URIRef("http://qudt.org/vocab/quantitykind/StatisticalWeight")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    StructuralEfficiency = URIRef("http://qudt.org/vocab/quantitykind/StructuralEfficiency")
    PhotoThresholdOfAwarenessFunction = URIRef("http://qudt.org/vocab/quantitykind/PhotoThresholdOfAwarenessFunction")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    SourceVoltageBetweenSubstances = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltageBetweenSubstances")
    SpecificHeatsRatio = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatsRatio")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    CouplingFactor = URIRef("http://qudt.org/vocab/quantitykind/CouplingFactor")
    WarmReceptorThreshold = URIRef("http://qudt.org/vocab/quantitykind/WarmReceptorThreshold")
    AbsorbedDoseRate = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDoseRate")
    SpectralRadiantEnergyDensityInTermsOfWavelength = URIRef("http://qudt.org/vocab/quantitykind/SpectralRadiantEnergyDensityInTermsOfWavelength")
    LengthMolarEnergy = URIRef("http://qudt.org/vocab/quantitykind/LengthMolarEnergy")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    FermiAngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/FermiAngularWavenumber")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    PressureBasedVolumeFlow = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedVolumeFlow")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    MultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/MultiplicationFactor")
    BitDataVolume = URIRef("http://qudt.org/vocab/quantitykind/BitDataVolume")
    PressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PressureCoefficient")
    LinearStiffness = URIRef("http://qudt.org/vocab/quantitykind/LinearStiffness")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    SeebeckCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SeebeckCoefficient")
    OrderOfReflection = URIRef("http://qudt.org/vocab/quantitykind/OrderOfReflection")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    ModulusOfImpedance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfImpedance")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    VideoFrameRate = URIRef("http://qudt.org/vocab/quantitykind/VideoFrameRate")
    FissionFuelUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionFuelUtilizationFactor")
    GroupSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/GroupSpeedOfSound")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    FlashPoint = URIRef("http://qudt.org/vocab/quantitykind/FlashPoint")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    MagneticField = URIRef("http://qudt.org/vocab/quantitykind/MagneticField")
    ThermalInsulance = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulance")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    KinematicViscosityOrDiffusionConstantOrThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosityOrDiffusionConstantOrThermalDiffusivity")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    Impedance = URIRef("http://qudt.org/vocab/quantitykind/Impedance")
    MortalityRate = URIRef("http://qudt.org/vocab/quantitykind/MortalityRate")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    MolarConductivity = URIRef("http://qudt.org/vocab/quantitykind/MolarConductivity")
    MolarOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/MolarOpticalRotatoryPower")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    ActionTime = URIRef("http://qudt.org/vocab/quantitykind/ActionTime")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    SpecificThrust = URIRef("http://qudt.org/vocab/quantitykind/SpecificThrust")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    ExhaustGasesSpecificHeat = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasesSpecificHeat")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    LogOctanolAirPartitionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LogOctanolAirPartitionCoefficient")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    LinearElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrentDensity")
    InternalConversionFactor = URIRef("http://qudt.org/vocab/quantitykind/InternalConversionFactor")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    ElectricChargePerMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerMass")
    LevelWidth = URIRef("http://qudt.org/vocab/quantitykind/LevelWidth")
    MassieuFunction = URIRef("http://qudt.org/vocab/quantitykind/MassieuFunction")
    TemperatureDifference = URIRef("http://qudt.org/vocab/quantitykind/TemperatureDifference")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    InformationContentExpressedAsALogarithmToBase10 = URIRef("http://qudt.org/vocab/quantitykind/InformationContentExpressedAsALogarithmToBase10")
    MaximumExpectedOperatingPressure = URIRef("http://qudt.org/vocab/quantitykind/MaximumExpectedOperatingPressure")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    InverseMass = URIRef("http://qudt.org/vocab/quantitykind/InverseMass")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    SurfaceRelatedVolumeFlow = URIRef("http://qudt.org/vocab/quantitykind/SurfaceRelatedVolumeFlow")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    TotalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentumQuantumNumber")
    AngularReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/AngularReciprocalLatticeVector")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    MaximumOperatingPressure = URIRef("http://qudt.org/vocab/quantitykind/MaximumOperatingPressure")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    SpecificEntropy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEntropy")
    EinsteinTransitionProbability = URIRef("http://qudt.org/vocab/quantitykind/EinsteinTransitionProbability")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    LinearForce = URIRef("http://qudt.org/vocab/quantitykind/LinearForce")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    ResistanceBasedInductance = URIRef("http://qudt.org/vocab/quantitykind/ResistanceBasedInductance")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    LogarithmRatioToBase10 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmRatioToBase10")
    SourceVoltageBetweenSubstances = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltageBetweenSubstances")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    LinearAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAttenuationCoefficient")
    GeneralizedForce = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedForce")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    LengthMass = URIRef("http://qudt.org/vocab/quantitykind/LengthMass")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    BevelGearPitchAngle = URIRef("http://qudt.org/vocab/quantitykind/BevelGearPitchAngle")
    LinearStiffness = URIRef("http://qudt.org/vocab/quantitykind/LinearStiffness")
    MassConcentrationOfWaterVapour = URIRef("http://qudt.org/vocab/quantitykind/MassConcentrationOfWaterVapour")
    MassPerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerAreaTime")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    InverseEnergy = URIRef("http://qudt.org/vocab/quantitykind/InverseEnergy")
    TrafficIntensity = URIRef("http://qudt.org/vocab/quantitykind/TrafficIntensity")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    OrbitalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/OrbitalAngularMomentumQuantumNumber")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    UpperCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/UpperCriticalMagneticFluxDensity")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    AuditoryThresholds = URIRef("http://qudt.org/vocab/quantitykind/AuditoryThresholds")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    PackingFraction = URIRef("http://qudt.org/vocab/quantitykind/PackingFraction")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    SecondPolarMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondPolarMomentOfArea")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    LinkedFlux = URIRef("http://qudt.org/vocab/quantitykind/LinkedFlux")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    ThermodynamicCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicCriticalMagneticFluxDensity")
    ChemicalConsumptionPerMass = URIRef("http://qudt.org/vocab/quantitykind/ChemicalConsumptionPerMass")
    MassConcentrationOfWater = URIRef("http://qudt.org/vocab/quantitykind/MassConcentrationOfWater")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    DistanceTraveledDuringBurn = URIRef("http://qudt.org/vocab/quantitykind/DistanceTraveledDuringBurn")
    LogarithmicFrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyInterval")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    ElectromagneticWavePhaseSpeed = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticWavePhaseSpeed")
    LinearForce = URIRef("http://qudt.org/vocab/quantitykind/LinearForce")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    InformationFlowRate = URIRef("http://qudt.org/vocab/quantitykind/InformationFlowRate")
    LineicTorque = URIRef("http://qudt.org/vocab/quantitykind/LineicTorque")
    LogOctanolWaterPartitionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LogOctanolWaterPartitionCoefficient")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    SignalStrength = URIRef("http://qudt.org/vocab/quantitykind/SignalStrength")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    GeneralizedMomentum = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedMomentum")
    LinearStrain = URIRef("http://qudt.org/vocab/quantitykind/LinearStrain")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    ChemicalConsumptionPerMass = URIRef("http://qudt.org/vocab/quantitykind/ChemicalConsumptionPerMass")
    PRODUCT_OF_INERTIA = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    GruneisenParameter = URIRef("http://qudt.org/vocab/quantitykind/GruneisenParameter")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    AreaTimeTemperature = URIRef("http://qudt.org/vocab/quantitykind/AreaTimeTemperature")
    HamiltonFunction = URIRef("http://qudt.org/vocab/quantitykind/HamiltonFunction")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    SpecificOpticalRotationalAbility = URIRef("http://qudt.org/vocab/quantitykind/SpecificOpticalRotationalAbility")
    ThermodynamicCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicCriticalMagneticFluxDensity")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    ResonanceEscapeProbabilityForFission = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbabilityForFission")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    DisplacementCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrentDensity")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    RF_Power = URIRef("http://qudt.org/vocab/quantitykind/RF-Power")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    SoundPressure = URIRef("http://qudt.org/vocab/quantitykind/SoundPressure")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    Exposure = URIRef("http://qudt.org/vocab/quantitykind/Exposure")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    EquilibriumConstantOnPressureBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnPressureBasis")
    CombustionChamberTemperature = URIRef("http://qudt.org/vocab/quantitykind/CombustionChamberTemperature")
    AngularDistance = URIRef("http://qudt.org/vocab/quantitykind/AngularDistance")
    OsmoticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/OsmoticCoefficient")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    DecayConstant = URIRef("http://qudt.org/vocab/quantitykind/DecayConstant")
    VolumetricFlux = URIRef("http://qudt.org/vocab/quantitykind/VolumetricFlux")
    MassAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAbsorptionCoefficient")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    SpecificEnthalpy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnthalpy")
    SectionAreaIntegral = URIRef("http://qudt.org/vocab/quantitykind/SectionAreaIntegral")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    ConvectiveHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/ConvectiveHeatTransfer")
    ThermalInsulation = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulation")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    AmountOfSubstanceFractionOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFractionOfB")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    MagneticDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMoment")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    LinearForce = URIRef("http://qudt.org/vocab/quantitykind/LinearForce")
    SourceVoltage = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltage")
    VolumeOrSectionModulus = URIRef("http://qudt.org/vocab/quantitykind/VolumeOrSectionModulus")
    ChemicalConsumptionPerMass = URIRef("http://qudt.org/vocab/quantitykind/ChemicalConsumptionPerMass")
    CostPerUnitEnergy = URIRef("http://qudt.org/vocab/quantitykind/CostPerUnitEnergy")
    FissionFuelUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionFuelUtilizationFactor")
    SeebeckCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SeebeckCoefficient")
    AmountOfSubstancePerUnitVolume = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitVolume")
    PressureLossPerLength = URIRef("http://qudt.org/vocab/quantitykind/PressureLossPerLength")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    InverseMass_Squared = URIRef("http://qudt.org/vocab/quantitykind/InverseMass_Squared")
    AngularReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/AngularReciprocalLatticeVector")
    Reflectance = URIRef("http://qudt.org/vocab/quantitykind/Reflectance")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    SpecificOpticalRotationalAbility = URIRef("http://qudt.org/vocab/quantitykind/SpecificOpticalRotationalAbility")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    SectionModulus = URIRef("http://qudt.org/vocab/quantitykind/SectionModulus")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    LinearThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/LinearThermalExpansion")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    ConductionSpeed = URIRef("http://qudt.org/vocab/quantitykind/ConductionSpeed")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    PropellantMeanBulkTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantMeanBulkTemperature")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    BurstFactor = URIRef("http://qudt.org/vocab/quantitykind/BurstFactor")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    PressurePercentage = URIRef("http://qudt.org/vocab/quantitykind/PressurePercentage")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    Count = URIRef("http://qudt.org/vocab/quantitykind/Count")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    ThrustToWeightRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToWeightRatio")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    VolumePerArea = URIRef("http://qudt.org/vocab/quantitykind/VolumePerArea")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    InverseMass_Squared = URIRef("http://qudt.org/vocab/quantitykind/InverseMass_Squared")
    FrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/FrictionCoefficient")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    MechanicalMobility = URIRef("http://qudt.org/vocab/quantitykind/MechanicalMobility")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    LuminousFluxPerArea = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxPerArea")
    Reluctance = URIRef("http://qudt.org/vocab/quantitykind/Reluctance")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    HamiltonFunction = URIRef("http://qudt.org/vocab/quantitykind/HamiltonFunction")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    ForcePerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/ForcePerAreaTime")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    ResistanceRatio = URIRef("http://qudt.org/vocab/quantitykind/ResistanceRatio")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    ExitPlaneTemperature = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneTemperature")
    ThermalAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalAdmittance")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    AbsorbedDose = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDose")
    ThrustToWeightRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToWeightRatio")
    ExposureRate = URIRef("http://qudt.org/vocab/quantitykind/ExposureRate")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    DiastolicBloodPressure = URIRef("http://qudt.org/vocab/quantitykind/DiastolicBloodPressure")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    MagneticDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMoment")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    StressIntensityFactor = URIRef("http://qudt.org/vocab/quantitykind/StressIntensityFactor")
    LineicCharge = URIRef("http://qudt.org/vocab/quantitykind/LineicCharge")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    Dissipance = URIRef("http://qudt.org/vocab/quantitykind/Dissipance")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    AverageSpecificImpulse = URIRef("http://qudt.org/vocab/quantitykind/AverageSpecificImpulse")
    Fluidity = URIRef("http://qudt.org/vocab/quantitykind/Fluidity")
    Half_Life = URIRef("http://qudt.org/vocab/quantitykind/Half-Life")
    WaterVaporDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/WaterVaporDiffusionCoefficient")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    TotalIonization = URIRef("http://qudt.org/vocab/quantitykind/TotalIonization")
    ReciprocalVoltage = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalVoltage")
    PressureBasedMolality = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedMolality")
    PressureBurningRateIndex = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateIndex")
    ElectricCurrentPhasor = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPhasor")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    Action = URIRef("http://qudt.org/vocab/quantitykind/Action")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    TemperaturePerTime_Squared = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime_Squared")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    FUEL_BIAS = URIRef("http://qudt.org/vocab/quantitykind/FUEL-BIAS")
    LinearElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrent")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    SeebeckCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SeebeckCoefficient")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    MagneticFluxPerUnitLength = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxPerUnitLength")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    LogarithmRatioToBaseE = URIRef("http://qudt.org/vocab/quantitykind/LogarithmRatioToBaseE")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    ThermalDiffusionRatio = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionRatio")
    ElectricCurrentPerAngle = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerAngle")
    MolarOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/MolarOpticalRotatoryPower")
    PRODUCT_OF_INERTIA_Z = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA_Z")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    TemperatureRatio = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRatio")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    SoundEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SoundEnergyDensity")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    FUEL_BIAS = URIRef("http://qudt.org/vocab/quantitykind/FUEL-BIAS")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    MomentumPerAngle = URIRef("http://qudt.org/vocab/quantitykind/MomentumPerAngle")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    StandardAbsoluteActivity = URIRef("http://qudt.org/vocab/quantitykind/StandardAbsoluteActivity")
    SpecificAcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/SpecificAcousticImpedance")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    Impulse = URIRef("http://qudt.org/vocab/quantitykind/Impulse")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    RotationalStiffness = URIRef("http://qudt.org/vocab/quantitykind/RotationalStiffness")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    DensityOfStates = URIRef("http://qudt.org/vocab/quantitykind/DensityOfStates")
    FastFissionFactor = URIRef("http://qudt.org/vocab/quantitykind/FastFissionFactor")
    ThermodynamicEntropy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEntropy")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    WarpingConstant = URIRef("http://qudt.org/vocab/quantitykind/WarpingConstant")
    FirstStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/FirstStageMassRatio")
    Circulation = URIRef("http://qudt.org/vocab/quantitykind/Circulation")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    AreicChargeDensityOrElectricFluxDensityOrElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/AreicChargeDensityOrElectricFluxDensityOrElectricPolarization")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    LevelWidth = URIRef("http://qudt.org/vocab/quantitykind/LevelWidth")
    TemperatureGradient = URIRef("http://qudt.org/vocab/quantitykind/TemperatureGradient")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    TemperatureBasedVolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedVolumeFlowRate")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    BindingFraction = URIRef("http://qudt.org/vocab/quantitykind/BindingFraction")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    ThermalDiffusionRatio = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionRatio")
    IonDensity = URIRef("http://qudt.org/vocab/quantitykind/IonDensity")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    ThermalCapacitance = URIRef("http://qudt.org/vocab/quantitykind/ThermalCapacitance")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    ElectricConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectricConductivity")
    LinearResistance = URIRef("http://qudt.org/vocab/quantitykind/LinearResistance")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    SpecificVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificVolume")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    Landau_GinzburgNumber = URIRef("http://qudt.org/vocab/quantitykind/Landau-GinzburgNumber")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    ElectricConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectricConductivity")
    MolarAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAttenuationCoefficient")
    RadiantFluence = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluence")
    GFactorOfNucleus = URIRef("http://qudt.org/vocab/quantitykind/GFactorOfNucleus")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    LengthRatio = URIRef("http://qudt.org/vocab/quantitykind/LengthRatio")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    PackingFraction = URIRef("http://qudt.org/vocab/quantitykind/PackingFraction")
    IncidenceRate = URIRef("http://qudt.org/vocab/quantitykind/IncidenceRate")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    ResistanceRatio = URIRef("http://qudt.org/vocab/quantitykind/ResistanceRatio")
    SpecificHeatCapacityAtSaturation = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtSaturation")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    StructuralEfficiency = URIRef("http://qudt.org/vocab/quantitykind/StructuralEfficiency")
    Time_Squared = URIRef("http://qudt.org/vocab/quantitykind/Time_Squared")
    SectionAreaIntegral = URIRef("http://qudt.org/vocab/quantitykind/SectionAreaIntegral")
    LengthTemperature = URIRef("http://qudt.org/vocab/quantitykind/LengthTemperature")
    PhotosyntheticPhotonFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/PhotosyntheticPhotonFluxDensity")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    Resistivity = URIRef("http://qudt.org/vocab/quantitykind/Resistivity")
    CubicElectricDipoleMomentPerSquareEnergy = URIRef("http://qudt.org/vocab/quantitykind/CubicElectricDipoleMomentPerSquareEnergy")
    DoseEquivalentQualityFactor = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalentQualityFactor")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    BucklingFactor = URIRef("http://qudt.org/vocab/quantitykind/BucklingFactor")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    ModulusOfLinearSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfLinearSubgradeReaction")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    KermaRate = URIRef("http://qudt.org/vocab/quantitykind/KermaRate")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    Angle = URIRef("http://qudt.org/vocab/quantitykind/Angle")
    CurvatureFromRadius = URIRef("http://qudt.org/vocab/quantitykind/CurvatureFromRadius")
    LinearVoltageCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearVoltageCoefficient")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    VolumeThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/VolumeThermalExpansion")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    VolumicDataQuantity = URIRef("http://qudt.org/vocab/quantitykind/VolumicDataQuantity")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    ThrustToWeightRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToWeightRatio")
    DryVolume = URIRef("http://qudt.org/vocab/quantitykind/DryVolume")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    MassConcentration = URIRef("http://qudt.org/vocab/quantitykind/MassConcentration")
    BucklingFactor = URIRef("http://qudt.org/vocab/quantitykind/BucklingFactor")
    CouplingFactor = URIRef("http://qudt.org/vocab/quantitykind/CouplingFactor")
    DiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficient")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    NuclearSpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/NuclearSpinQuantumNumber")
    SerumOrPlasmaLevel = URIRef("http://qudt.org/vocab/quantitykind/SerumOrPlasmaLevel")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    AttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AttenuationCoefficient")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    BoilingPoint = URIRef("http://qudt.org/vocab/quantitykind/BoilingPoint")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    MutualInductance = URIRef("http://qudt.org/vocab/quantitykind/MutualInductance")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    HeatFlowRatePerUnitArea = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRatePerUnitArea")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    MassRelatedElectricalCurrent = URIRef("http://qudt.org/vocab/quantitykind/MassRelatedElectricalCurrent")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    LuminousExposure = URIRef("http://qudt.org/vocab/quantitykind/LuminousExposure")
    SoundParticleVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleVelocity")
    LagrangeFunction = URIRef("http://qudt.org/vocab/quantitykind/LagrangeFunction")
    CurrentOfTheAmountOfSubtance = URIRef("http://qudt.org/vocab/quantitykind/CurrentOfTheAmountOfSubtance")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    RadiantIntensity = URIRef("http://qudt.org/vocab/quantitykind/RadiantIntensity")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    Admittance = URIRef("http://qudt.org/vocab/quantitykind/Admittance")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    LinearThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/LinearThermalExpansion")
    TorquePerAngle = URIRef("http://qudt.org/vocab/quantitykind/TorquePerAngle")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    MassicTorque = URIRef("http://qudt.org/vocab/quantitykind/MassicTorque")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    LinearAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAbsorptionCoefficient")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    AngleOfOpticalRotation = URIRef("http://qudt.org/vocab/quantitykind/AngleOfOpticalRotation")
    TotalCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrentDensity")
    VoltageRatio = URIRef("http://qudt.org/vocab/quantitykind/VoltageRatio")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    PowerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerArea")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    SpecificActivity = URIRef("http://qudt.org/vocab/quantitykind/SpecificActivity")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    EquilibriumConstantBasedOnPressure = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantBasedOnPressure")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    ResidualResistivity = URIRef("http://qudt.org/vocab/quantitykind/ResidualResistivity")
    ThermalInsulation = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulation")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    TimeRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRatio")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    FailureRate = URIRef("http://qudt.org/vocab/quantitykind/FailureRate")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    ElectricChargeLineDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeLineDensity")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    Solubility_Water = URIRef("http://qudt.org/vocab/quantitykind/Solubility_Water")
    DoseEquivalentQualityFactor = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalentQualityFactor")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    MassFractionOfWater = URIRef("http://qudt.org/vocab/quantitykind/MassFractionOfWater")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    AngularMomentumPerAngle = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentumPerAngle")
    FermiAngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/FermiAngularWavenumber")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    LinearMass = URIRef("http://qudt.org/vocab/quantitykind/LinearMass")
    ChemicalAffinity = URIRef("http://qudt.org/vocab/quantitykind/ChemicalAffinity")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    SpectralCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralCrossSection")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    MassRatioOfWaterVapourToDryGas = URIRef("http://qudt.org/vocab/quantitykind/MassRatioOfWaterVapourToDryGas")
    StrainEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/StrainEnergyDensity")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    LinearIonization = URIRef("http://qudt.org/vocab/quantitykind/LinearIonization")
    TemperaturePerTime = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime")
    AbsoluteTypographicMeasurement = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteTypographicMeasurement")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    NuclearEnergy = URIRef("http://qudt.org/vocab/quantitykind/NuclearEnergy")
    ElectricField = URIRef("http://qudt.org/vocab/quantitykind/ElectricField")
    ModulusOfSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfSubgradeReaction")
    MagneticQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/MagneticQuantumNumber")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    PressureBurningRateConstant = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateConstant")
    EnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensity")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    SoundParticleVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleVelocity")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    LuminousEmittance = URIRef("http://qudt.org/vocab/quantitykind/LuminousEmittance")
    ThermalUtilizationFactorForFission = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactorForFission")
    ElectricChargePerArea = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerArea")
    LinearTorque = URIRef("http://qudt.org/vocab/quantitykind/LinearTorque")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    MolecularMass = URIRef("http://qudt.org/vocab/quantitykind/MolecularMass")
    PowerPerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerPerArea")
    PressureLossPerLength = URIRef("http://qudt.org/vocab/quantitykind/PressureLossPerLength")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    MolarConductivity = URIRef("http://qudt.org/vocab/quantitykind/MolarConductivity")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    TorquePerLength = URIRef("http://qudt.org/vocab/quantitykind/TorquePerLength")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    StructuralEfficiency = URIRef("http://qudt.org/vocab/quantitykind/StructuralEfficiency")
    LineicTorque = URIRef("http://qudt.org/vocab/quantitykind/LineicTorque")
    Voltage = URIRef("http://qudt.org/vocab/quantitykind/Voltage")
    BurstFactor = URIRef("http://qudt.org/vocab/quantitykind/BurstFactor")
    SpecificHeatsRatio = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatsRatio")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    ParticleCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrentDensity")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    SuperconductionTransitionTemperature = URIRef("http://qudt.org/vocab/quantitykind/SuperconductionTransitionTemperature")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    AverageLogarithmicEnergyDecrement = URIRef("http://qudt.org/vocab/quantitykind/AverageLogarithmicEnergyDecrement")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    IntinsicCarrierDensity = URIRef("http://qudt.org/vocab/quantitykind/IntinsicCarrierDensity")
    MassieuFunction = URIRef("http://qudt.org/vocab/quantitykind/MassieuFunction")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    EinsteinCoefficients = URIRef("http://qudt.org/vocab/quantitykind/EinsteinCoefficients")
    ModulusOfSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfSubgradeReaction")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    PositiveDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/PositiveDimensionlessRatio")
    SoundReductionIndex = URIRef("http://qudt.org/vocab/quantitykind/SoundReductionIndex")
    Exposure = URIRef("http://qudt.org/vocab/quantitykind/Exposure")
    SurfaceCoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/SurfaceCoefficientOfHeatTransfer")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    LogarithmicMedianInformationFlow_SourceToBase10 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicMedianInformationFlow_SourceToBase10")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    RelativeHumidity = URIRef("http://qudt.org/vocab/quantitykind/RelativeHumidity")
    BevelGearPitchAngle = URIRef("http://qudt.org/vocab/quantitykind/BevelGearPitchAngle")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    FermiAngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/FermiAngularWavenumber")
    MeanMassRange = URIRef("http://qudt.org/vocab/quantitykind/MeanMassRange")
    AtomicStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/AtomicStoppingPower")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    SignalStrength = URIRef("http://qudt.org/vocab/quantitykind/SignalStrength")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    ThermalTransmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalTransmittance")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    SpectralLuminousEfficiency = URIRef("http://qudt.org/vocab/quantitykind/SpectralLuminousEfficiency")
    InfiniteMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/InfiniteMultiplicationFactor")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    LogarithmicMedianInformationFlow_SourceToBase2 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicMedianInformationFlow_SourceToBase2")
    ThermalAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalAdmittance")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    AreicTorque = URIRef("http://qudt.org/vocab/quantitykind/AreicTorque")
    PhaseSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/PhaseSpeedOfSound")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    LinearStrain = URIRef("http://qudt.org/vocab/quantitykind/LinearStrain")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    MassConcentration = URIRef("http://qudt.org/vocab/quantitykind/MassConcentration")
    ForcePerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/ForcePerAreaTime")
    AreaPerTime = URIRef("http://qudt.org/vocab/quantitykind/AreaPerTime")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    SourceVoltage = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltage")
    GeneralizedVelocity = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedVelocity")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    NumberDensity = URIRef("http://qudt.org/vocab/quantitykind/NumberDensity")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    Reluctance = URIRef("http://qudt.org/vocab/quantitykind/Reluctance")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    Flux = URIRef("http://qudt.org/vocab/quantitykind/Flux")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    Incidence = URIRef("http://qudt.org/vocab/quantitykind/Incidence")
    SoundParticleAcceleration = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleAcceleration")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    Temperature = URIRef("http://qudt.org/vocab/quantitykind/Temperature")
    AngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentum")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    SecondMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondMomentOfArea")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    CurrencyPerFlight = URIRef("http://qudt.org/vocab/quantitykind/CurrencyPerFlight")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    ThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusivity")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    VaporPermeability = URIRef("http://qudt.org/vocab/quantitykind/VaporPermeability")
    AuxillaryMagneticField = URIRef("http://qudt.org/vocab/quantitykind/AuxillaryMagneticField")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    DryVolume = URIRef("http://qudt.org/vocab/quantitykind/DryVolume")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    Temperature = URIRef("http://qudt.org/vocab/quantitykind/Temperature")
    MolarOpticalRotationalAbility = URIRef("http://qudt.org/vocab/quantitykind/MolarOpticalRotationalAbility")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    AngularDistance = URIRef("http://qudt.org/vocab/quantitykind/AngularDistance")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    SurfaceCoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/SurfaceCoefficientOfHeatTransfer")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    RelativeMassRatioOfVapour = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassRatioOfVapour")
    LinearIonization = URIRef("http://qudt.org/vocab/quantitykind/LinearIonization")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    Radiosity = URIRef("http://qudt.org/vocab/quantitykind/Radiosity")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    IsothermalMoistureCapacity = URIRef("http://qudt.org/vocab/quantitykind/IsothermalMoistureCapacity")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    DynamicFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DynamicFrictionCoefficient")
    ExtentOfReaction = URIRef("http://qudt.org/vocab/quantitykind/ExtentOfReaction")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    DisplacementCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrentDensity")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    LagrangeFunction = URIRef("http://qudt.org/vocab/quantitykind/LagrangeFunction")
    VolumicOutput = URIRef("http://qudt.org/vocab/quantitykind/VolumicOutput")
    ElectricCurrentPerUnitTemperature = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerUnitTemperature")
    BitDataVolume = URIRef("http://qudt.org/vocab/quantitykind/BitDataVolume")
    PolarizationField = URIRef("http://qudt.org/vocab/quantitykind/PolarizationField")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    CatalyticActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivityConcentration")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    ElectromagneticPermeability = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeability")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    TemperatureRelatedVolume = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRelatedVolume")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    StoichiometricNumber = URIRef("http://qudt.org/vocab/quantitykind/StoichiometricNumber")
    IsentropicCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsentropicCompressibility")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    TimeTemperature = URIRef("http://qudt.org/vocab/quantitykind/TimeTemperature")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    SourceVoltageBetweenSubstances = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltageBetweenSubstances")
    HeartRate = URIRef("http://qudt.org/vocab/quantitykind/HeartRate")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    ThermalTransmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalTransmittance")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    IonCurrent = URIRef("http://qudt.org/vocab/quantitykind/IonCurrent")
    AtomScatteringFactor = URIRef("http://qudt.org/vocab/quantitykind/AtomScatteringFactor")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    ElectrolyticConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectrolyticConductivity")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    MutualInductance = URIRef("http://qudt.org/vocab/quantitykind/MutualInductance")
    PhotoThresholdOfAwarenessFunction = URIRef("http://qudt.org/vocab/quantitykind/PhotoThresholdOfAwarenessFunction")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    NumberOfParticles = URIRef("http://qudt.org/vocab/quantitykind/NumberOfParticles")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    MagneticPolarization = URIRef("http://qudt.org/vocab/quantitykind/MagneticPolarization")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    Exposure = URIRef("http://qudt.org/vocab/quantitykind/Exposure")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    NumberDensity = URIRef("http://qudt.org/vocab/quantitykind/NumberDensity")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    PressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PressureCoefficient")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    ReciprocalPlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalPlaneAngle")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    TotalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentumQuantumNumber")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    MagnetizationField = URIRef("http://qudt.org/vocab/quantitykind/MagnetizationField")
    Susceptance = URIRef("http://qudt.org/vocab/quantitykind/Susceptance")
    MicrobialFormation = URIRef("http://qudt.org/vocab/quantitykind/MicrobialFormation")
    PressureBurningRateConstant = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateConstant")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    RotaryShock = URIRef("http://qudt.org/vocab/quantitykind/RotaryShock")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    EffectiveExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/EffectiveExhaustVelocity")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    MagneticPolarization = URIRef("http://qudt.org/vocab/quantitykind/MagneticPolarization")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    AreaPerPower = URIRef("http://qudt.org/vocab/quantitykind/AreaPerPower")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    LiquidVolume = URIRef("http://qudt.org/vocab/quantitykind/LiquidVolume")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    VolumeOrSectionModulus = URIRef("http://qudt.org/vocab/quantitykind/VolumeOrSectionModulus")
    IonicStrength = URIRef("http://qudt.org/vocab/quantitykind/IonicStrength")
    SecondOrderReactionRateConstant = URIRef("http://qudt.org/vocab/quantitykind/SecondOrderReactionRateConstant")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    Time_Squared = URIRef("http://qudt.org/vocab/quantitykind/Time_Squared")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    InverseSquareEnergy = URIRef("http://qudt.org/vocab/quantitykind/InverseSquareEnergy")
    Chromaticity = URIRef("http://qudt.org/vocab/quantitykind/Chromaticity")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    StaticFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StaticFrictionCoefficient")
    ThermalDiffusionRatioCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionRatioCoefficient")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    OrbitalAngularMomentumPerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/OrbitalAngularMomentumPerUnitMass")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    RichardsonConstant = URIRef("http://qudt.org/vocab/quantitykind/RichardsonConstant")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    RelativePressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/RelativePressureCoefficient")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    Resistivity = URIRef("http://qudt.org/vocab/quantitykind/Resistivity")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    LiftCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LiftCoefficient")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    DebyeTemperature = URIRef("http://qudt.org/vocab/quantitykind/DebyeTemperature")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    MolarAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAbsorptionCoefficient")
    GeneralizedCoordinate = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedCoordinate")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    SpectralCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralCrossSection")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    ThermalTransmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalTransmittance")
    TimeRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRatio")
    PressureBurningRateIndex = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateIndex")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    DisplacementCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrentDensity")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    Viscosity = URIRef("http://qudt.org/vocab/quantitykind/Viscosity")
    TotalCurrent = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrent")
    BloodGlucoseLevel = URIRef("http://qudt.org/vocab/quantitykind/BloodGlucoseLevel")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    FlightPathAngle = URIRef("http://qudt.org/vocab/quantitykind/FlightPathAngle")
    PhotonLuminance = URIRef("http://qudt.org/vocab/quantitykind/PhotonLuminance")
    AreaPerLength = URIRef("http://qudt.org/vocab/quantitykind/AreaPerLength")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    SurfaceRelatedVolumeFlow = URIRef("http://qudt.org/vocab/quantitykind/SurfaceRelatedVolumeFlow")
    MagneticDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMoment")
    SourceVoltage = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltage")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    ElectricChargeLinearDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeLinearDensity")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    SecondOrderReactionRateConstant = URIRef("http://qudt.org/vocab/quantitykind/SecondOrderReactionRateConstant")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    MolarThermalCapacity = URIRef("http://qudt.org/vocab/quantitykind/MolarThermalCapacity")
    ThermalTransmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalTransmittance")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    KermaRate = URIRef("http://qudt.org/vocab/quantitykind/KermaRate")
    Viscosity = URIRef("http://qudt.org/vocab/quantitykind/Viscosity")
    Angle = URIRef("http://qudt.org/vocab/quantitykind/Angle")
    BatteryCapacity = URIRef("http://qudt.org/vocab/quantitykind/BatteryCapacity")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    PressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PressureCoefficient")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    ElectricChargePerArea = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerArea")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    TotalCurrent = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrent")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    InitialExpansionRatio = URIRef("http://qudt.org/vocab/quantitykind/InitialExpansionRatio")
    DisplacementCurrent = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrent")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    ElectricQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricQuadrupoleMoment")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    Resistivity = URIRef("http://qudt.org/vocab/quantitykind/Resistivity")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    AreaTime = URIRef("http://qudt.org/vocab/quantitykind/AreaTime")
    AreaPerTime = URIRef("http://qudt.org/vocab/quantitykind/AreaPerTime")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    FlashPoint = URIRef("http://qudt.org/vocab/quantitykind/FlashPoint")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    NeelTemperature = URIRef("http://qudt.org/vocab/quantitykind/NeelTemperature")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    GyromagneticRatio = URIRef("http://qudt.org/vocab/quantitykind/GyromagneticRatio")
    KineticOrThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticOrThermalEnergy")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    StateDensity = URIRef("http://qudt.org/vocab/quantitykind/StateDensity")
    LengthTemperatureTime = URIRef("http://qudt.org/vocab/quantitykind/LengthTemperatureTime")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    CyclotronAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/CyclotronAngularFrequency")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    NumberOfParticles = URIRef("http://qudt.org/vocab/quantitykind/NumberOfParticles")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    FissionCoreRadiusToHeightRatio = URIRef("http://qudt.org/vocab/quantitykind/FissionCoreRadiusToHeightRatio")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    SpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/SpinQuantumNumber")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    Dimensionless = URIRef("http://qudt.org/vocab/quantitykind/Dimensionless")
    ChemicalAffinity = URIRef("http://qudt.org/vocab/quantitykind/ChemicalAffinity")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    LeakageFactor = URIRef("http://qudt.org/vocab/quantitykind/LeakageFactor")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    DewPointTemperature = URIRef("http://qudt.org/vocab/quantitykind/DewPointTemperature")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    PressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PressureCoefficient")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    MagneticDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMoment")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    SpecificHeatPressure = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatPressure")
    SpecificThrust = URIRef("http://qudt.org/vocab/quantitykind/SpecificThrust")
    IonTransportNumber = URIRef("http://qudt.org/vocab/quantitykind/IonTransportNumber")
    GasLeakRate = URIRef("http://qudt.org/vocab/quantitykind/GasLeakRate")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    Angle = URIRef("http://qudt.org/vocab/quantitykind/Angle")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    SpecificOpticalRotationalAbility = URIRef("http://qudt.org/vocab/quantitykind/SpecificOpticalRotationalAbility")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    StrainEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/StrainEnergyDensity")
    SpecificHeatCapacityAtConstantVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantVolume")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    MassFractionOfWater = URIRef("http://qudt.org/vocab/quantitykind/MassFractionOfWater")
    MeanMassRange = URIRef("http://qudt.org/vocab/quantitykind/MeanMassRange")
    InversePressure = URIRef("http://qudt.org/vocab/quantitykind/InversePressure")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    ElectricChargePerArea = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerArea")
    Viscosity = URIRef("http://qudt.org/vocab/quantitykind/Viscosity")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    Vorticity = URIRef("http://qudt.org/vocab/quantitykind/Vorticity")
    SoundExposure = URIRef("http://qudt.org/vocab/quantitykind/SoundExposure")
    QualityFactor = URIRef("http://qudt.org/vocab/quantitykind/QualityFactor")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    LinkedFlux = URIRef("http://qudt.org/vocab/quantitykind/LinkedFlux")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    ActivityThresholds = URIRef("http://qudt.org/vocab/quantitykind/ActivityThresholds")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    AtomicEnergy = URIRef("http://qudt.org/vocab/quantitykind/AtomicEnergy")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    AmountOfSubstanceConcentrationOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentrationOfB")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    ElectricChargeLineDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeLineDensity")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    ElectricChargePerAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerAmountOfSubstance")
    TemporalSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/TemporalSummationFunction")
    ForcePerLength = URIRef("http://qudt.org/vocab/quantitykind/ForcePerLength")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    TotalRadiance = URIRef("http://qudt.org/vocab/quantitykind/TotalRadiance")
    Viscosity = URIRef("http://qudt.org/vocab/quantitykind/Viscosity")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    RecombinationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/RecombinationCoefficient")
    HallCoefficient = URIRef("http://qudt.org/vocab/quantitykind/HallCoefficient")
    TotalRadiance = URIRef("http://qudt.org/vocab/quantitykind/TotalRadiance")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    MolarAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAbsorptionCoefficient")
    DegreeOfDissociation = URIRef("http://qudt.org/vocab/quantitykind/DegreeOfDissociation")
    EnergyPerSquareMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerSquareMagneticFluxDensity")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    Temperature = URIRef("http://qudt.org/vocab/quantitykind/Temperature")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    ElectricChargeSurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeSurfaceDensity")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    VolumetricOutputPower = URIRef("http://qudt.org/vocab/quantitykind/VolumetricOutputPower")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    MagneticFluxPerUnitLength = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxPerUnitLength")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    AngularReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/AngularReciprocalLatticeVector")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    MolecularViscosity = URIRef("http://qudt.org/vocab/quantitykind/MolecularViscosity")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    InverseEnergy_Squared = URIRef("http://qudt.org/vocab/quantitykind/InverseEnergy_Squared")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    MorbidityRate = URIRef("http://qudt.org/vocab/quantitykind/MorbidityRate")
    VoltageRatio = URIRef("http://qudt.org/vocab/quantitykind/VoltageRatio")
    Rotary_TranslatoryMotionConversion = URIRef("http://qudt.org/vocab/quantitykind/Rotary-TranslatoryMotionConversion")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    GasLeakRate = URIRef("http://qudt.org/vocab/quantitykind/GasLeakRate")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    LinearAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAttenuationCoefficient")
    DecayConstant = URIRef("http://qudt.org/vocab/quantitykind/DecayConstant")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    LogarithmicFrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyInterval")
    PoissonRatio = URIRef("http://qudt.org/vocab/quantitykind/PoissonRatio")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    MolarEntropy = URIRef("http://qudt.org/vocab/quantitykind/MolarEntropy")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    SurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceDensity")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    ThermalAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalAdmittance")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    LinearElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrentDensity")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    SpecificHeatCapacityAtConstantPressure = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantPressure")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    MassPerLength = URIRef("http://qudt.org/vocab/quantitykind/MassPerLength")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    LinearMomentum = URIRef("http://qudt.org/vocab/quantitykind/LinearMomentum")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    PositivePlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PositivePlaneAngle")
    SuperconductionTransitionTemperature = URIRef("http://qudt.org/vocab/quantitykind/SuperconductionTransitionTemperature")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    VolumicDataQuantity = URIRef("http://qudt.org/vocab/quantitykind/VolumicDataQuantity")
    ElectromagneticPermeabilityRatio = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeabilityRatio")
    ElectricalConductance = URIRef("http://qudt.org/vocab/quantitykind/ElectricalConductance")
    Emissivity = URIRef("http://qudt.org/vocab/quantitykind/Emissivity")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    MagneticPolarization = URIRef("http://qudt.org/vocab/quantitykind/MagneticPolarization")
    EffectiveMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMultiplicationFactor")
    RelativeMassDensity = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDensity")
    VolumetricHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/VolumetricHeatCapacity")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    AreaTimeTemperature = URIRef("http://qudt.org/vocab/quantitykind/AreaTimeTemperature")
    AngularDistance = URIRef("http://qudt.org/vocab/quantitykind/AngularDistance")
    InverseEnergy_Squared = URIRef("http://qudt.org/vocab/quantitykind/InverseEnergy_Squared")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    Prevalence = URIRef("http://qudt.org/vocab/quantitykind/Prevalence")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    LuminousEmittance = URIRef("http://qudt.org/vocab/quantitykind/LuminousEmittance")
    LuminousExitance = URIRef("http://qudt.org/vocab/quantitykind/LuminousExitance")
    MOMENT_OF_INERTIA_Z = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Z")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    LorenzCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LorenzCoefficient")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    VisionThresholds = URIRef("http://qudt.org/vocab/quantitykind/VisionThresholds")
    LinearBitDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearBitDensity")
    GeneralizedMomentum = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedMomentum")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    LengthEnergy = URIRef("http://qudt.org/vocab/quantitykind/LengthEnergy")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    DatasetOfBytes = URIRef("http://qudt.org/vocab/quantitykind/DatasetOfBytes")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    ElectromagneticPermeability = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeability")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    CatalyticActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivityConcentration")
    ResonanceEscapeProbabilityForFission = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbabilityForFission")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    PressureBasedTemperature = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedTemperature")
    AuxillaryMagneticField = URIRef("http://qudt.org/vocab/quantitykind/AuxillaryMagneticField")
    Constringence = URIRef("http://qudt.org/vocab/quantitykind/Constringence")
    VolumetricHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/VolumetricHeatCapacity")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    CharacteristicAcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicAcousticImpedance")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    ElectricCurrentPhasor = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPhasor")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    AmountOfSubstanceConcentrationOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentrationOfB")
    DryVolume = URIRef("http://qudt.org/vocab/quantitykind/DryVolume")
    PolarizationField = URIRef("http://qudt.org/vocab/quantitykind/PolarizationField")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    ElectricDisplacement = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacement")
    ScalarMagneticPotential = URIRef("http://qudt.org/vocab/quantitykind/ScalarMagneticPotential")
    SurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceDensity")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    NormalizedDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/NormalizedDimensionlessRatio")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    SpecificSurfaceArea = URIRef("http://qudt.org/vocab/quantitykind/SpecificSurfaceArea")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    MolarAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAttenuationCoefficient")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    RelativeHumidity = URIRef("http://qudt.org/vocab/quantitykind/RelativeHumidity")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    SourceVoltage = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltage")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    LinearElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCharge")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    DewPointTemperature = URIRef("http://qudt.org/vocab/quantitykind/DewPointTemperature")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    StrainEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/StrainEnergyDensity")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    PoyntingVector = URIRef("http://qudt.org/vocab/quantitykind/PoyntingVector")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    Prevalence = URIRef("http://qudt.org/vocab/quantitykind/Prevalence")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    QuantityOfLight = URIRef("http://qudt.org/vocab/quantitykind/QuantityOfLight")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    MolarAngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/MolarAngularMomentum")
    KermaRate = URIRef("http://qudt.org/vocab/quantitykind/KermaRate")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    PressurePercentage = URIRef("http://qudt.org/vocab/quantitykind/PressurePercentage")
    MassicActivity = URIRef("http://qudt.org/vocab/quantitykind/MassicActivity")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    MolarFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MolarFlowRate")
    DensityOfStates = URIRef("http://qudt.org/vocab/quantitykind/DensityOfStates")
    SeebeckCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SeebeckCoefficient")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    Half_Life = URIRef("http://qudt.org/vocab/quantitykind/Half-Life")
    AreaTemperature = URIRef("http://qudt.org/vocab/quantitykind/AreaTemperature")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    TransmittanceDensity = URIRef("http://qudt.org/vocab/quantitykind/TransmittanceDensity")
    PayloadRatio = URIRef("http://qudt.org/vocab/quantitykind/PayloadRatio")
    IncidenceRate = URIRef("http://qudt.org/vocab/quantitykind/IncidenceRate")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    MassPerTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerTime")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    MagnetomotiveForce = URIRef("http://qudt.org/vocab/quantitykind/MagnetomotiveForce")
    LarmorAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/LarmorAngularFrequency")
    SpecificModulus = URIRef("http://qudt.org/vocab/quantitykind/SpecificModulus")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    Susceptance = URIRef("http://qudt.org/vocab/quantitykind/Susceptance")
    DewPointTemperature = URIRef("http://qudt.org/vocab/quantitykind/DewPointTemperature")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    MassAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAttenuationCoefficient")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    SurfaceActivityDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceActivityDensity")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    NonActivePower = URIRef("http://qudt.org/vocab/quantitykind/NonActivePower")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    PressureBasedVolume = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedVolume")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    MechanicalImpedance = URIRef("http://qudt.org/vocab/quantitykind/MechanicalImpedance")
    LengthByForce = URIRef("http://qudt.org/vocab/quantitykind/LengthByForce")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    CoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/CoefficientOfHeatTransfer")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    AreaPerLength = URIRef("http://qudt.org/vocab/quantitykind/AreaPerLength")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    QualityFactor = URIRef("http://qudt.org/vocab/quantitykind/QualityFactor")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    SpecificWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificWeight")
    DryVolume = URIRef("http://qudt.org/vocab/quantitykind/DryVolume")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    OlfactoryThreshold = URIRef("http://qudt.org/vocab/quantitykind/OlfactoryThreshold")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    PressureBasedMassFlow = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedMassFlow")
    LuminousExposure = URIRef("http://qudt.org/vocab/quantitykind/LuminousExposure")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    EnergyPerTemperature = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerTemperature")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    AtomicNumber = URIRef("http://qudt.org/vocab/quantitykind/AtomicNumber")
    Basicity = URIRef("http://qudt.org/vocab/quantitykind/Basicity")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    PhotonIntensity = URIRef("http://qudt.org/vocab/quantitykind/PhotonIntensity")
    Capacitance = URIRef("http://qudt.org/vocab/quantitykind/Capacitance")
    Curvature = URIRef("http://qudt.org/vocab/quantitykind/Curvature")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    ThermalInsulance = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulance")
    MechanicalMobility = URIRef("http://qudt.org/vocab/quantitykind/MechanicalMobility")
    RelativeHumidity = URIRef("http://qudt.org/vocab/quantitykind/RelativeHumidity")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    EnergyPerArea = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerArea")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    AtomScatteringFactor = URIRef("http://qudt.org/vocab/quantitykind/AtomScatteringFactor")
    ElectricChargeLineDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeLineDensity")
    TemperatureRatio = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRatio")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    ActivityRelatedByMass = URIRef("http://qudt.org/vocab/quantitykind/ActivityRelatedByMass")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    LinearThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/LinearThermalExpansion")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    ElectromagneticEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticEnergyDensity")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    Period = URIRef("http://qudt.org/vocab/quantitykind/Period")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    EnergyPerMagneticFluxDensity_Squared = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerMagneticFluxDensity_Squared")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    ActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/ActivityConcentration")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    ScalarMagneticPotential = URIRef("http://qudt.org/vocab/quantitykind/ScalarMagneticPotential")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    SpectralCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralCrossSection")
    BulkModulus = URIRef("http://qudt.org/vocab/quantitykind/BulkModulus")
    LineicLogarithmicRatio = URIRef("http://qudt.org/vocab/quantitykind/LineicLogarithmicRatio")
    StrainEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/StrainEnergyDensity")
    RelativeMassExcess = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassExcess")
    ThermalDiffusionRatio = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionRatio")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    AmountOfSubstancePerUnitVolume = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitVolume")
    MicrobialFormation = URIRef("http://qudt.org/vocab/quantitykind/MicrobialFormation")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    AreaAngle = URIRef("http://qudt.org/vocab/quantitykind/AreaAngle")
    HyperfineStructureQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/HyperfineStructureQuantumNumber")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    ElectricChargeSurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeSurfaceDensity")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    InformationContentExpressedAsALogarithmToBaseE = URIRef("http://qudt.org/vocab/quantitykind/InformationContentExpressedAsALogarithmToBaseE")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    SpecificHeatPressure = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatPressure")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    AreicTorque = URIRef("http://qudt.org/vocab/quantitykind/AreicTorque")
    LiftCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LiftCoefficient")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    StaticFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StaticFrictionCoefficient")
    StateDensityAsExpressionOfAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/StateDensityAsExpressionOfAngularFrequency")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    GroupSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/GroupSpeedOfSound")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    LandeGFactor = URIRef("http://qudt.org/vocab/quantitykind/LandeGFactor")
    MolarEntropy = URIRef("http://qudt.org/vocab/quantitykind/MolarEntropy")
    ConductionSpeed = URIRef("http://qudt.org/vocab/quantitykind/ConductionSpeed")
    OrbitalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/OrbitalAngularMomentumQuantumNumber")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    InformationContentExpressedAsALogarithmToBase10 = URIRef("http://qudt.org/vocab/quantitykind/InformationContentExpressedAsALogarithmToBase10")
    LengthEnergy = URIRef("http://qudt.org/vocab/quantitykind/LengthEnergy")
    LinearDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearDensity")
    Reflectance = URIRef("http://qudt.org/vocab/quantitykind/Reflectance")
    PropagationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PropagationCoefficient")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    TemperatureRateOfChange = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRateOfChange")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    CurvatureFromRadius = URIRef("http://qudt.org/vocab/quantitykind/CurvatureFromRadius")
    Mobility = URIRef("http://qudt.org/vocab/quantitykind/Mobility")
    DisplacementCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrentDensity")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    MassFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MassFluxDensity")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    ThermalCapacitance = URIRef("http://qudt.org/vocab/quantitykind/ThermalCapacitance")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    OrbitalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/OrbitalAngularMomentumQuantumNumber")
    ScalarMagneticPotential = URIRef("http://qudt.org/vocab/quantitykind/ScalarMagneticPotential")
    MassConcentration = URIRef("http://qudt.org/vocab/quantitykind/MassConcentration")
    GroupSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/GroupSpeedOfSound")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    MagnetomotiveForce = URIRef("http://qudt.org/vocab/quantitykind/MagnetomotiveForce")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    EnergyPerSquareMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerSquareMagneticFluxDensity")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    AmountOfSubstancePerUnitVolume = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitVolume")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    CanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/CanonicalPartitionFunction")
    Prevalence = URIRef("http://qudt.org/vocab/quantitykind/Prevalence")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    MagneticAreaMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticAreaMoment")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    PayloadRatio = URIRef("http://qudt.org/vocab/quantitykind/PayloadRatio")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    MassRatio = URIRef("http://qudt.org/vocab/quantitykind/MassRatio")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    PolarMomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/PolarMomentOfInertia")
    CurrencyPerFlight = URIRef("http://qudt.org/vocab/quantitykind/CurrencyPerFlight")
    UpperCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/UpperCriticalMagneticFluxDensity")
    VisionThresholds = URIRef("http://qudt.org/vocab/quantitykind/VisionThresholds")
    RelativeMassConcentrationOfVapour = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassConcentrationOfVapour")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    PhaseCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PhaseCoefficient")
    LossFactor = URIRef("http://qudt.org/vocab/quantitykind/LossFactor")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    Speed = URIRef("http://qudt.org/vocab/quantitykind/Speed")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    LarmorAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/LarmorAngularFrequency")
    SpecificModulus = URIRef("http://qudt.org/vocab/quantitykind/SpecificModulus")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    LinearTorque = URIRef("http://qudt.org/vocab/quantitykind/LinearTorque")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    NuclearSpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/NuclearSpinQuantumNumber")
    ElectricQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricQuadrupoleMoment")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    LinearBitDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearBitDensity")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    CombinedNonEvaporativeHeatTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CombinedNonEvaporativeHeatTransferCoefficient")
    VentilationRatePerFloorArea = URIRef("http://qudt.org/vocab/quantitykind/VentilationRatePerFloorArea")
    LossAngle = URIRef("http://qudt.org/vocab/quantitykind/LossAngle")
    AmountOfSubstancePerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMass")
    SoundParticleAcceleration = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleAcceleration")
    ConductiveHeatTransferRate = URIRef("http://qudt.org/vocab/quantitykind/ConductiveHeatTransferRate")
    MolarEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarEnergy")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    FrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/FrictionCoefficient")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    StoichiometricNumber = URIRef("http://qudt.org/vocab/quantitykind/StoichiometricNumber")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    ReciprocalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalEnergy")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    CostPerUnitEnergy = URIRef("http://qudt.org/vocab/quantitykind/CostPerUnitEnergy")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    MolarEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarEnergy")
    RelativeMassDensity = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDensity")
    EnergyPerArea = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerArea")
    ElectricCurrentPerUnitLength = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerUnitLength")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    StructuralEfficiency = URIRef("http://qudt.org/vocab/quantitykind/StructuralEfficiency")
    Duv = URIRef("http://qudt.org/vocab/quantitykind/Duv")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    InitialExpansionRatio = URIRef("http://qudt.org/vocab/quantitykind/InitialExpansionRatio")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    MassRatioOfWaterVapourToDryGas = URIRef("http://qudt.org/vocab/quantitykind/MassRatioOfWaterVapourToDryGas")
    ThermalDiffusionFactor = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionFactor")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    CharacteristicAcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicAcousticImpedance")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    Speed = URIRef("http://qudt.org/vocab/quantitykind/Speed")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    ElectricField = URIRef("http://qudt.org/vocab/quantitykind/ElectricField")
    Reflectance = URIRef("http://qudt.org/vocab/quantitykind/Reflectance")
    PhotonRadiance = URIRef("http://qudt.org/vocab/quantitykind/PhotonRadiance")
    DistanceTraveledDuringBurn = URIRef("http://qudt.org/vocab/quantitykind/DistanceTraveledDuringBurn")
    Compressibility = URIRef("http://qudt.org/vocab/quantitykind/Compressibility")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    TotalMassStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalMassStoppingPower")
    WarpingConstant = URIRef("http://qudt.org/vocab/quantitykind/WarpingConstant")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    PoyntingVector = URIRef("http://qudt.org/vocab/quantitykind/PoyntingVector")
    CurvatureFromRadius = URIRef("http://qudt.org/vocab/quantitykind/CurvatureFromRadius")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    RateOfRiseOfVoltage = URIRef("http://qudt.org/vocab/quantitykind/RateOfRiseOfVoltage")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    SpecificGibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificGibbsEnergy")
    Radiosity = URIRef("http://qudt.org/vocab/quantitykind/Radiosity")
    LinearCompressibility = URIRef("http://qudt.org/vocab/quantitykind/LinearCompressibility")
    ReciprocalPlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalPlaneAngle")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    FlashPoint = URIRef("http://qudt.org/vocab/quantitykind/FlashPoint")
    RelativePartialPressure = URIRef("http://qudt.org/vocab/quantitykind/RelativePartialPressure")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    VolumetricHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/VolumetricHeatCapacity")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    VaporPermeability = URIRef("http://qudt.org/vocab/quantitykind/VaporPermeability")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    MassRatio = URIRef("http://qudt.org/vocab/quantitykind/MassRatio")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    ElectricDisplacement = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacement")
    PressureBurningRateIndex = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateIndex")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    TorqueConstant = URIRef("http://qudt.org/vocab/quantitykind/TorqueConstant")
    ConductionSpeed = URIRef("http://qudt.org/vocab/quantitykind/ConductionSpeed")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    NumberDensity = URIRef("http://qudt.org/vocab/quantitykind/NumberDensity")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    MassFractionOfDryMatter = URIRef("http://qudt.org/vocab/quantitykind/MassFractionOfDryMatter")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    VolumeThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/VolumeThermalExpansion")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    MolalityOfSolute = URIRef("http://qudt.org/vocab/quantitykind/MolalityOfSolute")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    CharacteristicNumber = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicNumber")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    SpecificHeatCapacityAtSaturation = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtSaturation")
    ElectricConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectricConductivity")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    EinsteinTransitionProbabilityForSpontaneousOrInducedEmissionAndAbsorption = URIRef("http://qudt.org/vocab/quantitykind/EinsteinTransitionProbabilityForSpontaneousOrInducedEmissionAndAbsorption")
    Unbalance = URIRef("http://qudt.org/vocab/quantitykind/Unbalance")
    LogarithmicFrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyInterval")
    InverseSquareMass = URIRef("http://qudt.org/vocab/quantitykind/InverseSquareMass")
    InverseTemperature = URIRef("http://qudt.org/vocab/quantitykind/InverseTemperature")
    LinearEnergyTransfer = URIRef("http://qudt.org/vocab/quantitykind/LinearEnergyTransfer")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    OsmoticPressure = URIRef("http://qudt.org/vocab/quantitykind/OsmoticPressure")
    MassieuFunction = URIRef("http://qudt.org/vocab/quantitykind/MassieuFunction")
    RadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergyDensity")
    ReynoldsNumber = URIRef("http://qudt.org/vocab/quantitykind/ReynoldsNumber")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    WaterVapourPermeability = URIRef("http://qudt.org/vocab/quantitykind/WaterVapourPermeability")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    ColdReceptorThreshold = URIRef("http://qudt.org/vocab/quantitykind/ColdReceptorThreshold")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    LuminousEfficacy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEfficacy")
    PhotosyntheticPhotonFlux = URIRef("http://qudt.org/vocab/quantitykind/PhotosyntheticPhotonFlux")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    TorquePerLength = URIRef("http://qudt.org/vocab/quantitykind/TorquePerLength")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    DynamicFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DynamicFrictionCoefficient")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    Capacity = URIRef("http://qudt.org/vocab/quantitykind/Capacity")
    AmountOfSubstancePerUnitVolume = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitVolume")
    Conductance = URIRef("http://qudt.org/vocab/quantitykind/Conductance")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    IntinsicCarrierDensity = URIRef("http://qudt.org/vocab/quantitykind/IntinsicCarrierDensity")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    PlanckFunction = URIRef("http://qudt.org/vocab/quantitykind/PlanckFunction")
    EquivalenceDoseOutput = URIRef("http://qudt.org/vocab/quantitykind/EquivalenceDoseOutput")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    ParticleSourceDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleSourceDensity")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    VolumetricOutputPower = URIRef("http://qudt.org/vocab/quantitykind/VolumetricOutputPower")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    Admittance = URIRef("http://qudt.org/vocab/quantitykind/Admittance")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    LuminousEmittance = URIRef("http://qudt.org/vocab/quantitykind/LuminousEmittance")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    Non_LeakageProbability = URIRef("http://qudt.org/vocab/quantitykind/Non-LeakageProbability")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    LineicPower = URIRef("http://qudt.org/vocab/quantitykind/LineicPower")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    RadiantFluence = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluence")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    LossAngle = URIRef("http://qudt.org/vocab/quantitykind/LossAngle")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    HeatFlowRatePerUnitArea = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRatePerUnitArea")
    TemperatureBasedDensity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedDensity")
    FirstStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/FirstStageMassRatio")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    MagneticDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMoment")
    VoltagePhasor = URIRef("http://qudt.org/vocab/quantitykind/VoltagePhasor")
    ColdReceptorThreshold = URIRef("http://qudt.org/vocab/quantitykind/ColdReceptorThreshold")
    SoundParticleVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleVelocity")
    Reluctance = URIRef("http://qudt.org/vocab/quantitykind/Reluctance")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    MagneticTension = URIRef("http://qudt.org/vocab/quantitykind/MagneticTension")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    DecayConstant = URIRef("http://qudt.org/vocab/quantitykind/DecayConstant")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    FissionMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionMultiplicationFactor")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    PowerPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/PowerPerElectricCharge")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    DonorDensity = URIRef("http://qudt.org/vocab/quantitykind/DonorDensity")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    InitialExpansionRatio = URIRef("http://qudt.org/vocab/quantitykind/InitialExpansionRatio")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    ModulusOfImpedance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfImpedance")
    PowerPerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerPerArea")
    LogarithmicFrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyInterval")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    MolarOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/MolarOpticalRotatoryPower")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    LogarithmicFrequencyIntervalToBase10 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyIntervalToBase10")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    ColdReceptorThreshold = URIRef("http://qudt.org/vocab/quantitykind/ColdReceptorThreshold")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    Conductance = URIRef("http://qudt.org/vocab/quantitykind/Conductance")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    StrainEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/StrainEnergyDensity")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    AverageSpecificImpulse = URIRef("http://qudt.org/vocab/quantitykind/AverageSpecificImpulse")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    RadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergyDensity")
    PRODUCT_OF_INERTIA_Y = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA_Y")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    FloatingPointCalculationCapability = URIRef("http://qudt.org/vocab/quantitykind/FloatingPointCalculationCapability")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    LineicDataVolume = URIRef("http://qudt.org/vocab/quantitykind/LineicDataVolume")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    LinearAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAttenuationCoefficient")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    ForceConstant = URIRef("http://qudt.org/vocab/quantitykind/ForceConstant")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    LineicPower = URIRef("http://qudt.org/vocab/quantitykind/LineicPower")
    LogOctanolWaterPartitionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LogOctanolWaterPartitionCoefficient")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    ThermalResistivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistivity")
    TransmittanceDensity = URIRef("http://qudt.org/vocab/quantitykind/TransmittanceDensity")
    StandardAbsoluteActivity = URIRef("http://qudt.org/vocab/quantitykind/StandardAbsoluteActivity")
    ComplexPower = URIRef("http://qudt.org/vocab/quantitykind/ComplexPower")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    TotalMassStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalMassStoppingPower")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    StrainEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/StrainEnergyDensity")
    StaticFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StaticFrictionCoefficient")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    PropellantBurnRate = URIRef("http://qudt.org/vocab/quantitykind/PropellantBurnRate")
    SectionAreaIntegral = URIRef("http://qudt.org/vocab/quantitykind/SectionAreaIntegral")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    SpectralRadiantEnergyDensityInTermsOfWavelength = URIRef("http://qudt.org/vocab/quantitykind/SpectralRadiantEnergyDensityInTermsOfWavelength")
    TemporalSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/TemporalSummationFunction")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    TotalMassStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalMassStoppingPower")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    PowerAreaPerSolidAngle = URIRef("http://qudt.org/vocab/quantitykind/PowerAreaPerSolidAngle")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    ThermalAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalAdmittance")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    FermiTemperature = URIRef("http://qudt.org/vocab/quantitykind/FermiTemperature")
    ElectricFlux = URIRef("http://qudt.org/vocab/quantitykind/ElectricFlux")
    HeadEndPressure = URIRef("http://qudt.org/vocab/quantitykind/HeadEndPressure")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    ForcePerLength = URIRef("http://qudt.org/vocab/quantitykind/ForcePerLength")
    LinearStrain = URIRef("http://qudt.org/vocab/quantitykind/LinearStrain")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    LowerCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/LowerCriticalMagneticFluxDensity")
    PressureBurningRateIndex = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateIndex")
    Half_Life = URIRef("http://qudt.org/vocab/quantitykind/Half-Life")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    MolarEntropy = URIRef("http://qudt.org/vocab/quantitykind/MolarEntropy")
    MassFraction = URIRef("http://qudt.org/vocab/quantitykind/MassFraction")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    LossFactor = URIRef("http://qudt.org/vocab/quantitykind/LossFactor")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    PressureInRelationToVolumeFlow = URIRef("http://qudt.org/vocab/quantitykind/PressureInRelationToVolumeFlow")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    IncidenceProportion = URIRef("http://qudt.org/vocab/quantitykind/IncidenceProportion")
    LineicCharge = URIRef("http://qudt.org/vocab/quantitykind/LineicCharge")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    MobilityRatio = URIRef("http://qudt.org/vocab/quantitykind/MobilityRatio")
    PressureBasedVolume = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedVolume")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    FissionFuelUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionFuelUtilizationFactor")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    FermiAngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/FermiAngularWavenumber")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    MassFraction = URIRef("http://qudt.org/vocab/quantitykind/MassFraction")
    SoundParticleAcceleration = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleAcceleration")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    SpecificEnthalpy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnthalpy")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    ReciprocalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalEnergy")
    LuminousFluxPerArea = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxPerArea")
    RF_Power = URIRef("http://qudt.org/vocab/quantitykind/RF-Power")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    RiseOfOffStateVoltage = URIRef("http://qudt.org/vocab/quantitykind/RiseOfOffStateVoltage")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    ExtentOfReaction = URIRef("http://qudt.org/vocab/quantitykind/ExtentOfReaction")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    NumberDensity = URIRef("http://qudt.org/vocab/quantitykind/NumberDensity")
    PositivePlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PositivePlaneAngle")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    RotationalStiffness = URIRef("http://qudt.org/vocab/quantitykind/RotationalStiffness")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    LineicCharge = URIRef("http://qudt.org/vocab/quantitykind/LineicCharge")
    NeutronDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionCoefficient")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    PowerPerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerPerArea")
    MassFractionOfDryMatter = URIRef("http://qudt.org/vocab/quantitykind/MassFractionOfDryMatter")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    SurgeImpedanceOfTheMedium = URIRef("http://qudt.org/vocab/quantitykind/SurgeImpedanceOfTheMedium")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    SpecificActivity = URIRef("http://qudt.org/vocab/quantitykind/SpecificActivity")
    LiftCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LiftCoefficient")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    ComplexPower = URIRef("http://qudt.org/vocab/quantitykind/ComplexPower")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    TotalLinearStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalLinearStoppingPower")
    MagneticReluctivity = URIRef("http://qudt.org/vocab/quantitykind/MagneticReluctivity")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    ForcePerLength = URIRef("http://qudt.org/vocab/quantitykind/ForcePerLength")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    PolarMomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/PolarMomentOfInertia")
    AbsorbedDoseRate = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDoseRate")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    Voltage = URIRef("http://qudt.org/vocab/quantitykind/Voltage")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    Concentration = URIRef("http://qudt.org/vocab/quantitykind/Concentration")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    InverseLength = URIRef("http://qudt.org/vocab/quantitykind/InverseLength")
    RadiantEnergyExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergyExposure")
    LeakageFactor = URIRef("http://qudt.org/vocab/quantitykind/LeakageFactor")
    MassPerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerAreaTime")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    MassFractionOfDryMatter = URIRef("http://qudt.org/vocab/quantitykind/MassFractionOfDryMatter")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    MagnetizationField = URIRef("http://qudt.org/vocab/quantitykind/MagnetizationField")
    MeanMassRange = URIRef("http://qudt.org/vocab/quantitykind/MeanMassRange")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    AreaRatio = URIRef("http://qudt.org/vocab/quantitykind/AreaRatio")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    DynamicFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DynamicFrictionCoefficient")
    SpecificVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificVolume")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    SoundReductionIndex = URIRef("http://qudt.org/vocab/quantitykind/SoundReductionIndex")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    EquilibriumConstantOnPressureBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnPressureBasis")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    LengthMass = URIRef("http://qudt.org/vocab/quantitykind/LengthMass")
    SpecificEntropy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEntropy")
    Exposure = URIRef("http://qudt.org/vocab/quantitykind/Exposure")
    ThermodynamicEntropy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEntropy")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    ElectricCurrentPerUnitEnergy = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerUnitEnergy")
    TemperatureBasedDensity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedDensity")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    BevelGearPitchAngle = URIRef("http://qudt.org/vocab/quantitykind/BevelGearPitchAngle")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    ExitPlaneTemperature = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneTemperature")
    LineicMass = URIRef("http://qudt.org/vocab/quantitykind/LineicMass")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    PayloadRatio = URIRef("http://qudt.org/vocab/quantitykind/PayloadRatio")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    Loudness = URIRef("http://qudt.org/vocab/quantitykind/Loudness")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    PayloadRatio = URIRef("http://qudt.org/vocab/quantitykind/PayloadRatio")
    PositivePlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PositivePlaneAngle")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    NormalizedDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/NormalizedDimensionlessRatio")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    SourceVoltageBetweenSubstances = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltageBetweenSubstances")
    DebyeAngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularWavenumber")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    EnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensity")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    InformationContentExpressedAsALogarithmToBaseE = URIRef("http://qudt.org/vocab/quantitykind/InformationContentExpressedAsALogarithmToBaseE")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    QuantityOfLight = URIRef("http://qudt.org/vocab/quantitykind/QuantityOfLight")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    BevelGearPitchAngle = URIRef("http://qudt.org/vocab/quantitykind/BevelGearPitchAngle")
    Short_RangeOrderParameter = URIRef("http://qudt.org/vocab/quantitykind/Short-RangeOrderParameter")
    VoltagePercentage = URIRef("http://qudt.org/vocab/quantitykind/VoltagePercentage")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    quantitykind = URIRef("http://qudt.org/vocab/quantitykind")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    ElectricFlux = URIRef("http://qudt.org/vocab/quantitykind/ElectricFlux")
    Radioactivity = URIRef("http://qudt.org/vocab/quantitykind/Radioactivity")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    PropellantMeanBulkTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantMeanBulkTemperature")
    ElectronDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectronDensity")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    VisionThresholds = URIRef("http://qudt.org/vocab/quantitykind/VisionThresholds")
    PowerPerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerPerArea")
    DynamicFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DynamicFrictionCoefficient")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    LorenzCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LorenzCoefficient")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    PowerConstant = URIRef("http://qudt.org/vocab/quantitykind/PowerConstant")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    MicrobialFormation = URIRef("http://qudt.org/vocab/quantitykind/MicrobialFormation")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    ElectricalConductance = URIRef("http://qudt.org/vocab/quantitykind/ElectricalConductance")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    MolarEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarEnergy")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    MicroCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/MicroCanonicalPartitionFunction")
    ChemicalAffinity = URIRef("http://qudt.org/vocab/quantitykind/ChemicalAffinity")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    MolarAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAbsorptionCoefficient")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    BevelGearPitchAngle = URIRef("http://qudt.org/vocab/quantitykind/BevelGearPitchAngle")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    BindingFraction = URIRef("http://qudt.org/vocab/quantitykind/BindingFraction")
    ElectricChargeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeDensity")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    MicroCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/MicroCanonicalPartitionFunction")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    QuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/QuantumNumber")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    LevelWidth = URIRef("http://qudt.org/vocab/quantitykind/LevelWidth")
    Permeance = URIRef("http://qudt.org/vocab/quantitykind/Permeance")
    RelativeMassExcess = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassExcess")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    PropagationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PropagationCoefficient")
    AbsorbedDose = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDose")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    Repetency = URIRef("http://qudt.org/vocab/quantitykind/Repetency")
    PermittivityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermittivityRatio")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    ElectricConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectricConductivity")
    GasLeakRate = URIRef("http://qudt.org/vocab/quantitykind/GasLeakRate")
    DewPointTemperature = URIRef("http://qudt.org/vocab/quantitykind/DewPointTemperature")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    MassAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAbsorptionCoefficient")
    Conductance = URIRef("http://qudt.org/vocab/quantitykind/Conductance")
    IonConcentration = URIRef("http://qudt.org/vocab/quantitykind/IonConcentration")
    AcceptorDensity = URIRef("http://qudt.org/vocab/quantitykind/AcceptorDensity")
    CurrentLinkage = URIRef("http://qudt.org/vocab/quantitykind/CurrentLinkage")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    FrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/FrictionCoefficient")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    ElectricQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricQuadrupoleMoment")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    PhaseCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PhaseCoefficient")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    VolumetricFlux = URIRef("http://qudt.org/vocab/quantitykind/VolumetricFlux")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    LinearIonization = URIRef("http://qudt.org/vocab/quantitykind/LinearIonization")
    Basicity = URIRef("http://qudt.org/vocab/quantitykind/Basicity")
    Chromaticity = URIRef("http://qudt.org/vocab/quantitykind/Chromaticity")
    SpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/SpinQuantumNumber")
    SoundPressure = URIRef("http://qudt.org/vocab/quantitykind/SoundPressure")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    Radiance = URIRef("http://qudt.org/vocab/quantitykind/Radiance")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    CouplingFactor = URIRef("http://qudt.org/vocab/quantitykind/CouplingFactor")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    ExpansionRatio = URIRef("http://qudt.org/vocab/quantitykind/ExpansionRatio")
    ThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusivity")
    DataRate = URIRef("http://qudt.org/vocab/quantitykind/DataRate")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    PlanckFunction = URIRef("http://qudt.org/vocab/quantitykind/PlanckFunction")
    BurstFactor = URIRef("http://qudt.org/vocab/quantitykind/BurstFactor")
    ExposureRateOfIonizingRadiation = URIRef("http://qudt.org/vocab/quantitykind/ExposureRateOfIonizingRadiation")
    ThomsonCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThomsonCoefficient")
    LuminousEnergy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEnergy")
    PhotosyntheticPhotonFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/PhotosyntheticPhotonFluxDensity")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    PoyntingVector = URIRef("http://qudt.org/vocab/quantitykind/PoyntingVector")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    Count = URIRef("http://qudt.org/vocab/quantitykind/Count")
    ElectricCurrentPhasor = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPhasor")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    Dissipance = URIRef("http://qudt.org/vocab/quantitykind/Dissipance")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    Resistivity = URIRef("http://qudt.org/vocab/quantitykind/Resistivity")
    LengthMolarEnergy = URIRef("http://qudt.org/vocab/quantitykind/LengthMolarEnergy")
    IntinsicCarrierDensity = URIRef("http://qudt.org/vocab/quantitykind/IntinsicCarrierDensity")
    TemperatureRateOfChange = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRateOfChange")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    DimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/DimensionlessRatio")
    EquilibriumConstantOnConcentrationBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnConcentrationBasis")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    NuclearQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/NuclearQuadrupoleMoment")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    Landau_GinzburgNumber = URIRef("http://qudt.org/vocab/quantitykind/Landau-GinzburgNumber")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    NuclearQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/NuclearQuadrupoleMoment")
    MolarAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAbsorptionCoefficient")
    IonCurrent = URIRef("http://qudt.org/vocab/quantitykind/IonCurrent")
    CyclotronAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/CyclotronAngularFrequency")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    SpecificPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificPower")
    PowerPerAreaQuarticTemperature = URIRef("http://qudt.org/vocab/quantitykind/PowerPerAreaQuarticTemperature")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    MolarHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MolarHeatCapacity")
    MassicPower = URIRef("http://qudt.org/vocab/quantitykind/MassicPower")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    DigitRate = URIRef("http://qudt.org/vocab/quantitykind/DigitRate")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    MassConcentrationOfWaterVapour = URIRef("http://qudt.org/vocab/quantitykind/MassConcentrationOfWaterVapour")
    InverseEnergy_Squared = URIRef("http://qudt.org/vocab/quantitykind/InverseEnergy_Squared")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    LinearMomentum = URIRef("http://qudt.org/vocab/quantitykind/LinearMomentum")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    LinearCompressibility = URIRef("http://qudt.org/vocab/quantitykind/LinearCompressibility")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    LossAngle = URIRef("http://qudt.org/vocab/quantitykind/LossAngle")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    EffectiveMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMultiplicationFactor")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    LinearResistance = URIRef("http://qudt.org/vocab/quantitykind/LinearResistance")
    GFactorOfNucleus = URIRef("http://qudt.org/vocab/quantitykind/GFactorOfNucleus")
    OsmoticPressure = URIRef("http://qudt.org/vocab/quantitykind/OsmoticPressure")
    SurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceDensity")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    ThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusivity")
    ChemicalConsumptionPerMass = URIRef("http://qudt.org/vocab/quantitykind/ChemicalConsumptionPerMass")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    IncidenceProportion = URIRef("http://qudt.org/vocab/quantitykind/IncidenceProportion")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    LinearMomentum = URIRef("http://qudt.org/vocab/quantitykind/LinearMomentum")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    GruneisenParameter = URIRef("http://qudt.org/vocab/quantitykind/GruneisenParameter")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    InversePermittivity = URIRef("http://qudt.org/vocab/quantitykind/InversePermittivity")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    RadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergyDensity")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    ThermalResistivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistivity")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    SpectralAngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralAngularCrossSection")
    SpecificModulus = URIRef("http://qudt.org/vocab/quantitykind/SpecificModulus")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    EnergyContent = URIRef("http://qudt.org/vocab/quantitykind/EnergyContent")
    MolecularConcentration = URIRef("http://qudt.org/vocab/quantitykind/MolecularConcentration")
    SuperconductionTransitionTemperature = URIRef("http://qudt.org/vocab/quantitykind/SuperconductionTransitionTemperature")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    CurvatureFromRadius = URIRef("http://qudt.org/vocab/quantitykind/CurvatureFromRadius")
    ExhaustGasesSpecificHeat = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasesSpecificHeat")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    ThrustToMassRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToMassRatio")
    SpecificPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificPower")
    PowerPerAreaQuarticTemperature = URIRef("http://qudt.org/vocab/quantitykind/PowerPerAreaQuarticTemperature")
    Turns = URIRef("http://qudt.org/vocab/quantitykind/Turns")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    AccelerationOfGravity = URIRef("http://qudt.org/vocab/quantitykind/AccelerationOfGravity")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    PropellantMeanBulkTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantMeanBulkTemperature")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    ThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusivity")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    AngleOfOpticalRotation = URIRef("http://qudt.org/vocab/quantitykind/AngleOfOpticalRotation")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    AngleOfOpticalRotation = URIRef("http://qudt.org/vocab/quantitykind/AngleOfOpticalRotation")
    TotalPressure = URIRef("http://qudt.org/vocab/quantitykind/TotalPressure")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    TemperaturePerMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerMagneticFluxDensity")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    Turns = URIRef("http://qudt.org/vocab/quantitykind/Turns")
    Angle = URIRef("http://qudt.org/vocab/quantitykind/Angle")
    MassRatio = URIRef("http://qudt.org/vocab/quantitykind/MassRatio")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    SecondStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SecondStageMassRatio")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    ActivityRelatedByMass = URIRef("http://qudt.org/vocab/quantitykind/ActivityRelatedByMass")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    Reactivity = URIRef("http://qudt.org/vocab/quantitykind/Reactivity")
    MolarEntropy = URIRef("http://qudt.org/vocab/quantitykind/MolarEntropy")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    PlanckFunction = URIRef("http://qudt.org/vocab/quantitykind/PlanckFunction")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    SpecificSurfaceArea = URIRef("http://qudt.org/vocab/quantitykind/SpecificSurfaceArea")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    Unbalance = URIRef("http://qudt.org/vocab/quantitykind/Unbalance")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    SignalStrength = URIRef("http://qudt.org/vocab/quantitykind/SignalStrength")
    HeartRate = URIRef("http://qudt.org/vocab/quantitykind/HeartRate")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    SpecificOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificOpticalRotatoryPower")
    CorrelatedColorTemperature = URIRef("http://qudt.org/vocab/quantitykind/CorrelatedColorTemperature")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    SecondAxialMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondAxialMomentOfArea")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    SystolicBloodPressure = URIRef("http://qudt.org/vocab/quantitykind/SystolicBloodPressure")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    UpperCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/UpperCriticalMagneticFluxDensity")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    EnergyPerMassAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerMassAmountOfSubstance")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    AttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AttenuationCoefficient")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    FissionFuelUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionFuelUtilizationFactor")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    ThermalTransmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalTransmittance")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    TotalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentumQuantumNumber")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    SpecificHeatCapacityAtConstantPressure = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantPressure")
    LogarithmicMedianInformationFlow_SourceToBaseE = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicMedianInformationFlow_SourceToBaseE")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    EnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensity")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    RadiantEnergyExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergyExposure")
    SpecificVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificVolume")
    SurfaceActivityDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceActivityDensity")
    ElectricQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricQuadrupoleMoment")
    ThermalConductance = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductance")
    GruneisenParameter = URIRef("http://qudt.org/vocab/quantitykind/GruneisenParameter")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    CouplingFactor = URIRef("http://qudt.org/vocab/quantitykind/CouplingFactor")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    ElectromagneticPermeabilityRatio = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeabilityRatio")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    MassPerTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerTime")
    SecondOrderReactionRateConstant = URIRef("http://qudt.org/vocab/quantitykind/SecondOrderReactionRateConstant")
    MechanicalSurfaceImpedance = URIRef("http://qudt.org/vocab/quantitykind/MechanicalSurfaceImpedance")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    SpecificSurfaceArea = URIRef("http://qudt.org/vocab/quantitykind/SpecificSurfaceArea")
    MolarEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarEnergy")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    TotalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentumQuantumNumber")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    PressureBasedVolume = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedVolume")
    Angle = URIRef("http://qudt.org/vocab/quantitykind/Angle")
    SpecificPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificPower")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    TotalIonization = URIRef("http://qudt.org/vocab/quantitykind/TotalIonization")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    OlfactoryThreshold = URIRef("http://qudt.org/vocab/quantitykind/OlfactoryThreshold")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    LengthMass = URIRef("http://qudt.org/vocab/quantitykind/LengthMass")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    StandardGravitationalParameter = URIRef("http://qudt.org/vocab/quantitykind/StandardGravitationalParameter")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    ActivityCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ActivityCoefficient")
    EquilibriumConstantOnPressureBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnPressureBasis")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    PhotonRadiance = URIRef("http://qudt.org/vocab/quantitykind/PhotonRadiance")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    AmountOfBiologicallyActiveSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfBiologicallyActiveSubstance")
    ThrustToWeightRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToWeightRatio")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    MassNumber = URIRef("http://qudt.org/vocab/quantitykind/MassNumber")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    ElectricalConductance = URIRef("http://qudt.org/vocab/quantitykind/ElectricalConductance")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    QuarticElectricDipoleMomentPerCubicEnergy = URIRef("http://qudt.org/vocab/quantitykind/QuarticElectricDipoleMomentPerCubicEnergy")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    MassPerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerAreaTime")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    CurvatureFromRadius = URIRef("http://qudt.org/vocab/quantitykind/CurvatureFromRadius")
    ElectricDisplacement = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacement")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    SecondStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SecondStageMassRatio")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    QuarticElectricDipoleMomentPerCubicEnergy = URIRef("http://qudt.org/vocab/quantitykind/QuarticElectricDipoleMomentPerCubicEnergy")
    TorsionalSpringConstant = URIRef("http://qudt.org/vocab/quantitykind/TorsionalSpringConstant")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    SoundPowerLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPowerLevel")
    DebyeTemperature = URIRef("http://qudt.org/vocab/quantitykind/DebyeTemperature")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    MolecularMass = URIRef("http://qudt.org/vocab/quantitykind/MolecularMass")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    DiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficient")
    NapierianAbsorbance = URIRef("http://qudt.org/vocab/quantitykind/NapierianAbsorbance")
    MassRatio = URIRef("http://qudt.org/vocab/quantitykind/MassRatio")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    SurgeImpedanceOfTheMedium = URIRef("http://qudt.org/vocab/quantitykind/SurgeImpedanceOfTheMedium")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    LinearStiffness = URIRef("http://qudt.org/vocab/quantitykind/LinearStiffness")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    VisionThresholds = URIRef("http://qudt.org/vocab/quantitykind/VisionThresholds")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    ModulusOfImpedance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfImpedance")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    ResistanceBasedInductance = URIRef("http://qudt.org/vocab/quantitykind/ResistanceBasedInductance")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    MassPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/MassPerElectricCharge")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    IonTransportNumber = URIRef("http://qudt.org/vocab/quantitykind/IonTransportNumber")
    SphericalIlluminance = URIRef("http://qudt.org/vocab/quantitykind/SphericalIlluminance")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    SquareEnergy = URIRef("http://qudt.org/vocab/quantitykind/SquareEnergy")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    PropagationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PropagationCoefficient")
    StressIntensityFactor = URIRef("http://qudt.org/vocab/quantitykind/StressIntensityFactor")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    SpectralConcentrationOfRadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SpectralConcentrationOfRadiantEnergyDensity")
    InformationContentExpressedAsALogarithmToBaseE = URIRef("http://qudt.org/vocab/quantitykind/InformationContentExpressedAsALogarithmToBaseE")
    SoundExposureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundExposureLevel")
    MagneticQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/MagneticQuantumNumber")
    AreaPerLength = URIRef("http://qudt.org/vocab/quantitykind/AreaPerLength")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    ElectricDisplacementField = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacementField")
    InitialExpansionRatio = URIRef("http://qudt.org/vocab/quantitykind/InitialExpansionRatio")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    ModulusOfAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfAdmittance")
    SpecificHeatCapacityAtConstantPressure = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantPressure")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    EnergyPerMagneticFluxDensity_Squared = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerMagneticFluxDensity_Squared")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    ResistanceRatio = URIRef("http://qudt.org/vocab/quantitykind/ResistanceRatio")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    SecondPolarMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondPolarMomentOfArea")
    LinearVoltageCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearVoltageCoefficient")
    NapierianAbsorbance = URIRef("http://qudt.org/vocab/quantitykind/NapierianAbsorbance")
    NeutronYieldPerAbsorption = URIRef("http://qudt.org/vocab/quantitykind/NeutronYieldPerAbsorption")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    CostPerUnitPower = URIRef("http://qudt.org/vocab/quantitykind/CostPerUnitPower")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    ExtentOfReaction = URIRef("http://qudt.org/vocab/quantitykind/ExtentOfReaction")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    LinearMomentum = URIRef("http://qudt.org/vocab/quantitykind/LinearMomentum")
    LinearVoltageCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearVoltageCoefficient")
    MassRatioOfWaterVapourToDryGas = URIRef("http://qudt.org/vocab/quantitykind/MassRatioOfWaterVapourToDryGas")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    ElectricalPowerToMassRatio = URIRef("http://qudt.org/vocab/quantitykind/ElectricalPowerToMassRatio")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    SurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceDensity")
    ResonanceEscapeProbabilityForFission = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbabilityForFission")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    FirstStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/FirstStageMassRatio")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    LengthRatio = URIRef("http://qudt.org/vocab/quantitykind/LengthRatio")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    AreicEnergyFlow = URIRef("http://qudt.org/vocab/quantitykind/AreicEnergyFlow")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    EnergyExpenditure = URIRef("http://qudt.org/vocab/quantitykind/EnergyExpenditure")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    MagnetomotiveForce = URIRef("http://qudt.org/vocab/quantitykind/MagnetomotiveForce")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    MolarHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MolarHeatCapacity")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    MassPerTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerTime")
    TotalCurrent = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrent")
    RotaryShock = URIRef("http://qudt.org/vocab/quantitykind/RotaryShock")
    Concentration = URIRef("http://qudt.org/vocab/quantitykind/Concentration")
    ResonanceEscapeProbabilityForFission = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbabilityForFission")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    RelativeHumidity = URIRef("http://qudt.org/vocab/quantitykind/RelativeHumidity")
    PoyntingVector = URIRef("http://qudt.org/vocab/quantitykind/PoyntingVector")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    PressureRatio = URIRef("http://qudt.org/vocab/quantitykind/PressureRatio")
    TemperatureBasedDynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedDynamicViscosity")
    MolecularViscosity = URIRef("http://qudt.org/vocab/quantitykind/MolecularViscosity")
    CyclotronAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/CyclotronAngularFrequency")
    PackingFraction = URIRef("http://qudt.org/vocab/quantitykind/PackingFraction")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    SignalStrength = URIRef("http://qudt.org/vocab/quantitykind/SignalStrength")
    SpecificHeatVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatVolume")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    SpecificAcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/SpecificAcousticImpedance")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    PayloadRatio = URIRef("http://qudt.org/vocab/quantitykind/PayloadRatio")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    AccelerationOfGravity = URIRef("http://qudt.org/vocab/quantitykind/AccelerationOfGravity")
    EnergyPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerElectricCharge")
    AtmosphericHydroxylationRate = URIRef("http://qudt.org/vocab/quantitykind/AtmosphericHydroxylationRate")
    HeartRate = URIRef("http://qudt.org/vocab/quantitykind/HeartRate")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    ElectricQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricQuadrupoleMoment")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    RiseOfOffStateVoltage = URIRef("http://qudt.org/vocab/quantitykind/RiseOfOffStateVoltage")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    Duv = URIRef("http://qudt.org/vocab/quantitykind/Duv")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    LinearForce = URIRef("http://qudt.org/vocab/quantitykind/LinearForce")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    PressureBasedElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedElectricCurrent")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    MolarHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MolarHeatCapacity")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    MobilityRatio = URIRef("http://qudt.org/vocab/quantitykind/MobilityRatio")
    RatioOfSpecificHeatCapacities = URIRef("http://qudt.org/vocab/quantitykind/RatioOfSpecificHeatCapacities")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    SpecificInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificInternalEnergy")
    Vorticity = URIRef("http://qudt.org/vocab/quantitykind/Vorticity")
    UpperCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/UpperCriticalMagneticFluxDensity")
    AuditoryThresholds = URIRef("http://qudt.org/vocab/quantitykind/AuditoryThresholds")
    RelativePartialPressure = URIRef("http://qudt.org/vocab/quantitykind/RelativePartialPressure")
    AngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentum")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    InformationContentExpressedAsALogarithmToBase10 = URIRef("http://qudt.org/vocab/quantitykind/InformationContentExpressedAsALogarithmToBase10")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    IonicStrength = URIRef("http://qudt.org/vocab/quantitykind/IonicStrength")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    QuarticElectricDipoleMomentPerCubicEnergy = URIRef("http://qudt.org/vocab/quantitykind/QuarticElectricDipoleMomentPerCubicEnergy")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    Dissipance = URIRef("http://qudt.org/vocab/quantitykind/Dissipance")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    ThermalConductance = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductance")
    TransmissionRatioBetweenRotationAndTranslation = URIRef("http://qudt.org/vocab/quantitykind/TransmissionRatioBetweenRotationAndTranslation")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    Reactance = URIRef("http://qudt.org/vocab/quantitykind/Reactance")
    MolarRefractivity = URIRef("http://qudt.org/vocab/quantitykind/MolarRefractivity")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    EvaporativeHeatTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/EvaporativeHeatTransferCoefficient")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    MassConcentration = URIRef("http://qudt.org/vocab/quantitykind/MassConcentration")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    Radiance = URIRef("http://qudt.org/vocab/quantitykind/Radiance")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    DragForce = URIRef("http://qudt.org/vocab/quantitykind/DragForce")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    LinearEnergyTransfer = URIRef("http://qudt.org/vocab/quantitykind/LinearEnergyTransfer")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    Reflectivity = URIRef("http://qudt.org/vocab/quantitykind/Reflectivity")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    ThermalEnergyLength = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergyLength")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    SoundPressure = URIRef("http://qudt.org/vocab/quantitykind/SoundPressure")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    PressureRatio = URIRef("http://qudt.org/vocab/quantitykind/PressureRatio")
    StaticFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StaticFrictionCoefficient")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    CharacteristicVelocity = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicVelocity")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    ExhaustGasesSpecificHeat = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasesSpecificHeat")
    FastFissionFactor = URIRef("http://qudt.org/vocab/quantitykind/FastFissionFactor")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    LoudnessLevel = URIRef("http://qudt.org/vocab/quantitykind/LoudnessLevel")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    DimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/DimensionlessRatio")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    MolarOpticalRotationalAbility = URIRef("http://qudt.org/vocab/quantitykind/MolarOpticalRotationalAbility")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    PressureBurningRateConstant = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateConstant")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    Resistivity = URIRef("http://qudt.org/vocab/quantitykind/Resistivity")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    FissionMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionMultiplicationFactor")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    DragCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DragCoefficient")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    GeneFamilyAbundance = URIRef("http://qudt.org/vocab/quantitykind/GeneFamilyAbundance")
    BioconcentrationFactor = URIRef("http://qudt.org/vocab/quantitykind/BioconcentrationFactor")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    SingleStageLauncherMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SingleStageLauncherMassRatio")
    EnergyExpenditure = URIRef("http://qudt.org/vocab/quantitykind/EnergyExpenditure")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    SpectralConcentrationOfVibrationalModes = URIRef("http://qudt.org/vocab/quantitykind/SpectralConcentrationOfVibrationalModes")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    ModulusOfRotationalSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfRotationalSubgradeReaction")
    Viscosity = URIRef("http://qudt.org/vocab/quantitykind/Viscosity")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    VolumeFlowRate_SurfaceRelated = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate_SurfaceRelated")
    Action = URIRef("http://qudt.org/vocab/quantitykind/Action")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    LengthRatio = URIRef("http://qudt.org/vocab/quantitykind/LengthRatio")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    Voltage = URIRef("http://qudt.org/vocab/quantitykind/Voltage")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    LinearAcceleration = URIRef("http://qudt.org/vocab/quantitykind/LinearAcceleration")
    MolarOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/MolarOpticalRotatoryPower")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    LinearElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrentDensity")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    StressIntensityFactor = URIRef("http://qudt.org/vocab/quantitykind/StressIntensityFactor")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    Susceptance = URIRef("http://qudt.org/vocab/quantitykind/Susceptance")
    ExposureRate = URIRef("http://qudt.org/vocab/quantitykind/ExposureRate")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    VolumetricFlux = URIRef("http://qudt.org/vocab/quantitykind/VolumetricFlux")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    LengthMass = URIRef("http://qudt.org/vocab/quantitykind/LengthMass")
    MagneticFluxPerUnitLength = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxPerUnitLength")
    ExhaustGasesSpecificHeat = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasesSpecificHeat")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    RelativeMassRatioOfVapour = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassRatioOfVapour")
    BodyMassIndex = URIRef("http://qudt.org/vocab/quantitykind/BodyMassIndex")
    LuminousEnergy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEnergy")
    StaticFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StaticFrictionCoefficient")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    PropagationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PropagationCoefficient")
    AngleOfOpticalRotation = URIRef("http://qudt.org/vocab/quantitykind/AngleOfOpticalRotation")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    LinearDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearDensity")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    Slowing_DownDensity = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownDensity")
    SecondAxialMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondAxialMomentOfArea")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    AbsorbedDoseRate = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDoseRate")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    AbsorbedDoseRate = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDoseRate")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    DynamicFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DynamicFrictionCoefficient")
    GrandCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/GrandCanonicalPartitionFunction")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    SpectralRadiantEnergyDensityInTermsOfWavelength = URIRef("http://qudt.org/vocab/quantitykind/SpectralRadiantEnergyDensityInTermsOfWavelength")
    AmountOfSubstancePerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMass")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    TouchThresholds = URIRef("http://qudt.org/vocab/quantitykind/TouchThresholds")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    SoilAdsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SoilAdsorptionCoefficient")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    Permeance = URIRef("http://qudt.org/vocab/quantitykind/Permeance")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    BitTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/BitTransmissionRate")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    MassFractionOfDryMatter = URIRef("http://qudt.org/vocab/quantitykind/MassFractionOfDryMatter")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    BoilingPoint = URIRef("http://qudt.org/vocab/quantitykind/BoilingPoint")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    IonicStrength = URIRef("http://qudt.org/vocab/quantitykind/IonicStrength")
    LineicDataVolume = URIRef("http://qudt.org/vocab/quantitykind/LineicDataVolume")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    ElectricChargePerMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerMass")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    ThermodynamicCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicCriticalMagneticFluxDensity")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    IsentropicCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsentropicCompressibility")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    RatioOfSpecificHeatCapacities = URIRef("http://qudt.org/vocab/quantitykind/RatioOfSpecificHeatCapacities")
    NeelTemperature = URIRef("http://qudt.org/vocab/quantitykind/NeelTemperature")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    PressureInRelationToVolumeFlow = URIRef("http://qudt.org/vocab/quantitykind/PressureInRelationToVolumeFlow")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    MobilityRatio = URIRef("http://qudt.org/vocab/quantitykind/MobilityRatio")
    FirstStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/FirstStageMassRatio")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    StandardChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/StandardChemicalPotential")
    Emissivity = URIRef("http://qudt.org/vocab/quantitykind/Emissivity")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    ElectricChargeVolumeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeVolumeDensity")
    TotalAtomicStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalAtomicStoppingPower")
    LossAngle = URIRef("http://qudt.org/vocab/quantitykind/LossAngle")
    MassicTorque = URIRef("http://qudt.org/vocab/quantitykind/MassicTorque")
    SpectralAngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralAngularCrossSection")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    InversePressure = URIRef("http://qudt.org/vocab/quantitykind/InversePressure")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    ThermalAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalAdmittance")
    AreicChargeDensityOrElectricFluxDensityOrElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/AreicChargeDensityOrElectricFluxDensityOrElectricPolarization")
    PackingFraction = URIRef("http://qudt.org/vocab/quantitykind/PackingFraction")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    RatioOfSpecificHeatCapacities = URIRef("http://qudt.org/vocab/quantitykind/RatioOfSpecificHeatCapacities")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    DataRate = URIRef("http://qudt.org/vocab/quantitykind/DataRate")
    EnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensity")
    PowerPerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerPerArea")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    DewPointTemperature = URIRef("http://qudt.org/vocab/quantitykind/DewPointTemperature")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    GustatoryThreshold = URIRef("http://qudt.org/vocab/quantitykind/GustatoryThreshold")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    Viscosity = URIRef("http://qudt.org/vocab/quantitykind/Viscosity")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    AcceptorDensity = URIRef("http://qudt.org/vocab/quantitykind/AcceptorDensity")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    LorenzCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LorenzCoefficient")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    TemperatureBasedAmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedAmountOfSubstanceConcentration")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    MadelungConstant = URIRef("http://qudt.org/vocab/quantitykind/MadelungConstant")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    ForcePerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/ForcePerAreaTime")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    BitDataVolume = URIRef("http://qudt.org/vocab/quantitykind/BitDataVolume")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    ParticleFluence = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluence")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    Resistivity = URIRef("http://qudt.org/vocab/quantitykind/Resistivity")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    IonTransportNumber = URIRef("http://qudt.org/vocab/quantitykind/IonTransportNumber")
    ElectronMobility = URIRef("http://qudt.org/vocab/quantitykind/ElectronMobility")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    AngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentum")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    MagnetizationField = URIRef("http://qudt.org/vocab/quantitykind/MagnetizationField")
    Period = URIRef("http://qudt.org/vocab/quantitykind/Period")
    SpecificVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificVolume")
    MassTemperature = URIRef("http://qudt.org/vocab/quantitykind/MassTemperature")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    BucklingFactor = URIRef("http://qudt.org/vocab/quantitykind/BucklingFactor")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    SpecificActivity = URIRef("http://qudt.org/vocab/quantitykind/SpecificActivity")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    MolarOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/MolarOpticalRotatoryPower")
    FlightPathAngle = URIRef("http://qudt.org/vocab/quantitykind/FlightPathAngle")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    AreaRatio = URIRef("http://qudt.org/vocab/quantitykind/AreaRatio")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    Debye_WallerFactor = URIRef("http://qudt.org/vocab/quantitykind/Debye-WallerFactor")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    RelativeMassDensity = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDensity")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    Short_RangeOrderParameter = URIRef("http://qudt.org/vocab/quantitykind/Short-RangeOrderParameter")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    ElectricChargeLineDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeLineDensity")
    AmountOfSubstancePerUnitVolume = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitVolume")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    LinearCompressibility = URIRef("http://qudt.org/vocab/quantitykind/LinearCompressibility")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    EnergyPerArea = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerArea")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    MeanMassRange = URIRef("http://qudt.org/vocab/quantitykind/MeanMassRange")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    PayloadRatio = URIRef("http://qudt.org/vocab/quantitykind/PayloadRatio")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    HoleDensity = URIRef("http://qudt.org/vocab/quantitykind/HoleDensity")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    LuminousEfficacy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEfficacy")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    MassConcentrationOfWaterVapour = URIRef("http://qudt.org/vocab/quantitykind/MassConcentrationOfWaterVapour")
    SpecificPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificPower")
    StaticPressure = URIRef("http://qudt.org/vocab/quantitykind/StaticPressure")
    LengthRatio = URIRef("http://qudt.org/vocab/quantitykind/LengthRatio")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    PhaseSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/PhaseSpeedOfSound")
    RelativeMassExcess = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassExcess")
    SpecificHeatPressure = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatPressure")
    ElectromagneticPermeability = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeability")
    MassRatio = URIRef("http://qudt.org/vocab/quantitykind/MassRatio")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    GeneralizedCoordinate = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedCoordinate")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    NeutronDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionCoefficient")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    MOMENT_OF_INERTIA_Y = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Y")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    GeneralizedForce = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedForce")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    RespiratoryRate = URIRef("http://qudt.org/vocab/quantitykind/RespiratoryRate")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    OrbitalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/OrbitalAngularMomentumQuantumNumber")
    CouplingFactor = URIRef("http://qudt.org/vocab/quantitykind/CouplingFactor")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    MagneticAreaMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticAreaMoment")
    InversePressure = URIRef("http://qudt.org/vocab/quantitykind/InversePressure")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    Gravity_API = URIRef("http://qudt.org/vocab/quantitykind/Gravity_API")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    TimeRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRatio")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    SpecificHeatCapacityAtSaturation = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtSaturation")
    RelativeMassRatioOfVapour = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassRatioOfVapour")
    LinearLogarithmicRatio = URIRef("http://qudt.org/vocab/quantitykind/LinearLogarithmicRatio")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    MassAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAttenuationCoefficient")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    ThermalTransmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalTransmittance")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    IncidenceProportion = URIRef("http://qudt.org/vocab/quantitykind/IncidenceProportion")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    VaporPermeability = URIRef("http://qudt.org/vocab/quantitykind/VaporPermeability")
    GyromagneticRatio = URIRef("http://qudt.org/vocab/quantitykind/GyromagneticRatio")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    ThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusivity")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    InverseTime_Squared = URIRef("http://qudt.org/vocab/quantitykind/InverseTime_Squared")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    ResistanceRatio = URIRef("http://qudt.org/vocab/quantitykind/ResistanceRatio")
    ResonanceEscapeProbabilityForFission = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbabilityForFission")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    NonActivePower = URIRef("http://qudt.org/vocab/quantitykind/NonActivePower")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    SingleStageLauncherMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SingleStageLauncherMassRatio")
    Capacitance = URIRef("http://qudt.org/vocab/quantitykind/Capacitance")
    LinearBitDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearBitDensity")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    ElectricChargeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeDensity")
    TotalAtomicStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalAtomicStoppingPower")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    TemperatureRatio = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRatio")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    VolumePerArea = URIRef("http://qudt.org/vocab/quantitykind/VolumePerArea")
    LineicMass = URIRef("http://qudt.org/vocab/quantitykind/LineicMass")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    AtomicNumber = URIRef("http://qudt.org/vocab/quantitykind/AtomicNumber")
    TotalMassStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalMassStoppingPower")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    ElectronDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectronDensity")
    Impedance = URIRef("http://qudt.org/vocab/quantitykind/Impedance")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    DistanceTraveledDuringBurn = URIRef("http://qudt.org/vocab/quantitykind/DistanceTraveledDuringBurn")
    DisplacementCurrent = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrent")
    Permittivity = URIRef("http://qudt.org/vocab/quantitykind/Permittivity")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    PeltierCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PeltierCoefficient")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    Constringence = URIRef("http://qudt.org/vocab/quantitykind/Constringence")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    SoundExposureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundExposureLevel")
    BloodGlucoseLevel = URIRef("http://qudt.org/vocab/quantitykind/BloodGlucoseLevel")
    LinearForce = URIRef("http://qudt.org/vocab/quantitykind/LinearForce")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    OrbitalAngularMomentumPerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/OrbitalAngularMomentumPerUnitMass")
    LiquidVolume = URIRef("http://qudt.org/vocab/quantitykind/LiquidVolume")
    DoseEquivalentQualityFactor = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalentQualityFactor")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    DynamicFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DynamicFrictionCoefficient")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    LinearStrain = URIRef("http://qudt.org/vocab/quantitykind/LinearStrain")
    TotalLinearStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalLinearStoppingPower")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    MassEnergyTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassEnergyTransferCoefficient")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    PictureElement = URIRef("http://qudt.org/vocab/quantitykind/PictureElement")
    BloodGlucoseLevel = URIRef("http://qudt.org/vocab/quantitykind/BloodGlucoseLevel")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    MassicPower = URIRef("http://qudt.org/vocab/quantitykind/MassicPower")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    Population = URIRef("http://qudt.org/vocab/quantitykind/Population")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    LowerCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/LowerCriticalMagneticFluxDensity")
    FundamentalReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalReciprocalLatticeVector")
    EquilibriumConstant = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstant")
    IncidenceProportion = URIRef("http://qudt.org/vocab/quantitykind/IncidenceProportion")
    SpecificHelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificHelmholtzEnergy")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    LuminousEmittance = URIRef("http://qudt.org/vocab/quantitykind/LuminousEmittance")
    SpectralConcentrationOfRadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SpectralConcentrationOfRadiantEnergyDensity")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    Capacity = URIRef("http://qudt.org/vocab/quantitykind/Capacity")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    SecondStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SecondStageMassRatio")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    PowerPerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerPerArea")
    MolecularMass = URIRef("http://qudt.org/vocab/quantitykind/MolecularMass")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    EinsteinCoefficients = URIRef("http://qudt.org/vocab/quantitykind/EinsteinCoefficients")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    AngleOfOpticalRotation = URIRef("http://qudt.org/vocab/quantitykind/AngleOfOpticalRotation")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    NeutronYieldPerAbsorption = URIRef("http://qudt.org/vocab/quantitykind/NeutronYieldPerAbsorption")
    AccelerationOfGravity = URIRef("http://qudt.org/vocab/quantitykind/AccelerationOfGravity")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    PressureBasedLength = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedLength")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    Half_Life = URIRef("http://qudt.org/vocab/quantitykind/Half-Life")
    CoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/CoefficientOfHeatTransfer")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    SpecificHeatsRatio = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatsRatio")
    DatasetOfBits = URIRef("http://qudt.org/vocab/quantitykind/DatasetOfBits")
    ReciprocalPlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalPlaneAngle")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    MolarAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAbsorptionCoefficient")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    TotalCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrentDensity")
    PackingFraction = URIRef("http://qudt.org/vocab/quantitykind/PackingFraction")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    PressureGradient = URIRef("http://qudt.org/vocab/quantitykind/PressureGradient")
    MagneticAreaMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticAreaMoment")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    AreaTime = URIRef("http://qudt.org/vocab/quantitykind/AreaTime")
    MadelungConstant = URIRef("http://qudt.org/vocab/quantitykind/MadelungConstant")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    ExhaustGasesSpecificHeat = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasesSpecificHeat")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    ElectricConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectricConductivity")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    PhotonLuminance = URIRef("http://qudt.org/vocab/quantitykind/PhotonLuminance")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    IntinsicCarrierDensity = URIRef("http://qudt.org/vocab/quantitykind/IntinsicCarrierDensity")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    AcceptorDensity = URIRef("http://qudt.org/vocab/quantitykind/AcceptorDensity")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    TemperatureBasedDynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedDynamicViscosity")
    ActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/ActivityConcentration")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    SpecificHeatCapacityAtConstantPressure = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantPressure")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    ElectricChargePerAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerAmountOfSubstance")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    MadelungConstant = URIRef("http://qudt.org/vocab/quantitykind/MadelungConstant")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    Viscosity = URIRef("http://qudt.org/vocab/quantitykind/Viscosity")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    TemperatureRateOfChange = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRateOfChange")
    SecondMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondMomentOfArea")
    LiftCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LiftCoefficient")
    MagneticTension = URIRef("http://qudt.org/vocab/quantitykind/MagneticTension")
    SoundParticleAcceleration = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleAcceleration")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    PoyntingVector = URIRef("http://qudt.org/vocab/quantitykind/PoyntingVector")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    SuperconductionTransitionTemperature = URIRef("http://qudt.org/vocab/quantitykind/SuperconductionTransitionTemperature")
    ExposureOfIonizingRadiation = URIRef("http://qudt.org/vocab/quantitykind/ExposureOfIonizingRadiation")
    TemporalSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/TemporalSummationFunction")
    RelativeHumidity = URIRef("http://qudt.org/vocab/quantitykind/RelativeHumidity")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    RelativeMassRatioOfVapour = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassRatioOfVapour")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    FrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/FrictionCoefficient")
    CurvatureFromRadius = URIRef("http://qudt.org/vocab/quantitykind/CurvatureFromRadius")
    TotalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentumQuantumNumber")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    DataRate = URIRef("http://qudt.org/vocab/quantitykind/DataRate")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    FahrenheitTemperature = URIRef("http://qudt.org/vocab/quantitykind/FahrenheitTemperature")
    LinearThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/LinearThermalExpansion")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    HallCoefficient = URIRef("http://qudt.org/vocab/quantitykind/HallCoefficient")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    ThermalUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactor")
    BitRate = URIRef("http://qudt.org/vocab/quantitykind/BitRate")
    SpecificInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificInternalEnergy")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    VolumicOutput = URIRef("http://qudt.org/vocab/quantitykind/VolumicOutput")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    PolarizationField = URIRef("http://qudt.org/vocab/quantitykind/PolarizationField")
    IsothermalMoistureCapacity = URIRef("http://qudt.org/vocab/quantitykind/IsothermalMoistureCapacity")
    ThermalCapacitance = URIRef("http://qudt.org/vocab/quantitykind/ThermalCapacitance")
    MassicTorque = URIRef("http://qudt.org/vocab/quantitykind/MassicTorque")
    MassicPower = URIRef("http://qudt.org/vocab/quantitykind/MassicPower")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    HamiltonFunction = URIRef("http://qudt.org/vocab/quantitykind/HamiltonFunction")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    AmountOfSubstancePerUnitVolume = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitVolume")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    SecondStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SecondStageMassRatio")
    SpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/SpinQuantumNumber")
    NeelTemperature = URIRef("http://qudt.org/vocab/quantitykind/NeelTemperature")
    SpectralAngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralAngularCrossSection")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    Flux = URIRef("http://qudt.org/vocab/quantitykind/Flux")
    Curvature = URIRef("http://qudt.org/vocab/quantitykind/Curvature")
    SignalStrength = URIRef("http://qudt.org/vocab/quantitykind/SignalStrength")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    LarmorAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/LarmorAngularFrequency")
    TorsionalSpringConstant = URIRef("http://qudt.org/vocab/quantitykind/TorsionalSpringConstant")
    LorenzCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LorenzCoefficient")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    TotalAngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentum")
    ParticleNumberDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleNumberDensity")
    SpecificInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificInternalEnergy")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    ForcePerLength = URIRef("http://qudt.org/vocab/quantitykind/ForcePerLength")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    Admittance = URIRef("http://qudt.org/vocab/quantitykind/Admittance")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    VoltageRatio = URIRef("http://qudt.org/vocab/quantitykind/VoltageRatio")
    TransmittanceDensity = URIRef("http://qudt.org/vocab/quantitykind/TransmittanceDensity")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    AmountOfSubstancePerUnitVolume = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitVolume")
    BloodGlucoseLevel = URIRef("http://qudt.org/vocab/quantitykind/BloodGlucoseLevel")
    DebyeAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularFrequency")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    SpecificThrust = URIRef("http://qudt.org/vocab/quantitykind/SpecificThrust")
    Impedance = URIRef("http://qudt.org/vocab/quantitykind/Impedance")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    MolarDensity = URIRef("http://qudt.org/vocab/quantitykind/MolarDensity")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    CatalyticActivity = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivity")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    Permittivity = URIRef("http://qudt.org/vocab/quantitykind/Permittivity")
    SpecificVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificVolume")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    MagneticDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMoment")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    MagneticDipoleMomentOfAMolecule = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMomentOfAMolecule")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    FastFissionFactor = URIRef("http://qudt.org/vocab/quantitykind/FastFissionFactor")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    HyperfineStructureQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/HyperfineStructureQuantumNumber")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    TemperatureRelatedMolarMass = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRelatedMolarMass")
    MutualInductance = URIRef("http://qudt.org/vocab/quantitykind/MutualInductance")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    SpecificModulus = URIRef("http://qudt.org/vocab/quantitykind/SpecificModulus")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    LogarithmRatioToBase10 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmRatioToBase10")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    SpecificSurfaceArea = URIRef("http://qudt.org/vocab/quantitykind/SpecificSurfaceArea")
    Temperature = URIRef("http://qudt.org/vocab/quantitykind/Temperature")
    Viscosity = URIRef("http://qudt.org/vocab/quantitykind/Viscosity")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    Curvature = URIRef("http://qudt.org/vocab/quantitykind/Curvature")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    PoissonRatio = URIRef("http://qudt.org/vocab/quantitykind/PoissonRatio")
    RelativeHumidity = URIRef("http://qudt.org/vocab/quantitykind/RelativeHumidity")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    FermiAngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/FermiAngularWavenumber")
    HeatFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/HeatFluxDensity")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    IonicStrength = URIRef("http://qudt.org/vocab/quantitykind/IonicStrength")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    CostPerArea = URIRef("http://qudt.org/vocab/quantitykind/CostPerArea")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    DragForce = URIRef("http://qudt.org/vocab/quantitykind/DragForce")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    TemperaturePerMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerMagneticFluxDensity")
    AttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AttenuationCoefficient")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    AbsorbedDoseRate = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDoseRate")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    InformationFlowRate = URIRef("http://qudt.org/vocab/quantitykind/InformationFlowRate")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    ChemicalAffinity = URIRef("http://qudt.org/vocab/quantitykind/ChemicalAffinity")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    Log10Ratio = URIRef("http://qudt.org/vocab/quantitykind/Log10Ratio")
    TotalMassStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalMassStoppingPower")
    SoundParticleVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleVelocity")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    SignalDetectionThreshold = URIRef("http://qudt.org/vocab/quantitykind/SignalDetectionThreshold")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    NumberDensity = URIRef("http://qudt.org/vocab/quantitykind/NumberDensity")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    LuminousExposure = URIRef("http://qudt.org/vocab/quantitykind/LuminousExposure")
    LinearStiffness = URIRef("http://qudt.org/vocab/quantitykind/LinearStiffness")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    ParticleFluence = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluence")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    AmountOfSubstancePerUnitVolume = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitVolume")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    StressIntensityFactor = URIRef("http://qudt.org/vocab/quantitykind/StressIntensityFactor")
    FlightPathAngle = URIRef("http://qudt.org/vocab/quantitykind/FlightPathAngle")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    ElectrolyticConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectrolyticConductivity")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    MultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/MultiplicationFactor")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    CyclotronAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/CyclotronAngularFrequency")
    OrbitalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/OrbitalAngularMomentumQuantumNumber")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    LogarithmRatioToBaseE = URIRef("http://qudt.org/vocab/quantitykind/LogarithmRatioToBaseE")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    TotalCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrentDensity")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    LiquidVolume = URIRef("http://qudt.org/vocab/quantitykind/LiquidVolume")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    MolarAngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/MolarAngularMomentum")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    BiodegredationHalfLife = URIRef("http://qudt.org/vocab/quantitykind/BiodegredationHalfLife")
    Slowing_DownDensity = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownDensity")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    ParticleFluence = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluence")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    InverseLengthTemperature = URIRef("http://qudt.org/vocab/quantitykind/InverseLengthTemperature")
    AverageSpecificImpulse = URIRef("http://qudt.org/vocab/quantitykind/AverageSpecificImpulse")
    EquilibriumConstantBasedOnConcentration = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantBasedOnConcentration")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    LinearThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/LinearThermalExpansion")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    OsmoticPressure = URIRef("http://qudt.org/vocab/quantitykind/OsmoticPressure")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    ElectricalPowerToMassRatio = URIRef("http://qudt.org/vocab/quantitykind/ElectricalPowerToMassRatio")
    Reflectivity = URIRef("http://qudt.org/vocab/quantitykind/Reflectivity")
    RelativeMassExcess = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassExcess")
    AtmosphericPressure = URIRef("http://qudt.org/vocab/quantitykind/AtmosphericPressure")
    LiquidVolume = URIRef("http://qudt.org/vocab/quantitykind/LiquidVolume")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    MassRatio = URIRef("http://qudt.org/vocab/quantitykind/MassRatio")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    Voltage = URIRef("http://qudt.org/vocab/quantitykind/Voltage")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    MolarAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAttenuationCoefficient")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    FishBiotransformationHalfLife = URIRef("http://qudt.org/vocab/quantitykind/FishBiotransformationHalfLife")
    ResidualResistivity = URIRef("http://qudt.org/vocab/quantitykind/ResidualResistivity")
    Kerma = URIRef("http://qudt.org/vocab/quantitykind/Kerma")
    FailureRate = URIRef("http://qudt.org/vocab/quantitykind/FailureRate")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    SecondOrderReactionRateConstant = URIRef("http://qudt.org/vocab/quantitykind/SecondOrderReactionRateConstant")
    AreaRatio = URIRef("http://qudt.org/vocab/quantitykind/AreaRatio")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    BodyMassIndex = URIRef("http://qudt.org/vocab/quantitykind/BodyMassIndex")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    LoudnessLevel = URIRef("http://qudt.org/vocab/quantitykind/LoudnessLevel")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    LogERatio = URIRef("http://qudt.org/vocab/quantitykind/LogERatio")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    TimeRelatedLogarithmicRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRelatedLogarithmicRatio")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    LinearAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAttenuationCoefficient")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    Permeability = URIRef("http://qudt.org/vocab/quantitykind/Permeability")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    MassieuFunction = URIRef("http://qudt.org/vocab/quantitykind/MassieuFunction")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    OrderOfReflection = URIRef("http://qudt.org/vocab/quantitykind/OrderOfReflection")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    TorsionalSpringConstant = URIRef("http://qudt.org/vocab/quantitykind/TorsionalSpringConstant")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    KermaRate = URIRef("http://qudt.org/vocab/quantitykind/KermaRate")
    PolarizationField = URIRef("http://qudt.org/vocab/quantitykind/PolarizationField")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    SpecificPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificPower")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    LevelWidth = URIRef("http://qudt.org/vocab/quantitykind/LevelWidth")
    MortalityRate = URIRef("http://qudt.org/vocab/quantitykind/MortalityRate")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    EccentricityOfOrbit = URIRef("http://qudt.org/vocab/quantitykind/EccentricityOfOrbit")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    MolarEntropy = URIRef("http://qudt.org/vocab/quantitykind/MolarEntropy")
    EnergyContent = URIRef("http://qudt.org/vocab/quantitykind/EnergyContent")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    ElectricConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectricConductivity")
    TorqueConstant = URIRef("http://qudt.org/vocab/quantitykind/TorqueConstant")
    MeltingPoint = URIRef("http://qudt.org/vocab/quantitykind/MeltingPoint")
    LogarithmicMedianInformationFlow_SourceToBase2 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicMedianInformationFlow_SourceToBase2")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    ModulusOfRotationalSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfRotationalSubgradeReaction")
    MagnetizationField = URIRef("http://qudt.org/vocab/quantitykind/MagnetizationField")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    FailureRate = URIRef("http://qudt.org/vocab/quantitykind/FailureRate")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    PressureBasedLength = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedLength")
    DoseEquivalent = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalent")
    DynamicPressure = URIRef("http://qudt.org/vocab/quantitykind/DynamicPressure")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    ThermodynamicCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicCriticalMagneticFluxDensity")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    LiquidVolume = URIRef("http://qudt.org/vocab/quantitykind/LiquidVolume")
    MassieuFunction = URIRef("http://qudt.org/vocab/quantitykind/MassieuFunction")
    SpecificHeatCapacityAtConstantVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantVolume")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    TotalCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrentDensity")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    ElectromagneticPermeability = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeability")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    Time_Squared = URIRef("http://qudt.org/vocab/quantitykind/Time_Squared")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    MadelungConstant = URIRef("http://qudt.org/vocab/quantitykind/MadelungConstant")
    AmountOfSubstanceFraction = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFraction")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    ExtentOfReaction = URIRef("http://qudt.org/vocab/quantitykind/ExtentOfReaction")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    RF_Power = URIRef("http://qudt.org/vocab/quantitykind/RF-Power")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    SecondAxialMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondAxialMomentOfArea")
    ResistanceRatio = URIRef("http://qudt.org/vocab/quantitykind/ResistanceRatio")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    DebyeTemperature = URIRef("http://qudt.org/vocab/quantitykind/DebyeTemperature")
    BatteryCapacity = URIRef("http://qudt.org/vocab/quantitykind/BatteryCapacity")
    LengthTemperatureTime = URIRef("http://qudt.org/vocab/quantitykind/LengthTemperatureTime")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    Reluctance = URIRef("http://qudt.org/vocab/quantitykind/Reluctance")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    ElectricChargeLinearDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeLinearDensity")
    AngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentum")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    LinearVoltageCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearVoltageCoefficient")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    MagneticField = URIRef("http://qudt.org/vocab/quantitykind/MagneticField")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    OsmoticPressure = URIRef("http://qudt.org/vocab/quantitykind/OsmoticPressure")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    Incidence = URIRef("http://qudt.org/vocab/quantitykind/Incidence")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    QuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/QuantumNumber")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    FissionCoreRadiusToHeightRatio = URIRef("http://qudt.org/vocab/quantitykind/FissionCoreRadiusToHeightRatio")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    ExitPlaneTemperature = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneTemperature")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    MotorConstant = URIRef("http://qudt.org/vocab/quantitykind/MotorConstant")
    MutualInductance = URIRef("http://qudt.org/vocab/quantitykind/MutualInductance")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    PressureBurningRateIndex = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateIndex")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    LiftCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LiftCoefficient")
    CurrentLinkage = URIRef("http://qudt.org/vocab/quantitykind/CurrentLinkage")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    LowerCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/LowerCriticalMagneticFluxDensity")
    TorsionalRigidity = URIRef("http://qudt.org/vocab/quantitykind/TorsionalRigidity")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    LarmorAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/LarmorAngularFrequency")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    ExhaustGasesSpecificHeat = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasesSpecificHeat")
    MassPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/MassPerElectricCharge")
    DiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficient")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    ComplexPower = URIRef("http://qudt.org/vocab/quantitykind/ComplexPower")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    MassEnergyTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassEnergyTransferCoefficient")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    SoundExposureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundExposureLevel")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    PolarMomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/PolarMomentOfInertia")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    InverseTime_Squared = URIRef("http://qudt.org/vocab/quantitykind/InverseTime_Squared")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    ElectrolyticConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectrolyticConductivity")
    MolarRefractivity = URIRef("http://qudt.org/vocab/quantitykind/MolarRefractivity")
    ExhaustGasesSpecificHeat = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasesSpecificHeat")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    CorrelatedColorTemperature = URIRef("http://qudt.org/vocab/quantitykind/CorrelatedColorTemperature")
    ElectricalConductance = URIRef("http://qudt.org/vocab/quantitykind/ElectricalConductance")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    ElectronMobility = URIRef("http://qudt.org/vocab/quantitykind/ElectronMobility")
    Short_RangeOrderParameter = URIRef("http://qudt.org/vocab/quantitykind/Short-RangeOrderParameter")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    RF_Power = URIRef("http://qudt.org/vocab/quantitykind/RF-Power")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    BloodGlucoseLevel_Mass = URIRef("http://qudt.org/vocab/quantitykind/BloodGlucoseLevel_Mass")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    FissionFuelUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionFuelUtilizationFactor")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    MagneticQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/MagneticQuantumNumber")
    LinearAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAbsorptionCoefficient")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    LineicResolution = URIRef("http://qudt.org/vocab/quantitykind/LineicResolution")
    PressureBasedTemperature = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedTemperature")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    VolumeOrSectionModulus = URIRef("http://qudt.org/vocab/quantitykind/VolumeOrSectionModulus")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    GrowingDegreeDay_Cereal = URIRef("http://qudt.org/vocab/quantitykind/GrowingDegreeDay_Cereal")
    ScalarMagneticPotential = URIRef("http://qudt.org/vocab/quantitykind/ScalarMagneticPotential")
    LuminousEfficacy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEfficacy")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    ByteTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/ByteTransmissionRate")
    Constringence = URIRef("http://qudt.org/vocab/quantitykind/Constringence")
    ForcePerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ForcePerElectricCharge")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    MassFractionOfWater = URIRef("http://qudt.org/vocab/quantitykind/MassFractionOfWater")
    TorsionalRigidity = URIRef("http://qudt.org/vocab/quantitykind/TorsionalRigidity")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    SpecificActivity = URIRef("http://qudt.org/vocab/quantitykind/SpecificActivity")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    Reactance = URIRef("http://qudt.org/vocab/quantitykind/Reactance")
    EccentricityOfOrbit = URIRef("http://qudt.org/vocab/quantitykind/EccentricityOfOrbit")
    VolumetricElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/VolumetricElectricCharge")
    LossAngle = URIRef("http://qudt.org/vocab/quantitykind/LossAngle")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    HoleDensity = URIRef("http://qudt.org/vocab/quantitykind/HoleDensity")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    ModulusOfAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfAdmittance")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    Susceptance = URIRef("http://qudt.org/vocab/quantitykind/Susceptance")
    TotalMassStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalMassStoppingPower")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    PoyntingVector = URIRef("http://qudt.org/vocab/quantitykind/PoyntingVector")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    PictureElement = URIRef("http://qudt.org/vocab/quantitykind/PictureElement")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    PressureBasedMolality = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedMolality")
    MagneticPolarization = URIRef("http://qudt.org/vocab/quantitykind/MagneticPolarization")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    ElectricFlux = URIRef("http://qudt.org/vocab/quantitykind/ElectricFlux")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    AtomScatteringFactor = URIRef("http://qudt.org/vocab/quantitykind/AtomScatteringFactor")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    SurfaceActivityDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceActivityDensity")
    PressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PressureCoefficient")
    ExchangeIntegral = URIRef("http://qudt.org/vocab/quantitykind/ExchangeIntegral")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    StructureFactor = URIRef("http://qudt.org/vocab/quantitykind/StructureFactor")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    MolarFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MolarFlowRate")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    PhotosyntheticPhotonFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/PhotosyntheticPhotonFluxDensity")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    SpecificHelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificHelmholtzEnergy")
    ChargeNumber = URIRef("http://qudt.org/vocab/quantitykind/ChargeNumber")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    TotalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentumQuantumNumber")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    CyclotronAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/CyclotronAngularFrequency")
    SecondStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SecondStageMassRatio")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    EnergyPerArea = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerArea")
    AbsorbedDose = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDose")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    MolecularConcentration = URIRef("http://qudt.org/vocab/quantitykind/MolecularConcentration")
    Absorptance = URIRef("http://qudt.org/vocab/quantitykind/Absorptance")
    ComplexPower = URIRef("http://qudt.org/vocab/quantitykind/ComplexPower")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    AbsoluteTypographicMeasurement = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteTypographicMeasurement")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    LinearEnergyTransfer = URIRef("http://qudt.org/vocab/quantitykind/LinearEnergyTransfer")
    Dimensionless = URIRef("http://qudt.org/vocab/quantitykind/Dimensionless")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    HeartRate = URIRef("http://qudt.org/vocab/quantitykind/HeartRate")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    StateDensity = URIRef("http://qudt.org/vocab/quantitykind/StateDensity")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    PRODUCT_OF_INERTIA_Z = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA_Z")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    AreaTimeTemperature = URIRef("http://qudt.org/vocab/quantitykind/AreaTimeTemperature")
    Dimensionless = URIRef("http://qudt.org/vocab/quantitykind/Dimensionless")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    CouplingFactor = URIRef("http://qudt.org/vocab/quantitykind/CouplingFactor")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    TotalCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrentDensity")
    PolarizationField = URIRef("http://qudt.org/vocab/quantitykind/PolarizationField")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    RelativeLuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/RelativeLuminousFlux")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    AreaRatio = URIRef("http://qudt.org/vocab/quantitykind/AreaRatio")
    ElectricDisplacement = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacement")
    HallCoefficient = URIRef("http://qudt.org/vocab/quantitykind/HallCoefficient")
    MeltingPoint = URIRef("http://qudt.org/vocab/quantitykind/MeltingPoint")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    MassPerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerAreaTime")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    MaximumOperatingPressure = URIRef("http://qudt.org/vocab/quantitykind/MaximumOperatingPressure")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    ExitPlanePressure = URIRef("http://qudt.org/vocab/quantitykind/ExitPlanePressure")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    IncidenceProportion = URIRef("http://qudt.org/vocab/quantitykind/IncidenceProportion")
    PowerPerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerPerArea")
    SuperconductionTransitionTemperature = URIRef("http://qudt.org/vocab/quantitykind/SuperconductionTransitionTemperature")
    PressureBurningRateConstant = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateConstant")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    ElectromagneticPermeability = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeability")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    MolarRefractivity = URIRef("http://qudt.org/vocab/quantitykind/MolarRefractivity")
    NozzleThroatPressure = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatPressure")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    MolarConductivity = URIRef("http://qudt.org/vocab/quantitykind/MolarConductivity")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    Asset = URIRef("http://qudt.org/vocab/quantitykind/Asset")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    ElectricCurrentPerUnitEnergy = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerUnitEnergy")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    LineicLogarithmicRatio = URIRef("http://qudt.org/vocab/quantitykind/LineicLogarithmicRatio")
    ElectricChargeSurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeSurfaceDensity")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    ThrustToWeightRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToWeightRatio")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    StressIntensityFactor = URIRef("http://qudt.org/vocab/quantitykind/StressIntensityFactor")
    NuclearEnergy = URIRef("http://qudt.org/vocab/quantitykind/NuclearEnergy")
    TemperaturePerTime_Squared = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime_Squared")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    ThermodynamicCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicCriticalMagneticFluxDensity")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    VolumetricOutputPower = URIRef("http://qudt.org/vocab/quantitykind/VolumetricOutputPower")
    Viscosity = URIRef("http://qudt.org/vocab/quantitykind/Viscosity")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    TotalPressure = URIRef("http://qudt.org/vocab/quantitykind/TotalPressure")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    TotalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentumQuantumNumber")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    ElectricalConductance = URIRef("http://qudt.org/vocab/quantitykind/ElectricalConductance")
    ThermalUtilizationFactorForFission = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactorForFission")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    BoilingPoint = URIRef("http://qudt.org/vocab/quantitykind/BoilingPoint")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    PH = URIRef("http://qudt.org/vocab/quantitykind/PH")
    Dissipance = URIRef("http://qudt.org/vocab/quantitykind/Dissipance")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    TimePercentage = URIRef("http://qudt.org/vocab/quantitykind/TimePercentage")
    LinearBitDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearBitDensity")
    LinearThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/LinearThermalExpansion")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    SpectralDensityOfVibrationalModes = URIRef("http://qudt.org/vocab/quantitykind/SpectralDensityOfVibrationalModes")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    ElectromagneticPermeabilityRatio = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeabilityRatio")
    ByteTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/ByteTransmissionRate")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    ForcePerLength = URIRef("http://qudt.org/vocab/quantitykind/ForcePerLength")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    VolumetricBitDensity = URIRef("http://qudt.org/vocab/quantitykind/VolumetricBitDensity")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    ElectromagneticWavePhaseSpeed = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticWavePhaseSpeed")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    PropellantBurnRate = URIRef("http://qudt.org/vocab/quantitykind/PropellantBurnRate")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    Reflectance = URIRef("http://qudt.org/vocab/quantitykind/Reflectance")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    DimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/DimensionlessRatio")
    SingleStageLauncherMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SingleStageLauncherMassRatio")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    LineicTorque = URIRef("http://qudt.org/vocab/quantitykind/LineicTorque")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    Conductance = URIRef("http://qudt.org/vocab/quantitykind/Conductance")
    WarpingConstant = URIRef("http://qudt.org/vocab/quantitykind/WarpingConstant")
    OsmoticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/OsmoticCoefficient")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    FUEL_BIAS = URIRef("http://qudt.org/vocab/quantitykind/FUEL-BIAS")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    FailureRate = URIRef("http://qudt.org/vocab/quantitykind/FailureRate")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    ResistancePercentage = URIRef("http://qudt.org/vocab/quantitykind/ResistancePercentage")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    MolarFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MolarFlowRate")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    VideoFrameRate = URIRef("http://qudt.org/vocab/quantitykind/VideoFrameRate")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    MolarOpticalRotationalAbility = URIRef("http://qudt.org/vocab/quantitykind/MolarOpticalRotationalAbility")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    SecondMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondMomentOfArea")
    MassFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MassFluxDensity")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    AngleOfOpticalRotation = URIRef("http://qudt.org/vocab/quantitykind/AngleOfOpticalRotation")
    InversePressure = URIRef("http://qudt.org/vocab/quantitykind/InversePressure")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    ThrustToMassRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToMassRatio")
    InformationContentExpressedAsALogarithmToBase2 = URIRef("http://qudt.org/vocab/quantitykind/InformationContentExpressedAsALogarithmToBase2")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    Compressibility = URIRef("http://qudt.org/vocab/quantitykind/Compressibility")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    ReflectanceFactor = URIRef("http://qudt.org/vocab/quantitykind/ReflectanceFactor")
    Kerma = URIRef("http://qudt.org/vocab/quantitykind/Kerma")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    Prevalence = URIRef("http://qudt.org/vocab/quantitykind/Prevalence")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    ConductionSpeed = URIRef("http://qudt.org/vocab/quantitykind/ConductionSpeed")
    Temperature = URIRef("http://qudt.org/vocab/quantitykind/Temperature")
    Temperature = URIRef("http://qudt.org/vocab/quantitykind/Temperature")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    LinearAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAttenuationCoefficient")
    DragCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DragCoefficient")
    QuarticElectricDipoleMomentPerCubicEnergy = URIRef("http://qudt.org/vocab/quantitykind/QuarticElectricDipoleMomentPerCubicEnergy")
    ThermalConductance = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductance")
    PressureBasedMolality = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedMolality")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    PhotonLuminance = URIRef("http://qudt.org/vocab/quantitykind/PhotonLuminance")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    MagneticPolarization = URIRef("http://qudt.org/vocab/quantitykind/MagneticPolarization")
    ResonanceEscapeProbabilityForFission = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbabilityForFission")
    PositiveDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/PositiveDimensionlessRatio")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    Adaptation = URIRef("http://qudt.org/vocab/quantitykind/Adaptation")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    RadiantIntensity = URIRef("http://qudt.org/vocab/quantitykind/RadiantIntensity")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    EnergyPerArea = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerArea")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    Repetency = URIRef("http://qudt.org/vocab/quantitykind/Repetency")
    MolarAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAttenuationCoefficient")
    NumberDensity = URIRef("http://qudt.org/vocab/quantitykind/NumberDensity")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    LinearStiffness = URIRef("http://qudt.org/vocab/quantitykind/LinearStiffness")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    EquivalenceDoseOutput = URIRef("http://qudt.org/vocab/quantitykind/EquivalenceDoseOutput")
    ResonanceEscapeProbabilityForFission = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbabilityForFission")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    PhotosyntheticPhotonFlux = URIRef("http://qudt.org/vocab/quantitykind/PhotosyntheticPhotonFlux")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    RelativeMassConcentrationOfVapour = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassConcentrationOfVapour")
    MASS_PROPERTY_UNCERTAINTY = URIRef("http://qudt.org/vocab/quantitykind/MASS-PROPERTY-UNCERTAINTY")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    LinearElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrentDensity")
    BulkModulus = URIRef("http://qudt.org/vocab/quantitykind/BulkModulus")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    QuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/QuantumNumber")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    Action = URIRef("http://qudt.org/vocab/quantitykind/Action")
    InverseLength = URIRef("http://qudt.org/vocab/quantitykind/InverseLength")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    DecayConstant = URIRef("http://qudt.org/vocab/quantitykind/DecayConstant")
    BucklingFactor = URIRef("http://qudt.org/vocab/quantitykind/BucklingFactor")
    LinearPower = URIRef("http://qudt.org/vocab/quantitykind/LinearPower")
    PoyntingVector = URIRef("http://qudt.org/vocab/quantitykind/PoyntingVector")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    MagneticReluctivity = URIRef("http://qudt.org/vocab/quantitykind/MagneticReluctivity")
    DoseEquivalent = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalent")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    AngleOfAttack = URIRef("http://qudt.org/vocab/quantitykind/AngleOfAttack")
    GeneralizedForce = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedForce")
    RiseOfOffStateVoltage = URIRef("http://qudt.org/vocab/quantitykind/RiseOfOffStateVoltage")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    Turns = URIRef("http://qudt.org/vocab/quantitykind/Turns")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    TimeRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRatio")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    SpecificHeatCapacityAtConstantPressure = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantPressure")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    ChemicalAffinity = URIRef("http://qudt.org/vocab/quantitykind/ChemicalAffinity")
    IncidenceRate = URIRef("http://qudt.org/vocab/quantitykind/IncidenceRate")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    SphericalIlluminance = URIRef("http://qudt.org/vocab/quantitykind/SphericalIlluminance")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    EnergyPerSquareMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerSquareMagneticFluxDensity")
    ThermalUtilizationFactorForFission = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactorForFission")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    CurvatureFromRadius = URIRef("http://qudt.org/vocab/quantitykind/CurvatureFromRadius")
    ElectricDisplacementField = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacementField")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    AbsorbedDoseRate = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDoseRate")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    PartialPressure = URIRef("http://qudt.org/vocab/quantitykind/PartialPressure")
    SoundExposureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundExposureLevel")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    SpectralRadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SpectralRadiantEnergyDensity")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    Concentration = URIRef("http://qudt.org/vocab/quantitykind/Concentration")
    AtomicEnergy = URIRef("http://qudt.org/vocab/quantitykind/AtomicEnergy")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    AreicEnergyFlow = URIRef("http://qudt.org/vocab/quantitykind/AreicEnergyFlow")
    RotationalMass = URIRef("http://qudt.org/vocab/quantitykind/RotationalMass")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    AngularDistance = URIRef("http://qudt.org/vocab/quantitykind/AngularDistance")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    ColdReceptorThreshold = URIRef("http://qudt.org/vocab/quantitykind/ColdReceptorThreshold")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    ParticleNumberDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleNumberDensity")
    SpecificVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificVolume")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    ThomsonCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThomsonCoefficient")
    Debye_WallerFactor = URIRef("http://qudt.org/vocab/quantitykind/Debye-WallerFactor")
    UpperCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/UpperCriticalMagneticFluxDensity")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    MortalityRate = URIRef("http://qudt.org/vocab/quantitykind/MortalityRate")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    ElectricQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricQuadrupoleMoment")
    TotalCurrent = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrent")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    VolumicElectromagneticEnergy = URIRef("http://qudt.org/vocab/quantitykind/VolumicElectromagneticEnergy")
    ForcePerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/ForcePerAreaTime")
    Debye_WallerFactor = URIRef("http://qudt.org/vocab/quantitykind/Debye-WallerFactor")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    CharacteristicAcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicAcousticImpedance")
    AngularReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/AngularReciprocalLatticeVector")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    LinearCompressibility = URIRef("http://qudt.org/vocab/quantitykind/LinearCompressibility")
    MassTemperature = URIRef("http://qudt.org/vocab/quantitykind/MassTemperature")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    CouplingFactor = URIRef("http://qudt.org/vocab/quantitykind/CouplingFactor")
    TotalCurrent = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrent")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    ElectricalResistance = URIRef("http://qudt.org/vocab/quantitykind/ElectricalResistance")
    StatisticalWeight = URIRef("http://qudt.org/vocab/quantitykind/StatisticalWeight")
    Rotary_TranslatoryMotionConversion = URIRef("http://qudt.org/vocab/quantitykind/Rotary-TranslatoryMotionConversion")
    SpectralAngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralAngularCrossSection")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    ElectricDisplacementField = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacementField")
    StressOpticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StressOpticCoefficient")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    PressureBasedMolality = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedMolality")
    Fluidity = URIRef("http://qudt.org/vocab/quantitykind/Fluidity")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    PoissonRatio = URIRef("http://qudt.org/vocab/quantitykind/PoissonRatio")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    DoseEquivalentQualityFactor = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalentQualityFactor")
    ElectromagneticPermeability = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeability")
    HamiltonFunction = URIRef("http://qudt.org/vocab/quantitykind/HamiltonFunction")
    LagrangeFunction = URIRef("http://qudt.org/vocab/quantitykind/LagrangeFunction")
    DoseEquivalent = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalent")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    LineicDataVolume = URIRef("http://qudt.org/vocab/quantitykind/LineicDataVolume")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    MOMENT_OF_INERTIA_Z = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Z")
    SingleStageLauncherMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SingleStageLauncherMassRatio")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    DewPointTemperature = URIRef("http://qudt.org/vocab/quantitykind/DewPointTemperature")
    ElectricDisplacement = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacement")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    OrderOfReflection = URIRef("http://qudt.org/vocab/quantitykind/OrderOfReflection")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    StandardAbsoluteActivity = URIRef("http://qudt.org/vocab/quantitykind/StandardAbsoluteActivity")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    BloodGlucoseLevel_Mass = URIRef("http://qudt.org/vocab/quantitykind/BloodGlucoseLevel_Mass")
    WebTimeAveragePressure = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAveragePressure")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    LowerCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/LowerCriticalMagneticFluxDensity")
    DecayConstant = URIRef("http://qudt.org/vocab/quantitykind/DecayConstant")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    Prevalence = URIRef("http://qudt.org/vocab/quantitykind/Prevalence")
    PowerPerAreaAngle = URIRef("http://qudt.org/vocab/quantitykind/PowerPerAreaAngle")
    OsmoticPressure = URIRef("http://qudt.org/vocab/quantitykind/OsmoticPressure")
    PhotosyntheticPhotonFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/PhotosyntheticPhotonFluxDensity")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    ElectrolyticConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectrolyticConductivity")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    PhotonIntensity = URIRef("http://qudt.org/vocab/quantitykind/PhotonIntensity")
    Exposure = URIRef("http://qudt.org/vocab/quantitykind/Exposure")
    ThrustCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThrustCoefficient")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    NeelTemperature = URIRef("http://qudt.org/vocab/quantitykind/NeelTemperature")
    InternalConversionFactor = URIRef("http://qudt.org/vocab/quantitykind/InternalConversionFactor")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    NapierianAbsorbance = URIRef("http://qudt.org/vocab/quantitykind/NapierianAbsorbance")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    NeutronDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionCoefficient")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    CoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/CoefficientOfHeatTransfer")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    GeneralizedVelocity = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedVelocity")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    EvaporativeHeatTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/EvaporativeHeatTransferCoefficient")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    LogarithmicMedianInformationFlow_SourceToBase2 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicMedianInformationFlow_SourceToBase2")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    QualityFactor = URIRef("http://qudt.org/vocab/quantitykind/QualityFactor")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    ElectricChargeSurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeSurfaceDensity")
    ExitPlaneTemperature = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneTemperature")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    Population = URIRef("http://qudt.org/vocab/quantitykind/Population")
    PictureElement = URIRef("http://qudt.org/vocab/quantitykind/PictureElement")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    SunProtectionFactorOfAProduct = URIRef("http://qudt.org/vocab/quantitykind/SunProtectionFactorOfAProduct")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    SpecificHelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificHelmholtzEnergy")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    EnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensity")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    Capacity = URIRef("http://qudt.org/vocab/quantitykind/Capacity")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    MolarInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarInternalEnergy")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    ByteRate = URIRef("http://qudt.org/vocab/quantitykind/ByteRate")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    StaticPressure = URIRef("http://qudt.org/vocab/quantitykind/StaticPressure")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    SoilAdsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SoilAdsorptionCoefficient")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    EinsteinTransitionProbability = URIRef("http://qudt.org/vocab/quantitykind/EinsteinTransitionProbability")
    ParticleNumberDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleNumberDensity")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    GustatoryThreshold = URIRef("http://qudt.org/vocab/quantitykind/GustatoryThreshold")
    MortalityRate = URIRef("http://qudt.org/vocab/quantitykind/MortalityRate")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    LinearAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAbsorptionCoefficient")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    Capacitance = URIRef("http://qudt.org/vocab/quantitykind/Capacitance")
    NeutralRatio = URIRef("http://qudt.org/vocab/quantitykind/NeutralRatio")
    GeneralizedForce = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedForce")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    AbsorbedDoseRate = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDoseRate")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    Circulation = URIRef("http://qudt.org/vocab/quantitykind/Circulation")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    ParticleFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluenceRate")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    Turbidity = URIRef("http://qudt.org/vocab/quantitykind/Turbidity")
    LagrangeFunction = URIRef("http://qudt.org/vocab/quantitykind/LagrangeFunction")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    NormalizedDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/NormalizedDimensionlessRatio")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    LinearAcceleration = URIRef("http://qudt.org/vocab/quantitykind/LinearAcceleration")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    MassFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MassFluxDensity")
    IncidenceRate = URIRef("http://qudt.org/vocab/quantitykind/IncidenceRate")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    MaximumOperatingPressure = URIRef("http://qudt.org/vocab/quantitykind/MaximumOperatingPressure")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    CurrencyPerFlight = URIRef("http://qudt.org/vocab/quantitykind/CurrencyPerFlight")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    Acidity = URIRef("http://qudt.org/vocab/quantitykind/Acidity")
    PressureBasedTemperature = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedTemperature")
    Conductance = URIRef("http://qudt.org/vocab/quantitykind/Conductance")
    MassFractionOfDryMatter = URIRef("http://qudt.org/vocab/quantitykind/MassFractionOfDryMatter")
    ThermalInsulance = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulance")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    EquilibriumConstantOnConcentrationBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnConcentrationBasis")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    SpecificElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/SpecificElectricCurrent")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    DebyeAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularFrequency")
    GroupSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/GroupSpeedOfSound")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    LagrangeFunction = URIRef("http://qudt.org/vocab/quantitykind/LagrangeFunction")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    Half_Life = URIRef("http://qudt.org/vocab/quantitykind/Half-Life")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    MagneticTension = URIRef("http://qudt.org/vocab/quantitykind/MagneticTension")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    CostPerUnitPower = URIRef("http://qudt.org/vocab/quantitykind/CostPerUnitPower")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    NeutronDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionCoefficient")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    PropellantTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantTemperature")
    MaximumOperatingPressure = URIRef("http://qudt.org/vocab/quantitykind/MaximumOperatingPressure")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    TimeSquared = URIRef("http://qudt.org/vocab/quantitykind/TimeSquared")
    SurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceDensity")
    SeebeckCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SeebeckCoefficient")
    AngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentum")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    TorsionalSpringConstant = URIRef("http://qudt.org/vocab/quantitykind/TorsionalSpringConstant")
    ThermalCapacitance = URIRef("http://qudt.org/vocab/quantitykind/ThermalCapacitance")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    CombinedNonEvaporativeHeatTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CombinedNonEvaporativeHeatTransferCoefficient")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    IsothermalMoistureCapacity = URIRef("http://qudt.org/vocab/quantitykind/IsothermalMoistureCapacity")
    BoilingPoint = URIRef("http://qudt.org/vocab/quantitykind/BoilingPoint")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    RF_Power = URIRef("http://qudt.org/vocab/quantitykind/RF-Power")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    LogOctanolWaterPartitionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LogOctanolWaterPartitionCoefficient")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    Compressibility = URIRef("http://qudt.org/vocab/quantitykind/Compressibility")
    AreaTime = URIRef("http://qudt.org/vocab/quantitykind/AreaTime")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    RelativeMassConcentrationOfVapour = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassConcentrationOfVapour")
    StandardAbsoluteActivity = URIRef("http://qudt.org/vocab/quantitykind/StandardAbsoluteActivity")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    ResonanceEscapeProbability = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbability")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    NumberOfParticles = URIRef("http://qudt.org/vocab/quantitykind/NumberOfParticles")
    TimeRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRatio")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    TemporalSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/TemporalSummationFunction")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    ModulusOfAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfAdmittance")
    PropagationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PropagationCoefficient")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    VoltageRatio = URIRef("http://qudt.org/vocab/quantitykind/VoltageRatio")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    AreicEnergyFlow = URIRef("http://qudt.org/vocab/quantitykind/AreicEnergyFlow")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    HallCoefficient = URIRef("http://qudt.org/vocab/quantitykind/HallCoefficient")
    InverseLength = URIRef("http://qudt.org/vocab/quantitykind/InverseLength")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    ElectricalResistance = URIRef("http://qudt.org/vocab/quantitykind/ElectricalResistance")
    PlanckFunction = URIRef("http://qudt.org/vocab/quantitykind/PlanckFunction")
    EnergyPerMagneticFluxDensity_Squared = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerMagneticFluxDensity_Squared")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    FUEL_BIAS = URIRef("http://qudt.org/vocab/quantitykind/FUEL-BIAS")
    PressureBurningRateConstant = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateConstant")
    MolalityOfSolute = URIRef("http://qudt.org/vocab/quantitykind/MolalityOfSolute")
    MassPerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerAreaTime")
    StandardAbsoluteActivity = URIRef("http://qudt.org/vocab/quantitykind/StandardAbsoluteActivity")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    DensityInCombustionChamber = URIRef("http://qudt.org/vocab/quantitykind/DensityInCombustionChamber")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    LiquidVolume = URIRef("http://qudt.org/vocab/quantitykind/LiquidVolume")
    MassicHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MassicHeatCapacity")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    HeatFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/HeatFluxDensity")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    HyperfineStructureQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/HyperfineStructureQuantumNumber")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    SpectralRadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SpectralRadiantEnergyDensity")
    CostPerUnitEnergy = URIRef("http://qudt.org/vocab/quantitykind/CostPerUnitEnergy")
    MassFraction = URIRef("http://qudt.org/vocab/quantitykind/MassFraction")
    CyclotronAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/CyclotronAngularFrequency")
    Resistivity = URIRef("http://qudt.org/vocab/quantitykind/Resistivity")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    CorrelatedColorTemperature = URIRef("http://qudt.org/vocab/quantitykind/CorrelatedColorTemperature")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    StaticPressure = URIRef("http://qudt.org/vocab/quantitykind/StaticPressure")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    InverseAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/InverseAmountOfSubstance")
    Impedance = URIRef("http://qudt.org/vocab/quantitykind/Impedance")
    Curvature = URIRef("http://qudt.org/vocab/quantitykind/Curvature")
    SpecificActivity = URIRef("http://qudt.org/vocab/quantitykind/SpecificActivity")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    PositiveDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/PositiveDimensionlessRatio")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    PayloadRatio = URIRef("http://qudt.org/vocab/quantitykind/PayloadRatio")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    SpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/SpinQuantumNumber")
    Turns = URIRef("http://qudt.org/vocab/quantitykind/Turns")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    AreaBitDensity = URIRef("http://qudt.org/vocab/quantitykind/AreaBitDensity")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    Coercivity = URIRef("http://qudt.org/vocab/quantitykind/Coercivity")
    NormalizedDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/NormalizedDimensionlessRatio")
    AngleOfAttack = URIRef("http://qudt.org/vocab/quantitykind/AngleOfAttack")
    ThermalInsulance = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulance")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    PressureGradient = URIRef("http://qudt.org/vocab/quantitykind/PressureGradient")
    MassPerTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerTime")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    CostPerUnitPower = URIRef("http://qudt.org/vocab/quantitykind/CostPerUnitPower")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    ForcePerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/ForcePerAreaTime")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    EnergyPerArea = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerArea")
    UpperCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/UpperCriticalMagneticFluxDensity")
    DisplacementCurrent = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrent")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    UpperCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/UpperCriticalMagneticFluxDensity")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    ThomsonCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThomsonCoefficient")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    Dimensionless = URIRef("http://qudt.org/vocab/quantitykind/Dimensionless")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    ElectronDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectronDensity")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    EvaporativeHeatTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/EvaporativeHeatTransferCoefficient")
    Period = URIRef("http://qudt.org/vocab/quantitykind/Period")
    CatalyticActivity = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivity")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    ExchangeIntegral = URIRef("http://qudt.org/vocab/quantitykind/ExchangeIntegral")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    SoilAdsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SoilAdsorptionCoefficient")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    ElectrolyticConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectrolyticConductivity")
    AmountOfSubstanceFractionOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFractionOfB")
    Conductance = URIRef("http://qudt.org/vocab/quantitykind/Conductance")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    EnergyPerArea = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerArea")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    LengthRatio = URIRef("http://qudt.org/vocab/quantitykind/LengthRatio")
    DiastolicBloodPressure = URIRef("http://qudt.org/vocab/quantitykind/DiastolicBloodPressure")
    PressureBasedKinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedKinematicViscosity")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    EnergyDensityOfStates = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensityOfStates")
    DebyeAngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularWavenumber")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    SpecificOpticalRotationalAbility = URIRef("http://qudt.org/vocab/quantitykind/SpecificOpticalRotationalAbility")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    PoissonRatio = URIRef("http://qudt.org/vocab/quantitykind/PoissonRatio")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    OsmoticPressure = URIRef("http://qudt.org/vocab/quantitykind/OsmoticPressure")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    ExtentOfReaction = URIRef("http://qudt.org/vocab/quantitykind/ExtentOfReaction")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    TemperatureBasedMass = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedMass")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    AbsoluteTypographicMeasurement = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteTypographicMeasurement")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    CorrelatedColorTemperature = URIRef("http://qudt.org/vocab/quantitykind/CorrelatedColorTemperature")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    DisplacementCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrentDensity")
    ReynoldsNumber = URIRef("http://qudt.org/vocab/quantitykind/ReynoldsNumber")
    MotorConstant = URIRef("http://qudt.org/vocab/quantitykind/MotorConstant")
    IonDensity = URIRef("http://qudt.org/vocab/quantitykind/IonDensity")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    ThermalInsulance = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulance")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    SecondAxialMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondAxialMomentOfArea")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    RespiratoryRate = URIRef("http://qudt.org/vocab/quantitykind/RespiratoryRate")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    LengthPerUnitElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/LengthPerUnitElectricCurrent")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    SpecificImpulse = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulse")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    MolarConductivity = URIRef("http://qudt.org/vocab/quantitykind/MolarConductivity")
    BurstFactor = URIRef("http://qudt.org/vocab/quantitykind/BurstFactor")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    GeneFamilyAbundance = URIRef("http://qudt.org/vocab/quantitykind/GeneFamilyAbundance")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    LagrangeFunction = URIRef("http://qudt.org/vocab/quantitykind/LagrangeFunction")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    InverseTime = URIRef("http://qudt.org/vocab/quantitykind/InverseTime")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    VisionThresholds = URIRef("http://qudt.org/vocab/quantitykind/VisionThresholds")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    Energy_Squared = URIRef("http://qudt.org/vocab/quantitykind/Energy_Squared")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    EnergyPerMassAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerMassAmountOfSubstance")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    InverseLengthTemperature = URIRef("http://qudt.org/vocab/quantitykind/InverseLengthTemperature")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    CatalyticActivity = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivity")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    DimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/DimensionlessRatio")
    MolecularViscosity = URIRef("http://qudt.org/vocab/quantitykind/MolecularViscosity")
    Turns = URIRef("http://qudt.org/vocab/quantitykind/Turns")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    TotalCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrentDensity")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    Conductance = URIRef("http://qudt.org/vocab/quantitykind/Conductance")
    ReflectanceFactor = URIRef("http://qudt.org/vocab/quantitykind/ReflectanceFactor")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    EquilibriumConstantOnPressureBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnPressureBasis")
    MassFractionOfDryMatter = URIRef("http://qudt.org/vocab/quantitykind/MassFractionOfDryMatter")
    TotalAtomicStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalAtomicStoppingPower")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    PressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PressureCoefficient")
    Turns = URIRef("http://qudt.org/vocab/quantitykind/Turns")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    SoundParticleAcceleration = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleAcceleration")
    LineicResistance = URIRef("http://qudt.org/vocab/quantitykind/LineicResistance")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    ElectricalConductance = URIRef("http://qudt.org/vocab/quantitykind/ElectricalConductance")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    ThermalDiffusionFactor = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionFactor")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    LinearAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAbsorptionCoefficient")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    ElectromagneticPermeability = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeability")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    SpecificEnthalpy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnthalpy")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    FlightPathAngle = URIRef("http://qudt.org/vocab/quantitykind/FlightPathAngle")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    TemperatureBasedKinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedKinematicViscosity")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    PressureGradient = URIRef("http://qudt.org/vocab/quantitykind/PressureGradient")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    Impulse = URIRef("http://qudt.org/vocab/quantitykind/Impulse")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    DiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficient")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    EquilibriumConstantOnPressureBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnPressureBasis")
    AmountOfSubstancePerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMass")
    ThermalTransmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalTransmittance")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    AtomicStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/AtomicStoppingPower")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    InverseSquareTime = URIRef("http://qudt.org/vocab/quantitykind/InverseSquareTime")
    HeatFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/HeatFluxDensity")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    ElectronMobility = URIRef("http://qudt.org/vocab/quantitykind/ElectronMobility")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    MolecularConcentration = URIRef("http://qudt.org/vocab/quantitykind/MolecularConcentration")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    Compressibility = URIRef("http://qudt.org/vocab/quantitykind/Compressibility")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    ElectricChargePerMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerMass")
    Permeance = URIRef("http://qudt.org/vocab/quantitykind/Permeance")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    BevelGearPitchAngle = URIRef("http://qudt.org/vocab/quantitykind/BevelGearPitchAngle")
    ExhaustGasesSpecificHeat = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasesSpecificHeat")
    MolecularConcentration = URIRef("http://qudt.org/vocab/quantitykind/MolecularConcentration")
    FlightPathAngle = URIRef("http://qudt.org/vocab/quantitykind/FlightPathAngle")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    MadelungConstant = URIRef("http://qudt.org/vocab/quantitykind/MadelungConstant")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    AreaPerTime = URIRef("http://qudt.org/vocab/quantitykind/AreaPerTime")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    Radiosity = URIRef("http://qudt.org/vocab/quantitykind/Radiosity")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    Asset = URIRef("http://qudt.org/vocab/quantitykind/Asset")
    FUEL_BIAS = URIRef("http://qudt.org/vocab/quantitykind/FUEL-BIAS")
    AngularDistance = URIRef("http://qudt.org/vocab/quantitykind/AngularDistance")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    SourceVoltageBetweenSubstances = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltageBetweenSubstances")
    EnergyPerMagneticFluxDensity_Squared = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerMagneticFluxDensity_Squared")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    ResistancePercentage = URIRef("http://qudt.org/vocab/quantitykind/ResistancePercentage")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    AtomicNumber = URIRef("http://qudt.org/vocab/quantitykind/AtomicNumber")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    ReciprocalElectricResistance = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalElectricResistance")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    LogOctanolWaterPartitionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LogOctanolWaterPartitionCoefficient")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    PermittivityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermittivityRatio")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    MOMENT_OF_INERTIA_Y = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Y")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    ExposureRate = URIRef("http://qudt.org/vocab/quantitykind/ExposureRate")
    OsmoticPressure = URIRef("http://qudt.org/vocab/quantitykind/OsmoticPressure")
    RotationalMass = URIRef("http://qudt.org/vocab/quantitykind/RotationalMass")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    PowerPerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerPerArea")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    SpecificGibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificGibbsEnergy")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    VolumePerArea = URIRef("http://qudt.org/vocab/quantitykind/VolumePerArea")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    DegreeOfDissociation = URIRef("http://qudt.org/vocab/quantitykind/DegreeOfDissociation")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    PermeabilityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermeabilityRatio")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    AngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentum")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    PRODUCT_OF_INERTIA_Z = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA_Z")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    LarmorAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/LarmorAngularFrequency")
    SpecificActivity = URIRef("http://qudt.org/vocab/quantitykind/SpecificActivity")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    SpecificHeatsRatio = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatsRatio")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    ForcePerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ForcePerElectricCharge")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    IonTransportNumber = URIRef("http://qudt.org/vocab/quantitykind/IonTransportNumber")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    SpecificHeatCapacityAtConstantVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantVolume")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    Reactance = URIRef("http://qudt.org/vocab/quantitykind/Reactance")
    ForcePerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ForcePerElectricCharge")
    Log10FrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/Log10FrequencyInterval")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    Permeability = URIRef("http://qudt.org/vocab/quantitykind/Permeability")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    BucklingFactor = URIRef("http://qudt.org/vocab/quantitykind/BucklingFactor")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    ElectricChargeLinearDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeLinearDensity")
    ResidualResistivity = URIRef("http://qudt.org/vocab/quantitykind/ResidualResistivity")
    VoltagePhasor = URIRef("http://qudt.org/vocab/quantitykind/VoltagePhasor")
    MassFraction = URIRef("http://qudt.org/vocab/quantitykind/MassFraction")
    SignalStrength = URIRef("http://qudt.org/vocab/quantitykind/SignalStrength")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    SurfaceCoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/SurfaceCoefficientOfHeatTransfer")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    TotalLinearStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalLinearStoppingPower")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    SoundReductionIndex = URIRef("http://qudt.org/vocab/quantitykind/SoundReductionIndex")
    RankineTemperature = URIRef("http://qudt.org/vocab/quantitykind/RankineTemperature")
    SectionAreaIntegral = URIRef("http://qudt.org/vocab/quantitykind/SectionAreaIntegral")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    LogarithmicMedianInformationFlow_SourceToBase2 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicMedianInformationFlow_SourceToBase2")
    ActionTime = URIRef("http://qudt.org/vocab/quantitykind/ActionTime")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    EquilibriumConstant = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstant")
    ExitPlaneTemperature = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneTemperature")
    CatalyticActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivityConcentration")
    VolumeThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/VolumeThermalExpansion")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    MolarThermalCapacity = URIRef("http://qudt.org/vocab/quantitykind/MolarThermalCapacity")
    GeneralizedVelocity = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedVelocity")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    AbsorbedDose = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDose")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    MagneticAreaMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticAreaMoment")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    MassConcentrationOfWater = URIRef("http://qudt.org/vocab/quantitykind/MassConcentrationOfWater")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    ThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusivity")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    DegreeOfDissociation = URIRef("http://qudt.org/vocab/quantitykind/DegreeOfDissociation")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    Reflectance = URIRef("http://qudt.org/vocab/quantitykind/Reflectance")
    StoichiometricNumber = URIRef("http://qudt.org/vocab/quantitykind/StoichiometricNumber")
    MOMENT_OF_INERTIA_Z = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Z")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    EinsteinTransitionProbability = URIRef("http://qudt.org/vocab/quantitykind/EinsteinTransitionProbability")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    VolumeDensityOfCharge = URIRef("http://qudt.org/vocab/quantitykind/VolumeDensityOfCharge")
    VolumicAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/VolumicAmountOfSubstance")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    ThermalUtilizationFactorForFission = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactorForFission")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    LineicQuantity = URIRef("http://qudt.org/vocab/quantitykind/LineicQuantity")
    LinkedFlux = URIRef("http://qudt.org/vocab/quantitykind/LinkedFlux")
    LinearStiffness = URIRef("http://qudt.org/vocab/quantitykind/LinearStiffness")
    Reluctance = URIRef("http://qudt.org/vocab/quantitykind/Reluctance")
    MassConcentration = URIRef("http://qudt.org/vocab/quantitykind/MassConcentration")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    MicroCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/MicroCanonicalPartitionFunction")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    StoichiometricNumber = URIRef("http://qudt.org/vocab/quantitykind/StoichiometricNumber")
    EnergyPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerElectricCharge")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    EnergyPerArea = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerArea")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    SpecificEnthalpy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnthalpy")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    LogarithmicMedianInformationFlow_SourceToBaseE = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicMedianInformationFlow_SourceToBaseE")
    StandardChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/StandardChemicalPotential")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    InverseTimeTemperature = URIRef("http://qudt.org/vocab/quantitykind/InverseTimeTemperature")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    MagneticField = URIRef("http://qudt.org/vocab/quantitykind/MagneticField")
    VolumeOrSectionModulus = URIRef("http://qudt.org/vocab/quantitykind/VolumeOrSectionModulus")
    VoltagePhasor = URIRef("http://qudt.org/vocab/quantitykind/VoltagePhasor")
    UpperCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/UpperCriticalMagneticFluxDensity")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    LengthByForce = URIRef("http://qudt.org/vocab/quantitykind/LengthByForce")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    GrowingDegreeDay_Cereal = URIRef("http://qudt.org/vocab/quantitykind/GrowingDegreeDay_Cereal")
    WarmReceptorThreshold = URIRef("http://qudt.org/vocab/quantitykind/WarmReceptorThreshold")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    BioconcentrationFactor = URIRef("http://qudt.org/vocab/quantitykind/BioconcentrationFactor")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    MolarAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAttenuationCoefficient")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    DecayConstant = URIRef("http://qudt.org/vocab/quantitykind/DecayConstant")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    Angle = URIRef("http://qudt.org/vocab/quantitykind/Angle")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    SoundExposureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundExposureLevel")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    SpecificVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificVolume")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    EquilibriumConstantOnConcentrationBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnConcentrationBasis")
    FishBiotransformationHalfLife = URIRef("http://qudt.org/vocab/quantitykind/FishBiotransformationHalfLife")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    TotalCurrent = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrent")
    Luminance = URIRef("http://qudt.org/vocab/quantitykind/Luminance")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    SignalStrength = URIRef("http://qudt.org/vocab/quantitykind/SignalStrength")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    WarpingMoment = URIRef("http://qudt.org/vocab/quantitykind/WarpingMoment")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    PowerPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/PowerPerElectricCharge")
    MechanicalSurfaceImpedance = URIRef("http://qudt.org/vocab/quantitykind/MechanicalSurfaceImpedance")
    AngularReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/AngularReciprocalLatticeVector")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    Reflectivity = URIRef("http://qudt.org/vocab/quantitykind/Reflectivity")
    DragForce = URIRef("http://qudt.org/vocab/quantitykind/DragForce")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    ElectricFlux = URIRef("http://qudt.org/vocab/quantitykind/ElectricFlux")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    ElectricDipoleMoment_QuarticPerEnergy_Cubic = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment_QuarticPerEnergy_Cubic")
    ParticleCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrentDensity")
    ThermalDiffusionFactor = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionFactor")
    BatteryCapacity = URIRef("http://qudt.org/vocab/quantitykind/BatteryCapacity")
    LinearForce = URIRef("http://qudt.org/vocab/quantitykind/LinearForce")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    MutualInductance = URIRef("http://qudt.org/vocab/quantitykind/MutualInductance")
    LuminousExposure = URIRef("http://qudt.org/vocab/quantitykind/LuminousExposure")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    Angle = URIRef("http://qudt.org/vocab/quantitykind/Angle")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    MassRatio = URIRef("http://qudt.org/vocab/quantitykind/MassRatio")
    MassieuFunction = URIRef("http://qudt.org/vocab/quantitykind/MassieuFunction")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    Dimensionless = URIRef("http://qudt.org/vocab/quantitykind/Dimensionless")
    ChargeNumber = URIRef("http://qudt.org/vocab/quantitykind/ChargeNumber")
    GustatoryThreshold = URIRef("http://qudt.org/vocab/quantitykind/GustatoryThreshold")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    MagneticDipoleMomentOfAMolecule = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMomentOfAMolecule")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    MassPerEnergy = URIRef("http://qudt.org/vocab/quantitykind/MassPerEnergy")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    PhotonLuminance = URIRef("http://qudt.org/vocab/quantitykind/PhotonLuminance")
    ThermalDiffusionFactor = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionFactor")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    GeneralizedVelocity = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedVelocity")
    PressureBasedMolality = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedMolality")
    Susceptance = URIRef("http://qudt.org/vocab/quantitykind/Susceptance")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    VolumePerArea = URIRef("http://qudt.org/vocab/quantitykind/VolumePerArea")
    RF_Power = URIRef("http://qudt.org/vocab/quantitykind/RF-Power")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    LuminousExposure = URIRef("http://qudt.org/vocab/quantitykind/LuminousExposure")
    SectionAreaIntegral = URIRef("http://qudt.org/vocab/quantitykind/SectionAreaIntegral")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    SecondRadiationConstant = URIRef("http://qudt.org/vocab/quantitykind/SecondRadiationConstant")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    NormalizedDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/NormalizedDimensionlessRatio")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    IonDensity = URIRef("http://qudt.org/vocab/quantitykind/IonDensity")
    LarmorAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/LarmorAngularFrequency")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    ElectricChargeVolumeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeVolumeDensity")
    MassNumber = URIRef("http://qudt.org/vocab/quantitykind/MassNumber")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    InverseMagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/InverseMagneticFlux")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    ExtentOfReaction = URIRef("http://qudt.org/vocab/quantitykind/ExtentOfReaction")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    LinearAcceleration = URIRef("http://qudt.org/vocab/quantitykind/LinearAcceleration")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    PowerConstant = URIRef("http://qudt.org/vocab/quantitykind/PowerConstant")
    SpecificHeatsRatio = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatsRatio")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    MolarConductivity = URIRef("http://qudt.org/vocab/quantitykind/MolarConductivity")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    Lethargy = URIRef("http://qudt.org/vocab/quantitykind/Lethargy")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    EnergyPerArea = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerArea")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    ElectricCurrentPhasor = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPhasor")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    AmountOfSubstanceFractionOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFractionOfB")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    GroupSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/GroupSpeedOfSound")
    PRODUCT_OF_INERTIA_Y = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA_Y")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    VoltageRatio = URIRef("http://qudt.org/vocab/quantitykind/VoltageRatio")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    ElectricChargeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeDensity")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    PressureBasedMassFlow = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedMassFlow")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    ElectronDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectronDensity")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    AngularReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/AngularReciprocalLatticeVector")
    AbsoluteActivity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteActivity")
    SecondPolarMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondPolarMomentOfArea")
    AtomicEnergy = URIRef("http://qudt.org/vocab/quantitykind/AtomicEnergy")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    TotalCurrent = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrent")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    DewPointTemperature = URIRef("http://qudt.org/vocab/quantitykind/DewPointTemperature")
    MOMENT_OF_INERTIA_Z = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Z")
    MolarOpticalRotationalAbility = URIRef("http://qudt.org/vocab/quantitykind/MolarOpticalRotationalAbility")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    Resistivity = URIRef("http://qudt.org/vocab/quantitykind/Resistivity")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    PropellantMeanBulkTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantMeanBulkTemperature")
    MeltingPoint = URIRef("http://qudt.org/vocab/quantitykind/MeltingPoint")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    VolumetricElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/VolumetricElectricCharge")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    AmbientPressure = URIRef("http://qudt.org/vocab/quantitykind/AmbientPressure")
    LinearThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/LinearThermalExpansion")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    AuditoryThresholds = URIRef("http://qudt.org/vocab/quantitykind/AuditoryThresholds")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    NeelTemperature = URIRef("http://qudt.org/vocab/quantitykind/NeelTemperature")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    InfiniteMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/InfiniteMultiplicationFactor")
    ElectrolyticConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectrolyticConductivity")
    BitRate = URIRef("http://qudt.org/vocab/quantitykind/BitRate")
    LineicPower = URIRef("http://qudt.org/vocab/quantitykind/LineicPower")
    SpecificSurfaceArea = URIRef("http://qudt.org/vocab/quantitykind/SpecificSurfaceArea")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    MassPerLength = URIRef("http://qudt.org/vocab/quantitykind/MassPerLength")
    MolecularConcentration = URIRef("http://qudt.org/vocab/quantitykind/MolecularConcentration")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    Turbidity = URIRef("http://qudt.org/vocab/quantitykind/Turbidity")
    MassStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/MassStoppingPower")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    WarpingConstant = URIRef("http://qudt.org/vocab/quantitykind/WarpingConstant")
    MassAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/MassAmountOfSubstance")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    MutualInductance = URIRef("http://qudt.org/vocab/quantitykind/MutualInductance")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    ElectricDipoleMoment_QuarticPerEnergy_Cubic = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment_QuarticPerEnergy_Cubic")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    KermaRate = URIRef("http://qudt.org/vocab/quantitykind/KermaRate")
    AcceptorDensity = URIRef("http://qudt.org/vocab/quantitykind/AcceptorDensity")
    MagneticFluxDensityOrMagneticPolarization = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensityOrMagneticPolarization")
    Viscosity = URIRef("http://qudt.org/vocab/quantitykind/Viscosity")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    AngleOfAttack = URIRef("http://qudt.org/vocab/quantitykind/AngleOfAttack")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    VentilationRatePerFloorArea = URIRef("http://qudt.org/vocab/quantitykind/VentilationRatePerFloorArea")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    Temperature = URIRef("http://qudt.org/vocab/quantitykind/Temperature")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    SurgeImpedanceOfTheMedium = URIRef("http://qudt.org/vocab/quantitykind/SurgeImpedanceOfTheMedium")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    IsothermalMoistureCapacity = URIRef("http://qudt.org/vocab/quantitykind/IsothermalMoistureCapacity")
    CurrencyPerFlight = URIRef("http://qudt.org/vocab/quantitykind/CurrencyPerFlight")
    ThermalEnergyLength = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergyLength")
    InverseTime_Squared = URIRef("http://qudt.org/vocab/quantitykind/InverseTime_Squared")
    MassFractionOfWater = URIRef("http://qudt.org/vocab/quantitykind/MassFractionOfWater")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    DensityOfStates = URIRef("http://qudt.org/vocab/quantitykind/DensityOfStates")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    FissionMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionMultiplicationFactor")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    PressureBasedKinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedKinematicViscosity")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    TorquePerLength = URIRef("http://qudt.org/vocab/quantitykind/TorquePerLength")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    LorenzCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LorenzCoefficient")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    ThermalUtilizationFactorForFission = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactorForFission")
    ChargeNumber = URIRef("http://qudt.org/vocab/quantitykind/ChargeNumber")
    DebyeAngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularWavenumber")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    AmountOfSubstanceFraction = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFraction")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    AverageLogarithmicEnergyDecrement = URIRef("http://qudt.org/vocab/quantitykind/AverageLogarithmicEnergyDecrement")
    EnergyPerArea = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerArea")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    SectionAreaIntegral = URIRef("http://qudt.org/vocab/quantitykind/SectionAreaIntegral")
    ByteRate = URIRef("http://qudt.org/vocab/quantitykind/ByteRate")
    IncidenceProportion = URIRef("http://qudt.org/vocab/quantitykind/IncidenceProportion")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    ThrusterPowerToThrustEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThrusterPowerToThrustEfficiency")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    Mobility = URIRef("http://qudt.org/vocab/quantitykind/Mobility")
    GeneralizedCoordinate = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedCoordinate")
    SoundVolumeVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundVolumeVelocity")
    Reactance = URIRef("http://qudt.org/vocab/quantitykind/Reactance")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    VoltagePercentage = URIRef("http://qudt.org/vocab/quantitykind/VoltagePercentage")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    PhaseCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PhaseCoefficient")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    AuxillaryMagneticField = URIRef("http://qudt.org/vocab/quantitykind/AuxillaryMagneticField")
    LinearDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearDensity")
    Reactivity = URIRef("http://qudt.org/vocab/quantitykind/Reactivity")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    NeutronYieldPerFission = URIRef("http://qudt.org/vocab/quantitykind/NeutronYieldPerFission")
    PartialPressure = URIRef("http://qudt.org/vocab/quantitykind/PartialPressure")
    PowerConstant = URIRef("http://qudt.org/vocab/quantitykind/PowerConstant")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    NumberOfParticles = URIRef("http://qudt.org/vocab/quantitykind/NumberOfParticles")
    TorquePerAngle = URIRef("http://qudt.org/vocab/quantitykind/TorquePerAngle")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    MassConcentration = URIRef("http://qudt.org/vocab/quantitykind/MassConcentration")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    AcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/AcousticImpedance")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    GrandCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/GrandCanonicalPartitionFunction")
    ThermalDiffusionRatioCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionRatioCoefficient")
    AmountOfSubstanceFraction = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFraction")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    LogarithmicFrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyInterval")
    DryVolume = URIRef("http://qudt.org/vocab/quantitykind/DryVolume")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    QualityFactor = URIRef("http://qudt.org/vocab/quantitykind/QualityFactor")
    Reactivity = URIRef("http://qudt.org/vocab/quantitykind/Reactivity")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    DynamicFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DynamicFrictionCoefficient")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    Flux = URIRef("http://qudt.org/vocab/quantitykind/Flux")
    FishBiotransformationHalfLife = URIRef("http://qudt.org/vocab/quantitykind/FishBiotransformationHalfLife")
    LinearElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrent")
    PoissonRatio = URIRef("http://qudt.org/vocab/quantitykind/PoissonRatio")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    DigitRate = URIRef("http://qudt.org/vocab/quantitykind/DigitRate")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    Basicity = URIRef("http://qudt.org/vocab/quantitykind/Basicity")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    EarthquakeMagnitude = URIRef("http://qudt.org/vocab/quantitykind/EarthquakeMagnitude")
    Basicity = URIRef("http://qudt.org/vocab/quantitykind/Basicity")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    ThermalExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalExpansionCoefficient")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    InverseSquareTime = URIRef("http://qudt.org/vocab/quantitykind/InverseSquareTime")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    UpperCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/UpperCriticalMagneticFluxDensity")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    NonActivePower = URIRef("http://qudt.org/vocab/quantitykind/NonActivePower")
    AbsorbedDose = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDose")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    TemperatureDifference = URIRef("http://qudt.org/vocab/quantitykind/TemperatureDifference")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    ElectricalResistance = URIRef("http://qudt.org/vocab/quantitykind/ElectricalResistance")
    SpecificHeatPressure = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatPressure")
    MagneticDipoleMomentOfAMolecule = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMomentOfAMolecule")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    GasLeakRate = URIRef("http://qudt.org/vocab/quantitykind/GasLeakRate")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    InverseAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/InverseAmountOfSubstance")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    PRODUCT_OF_INERTIA_Y = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA_Y")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    EnergyExpenditure = URIRef("http://qudt.org/vocab/quantitykind/EnergyExpenditure")
    FirstStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/FirstStageMassRatio")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    PartialPressure = URIRef("http://qudt.org/vocab/quantitykind/PartialPressure")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    SpecificElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/SpecificElectricCharge")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    AreicEnergyFlow = URIRef("http://qudt.org/vocab/quantitykind/AreicEnergyFlow")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    LinearStiffness = URIRef("http://qudt.org/vocab/quantitykind/LinearStiffness")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    HeartRate = URIRef("http://qudt.org/vocab/quantitykind/HeartRate")
    StandardGravitationalParameter = URIRef("http://qudt.org/vocab/quantitykind/StandardGravitationalParameter")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    TemperatureBasedLength = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedLength")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    RelativeMassConcentrationOfVapour = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassConcentrationOfVapour")
    StressOpticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StressOpticCoefficient")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    MagneticAreaMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticAreaMoment")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    SeebeckCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SeebeckCoefficient")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    PressureLossPerLength = URIRef("http://qudt.org/vocab/quantitykind/PressureLossPerLength")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    PressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PressureCoefficient")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    NeutronDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionCoefficient")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    MagneticAreaMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticAreaMoment")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    AmountOfSubstancePerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMass")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    MassRatioOfWaterToDryMatter = URIRef("http://qudt.org/vocab/quantitykind/MassRatioOfWaterToDryMatter")
    WaterVapourPermeability = URIRef("http://qudt.org/vocab/quantitykind/WaterVapourPermeability")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    EnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensity")
    Mobility = URIRef("http://qudt.org/vocab/quantitykind/Mobility")
    TemperatureDifference = URIRef("http://qudt.org/vocab/quantitykind/TemperatureDifference")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    Reactance = URIRef("http://qudt.org/vocab/quantitykind/Reactance")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    MutualInductance = URIRef("http://qudt.org/vocab/quantitykind/MutualInductance")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    ActivityRelatedByMass = URIRef("http://qudt.org/vocab/quantitykind/ActivityRelatedByMass")
    LinearMomentum = URIRef("http://qudt.org/vocab/quantitykind/LinearMomentum")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    HeatFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/HeatFluxDensity")
    Polarizability = URIRef("http://qudt.org/vocab/quantitykind/Polarizability")
    TransmissionRatioBetweenRotationAndTranslation = URIRef("http://qudt.org/vocab/quantitykind/TransmissionRatioBetweenRotationAndTranslation")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    ElectricChargeLinearDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeLinearDensity")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    StateDensity = URIRef("http://qudt.org/vocab/quantitykind/StateDensity")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    Voltage = URIRef("http://qudt.org/vocab/quantitykind/Voltage")
    IonDensity = URIRef("http://qudt.org/vocab/quantitykind/IonDensity")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    LiftCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LiftCoefficient")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    ElectromagneticPermeabilityRatio = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeabilityRatio")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    QualityFactor = URIRef("http://qudt.org/vocab/quantitykind/QualityFactor")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    ElectricQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricQuadrupoleMoment")
    CyclotronAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/CyclotronAngularFrequency")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    DryVolume = URIRef("http://qudt.org/vocab/quantitykind/DryVolume")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    SpecificHeatPressure = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatPressure")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    Impedance = URIRef("http://qudt.org/vocab/quantitykind/Impedance")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    Luminance = URIRef("http://qudt.org/vocab/quantitykind/Luminance")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    MolarAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAttenuationCoefficient")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    LineicDataVolume = URIRef("http://qudt.org/vocab/quantitykind/LineicDataVolume")
    ElectricConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectricConductivity")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    FissionMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionMultiplicationFactor")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    FlashPoint = URIRef("http://qudt.org/vocab/quantitykind/FlashPoint")
    RelativeLuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/RelativeLuminousFlux")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    HeatFlowRatePerUnitArea = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRatePerUnitArea")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    ThermalUtilizationFactorForFission = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactorForFission")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    PressureBasedMassFlow = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedMassFlow")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    FirstStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/FirstStageMassRatio")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    LuminousEfficacy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEfficacy")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    DebyeAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularFrequency")
    LinearForce = URIRef("http://qudt.org/vocab/quantitykind/LinearForce")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    RadiantFluence = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluence")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    Solubility_Water = URIRef("http://qudt.org/vocab/quantitykind/Solubility_Water")
    SpectralRadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SpectralRadiantEnergyDensity")
    SoundExposure = URIRef("http://qudt.org/vocab/quantitykind/SoundExposure")
    ResistanceRatio = URIRef("http://qudt.org/vocab/quantitykind/ResistanceRatio")
    DiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficient")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    PowerPerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerPerArea")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    Emissivity = URIRef("http://qudt.org/vocab/quantitykind/Emissivity")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    MassicElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/MassicElectricCurrent")
    quantitykind = URIRef("http://qudt.org/vocab/quantitykind")
    ElectricQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricQuadrupoleMoment")
    MagneticSusceptability = URIRef("http://qudt.org/vocab/quantitykind/MagneticSusceptability")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    WarpingConstant = URIRef("http://qudt.org/vocab/quantitykind/WarpingConstant")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    MicroCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/MicroCanonicalPartitionFunction")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    PowerPerAreaQuarticTemperature = URIRef("http://qudt.org/vocab/quantitykind/PowerPerAreaQuarticTemperature")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    MassAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAttenuationCoefficient")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    PowerConstant = URIRef("http://qudt.org/vocab/quantitykind/PowerConstant")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    SymbolTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/SymbolTransmissionRate")
    TemperatureBasedAmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedAmountOfSubstanceConcentration")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    ThrustToWeightRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToWeightRatio")
    InverseLengthTemperature = URIRef("http://qudt.org/vocab/quantitykind/InverseLengthTemperature")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    SecondMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondMomentOfArea")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    DryVolume = URIRef("http://qudt.org/vocab/quantitykind/DryVolume")
    Permeability = URIRef("http://qudt.org/vocab/quantitykind/Permeability")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    EquilibriumConstant = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstant")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    Long_RangeOrderParameter = URIRef("http://qudt.org/vocab/quantitykind/Long-RangeOrderParameter")
    SpectralLuminousEfficiency = URIRef("http://qudt.org/vocab/quantitykind/SpectralLuminousEfficiency")
    MassConcentrationOfWaterVapour = URIRef("http://qudt.org/vocab/quantitykind/MassConcentrationOfWaterVapour")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    PRODUCT_OF_INERTIA_Z = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA_Z")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    CanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/CanonicalPartitionFunction")
    Permeability = URIRef("http://qudt.org/vocab/quantitykind/Permeability")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    Viscosity = URIRef("http://qudt.org/vocab/quantitykind/Viscosity")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    LossFactor = URIRef("http://qudt.org/vocab/quantitykind/LossFactor")
    NormalizedDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/NormalizedDimensionlessRatio")
    EvaporativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/EvaporativeHeatTransfer")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    ReflectanceFactor = URIRef("http://qudt.org/vocab/quantitykind/ReflectanceFactor")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    ResonanceEscapeProbability = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbability")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    Concentration = URIRef("http://qudt.org/vocab/quantitykind/Concentration")
    SpecificGibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificGibbsEnergy")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    VolumicOutput = URIRef("http://qudt.org/vocab/quantitykind/VolumicOutput")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    TemporalSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/TemporalSummationFunction")
    LeakageFactor = URIRef("http://qudt.org/vocab/quantitykind/LeakageFactor")
    AngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentum")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    TemporalSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/TemporalSummationFunction")
    InfiniteMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/InfiniteMultiplicationFactor")
    MagneticFluxPerUnitLength = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxPerUnitLength")
    AccelerationOfGravity = URIRef("http://qudt.org/vocab/quantitykind/AccelerationOfGravity")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    PositivePlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PositivePlaneAngle")
    SpecificOpticalRotationalAbility = URIRef("http://qudt.org/vocab/quantitykind/SpecificOpticalRotationalAbility")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    HamiltonFunction = URIRef("http://qudt.org/vocab/quantitykind/HamiltonFunction")
    FundamentalReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalReciprocalLatticeVector")
    AngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentum")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    Vorticity = URIRef("http://qudt.org/vocab/quantitykind/Vorticity")
    EquilibriumConstantOnPressureBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnPressureBasis")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    TotalAngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentum")
    IonDensity = URIRef("http://qudt.org/vocab/quantitykind/IonDensity")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    TemperatureDifference = URIRef("http://qudt.org/vocab/quantitykind/TemperatureDifference")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    ModulusOfLinearSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfLinearSubgradeReaction")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    SpecificHeatsRatio = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatsRatio")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    CombinedNonEvaporativeHeatTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CombinedNonEvaporativeHeatTransferCoefficient")
    LengthRatio = URIRef("http://qudt.org/vocab/quantitykind/LengthRatio")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    MassPerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerAreaTime")
    MicroCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/MicroCanonicalPartitionFunction")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    DataRate = URIRef("http://qudt.org/vocab/quantitykind/DataRate")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    MolarDensity = URIRef("http://qudt.org/vocab/quantitykind/MolarDensity")
    AreicTorque = URIRef("http://qudt.org/vocab/quantitykind/AreicTorque")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    HoleDensity = URIRef("http://qudt.org/vocab/quantitykind/HoleDensity")
    SpecificEntropy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEntropy")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    NuclearEnergy = URIRef("http://qudt.org/vocab/quantitykind/NuclearEnergy")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    NumberDensity = URIRef("http://qudt.org/vocab/quantitykind/NumberDensity")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    Radiance = URIRef("http://qudt.org/vocab/quantitykind/Radiance")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    TorsionalSpringConstant = URIRef("http://qudt.org/vocab/quantitykind/TorsionalSpringConstant")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    InverseMass = URIRef("http://qudt.org/vocab/quantitykind/InverseMass")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    LuminousEnergy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEnergy")
    SpecificVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificVolume")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    Permittivity = URIRef("http://qudt.org/vocab/quantitykind/Permittivity")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    CurvatureFromRadius = URIRef("http://qudt.org/vocab/quantitykind/CurvatureFromRadius")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    SpecificPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificPower")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    WarpingMoment = URIRef("http://qudt.org/vocab/quantitykind/WarpingMoment")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    GruneisenParameter = URIRef("http://qudt.org/vocab/quantitykind/GruneisenParameter")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    RadioactiveDecay = URIRef("http://qudt.org/vocab/quantitykind/RadioactiveDecay")
    ModulusOfSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfSubgradeReaction")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    Luminance = URIRef("http://qudt.org/vocab/quantitykind/Luminance")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    ForcePerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ForcePerElectricCharge")
    BodyMassIndex = URIRef("http://qudt.org/vocab/quantitykind/BodyMassIndex")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    BandwidthLengthProduct = URIRef("http://qudt.org/vocab/quantitykind/BandwidthLengthProduct")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    LevelWidth = URIRef("http://qudt.org/vocab/quantitykind/LevelWidth")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    Admittance = URIRef("http://qudt.org/vocab/quantitykind/Admittance")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    VolumeDensityOfCharge = URIRef("http://qudt.org/vocab/quantitykind/VolumeDensityOfCharge")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    ThermalDiffusionRatioCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionRatioCoefficient")
    ElectricChargeLinearDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeLinearDensity")
    OrbitalAngularMomentumPerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/OrbitalAngularMomentumPerUnitMass")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    VolumetricFlux = URIRef("http://qudt.org/vocab/quantitykind/VolumetricFlux")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    LowerCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/LowerCriticalMagneticFluxDensity")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    FirstStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/FirstStageMassRatio")
    Exposure = URIRef("http://qudt.org/vocab/quantitykind/Exposure")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    PermittivityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermittivityRatio")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    EnergyFluence = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluence")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    TemperatureBasedVolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedVolumeFlowRate")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    LengthTemperatureTime = URIRef("http://qudt.org/vocab/quantitykind/LengthTemperatureTime")
    LinearElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrent")
    ThrustToWeightRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToWeightRatio")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    CorrelatedColorTemperature = URIRef("http://qudt.org/vocab/quantitykind/CorrelatedColorTemperature")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    InverseMagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/InverseMagneticFlux")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    EnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensity")
    ElectricField = URIRef("http://qudt.org/vocab/quantitykind/ElectricField")
    RotationalStiffness = URIRef("http://qudt.org/vocab/quantitykind/RotationalStiffness")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    VisionThresholds = URIRef("http://qudt.org/vocab/quantitykind/VisionThresholds")
    MolarRefractivity = URIRef("http://qudt.org/vocab/quantitykind/MolarRefractivity")
    VolumetricFlux = URIRef("http://qudt.org/vocab/quantitykind/VolumetricFlux")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    ExhaustGasMeanMolecularWeight = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasMeanMolecularWeight")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    Vorticity = URIRef("http://qudt.org/vocab/quantitykind/Vorticity")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    QuantityOfLight = URIRef("http://qudt.org/vocab/quantitykind/QuantityOfLight")
    ReciprocalPlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalPlaneAngle")
    ScalarMagneticPotential = URIRef("http://qudt.org/vocab/quantitykind/ScalarMagneticPotential")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    GeneralizedCoordinate = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedCoordinate")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    AreicDataVolume = URIRef("http://qudt.org/vocab/quantitykind/AreicDataVolume")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    BandwidthDistanceProduct = URIRef("http://qudt.org/vocab/quantitykind/BandwidthDistanceProduct")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    Permeance = URIRef("http://qudt.org/vocab/quantitykind/Permeance")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    MassRatio = URIRef("http://qudt.org/vocab/quantitykind/MassRatio")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    LinearIonization = URIRef("http://qudt.org/vocab/quantitykind/LinearIonization")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    AverageHeadEndPressure = URIRef("http://qudt.org/vocab/quantitykind/AverageHeadEndPressure")
    EnergyPerArea = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerArea")
    LineicResolution = URIRef("http://qudt.org/vocab/quantitykind/LineicResolution")
    NumberDensity = URIRef("http://qudt.org/vocab/quantitykind/NumberDensity")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    PhaseSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/PhaseSpeedOfSound")
    SpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/SpinQuantumNumber")
    EnergyFluence = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluence")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    TotalMassStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalMassStoppingPower")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    ParticleFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluenceRate")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    HoleDensity = URIRef("http://qudt.org/vocab/quantitykind/HoleDensity")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    ConvectiveHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/ConvectiveHeatTransfer")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    GFactorOfNucleus = URIRef("http://qudt.org/vocab/quantitykind/GFactorOfNucleus")
    RateOfChangeOfTemperature = URIRef("http://qudt.org/vocab/quantitykind/RateOfChangeOfTemperature")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    CostPerUnitPower = URIRef("http://qudt.org/vocab/quantitykind/CostPerUnitPower")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    AreaTemperature = URIRef("http://qudt.org/vocab/quantitykind/AreaTemperature")
    GruneisenParameter = URIRef("http://qudt.org/vocab/quantitykind/GruneisenParameter")
    PayloadRatio = URIRef("http://qudt.org/vocab/quantitykind/PayloadRatio")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    DegreeOfDissociation = URIRef("http://qudt.org/vocab/quantitykind/DegreeOfDissociation")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    PressureLossPerLength = URIRef("http://qudt.org/vocab/quantitykind/PressureLossPerLength")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    Mobility = URIRef("http://qudt.org/vocab/quantitykind/Mobility")
    HyperfineStructureQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/HyperfineStructureQuantumNumber")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    NeutronYieldPerFission = URIRef("http://qudt.org/vocab/quantitykind/NeutronYieldPerFission")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    LinearStrain = URIRef("http://qudt.org/vocab/quantitykind/LinearStrain")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    MolecularConcentration = URIRef("http://qudt.org/vocab/quantitykind/MolecularConcentration")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    SpecificGibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificGibbsEnergy")
    TemperatureDifference = URIRef("http://qudt.org/vocab/quantitykind/TemperatureDifference")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    ForcePerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/ForcePerAreaTime")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    Susceptance = URIRef("http://qudt.org/vocab/quantitykind/Susceptance")
    MOMENT_OF_INERTIA_Z = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Z")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    ThrusterPowerToThrustEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThrusterPowerToThrustEfficiency")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    GrandCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/GrandCanonicalPartitionFunction")
    ElectricChargePerArea = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerArea")
    Permittivity = URIRef("http://qudt.org/vocab/quantitykind/Permittivity")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    MassAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAbsorptionCoefficient")
    VolumicDataQuantity = URIRef("http://qudt.org/vocab/quantitykind/VolumicDataQuantity")
    BitDataVolume = URIRef("http://qudt.org/vocab/quantitykind/BitDataVolume")
    AreaTimeTemperature = URIRef("http://qudt.org/vocab/quantitykind/AreaTimeTemperature")
    LinearAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAttenuationCoefficient")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    MagneticQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/MagneticQuantumNumber")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    DonorDensity = URIRef("http://qudt.org/vocab/quantitykind/DonorDensity")
    FissionFuelUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionFuelUtilizationFactor")
    AreaPerLength = URIRef("http://qudt.org/vocab/quantitykind/AreaPerLength")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    EnergyPerTemperature = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerTemperature")
    Unbalance = URIRef("http://qudt.org/vocab/quantitykind/Unbalance")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    StoichiometricNumber = URIRef("http://qudt.org/vocab/quantitykind/StoichiometricNumber")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    SpecificSurfaceArea = URIRef("http://qudt.org/vocab/quantitykind/SpecificSurfaceArea")
    ElectricChargePerMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerMass")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    QuantityOfLight = URIRef("http://qudt.org/vocab/quantitykind/QuantityOfLight")
    SpecificOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificOpticalRotatoryPower")
    ThermodynamicCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicCriticalMagneticFluxDensity")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    BatteryCapacity = URIRef("http://qudt.org/vocab/quantitykind/BatteryCapacity")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    IsothermalMoistureCapacity = URIRef("http://qudt.org/vocab/quantitykind/IsothermalMoistureCapacity")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    ElectricChargeVolumeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeVolumeDensity")
    PressureBasedAmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedAmountOfSubstanceConcentration")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    MagneticPolarization = URIRef("http://qudt.org/vocab/quantitykind/MagneticPolarization")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    PressureLossPerLength = URIRef("http://qudt.org/vocab/quantitykind/PressureLossPerLength")
    Short_RangeOrderParameter = URIRef("http://qudt.org/vocab/quantitykind/Short-RangeOrderParameter")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    PhaseCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PhaseCoefficient")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    PressureBasedElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedElectricCurrent")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    ThermalUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactor")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    SpecificActivity = URIRef("http://qudt.org/vocab/quantitykind/SpecificActivity")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    ParticleSourceDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleSourceDensity")
    VolumetricBitDensity = URIRef("http://qudt.org/vocab/quantitykind/VolumetricBitDensity")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    HyperfineStructureQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/HyperfineStructureQuantumNumber")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    SpecificImpulse = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulse")
    CharacteristicVelocity = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicVelocity")
    QualityFactor = URIRef("http://qudt.org/vocab/quantitykind/QualityFactor")
    AverageSpecificImpulse = URIRef("http://qudt.org/vocab/quantitykind/AverageSpecificImpulse")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    ReciprocalVoltage = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalVoltage")
    RelativeHumidity = URIRef("http://qudt.org/vocab/quantitykind/RelativeHumidity")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    PressureInRelationToVolumeFlow = URIRef("http://qudt.org/vocab/quantitykind/PressureInRelationToVolumeFlow")
    EinsteinCoefficients = URIRef("http://qudt.org/vocab/quantitykind/EinsteinCoefficients")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    LinearElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrent")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    Unbalance = URIRef("http://qudt.org/vocab/quantitykind/Unbalance")
    PhaseSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/PhaseSpeedOfSound")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    SpecificInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificInternalEnergy")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    ModulusOfSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfSubgradeReaction")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    DensityOfStates = URIRef("http://qudt.org/vocab/quantitykind/DensityOfStates")
    LarmorAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/LarmorAngularFrequency")
    MassicActivity = URIRef("http://qudt.org/vocab/quantitykind/MassicActivity")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    LengthTemperatureTime = URIRef("http://qudt.org/vocab/quantitykind/LengthTemperatureTime")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    AreaMass = URIRef("http://qudt.org/vocab/quantitykind/AreaMass")
    MolecularViscosity = URIRef("http://qudt.org/vocab/quantitykind/MolecularViscosity")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    TemperatureAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/TemperatureAmountOfSubstance")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    VolumicElectromagneticEnergy = URIRef("http://qudt.org/vocab/quantitykind/VolumicElectromagneticEnergy")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    MassPerEnergy = URIRef("http://qudt.org/vocab/quantitykind/MassPerEnergy")
    TotalAngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentum")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    MagneticAreaMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticAreaMoment")
    ExposureRateOfIonizingRadiation = URIRef("http://qudt.org/vocab/quantitykind/ExposureRateOfIonizingRadiation")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    SpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/SpinQuantumNumber")
    RelativeMassDensity = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDensity")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    AngleOfOpticalRotation = URIRef("http://qudt.org/vocab/quantitykind/AngleOfOpticalRotation")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    Concentration = URIRef("http://qudt.org/vocab/quantitykind/Concentration")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    SpecificHeatCapacityAtSaturation = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtSaturation")
    ResidualResistivity = URIRef("http://qudt.org/vocab/quantitykind/ResidualResistivity")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    ElectromagneticWavePhaseSpeed = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticWavePhaseSpeed")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    OrderOfReflection = URIRef("http://qudt.org/vocab/quantitykind/OrderOfReflection")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    DataTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/DataTransmissionRate")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    CanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/CanonicalPartitionFunction")
    AmountOfSubstancePerUnitVolume = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitVolume")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    ActivityCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ActivityCoefficient")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    GustatoryThreshold = URIRef("http://qudt.org/vocab/quantitykind/GustatoryThreshold")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    Dimensionless = URIRef("http://qudt.org/vocab/quantitykind/Dimensionless")
    MolarInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarInternalEnergy")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    ExhaustGasesSpecificHeat = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasesSpecificHeat")
    BevelGearPitchAngle = URIRef("http://qudt.org/vocab/quantitykind/BevelGearPitchAngle")
    ExpansionRatio = URIRef("http://qudt.org/vocab/quantitykind/ExpansionRatio")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    LandeGFactor = URIRef("http://qudt.org/vocab/quantitykind/LandeGFactor")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    Energy_Squared = URIRef("http://qudt.org/vocab/quantitykind/Energy_Squared")
    EquilibriumConstantOnPressureBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnPressureBasis")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    SpecificOpticalRotationalAbility = URIRef("http://qudt.org/vocab/quantitykind/SpecificOpticalRotationalAbility")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    HoleDensity = URIRef("http://qudt.org/vocab/quantitykind/HoleDensity")
    ExposureRate = URIRef("http://qudt.org/vocab/quantitykind/ExposureRate")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    NeutralRatio = URIRef("http://qudt.org/vocab/quantitykind/NeutralRatio")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    AmountOfSubstanceFraction = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFraction")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    PropellantMeanBulkTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantMeanBulkTemperature")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    SpecificModulus = URIRef("http://qudt.org/vocab/quantitykind/SpecificModulus")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    SpecificHeatCapacityAtConstantVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantVolume")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    NormalizedDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/NormalizedDimensionlessRatio")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    AttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AttenuationCoefficient")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    MassConcentration = URIRef("http://qudt.org/vocab/quantitykind/MassConcentration")
    InformationContentExpressedAsALogarithmToBase2 = URIRef("http://qudt.org/vocab/quantitykind/InformationContentExpressedAsALogarithmToBase2")
    SoundPowerLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPowerLevel")
    BloodGlucoseLevel_Mass = URIRef("http://qudt.org/vocab/quantitykind/BloodGlucoseLevel_Mass")
    ParticleCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrentDensity")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    LuminousIntensityDistribution = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensityDistribution")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    LorenzCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LorenzCoefficient")
    AmountOfSubstanceFractionOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFractionOfB")
    TimeRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRatio")
    Acidity = URIRef("http://qudt.org/vocab/quantitykind/Acidity")
    TorsionalSpringConstant = URIRef("http://qudt.org/vocab/quantitykind/TorsionalSpringConstant")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    LinkedFlux = URIRef("http://qudt.org/vocab/quantitykind/LinkedFlux")
    PoyntingVector = URIRef("http://qudt.org/vocab/quantitykind/PoyntingVector")
    Solubility_Water = URIRef("http://qudt.org/vocab/quantitykind/Solubility_Water")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    MolarOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/MolarOpticalRotatoryPower")
    StructureFactor = URIRef("http://qudt.org/vocab/quantitykind/StructureFactor")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    ModulusOfSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfSubgradeReaction")
    MagneticDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMoment")
    OrbitalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/OrbitalAngularMomentumQuantumNumber")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    LowerCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/LowerCriticalMagneticFluxDensity")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    GrandCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/GrandCanonicalPartitionFunction")
    RotationalStiffness = URIRef("http://qudt.org/vocab/quantitykind/RotationalStiffness")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    LineicQuantity = URIRef("http://qudt.org/vocab/quantitykind/LineicQuantity")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    PrincipalQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/PrincipalQuantumNumber")
    WaterVapourPermeability = URIRef("http://qudt.org/vocab/quantitykind/WaterVapourPermeability")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    ActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/ActivityConcentration")
    ElectromagneticEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticEnergyDensity")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    AmountOfSubstancePerUnitVolume = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitVolume")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    AngleOfAttack = URIRef("http://qudt.org/vocab/quantitykind/AngleOfAttack")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    ThermalTransmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalTransmittance")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    CostPerUnitPower = URIRef("http://qudt.org/vocab/quantitykind/CostPerUnitPower")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    Impulse = URIRef("http://qudt.org/vocab/quantitykind/Impulse")
    MassFractionOfWater = URIRef("http://qudt.org/vocab/quantitykind/MassFractionOfWater")
    IonConcentration = URIRef("http://qudt.org/vocab/quantitykind/IonConcentration")
    SoundPowerLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPowerLevel")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    LuminousEnergy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEnergy")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    RotationalMass = URIRef("http://qudt.org/vocab/quantitykind/RotationalMass")
    SectionModulus = URIRef("http://qudt.org/vocab/quantitykind/SectionModulus")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    EnergyPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerElectricCharge")
    ChemicalAffinity = URIRef("http://qudt.org/vocab/quantitykind/ChemicalAffinity")
    AverageLogarithmicEnergyDecrement = URIRef("http://qudt.org/vocab/quantitykind/AverageLogarithmicEnergyDecrement")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    PressureBasedLength = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedLength")
    Energy_Squared = URIRef("http://qudt.org/vocab/quantitykind/Energy_Squared")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    IntinsicCarrierDensity = URIRef("http://qudt.org/vocab/quantitykind/IntinsicCarrierDensity")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    Half_Life = URIRef("http://qudt.org/vocab/quantitykind/Half-Life")
    SeebeckCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SeebeckCoefficient")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    PressureBasedVelocity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedVelocity")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    DoseEquivalentQualityFactor = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalentQualityFactor")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    SpecificHeatsRatio = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatsRatio")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    AccelerationOfGravity = URIRef("http://qudt.org/vocab/quantitykind/AccelerationOfGravity")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    Luminance = URIRef("http://qudt.org/vocab/quantitykind/Luminance")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    ThermalUtilizationFactorForFission = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactorForFission")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    LogarithmicFrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyInterval")
    AngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentum")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    SecondAxialMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondAxialMomentOfArea")
    SoundEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SoundEnergyDensity")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    Resistivity = URIRef("http://qudt.org/vocab/quantitykind/Resistivity")
    LengthPercentage = URIRef("http://qudt.org/vocab/quantitykind/LengthPercentage")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    TemperatureRateOfChange = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRateOfChange")
    AbsorbedDoseRate = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDoseRate")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    VoltageRatio = URIRef("http://qudt.org/vocab/quantitykind/VoltageRatio")
    OsmoticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/OsmoticCoefficient")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    ElectricDisplacement = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacement")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    PressureRatio = URIRef("http://qudt.org/vocab/quantitykind/PressureRatio")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    PressureBasedDensity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedDensity")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    DensityOfStates = URIRef("http://qudt.org/vocab/quantitykind/DensityOfStates")
    quantitykind = URIRef("http://qudt.org/vocab/quantitykind")
    ElectrolyticConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectrolyticConductivity")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    RankineTemperature = URIRef("http://qudt.org/vocab/quantitykind/RankineTemperature")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    IncidenceProportion = URIRef("http://qudt.org/vocab/quantitykind/IncidenceProportion")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    SingleStageLauncherMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SingleStageLauncherMassRatio")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    ElectronMobility = URIRef("http://qudt.org/vocab/quantitykind/ElectronMobility")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    TotalAtomicStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalAtomicStoppingPower")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    InverseTemperature = URIRef("http://qudt.org/vocab/quantitykind/InverseTemperature")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    Asset = URIRef("http://qudt.org/vocab/quantitykind/Asset")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    MaximumOperatingPressure = URIRef("http://qudt.org/vocab/quantitykind/MaximumOperatingPressure")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    Impulse = URIRef("http://qudt.org/vocab/quantitykind/Impulse")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    Capacitance = URIRef("http://qudt.org/vocab/quantitykind/Capacitance")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    ThrustCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThrustCoefficient")
    OlfactoryThreshold = URIRef("http://qudt.org/vocab/quantitykind/OlfactoryThreshold")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    ActivityCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ActivityCoefficient")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    MagneticDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMoment")
    DecayConstant = URIRef("http://qudt.org/vocab/quantitykind/DecayConstant")
    Reluctance = URIRef("http://qudt.org/vocab/quantitykind/Reluctance")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    DoseEquivalent = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalent")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    CubicElectricDipoleMomentPerSquareEnergy = URIRef("http://qudt.org/vocab/quantitykind/CubicElectricDipoleMomentPerSquareEnergy")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    TimeRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRatio")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    AmountOfSubstanceConcentrationOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentrationOfB")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    FahrenheitTemperature = URIRef("http://qudt.org/vocab/quantitykind/FahrenheitTemperature")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    BodyMassIndex = URIRef("http://qudt.org/vocab/quantitykind/BodyMassIndex")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    ThrustToWeightRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToWeightRatio")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    NumberDensity = URIRef("http://qudt.org/vocab/quantitykind/NumberDensity")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    PressureBasedDynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedDynamicViscosity")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    PH = URIRef("http://qudt.org/vocab/quantitykind/PH")
    NuclearSpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/NuclearSpinQuantumNumber")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    MOMENT_OF_INERTIA_Y = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Y")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    SignalDetectionThreshold = URIRef("http://qudt.org/vocab/quantitykind/SignalDetectionThreshold")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    TemporalSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/TemporalSummationFunction")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    ThomsonCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThomsonCoefficient")
    ExchangeIntegral = URIRef("http://qudt.org/vocab/quantitykind/ExchangeIntegral")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    AngularDistance = URIRef("http://qudt.org/vocab/quantitykind/AngularDistance")
    ThrustToWeightRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToWeightRatio")
    ReflectanceFactor = URIRef("http://qudt.org/vocab/quantitykind/ReflectanceFactor")
    VolumicAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/VolumicAmountOfSubstance")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    BloodGlucoseLevel = URIRef("http://qudt.org/vocab/quantitykind/BloodGlucoseLevel")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    Luminance = URIRef("http://qudt.org/vocab/quantitykind/Luminance")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    EnergyFluence = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluence")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    TemperatureBasedAmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedAmountOfSubstanceConcentration")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    RecombinationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/RecombinationCoefficient")
    ElectromagneticPermeabilityRatio = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeabilityRatio")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    Polarizability = URIRef("http://qudt.org/vocab/quantitykind/Polarizability")
    CostPerUnitPower = URIRef("http://qudt.org/vocab/quantitykind/CostPerUnitPower")
    RatioOfSpecificHeatCapacities = URIRef("http://qudt.org/vocab/quantitykind/RatioOfSpecificHeatCapacities")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    Angle = URIRef("http://qudt.org/vocab/quantitykind/Angle")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    LuminousEmittance = URIRef("http://qudt.org/vocab/quantitykind/LuminousEmittance")
    Debye_WallerFactor = URIRef("http://qudt.org/vocab/quantitykind/Debye-WallerFactor")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    Exposure = URIRef("http://qudt.org/vocab/quantitykind/Exposure")
    ElectricQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricQuadrupoleMoment")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    Luminance = URIRef("http://qudt.org/vocab/quantitykind/Luminance")
    ChemicalConsumptionPerMass = URIRef("http://qudt.org/vocab/quantitykind/ChemicalConsumptionPerMass")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    MassAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAttenuationCoefficient")
    LinearThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/LinearThermalExpansion")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    PressureBasedTemperature = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedTemperature")
    CharacteristicNumber = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicNumber")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    MassRatioOfWaterVapourToDryGas = URIRef("http://qudt.org/vocab/quantitykind/MassRatioOfWaterVapourToDryGas")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    SystolicBloodPressure = URIRef("http://qudt.org/vocab/quantitykind/SystolicBloodPressure")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    AngularDistance = URIRef("http://qudt.org/vocab/quantitykind/AngularDistance")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    quantitykind = URIRef("http://qudt.org/vocab/quantitykind")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    HeatFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/HeatFluxDensity")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    Reflectivity = URIRef("http://qudt.org/vocab/quantitykind/Reflectivity")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    SpecificEnthalpy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnthalpy")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    RelativePressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/RelativePressureCoefficient")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    SquareEnergy = URIRef("http://qudt.org/vocab/quantitykind/SquareEnergy")
    CanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/CanonicalPartitionFunction")
    ParticleNumberDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleNumberDensity")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    Emissivity = URIRef("http://qudt.org/vocab/quantitykind/Emissivity")
    Short_RangeOrderParameter = URIRef("http://qudt.org/vocab/quantitykind/Short-RangeOrderParameter")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    ThermalExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalExpansionCoefficient")
    RadiantIntensity = URIRef("http://qudt.org/vocab/quantitykind/RadiantIntensity")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    SignalStrength = URIRef("http://qudt.org/vocab/quantitykind/SignalStrength")
    StandardChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/StandardChemicalPotential")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    MassEnergyTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassEnergyTransferCoefficient")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    LoudnessLevel = URIRef("http://qudt.org/vocab/quantitykind/LoudnessLevel")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    PowerPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/PowerPerElectricCharge")
    DoseEquivalentQualityFactor = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalentQualityFactor")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    ExtentOfReaction = URIRef("http://qudt.org/vocab/quantitykind/ExtentOfReaction")
    ResistancePercentage = URIRef("http://qudt.org/vocab/quantitykind/ResistancePercentage")
    Reactance = URIRef("http://qudt.org/vocab/quantitykind/Reactance")
    Resistivity = URIRef("http://qudt.org/vocab/quantitykind/Resistivity")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    ExpansionRatio = URIRef("http://qudt.org/vocab/quantitykind/ExpansionRatio")
    AbsoluteTypographicMeasurement = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteTypographicMeasurement")
    LinearElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrentDensity")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    GroupSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/GroupSpeedOfSound")
    PowerPerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerPerArea")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    PositivePlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PositivePlaneAngle")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    SoundExposure = URIRef("http://qudt.org/vocab/quantitykind/SoundExposure")
    TotalMassStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalMassStoppingPower")
    EnergyContent = URIRef("http://qudt.org/vocab/quantitykind/EnergyContent")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    MolarAngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/MolarAngularMomentum")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    ElectromagneticWavePhaseSpeed = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticWavePhaseSpeed")
    TemperatureRateOfChange = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRateOfChange")
    EquilibriumConstantOnConcentrationBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnConcentrationBasis")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    StructuralEfficiency = URIRef("http://qudt.org/vocab/quantitykind/StructuralEfficiency")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    Capacity = URIRef("http://qudt.org/vocab/quantitykind/Capacity")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    Vorticity = URIRef("http://qudt.org/vocab/quantitykind/Vorticity")
    MolalityOfSolute = URIRef("http://qudt.org/vocab/quantitykind/MolalityOfSolute")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    Acidity = URIRef("http://qudt.org/vocab/quantitykind/Acidity")
    ThermalUtilizationFactorForFission = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactorForFission")
    FirstStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/FirstStageMassRatio")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    Action = URIRef("http://qudt.org/vocab/quantitykind/Action")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    ConductionSpeed = URIRef("http://qudt.org/vocab/quantitykind/ConductionSpeed")
    NeutronDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionCoefficient")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    CombinedNonEvaporativeHeatTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CombinedNonEvaporativeHeatTransferCoefficient")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    ElectricDisplacement = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacement")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    MassStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/MassStoppingPower")
    PartialPressure = URIRef("http://qudt.org/vocab/quantitykind/PartialPressure")
    SurfaceCoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/SurfaceCoefficientOfHeatTransfer")
    Reflectivity = URIRef("http://qudt.org/vocab/quantitykind/Reflectivity")
    PictureElement = URIRef("http://qudt.org/vocab/quantitykind/PictureElement")
    ByteDataVolume = URIRef("http://qudt.org/vocab/quantitykind/ByteDataVolume")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    PropellantTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantTemperature")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    ResidualResistivity = URIRef("http://qudt.org/vocab/quantitykind/ResidualResistivity")
    Adaptation = URIRef("http://qudt.org/vocab/quantitykind/Adaptation")
    Long_RangeOrderParameter = URIRef("http://qudt.org/vocab/quantitykind/Long-RangeOrderParameter")
    BloodGlucoseLevel_Mass = URIRef("http://qudt.org/vocab/quantitykind/BloodGlucoseLevel_Mass")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    Solubility_Water = URIRef("http://qudt.org/vocab/quantitykind/Solubility_Water")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    LinearPower = URIRef("http://qudt.org/vocab/quantitykind/LinearPower")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    MagneticTension = URIRef("http://qudt.org/vocab/quantitykind/MagneticTension")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    AngleOfOpticalRotation = URIRef("http://qudt.org/vocab/quantitykind/AngleOfOpticalRotation")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    SpectralLuminousEfficiency = URIRef("http://qudt.org/vocab/quantitykind/SpectralLuminousEfficiency")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    Dimensionless = URIRef("http://qudt.org/vocab/quantitykind/Dimensionless")
    ElectricConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectricConductivity")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    IsothermalMoistureCapacity = URIRef("http://qudt.org/vocab/quantitykind/IsothermalMoistureCapacity")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    MagneticQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/MagneticQuantumNumber")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    BiodegredationHalfLife = URIRef("http://qudt.org/vocab/quantitykind/BiodegredationHalfLife")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    LinearForce = URIRef("http://qudt.org/vocab/quantitykind/LinearForce")
    LinearAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAttenuationCoefficient")
    TimeTemperature = URIRef("http://qudt.org/vocab/quantitykind/TimeTemperature")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    CombinedNonEvaporativeHeatTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CombinedNonEvaporativeHeatTransferCoefficient")
    GeneralizedVelocity = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedVelocity")
    LinearStiffness = URIRef("http://qudt.org/vocab/quantitykind/LinearStiffness")
    MassNumber = URIRef("http://qudt.org/vocab/quantitykind/MassNumber")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    AmountOfSubstanceConcentrationOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentrationOfB")
    AbsorbedDose = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDose")
    ParticleCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrentDensity")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    ActivityThresholds = URIRef("http://qudt.org/vocab/quantitykind/ActivityThresholds")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    PhaseCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PhaseCoefficient")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    MassRatio = URIRef("http://qudt.org/vocab/quantitykind/MassRatio")
    LowerCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/LowerCriticalMagneticFluxDensity")
    InternalConversionFactor = URIRef("http://qudt.org/vocab/quantitykind/InternalConversionFactor")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    QuantityOfLight = URIRef("http://qudt.org/vocab/quantitykind/QuantityOfLight")
    LogOctanolAirPartitionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LogOctanolAirPartitionCoefficient")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    HeatFlowRatePerUnitArea = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRatePerUnitArea")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    GeneralizedMomentum = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedMomentum")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    Solubility_Water = URIRef("http://qudt.org/vocab/quantitykind/Solubility_Water")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    LinearAcceleration = URIRef("http://qudt.org/vocab/quantitykind/LinearAcceleration")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    ModulusOfImpedance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfImpedance")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    GrandCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/GrandCanonicalPartitionFunction")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    StrainEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/StrainEnergyDensity")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    SecondAxialMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondAxialMomentOfArea")
    Action = URIRef("http://qudt.org/vocab/quantitykind/Action")
    SymbolTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/SymbolTransmissionRate")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    MechanicalSurfaceImpedance = URIRef("http://qudt.org/vocab/quantitykind/MechanicalSurfaceImpedance")
    PhotonRadiance = URIRef("http://qudt.org/vocab/quantitykind/PhotonRadiance")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    Half_Life = URIRef("http://qudt.org/vocab/quantitykind/Half-Life")
    EnergyPerArea = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerArea")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    AmbientPressure = URIRef("http://qudt.org/vocab/quantitykind/AmbientPressure")
    MeltingPoint = URIRef("http://qudt.org/vocab/quantitykind/MeltingPoint")
    AtmosphericPressure = URIRef("http://qudt.org/vocab/quantitykind/AtmosphericPressure")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    MolarAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAttenuationCoefficient")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    ElectrolyticConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectrolyticConductivity")
    Loudness = URIRef("http://qudt.org/vocab/quantitykind/Loudness")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    LuminousExitance = URIRef("http://qudt.org/vocab/quantitykind/LuminousExitance")
    SpectralRadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SpectralRadiantEnergyDensity")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    ParticleFluence = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluence")
    PhotoThresholdOfAwarenessFunction = URIRef("http://qudt.org/vocab/quantitykind/PhotoThresholdOfAwarenessFunction")
    LinearStiffness = URIRef("http://qudt.org/vocab/quantitykind/LinearStiffness")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    TotalCurrent = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrent")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    NormalizedDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/NormalizedDimensionlessRatio")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    ExhaustGasesSpecificHeat = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasesSpecificHeat")
    EnergyPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerElectricCharge")
    DistanceTraveledDuringBurn = URIRef("http://qudt.org/vocab/quantitykind/DistanceTraveledDuringBurn")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    LinearForce = URIRef("http://qudt.org/vocab/quantitykind/LinearForce")
    Capacitance = URIRef("http://qudt.org/vocab/quantitykind/Capacitance")
    DebyeAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularFrequency")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    BoilingPoint = URIRef("http://qudt.org/vocab/quantitykind/BoilingPoint")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    SerumOrPlasmaLevel = URIRef("http://qudt.org/vocab/quantitykind/SerumOrPlasmaLevel")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    PowerPerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerPerArea")
    ExchangeIntegral = URIRef("http://qudt.org/vocab/quantitykind/ExchangeIntegral")
    ElectricCurrentPhasor = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPhasor")
    MassTemperature = URIRef("http://qudt.org/vocab/quantitykind/MassTemperature")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    AreicDataVolume = URIRef("http://qudt.org/vocab/quantitykind/AreicDataVolume")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    StandardChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/StandardChemicalPotential")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    PositiveDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/PositiveDimensionlessRatio")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    PressureBasedDensity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedDensity")
    ElectricalConductance = URIRef("http://qudt.org/vocab/quantitykind/ElectricalConductance")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    EffectiveExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/EffectiveExhaustVelocity")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    Half_Life = URIRef("http://qudt.org/vocab/quantitykind/Half-Life")
    DiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficient")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    SurfaceCoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/SurfaceCoefficientOfHeatTransfer")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    PartialPressure = URIRef("http://qudt.org/vocab/quantitykind/PartialPressure")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    PressureBurningRateConstant = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateConstant")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    HallCoefficient = URIRef("http://qudt.org/vocab/quantitykind/HallCoefficient")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    AverageHeadEndPressure = URIRef("http://qudt.org/vocab/quantitykind/AverageHeadEndPressure")
    AcceptorDensity = URIRef("http://qudt.org/vocab/quantitykind/AcceptorDensity")
    ActivityCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ActivityCoefficient")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    LarmorAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/LarmorAngularFrequency")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    Speed = URIRef("http://qudt.org/vocab/quantitykind/Speed")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    RiseOfOffStateVoltage = URIRef("http://qudt.org/vocab/quantitykind/RiseOfOffStateVoltage")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    WarpingConstant = URIRef("http://qudt.org/vocab/quantitykind/WarpingConstant")
    MOMENT_OF_INERTIA_Z = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Z")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    EinsteinTransitionProbabilityForSpontaneousOrInducedEmissionAndAbsorption = URIRef("http://qudt.org/vocab/quantitykind/EinsteinTransitionProbabilityForSpontaneousOrInducedEmissionAndAbsorption")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    DoseEquivalentRate = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalentRate")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    EffectiveMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMultiplicationFactor")
    DimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/DimensionlessRatio")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    ElectricChargePerMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerMass")
    SoundEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SoundEnergyDensity")
    RadioactiveDecay = URIRef("http://qudt.org/vocab/quantitykind/RadioactiveDecay")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    ThermalResistivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistivity")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    Reactivity = URIRef("http://qudt.org/vocab/quantitykind/Reactivity")
    SpecificHelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificHelmholtzEnergy")
    FishBiotransformationHalfLife = URIRef("http://qudt.org/vocab/quantitykind/FishBiotransformationHalfLife")
    SpecificImpulse = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulse")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    GeneralizedMomentum = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedMomentum")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    RatioOfSpecificHeatCapacities = URIRef("http://qudt.org/vocab/quantitykind/RatioOfSpecificHeatCapacities")
    PayloadRatio = URIRef("http://qudt.org/vocab/quantitykind/PayloadRatio")
    MadelungConstant = URIRef("http://qudt.org/vocab/quantitykind/MadelungConstant")
    CurrentOfTheAmountOfSubtance = URIRef("http://qudt.org/vocab/quantitykind/CurrentOfTheAmountOfSubtance")
    ElectricalResistance = URIRef("http://qudt.org/vocab/quantitykind/ElectricalResistance")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    EquivalenceDoseOutput = URIRef("http://qudt.org/vocab/quantitykind/EquivalenceDoseOutput")
    Loudness = URIRef("http://qudt.org/vocab/quantitykind/Loudness")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    SoundParticleAcceleration = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleAcceleration")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    LinearStrain = URIRef("http://qudt.org/vocab/quantitykind/LinearStrain")
    MassicActivity = URIRef("http://qudt.org/vocab/quantitykind/MassicActivity")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    LinearForce = URIRef("http://qudt.org/vocab/quantitykind/LinearForce")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    MagneticFluxDensityOrMagneticPolarization = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensityOrMagneticPolarization")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    StructureFactor = URIRef("http://qudt.org/vocab/quantitykind/StructureFactor")
    CyclotronAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/CyclotronAngularFrequency")
    AuxillaryMagneticField = URIRef("http://qudt.org/vocab/quantitykind/AuxillaryMagneticField")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    IonCurrent = URIRef("http://qudt.org/vocab/quantitykind/IonCurrent")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    ElectricQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricQuadrupoleMoment")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    AreicMass = URIRef("http://qudt.org/vocab/quantitykind/AreicMass")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    AcceptorDensity = URIRef("http://qudt.org/vocab/quantitykind/AcceptorDensity")
    LinearIonization = URIRef("http://qudt.org/vocab/quantitykind/LinearIonization")
    SpectralConcentrationOfRadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SpectralConcentrationOfRadiantEnergyDensity")
    DebyeAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularFrequency")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    PolarizationField = URIRef("http://qudt.org/vocab/quantitykind/PolarizationField")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    SoundReductionIndex = URIRef("http://qudt.org/vocab/quantitykind/SoundReductionIndex")
    ThrusterPowerToThrustEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThrusterPowerToThrustEfficiency")
    PH = URIRef("http://qudt.org/vocab/quantitykind/PH")
    SpecificWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificWeight")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    EnergyDensityOfStates = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensityOfStates")
    GyromagneticRatio = URIRef("http://qudt.org/vocab/quantitykind/GyromagneticRatio")
    GeneFamilyAbundance = URIRef("http://qudt.org/vocab/quantitykind/GeneFamilyAbundance")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    Landau_GinzburgNumber = URIRef("http://qudt.org/vocab/quantitykind/Landau-GinzburgNumber")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    ModulusOfImpedance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfImpedance")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    PhotosyntheticPhotonFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/PhotosyntheticPhotonFluxDensity")
    SectionModulus = URIRef("http://qudt.org/vocab/quantitykind/SectionModulus")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    SoundParticleAcceleration = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleAcceleration")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    ThermalDiffusionRatioCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionRatioCoefficient")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    Incidence = URIRef("http://qudt.org/vocab/quantitykind/Incidence")
    MassPerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerAreaTime")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    PermittivityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermittivityRatio")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    LengthPercentage = URIRef("http://qudt.org/vocab/quantitykind/LengthPercentage")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    MagneticReluctivity = URIRef("http://qudt.org/vocab/quantitykind/MagneticReluctivity")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    AbsorbedDose = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDose")
    LorenzCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LorenzCoefficient")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    HeatFlowRatePerUnitArea = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRatePerUnitArea")
    ResistanceRatio = URIRef("http://qudt.org/vocab/quantitykind/ResistanceRatio")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    AttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AttenuationCoefficient")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    ElectricDisplacementField = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacementField")
    LineicPower = URIRef("http://qudt.org/vocab/quantitykind/LineicPower")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    NonActivePower = URIRef("http://qudt.org/vocab/quantitykind/NonActivePower")
    ElectricChargePerArea = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerArea")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    SurgeImpedanceOfTheMedium = URIRef("http://qudt.org/vocab/quantitykind/SurgeImpedanceOfTheMedium")
    RespiratoryRate = URIRef("http://qudt.org/vocab/quantitykind/RespiratoryRate")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    NuclearQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/NuclearQuadrupoleMoment")
    Viscosity = URIRef("http://qudt.org/vocab/quantitykind/Viscosity")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    MolarEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarEnergy")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    FahrenheitTemperature = URIRef("http://qudt.org/vocab/quantitykind/FahrenheitTemperature")
    PhotonLuminance = URIRef("http://qudt.org/vocab/quantitykind/PhotonLuminance")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    EnergyPerTemperature = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerTemperature")
    AcceptorDensity = URIRef("http://qudt.org/vocab/quantitykind/AcceptorDensity")
    Resistivity = URIRef("http://qudt.org/vocab/quantitykind/Resistivity")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    SpecificHeatCapacityAtConstantVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantVolume")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    ElectricQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricQuadrupoleMoment")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    IncidenceProportion = URIRef("http://qudt.org/vocab/quantitykind/IncidenceProportion")
    NonActivePower = URIRef("http://qudt.org/vocab/quantitykind/NonActivePower")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    PlanckFunction = URIRef("http://qudt.org/vocab/quantitykind/PlanckFunction")
    ByteTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/ByteTransmissionRate")
    AreaThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/AreaThermalExpansion")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    Landau_GinzburgNumber = URIRef("http://qudt.org/vocab/quantitykind/Landau-GinzburgNumber")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    LinkedFlux = URIRef("http://qudt.org/vocab/quantitykind/LinkedFlux")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    BandwidthLengthProduct = URIRef("http://qudt.org/vocab/quantitykind/BandwidthLengthProduct")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    CostPerUnitEnergy = URIRef("http://qudt.org/vocab/quantitykind/CostPerUnitEnergy")
    TransmissionRatioBetweenRotationAndTranslation = URIRef("http://qudt.org/vocab/quantitykind/TransmissionRatioBetweenRotationAndTranslation")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    HenrysLawVolatilityConstant = URIRef("http://qudt.org/vocab/quantitykind/HenrysLawVolatilityConstant")
    LinearStiffness = URIRef("http://qudt.org/vocab/quantitykind/LinearStiffness")
    ParticleFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluenceRate")
    NormalizedDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/NormalizedDimensionlessRatio")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    ResistancePercentage = URIRef("http://qudt.org/vocab/quantitykind/ResistancePercentage")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    BevelGearPitchAngle = URIRef("http://qudt.org/vocab/quantitykind/BevelGearPitchAngle")
    Slowing_DownDensity = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownDensity")
    PRODUCT_OF_INERTIA_X = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA_X")
    LiftCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LiftCoefficient")
    TimeRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRatio")
    DonorDensity = URIRef("http://qudt.org/vocab/quantitykind/DonorDensity")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    IsentropicCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsentropicCompressibility")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    MassRatio = URIRef("http://qudt.org/vocab/quantitykind/MassRatio")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    Impedance = URIRef("http://qudt.org/vocab/quantitykind/Impedance")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    StateDensityAsExpressionOfAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/StateDensityAsExpressionOfAngularFrequency")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    FermiTemperature = URIRef("http://qudt.org/vocab/quantitykind/FermiTemperature")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    LiftCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LiftCoefficient")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    VaporPermeability = URIRef("http://qudt.org/vocab/quantitykind/VaporPermeability")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    Speed = URIRef("http://qudt.org/vocab/quantitykind/Speed")
    EnergyPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerElectricCharge")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    StressOpticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StressOpticCoefficient")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    LogarithmRatioToBaseE = URIRef("http://qudt.org/vocab/quantitykind/LogarithmRatioToBaseE")
    LowerCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/LowerCriticalMagneticFluxDensity")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    LuminousExitance = URIRef("http://qudt.org/vocab/quantitykind/LuminousExitance")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    LinearMomentum = URIRef("http://qudt.org/vocab/quantitykind/LinearMomentum")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    IonCurrent = URIRef("http://qudt.org/vocab/quantitykind/IonCurrent")
    MadelungConstant = URIRef("http://qudt.org/vocab/quantitykind/MadelungConstant")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    StaticFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StaticFrictionCoefficient")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    InverseSquareTime = URIRef("http://qudt.org/vocab/quantitykind/InverseSquareTime")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    InverseVolume = URIRef("http://qudt.org/vocab/quantitykind/InverseVolume")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    EarthquakeMagnitude = URIRef("http://qudt.org/vocab/quantitykind/EarthquakeMagnitude")
    GasLeakRate = URIRef("http://qudt.org/vocab/quantitykind/GasLeakRate")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    Fluidity = URIRef("http://qudt.org/vocab/quantitykind/Fluidity")
    ComplexFrequency_Real = URIRef("http://qudt.org/vocab/quantitykind/ComplexFrequency_Real")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    IonDensity = URIRef("http://qudt.org/vocab/quantitykind/IonDensity")
    ElectronDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectronDensity")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    NeutralRatio = URIRef("http://qudt.org/vocab/quantitykind/NeutralRatio")
    ExtentOfReaction = URIRef("http://qudt.org/vocab/quantitykind/ExtentOfReaction")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    AreaThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/AreaThermalExpansion")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    TimeRelatedLogarithmicRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRelatedLogarithmicRatio")
    MaximumExpectedOperatingPressure = URIRef("http://qudt.org/vocab/quantitykind/MaximumExpectedOperatingPressure")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    ChemicalConsumptionPerMass = URIRef("http://qudt.org/vocab/quantitykind/ChemicalConsumptionPerMass")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    NuclearQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/NuclearQuadrupoleMoment")
    LarmorAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/LarmorAngularFrequency")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    LinkedFlux = URIRef("http://qudt.org/vocab/quantitykind/LinkedFlux")
    AreaBitDensity = URIRef("http://qudt.org/vocab/quantitykind/AreaBitDensity")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    VolumicElectromagneticEnergy = URIRef("http://qudt.org/vocab/quantitykind/VolumicElectromagneticEnergy")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    CouplingFactor = URIRef("http://qudt.org/vocab/quantitykind/CouplingFactor")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    Log10Ratio = URIRef("http://qudt.org/vocab/quantitykind/Log10Ratio")
    Reluctance = URIRef("http://qudt.org/vocab/quantitykind/Reluctance")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    SpectralCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralCrossSection")
    AuditoryThresholds = URIRef("http://qudt.org/vocab/quantitykind/AuditoryThresholds")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    CatalyticActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivityConcentration")
    PoissonRatio = URIRef("http://qudt.org/vocab/quantitykind/PoissonRatio")
    AngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/AngularCrossSection")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    RotaryShock = URIRef("http://qudt.org/vocab/quantitykind/RotaryShock")
    IonicStrength = URIRef("http://qudt.org/vocab/quantitykind/IonicStrength")
    Turns = URIRef("http://qudt.org/vocab/quantitykind/Turns")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    WaterVapourPermeability = URIRef("http://qudt.org/vocab/quantitykind/WaterVapourPermeability")
    SpecificActivity = URIRef("http://qudt.org/vocab/quantitykind/SpecificActivity")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    SoundParticleVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleVelocity")
    LinkedFlux = URIRef("http://qudt.org/vocab/quantitykind/LinkedFlux")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    BindingFraction = URIRef("http://qudt.org/vocab/quantitykind/BindingFraction")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    MolarConductivity = URIRef("http://qudt.org/vocab/quantitykind/MolarConductivity")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    TemperatureRelatedMolarMass = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRelatedMolarMass")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    CombustionChamberTemperature = URIRef("http://qudt.org/vocab/quantitykind/CombustionChamberTemperature")
    MassRatio = URIRef("http://qudt.org/vocab/quantitykind/MassRatio")
    TemperatureBasedQuantity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedQuantity")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    Capacitance = URIRef("http://qudt.org/vocab/quantitykind/Capacitance")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    LinearElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrentDensity")
    Susceptance = URIRef("http://qudt.org/vocab/quantitykind/Susceptance")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    SpecificOpticalRotationalAbility = URIRef("http://qudt.org/vocab/quantitykind/SpecificOpticalRotationalAbility")
    DewPointTemperature = URIRef("http://qudt.org/vocab/quantitykind/DewPointTemperature")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    LeakageFactor = URIRef("http://qudt.org/vocab/quantitykind/LeakageFactor")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    Capacitance = URIRef("http://qudt.org/vocab/quantitykind/Capacitance")
    ThermalInsulation = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulation")
    ElectromagneticWavePhaseSpeed = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticWavePhaseSpeed")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    FrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/FrictionCoefficient")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    TemperatureBasedAmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedAmountOfSubstanceConcentration")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    VolumicAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/VolumicAmountOfSubstance")
    Exposure = URIRef("http://qudt.org/vocab/quantitykind/Exposure")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    SecondStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SecondStageMassRatio")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    AreaPerTime = URIRef("http://qudt.org/vocab/quantitykind/AreaPerTime")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    SpecificHeatsRatio = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatsRatio")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    quantitykind = URIRef("http://qudt.org/vocab/quantitykind")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    RelativePartialPressure = URIRef("http://qudt.org/vocab/quantitykind/RelativePartialPressure")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    Speed = URIRef("http://qudt.org/vocab/quantitykind/Speed")
    LogOctanolAirPartitionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LogOctanolAirPartitionCoefficient")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    HeatFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/HeatFluxDensity")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    BurstFactor = URIRef("http://qudt.org/vocab/quantitykind/BurstFactor")
    EnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensity")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    TimePercentage = URIRef("http://qudt.org/vocab/quantitykind/TimePercentage")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    Angle = URIRef("http://qudt.org/vocab/quantitykind/Angle")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    CatalyticActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivityConcentration")
    EnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensity")
    ElectronDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectronDensity")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    CoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/CoefficientOfHeatTransfer")
    Capacitance = URIRef("http://qudt.org/vocab/quantitykind/Capacitance")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    MassicElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/MassicElectricCurrent")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    RelativeMassConcentrationOfVapour = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassConcentrationOfVapour")
    AttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AttenuationCoefficient")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    MagneticFluxPerUnitLength = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxPerUnitLength")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    Unbalance = URIRef("http://qudt.org/vocab/quantitykind/Unbalance")
    SpectralCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralCrossSection")
    PowerAreaPerSolidAngle = URIRef("http://qudt.org/vocab/quantitykind/PowerAreaPerSolidAngle")
    Vorticity = URIRef("http://qudt.org/vocab/quantitykind/Vorticity")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    AmountOfSubstancePerUnitVolume = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitVolume")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    Polarizability = URIRef("http://qudt.org/vocab/quantitykind/Polarizability")
    ReflectanceFactor = URIRef("http://qudt.org/vocab/quantitykind/ReflectanceFactor")
    CorrelatedColorTemperature = URIRef("http://qudt.org/vocab/quantitykind/CorrelatedColorTemperature")
    RelativePressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/RelativePressureCoefficient")
    Repetency = URIRef("http://qudt.org/vocab/quantitykind/Repetency")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    FastFissionFactor = URIRef("http://qudt.org/vocab/quantitykind/FastFissionFactor")
    LinearElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCharge")
    AtomScatteringFactor = URIRef("http://qudt.org/vocab/quantitykind/AtomScatteringFactor")
    AuxillaryMagneticField = URIRef("http://qudt.org/vocab/quantitykind/AuxillaryMagneticField")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    TorsionalSpringConstant = URIRef("http://qudt.org/vocab/quantitykind/TorsionalSpringConstant")
    RelativeHumidity = URIRef("http://qudt.org/vocab/quantitykind/RelativeHumidity")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    LinearElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrent")
    ModulusOfImpedance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfImpedance")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    AreaPerPower = URIRef("http://qudt.org/vocab/quantitykind/AreaPerPower")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    MolarThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarThermodynamicEnergy")
    CoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/CoefficientOfHeatTransfer")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    AtomScatteringFactor = URIRef("http://qudt.org/vocab/quantitykind/AtomScatteringFactor")
    MASS_PROPERTY_UNCERTAINTY = URIRef("http://qudt.org/vocab/quantitykind/MASS-PROPERTY-UNCERTAINTY")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    ElectricChargePerMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerMass")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    SecondRadiationConstant = URIRef("http://qudt.org/vocab/quantitykind/SecondRadiationConstant")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    ThermalDiffusionRatio = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionRatio")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    EquilibriumConstantBasedOnConcentration = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantBasedOnConcentration")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    SourceVoltage = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltage")
    Absorptance = URIRef("http://qudt.org/vocab/quantitykind/Absorptance")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    CutoffCurrentRating = URIRef("http://qudt.org/vocab/quantitykind/CutoffCurrentRating")
    Voltage = URIRef("http://qudt.org/vocab/quantitykind/Voltage")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    RelativeHumidity = URIRef("http://qudt.org/vocab/quantitykind/RelativeHumidity")
    ThermalDiffusionRatio = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionRatio")
    MOMENT_OF_INERTIA_Z = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Z")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    GustatoryThreshold = URIRef("http://qudt.org/vocab/quantitykind/GustatoryThreshold")
    DebyeTemperature = URIRef("http://qudt.org/vocab/quantitykind/DebyeTemperature")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    RadianceFactor = URIRef("http://qudt.org/vocab/quantitykind/RadianceFactor")
    StaticPressure = URIRef("http://qudt.org/vocab/quantitykind/StaticPressure")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    MassAmountOfSubstanceTemperature = URIRef("http://qudt.org/vocab/quantitykind/MassAmountOfSubstanceTemperature")
    SecondPolarMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondPolarMomentOfArea")
    MomentumPerAngle = URIRef("http://qudt.org/vocab/quantitykind/MomentumPerAngle")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    Slowing_DownDensity = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownDensity")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    MassPerLength = URIRef("http://qudt.org/vocab/quantitykind/MassPerLength")
    SpecificHeatsRatio = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatsRatio")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    Incidence = URIRef("http://qudt.org/vocab/quantitykind/Incidence")
    StandardChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/StandardChemicalPotential")
    LogOctanolWaterPartitionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LogOctanolWaterPartitionCoefficient")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    PositivePlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PositivePlaneAngle")
    PhotonLuminance = URIRef("http://qudt.org/vocab/quantitykind/PhotonLuminance")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    MeanMassRange = URIRef("http://qudt.org/vocab/quantitykind/MeanMassRange")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    SurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceDensity")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    ChemicalAffinity = URIRef("http://qudt.org/vocab/quantitykind/ChemicalAffinity")
    SystolicBloodPressure = URIRef("http://qudt.org/vocab/quantitykind/SystolicBloodPressure")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    Turbidity = URIRef("http://qudt.org/vocab/quantitykind/Turbidity")
    LinearTorque = URIRef("http://qudt.org/vocab/quantitykind/LinearTorque")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    MassPerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerAreaTime")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    EquilibriumConstantOnConcentrationBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnConcentrationBasis")
    Reluctance = URIRef("http://qudt.org/vocab/quantitykind/Reluctance")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    FundamentalReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalReciprocalLatticeVector")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    LinearResistance = URIRef("http://qudt.org/vocab/quantitykind/LinearResistance")
    DiastolicBloodPressure = URIRef("http://qudt.org/vocab/quantitykind/DiastolicBloodPressure")
    Repetency = URIRef("http://qudt.org/vocab/quantitykind/Repetency")
    ChargeNumber = URIRef("http://qudt.org/vocab/quantitykind/ChargeNumber")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    StandardAbsoluteActivity = URIRef("http://qudt.org/vocab/quantitykind/StandardAbsoluteActivity")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    ReflectanceFactor = URIRef("http://qudt.org/vocab/quantitykind/ReflectanceFactor")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    ThermalTransmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalTransmittance")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    LossAngle = URIRef("http://qudt.org/vocab/quantitykind/LossAngle")
    BoilingPoint = URIRef("http://qudt.org/vocab/quantitykind/BoilingPoint")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    EffectiveExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/EffectiveExhaustVelocity")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    AreaPerPower = URIRef("http://qudt.org/vocab/quantitykind/AreaPerPower")
    ConductiveHeatTransferRate = URIRef("http://qudt.org/vocab/quantitykind/ConductiveHeatTransferRate")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    TemperatureDifference = URIRef("http://qudt.org/vocab/quantitykind/TemperatureDifference")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    LengthPercentage = URIRef("http://qudt.org/vocab/quantitykind/LengthPercentage")
    RelativePressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/RelativePressureCoefficient")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    TotalAtomicStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalAtomicStoppingPower")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    ExposureRateOfIonizingRadiation = URIRef("http://qudt.org/vocab/quantitykind/ExposureRateOfIonizingRadiation")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    BandwidthLengthProduct = URIRef("http://qudt.org/vocab/quantitykind/BandwidthLengthProduct")
    MassAmountOfSubstanceTemperature = URIRef("http://qudt.org/vocab/quantitykind/MassAmountOfSubstanceTemperature")
    ElectricFlux = URIRef("http://qudt.org/vocab/quantitykind/ElectricFlux")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    ComplexPower = URIRef("http://qudt.org/vocab/quantitykind/ComplexPower")
    PolarizationField = URIRef("http://qudt.org/vocab/quantitykind/PolarizationField")
    ColdReceptorThreshold = URIRef("http://qudt.org/vocab/quantitykind/ColdReceptorThreshold")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    RichardsonConstant = URIRef("http://qudt.org/vocab/quantitykind/RichardsonConstant")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    WarpingConstant = URIRef("http://qudt.org/vocab/quantitykind/WarpingConstant")
    OrbitalAngularMomentumPerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/OrbitalAngularMomentumPerUnitMass")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    RespiratoryRate = URIRef("http://qudt.org/vocab/quantitykind/RespiratoryRate")
    MolarHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MolarHeatCapacity")
    ReciprocalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalEnergy")
    LinkedFlux = URIRef("http://qudt.org/vocab/quantitykind/LinkedFlux")
    AreicEnergyFlow = URIRef("http://qudt.org/vocab/quantitykind/AreicEnergyFlow")
    IntinsicCarrierDensity = URIRef("http://qudt.org/vocab/quantitykind/IntinsicCarrierDensity")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    NumberDensity = URIRef("http://qudt.org/vocab/quantitykind/NumberDensity")
    IonicStrength = URIRef("http://qudt.org/vocab/quantitykind/IonicStrength")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    ResistanceRatio = URIRef("http://qudt.org/vocab/quantitykind/ResistanceRatio")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    AccelerationOfGravity = URIRef("http://qudt.org/vocab/quantitykind/AccelerationOfGravity")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    MOMENT_OF_INERTIA_Y = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Y")
    BoilingPoint = URIRef("http://qudt.org/vocab/quantitykind/BoilingPoint")
    Gradient = URIRef("http://qudt.org/vocab/quantitykind/Gradient")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    MassEnergyTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassEnergyTransferCoefficient")
    AngleOfAttack = URIRef("http://qudt.org/vocab/quantitykind/AngleOfAttack")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    MassAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAttenuationCoefficient")
    ResistanceRatio = URIRef("http://qudt.org/vocab/quantitykind/ResistanceRatio")
    MassRatioOfWaterVapourToDryGas = URIRef("http://qudt.org/vocab/quantitykind/MassRatioOfWaterVapourToDryGas")
    FissionFuelUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionFuelUtilizationFactor")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    NuclearSpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/NuclearSpinQuantumNumber")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    FlightPathAngle = URIRef("http://qudt.org/vocab/quantitykind/FlightPathAngle")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    AmountOfSubstancePerUnitVolume = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitVolume")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    ElectricFlux = URIRef("http://qudt.org/vocab/quantitykind/ElectricFlux")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    TemperatureRateOfChange = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRateOfChange")
    PressureBasedDynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedDynamicViscosity")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    InformationContentExpressedAsALogarithmToBase2 = URIRef("http://qudt.org/vocab/quantitykind/InformationContentExpressedAsALogarithmToBase2")
    EffectiveMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMultiplicationFactor")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    NumberDensity = URIRef("http://qudt.org/vocab/quantitykind/NumberDensity")
    PowerAreaPerSolidAngle = URIRef("http://qudt.org/vocab/quantitykind/PowerAreaPerSolidAngle")
    FissionFuelUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionFuelUtilizationFactor")
    MassRatioOfWaterVapourToDryGas = URIRef("http://qudt.org/vocab/quantitykind/MassRatioOfWaterVapourToDryGas")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    SpecificHeatCapacityAtConstantVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantVolume")
    NonActivePower = URIRef("http://qudt.org/vocab/quantitykind/NonActivePower")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    FUEL_BIAS = URIRef("http://qudt.org/vocab/quantitykind/FUEL-BIAS")
    PressureInRelationToVolumeFlow = URIRef("http://qudt.org/vocab/quantitykind/PressureInRelationToVolumeFlow")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    Vorticity = URIRef("http://qudt.org/vocab/quantitykind/Vorticity")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    SourceVoltage = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltage")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    MolarThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarThermodynamicEnergy")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    ChemicalAffinity = URIRef("http://qudt.org/vocab/quantitykind/ChemicalAffinity")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    PressureRatio = URIRef("http://qudt.org/vocab/quantitykind/PressureRatio")
    ElectromagneticEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticEnergyDensity")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    SecondStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SecondStageMassRatio")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    LinearStrain = URIRef("http://qudt.org/vocab/quantitykind/LinearStrain")
    Mobility = URIRef("http://qudt.org/vocab/quantitykind/Mobility")
    MassRelatedElectricalCurrent = URIRef("http://qudt.org/vocab/quantitykind/MassRelatedElectricalCurrent")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    MassPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/MassPerElectricCharge")
    AtomicEnergy = URIRef("http://qudt.org/vocab/quantitykind/AtomicEnergy")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    FlightPathAngle = URIRef("http://qudt.org/vocab/quantitykind/FlightPathAngle")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    LevelWidth = URIRef("http://qudt.org/vocab/quantitykind/LevelWidth")
    VolumetricEntityDensity = URIRef("http://qudt.org/vocab/quantitykind/VolumetricEntityDensity")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    RotationalMass = URIRef("http://qudt.org/vocab/quantitykind/RotationalMass")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    Half_Life = URIRef("http://qudt.org/vocab/quantitykind/Half-Life")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    Long_RangeOrderParameter = URIRef("http://qudt.org/vocab/quantitykind/Long-RangeOrderParameter")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    PropellantMeanBulkTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantMeanBulkTemperature")
    InversePressure = URIRef("http://qudt.org/vocab/quantitykind/InversePressure")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    LarmorAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/LarmorAngularFrequency")
    VolumicDataQuantity = URIRef("http://qudt.org/vocab/quantitykind/VolumicDataQuantity")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    EnergyContent = URIRef("http://qudt.org/vocab/quantitykind/EnergyContent")
    ThermodynamicCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicCriticalMagneticFluxDensity")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    Capacitance = URIRef("http://qudt.org/vocab/quantitykind/Capacitance")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    VoltageRatio = URIRef("http://qudt.org/vocab/quantitykind/VoltageRatio")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    TemperaturePerTime = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime")
    AmountOfSubstancePerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMass")
    LogarithmicMedianInformationFlow_SourceToBase2 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicMedianInformationFlow_SourceToBase2")
    TemperatureRatio = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRatio")
    DryVolume = URIRef("http://qudt.org/vocab/quantitykind/DryVolume")
    FrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/FrictionCoefficient")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    ElectronDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectronDensity")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    VolumetricBitDensity = URIRef("http://qudt.org/vocab/quantitykind/VolumetricBitDensity")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    PowerPerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerPerArea")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    ActivityCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ActivityCoefficient")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    PhotosyntheticPhotonFlux = URIRef("http://qudt.org/vocab/quantitykind/PhotosyntheticPhotonFlux")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    HyperfineStructureQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/HyperfineStructureQuantumNumber")
    Voltage = URIRef("http://qudt.org/vocab/quantitykind/Voltage")
    LinearVoltageCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearVoltageCoefficient")
    MassAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAttenuationCoefficient")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    TotalCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrentDensity")
    EquilibriumConstantOnConcentrationBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnConcentrationBasis")
    PressureBurningRateConstant = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateConstant")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    IsothermalMoistureCapacity = URIRef("http://qudt.org/vocab/quantitykind/IsothermalMoistureCapacity")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    Dimensionless = URIRef("http://qudt.org/vocab/quantitykind/Dimensionless")
    FissionMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionMultiplicationFactor")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    AuditoryThresholds = URIRef("http://qudt.org/vocab/quantitykind/AuditoryThresholds")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    AreaPerPower = URIRef("http://qudt.org/vocab/quantitykind/AreaPerPower")
    MolarHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MolarHeatCapacity")
    EinsteinTransitionProbability = URIRef("http://qudt.org/vocab/quantitykind/EinsteinTransitionProbability")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    LinearEnergyTransfer = URIRef("http://qudt.org/vocab/quantitykind/LinearEnergyTransfer")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    ParticleFluence = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluence")
    MassAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAbsorptionCoefficient")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    RiseOfOffStateVoltage = URIRef("http://qudt.org/vocab/quantitykind/RiseOfOffStateVoltage")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    SpectralAngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralAngularCrossSection")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    EnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensity")
    TemperatureBasedDensity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedDensity")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    MassPerEnergy = URIRef("http://qudt.org/vocab/quantitykind/MassPerEnergy")
    InformationContent = URIRef("http://qudt.org/vocab/quantitykind/InformationContent")
    ColdReceptorThreshold = URIRef("http://qudt.org/vocab/quantitykind/ColdReceptorThreshold")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    LinearMass = URIRef("http://qudt.org/vocab/quantitykind/LinearMass")
    AreicTorque = URIRef("http://qudt.org/vocab/quantitykind/AreicTorque")
    ResonanceEscapeProbabilityForFission = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbabilityForFission")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    BindingFraction = URIRef("http://qudt.org/vocab/quantitykind/BindingFraction")
    SurfaceActivityDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceActivityDensity")
    Ratio = URIRef("http://qudt.org/vocab/quantitykind/Ratio")
    DecayConstant = URIRef("http://qudt.org/vocab/quantitykind/DecayConstant")
    VolumetricHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/VolumetricHeatCapacity")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    MolecularMass = URIRef("http://qudt.org/vocab/quantitykind/MolecularMass")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    Absorptance = URIRef("http://qudt.org/vocab/quantitykind/Absorptance")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    Conductance = URIRef("http://qudt.org/vocab/quantitykind/Conductance")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    StatisticalWeight = URIRef("http://qudt.org/vocab/quantitykind/StatisticalWeight")
    TimePercentage = URIRef("http://qudt.org/vocab/quantitykind/TimePercentage")
    HoleDensity = URIRef("http://qudt.org/vocab/quantitykind/HoleDensity")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    Exposure = URIRef("http://qudt.org/vocab/quantitykind/Exposure")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    AreicChargeDensityOrElectricFluxDensityOrElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/AreicChargeDensityOrElectricFluxDensityOrElectricPolarization")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    LogarithmRatioToBaseE = URIRef("http://qudt.org/vocab/quantitykind/LogarithmRatioToBaseE")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    LinkedFlux = URIRef("http://qudt.org/vocab/quantitykind/LinkedFlux")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    FlashPoint = URIRef("http://qudt.org/vocab/quantitykind/FlashPoint")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    AreaPerLength = URIRef("http://qudt.org/vocab/quantitykind/AreaPerLength")
    TemperatureDifference = URIRef("http://qudt.org/vocab/quantitykind/TemperatureDifference")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    PhaseSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/PhaseSpeedOfSound")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    Permeance = URIRef("http://qudt.org/vocab/quantitykind/Permeance")
    SpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/SpinQuantumNumber")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    Admittance = URIRef("http://qudt.org/vocab/quantitykind/Admittance")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    StandardGravitationalParameter = URIRef("http://qudt.org/vocab/quantitykind/StandardGravitationalParameter")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    ThrustToMassRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToMassRatio")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    StatisticalWeight = URIRef("http://qudt.org/vocab/quantitykind/StatisticalWeight")
    LinearMomentum = URIRef("http://qudt.org/vocab/quantitykind/LinearMomentum")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    LinearLogarithmicRatio = URIRef("http://qudt.org/vocab/quantitykind/LinearLogarithmicRatio")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    StructureFactor = URIRef("http://qudt.org/vocab/quantitykind/StructureFactor")
    PropellantBurnRate = URIRef("http://qudt.org/vocab/quantitykind/PropellantBurnRate")
    Coercivity = URIRef("http://qudt.org/vocab/quantitykind/Coercivity")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    VolumicOutput = URIRef("http://qudt.org/vocab/quantitykind/VolumicOutput")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    SpecificHelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificHelmholtzEnergy")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    ParticleFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluenceRate")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    RadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergyDensity")
    AngularDistance = URIRef("http://qudt.org/vocab/quantitykind/AngularDistance")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    ForcePerLength = URIRef("http://qudt.org/vocab/quantitykind/ForcePerLength")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    SoundEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SoundEnergyDensity")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    MultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/MultiplicationFactor")
    ParticleFluence = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluence")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    CatalyticActivity = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivity")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    ElectricChargeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeDensity")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    EnergyPerArea = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerArea")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    Debye_WallerFactor = URIRef("http://qudt.org/vocab/quantitykind/Debye-WallerFactor")
    Debye_WallerFactor = URIRef("http://qudt.org/vocab/quantitykind/Debye-WallerFactor")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    AmountOfSubstancePerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMass")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    NumberDensity = URIRef("http://qudt.org/vocab/quantitykind/NumberDensity")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    MagnetomotiveForce = URIRef("http://qudt.org/vocab/quantitykind/MagnetomotiveForce")
    FissionMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionMultiplicationFactor")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    LogarithmicFrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyInterval")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    MicrobialFormation = URIRef("http://qudt.org/vocab/quantitykind/MicrobialFormation")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    AmountOfSubstanceConcentrationOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentrationOfB")
    MassicActivity = URIRef("http://qudt.org/vocab/quantitykind/MassicActivity")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    EnergyPerSquareMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerSquareMagneticFluxDensity")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    MorbidityRate = URIRef("http://qudt.org/vocab/quantitykind/MorbidityRate")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    SpecificElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/SpecificElectricCharge")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    GeneralizedVelocity = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedVelocity")
    DataRate = URIRef("http://qudt.org/vocab/quantitykind/DataRate")
    QuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/QuantumNumber")
    HallCoefficient = URIRef("http://qudt.org/vocab/quantitykind/HallCoefficient")
    ParticleFluence = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluence")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    StateDensity = URIRef("http://qudt.org/vocab/quantitykind/StateDensity")
    VolumeDensityOfCharge = URIRef("http://qudt.org/vocab/quantitykind/VolumeDensityOfCharge")
    StressOpticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StressOpticCoefficient")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    TemperatureRateOfChange = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRateOfChange")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    DisplacementCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrentDensity")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    Polarizability = URIRef("http://qudt.org/vocab/quantitykind/Polarizability")
    TotalIonization = URIRef("http://qudt.org/vocab/quantitykind/TotalIonization")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    SpectralLuminousEfficiency = URIRef("http://qudt.org/vocab/quantitykind/SpectralLuminousEfficiency")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    ElectricChargeVolumeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeVolumeDensity")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    AtomicNumber = URIRef("http://qudt.org/vocab/quantitykind/AtomicNumber")
    PowerPerAreaQuarticTemperature = URIRef("http://qudt.org/vocab/quantitykind/PowerPerAreaQuarticTemperature")
    ElectricChargePerMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerMass")
    LengthRatio = URIRef("http://qudt.org/vocab/quantitykind/LengthRatio")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    OrderOfReflection = URIRef("http://qudt.org/vocab/quantitykind/OrderOfReflection")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    AngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/AngularCrossSection")
    PressureBasedQuantity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedQuantity")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    Admittance = URIRef("http://qudt.org/vocab/quantitykind/Admittance")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    EnergyPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerElectricCharge")
    DonorDensity = URIRef("http://qudt.org/vocab/quantitykind/DonorDensity")
    SingleStageLauncherMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SingleStageLauncherMassRatio")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    SpecificEntropy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEntropy")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    RadianceFactor = URIRef("http://qudt.org/vocab/quantitykind/RadianceFactor")
    LinearEnergyTransfer = URIRef("http://qudt.org/vocab/quantitykind/LinearEnergyTransfer")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    HoleDensity = URIRef("http://qudt.org/vocab/quantitykind/HoleDensity")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    PressureRatio = URIRef("http://qudt.org/vocab/quantitykind/PressureRatio")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    MotorConstant = URIRef("http://qudt.org/vocab/quantitykind/MotorConstant")
    CostPerUnitEnergy = URIRef("http://qudt.org/vocab/quantitykind/CostPerUnitEnergy")
    ConvectiveHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/ConvectiveHeatTransfer")
    BatteryCapacity = URIRef("http://qudt.org/vocab/quantitykind/BatteryCapacity")
    ElectromagneticEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticEnergyDensity")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    Vorticity = URIRef("http://qudt.org/vocab/quantitykind/Vorticity")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    SystolicBloodPressure = URIRef("http://qudt.org/vocab/quantitykind/SystolicBloodPressure")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    StressOpticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StressOpticCoefficient")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    NeutronYieldPerFission = URIRef("http://qudt.org/vocab/quantitykind/NeutronYieldPerFission")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    ReciprocalElectricResistance = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalElectricResistance")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    TouchThresholds = URIRef("http://qudt.org/vocab/quantitykind/TouchThresholds")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    IonDensity = URIRef("http://qudt.org/vocab/quantitykind/IonDensity")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    MassicTorque = URIRef("http://qudt.org/vocab/quantitykind/MassicTorque")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    ReciprocalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalEnergy")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    ConductiveHeatTransferRate = URIRef("http://qudt.org/vocab/quantitykind/ConductiveHeatTransferRate")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    FishBiotransformationHalfLife = URIRef("http://qudt.org/vocab/quantitykind/FishBiotransformationHalfLife")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    MultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/MultiplicationFactor")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    SecondMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondMomentOfArea")
    SourceVoltage = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltage")
    Conductance = URIRef("http://qudt.org/vocab/quantitykind/Conductance")
    BevelGearPitchAngle = URIRef("http://qudt.org/vocab/quantitykind/BevelGearPitchAngle")
    LineicResolution = URIRef("http://qudt.org/vocab/quantitykind/LineicResolution")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    SquareEnergy = URIRef("http://qudt.org/vocab/quantitykind/SquareEnergy")
    AngleOfOpticalRotation = URIRef("http://qudt.org/vocab/quantitykind/AngleOfOpticalRotation")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    Voltage = URIRef("http://qudt.org/vocab/quantitykind/Voltage")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    ThermalResistivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistivity")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    NuclearSpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/NuclearSpinQuantumNumber")
    NormalizedDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/NormalizedDimensionlessRatio")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    TemperatureBasedMassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedMassFlowRate")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    RateOfRiseOfVoltage = URIRef("http://qudt.org/vocab/quantitykind/RateOfRiseOfVoltage")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    Incidence = URIRef("http://qudt.org/vocab/quantitykind/Incidence")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    PeltierCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PeltierCoefficient")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    ThermalUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactor")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    LogERatio = URIRef("http://qudt.org/vocab/quantitykind/LogERatio")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    SpecificSurfaceArea = URIRef("http://qudt.org/vocab/quantitykind/SpecificSurfaceArea")
    OsmoticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/OsmoticCoefficient")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    RelativeMassExcess = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassExcess")
    ThermodynamicCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicCriticalMagneticFluxDensity")
    Basicity = URIRef("http://qudt.org/vocab/quantitykind/Basicity")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    TemperatureRateOfChange = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRateOfChange")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    Solubility_Water = URIRef("http://qudt.org/vocab/quantitykind/Solubility_Water")
    MolecularMass = URIRef("http://qudt.org/vocab/quantitykind/MolecularMass")
    AreaPerLength = URIRef("http://qudt.org/vocab/quantitykind/AreaPerLength")
    AreicDataVolume = URIRef("http://qudt.org/vocab/quantitykind/AreicDataVolume")
    TemperatureBasedLength = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedLength")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    Dimensionless = URIRef("http://qudt.org/vocab/quantitykind/Dimensionless")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    RelativeMassExcess = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassExcess")
    ThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusivity")
    AngleOfOpticalRotation = URIRef("http://qudt.org/vocab/quantitykind/AngleOfOpticalRotation")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    LogarithmRatioToBaseE = URIRef("http://qudt.org/vocab/quantitykind/LogarithmRatioToBaseE")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    Mobility = URIRef("http://qudt.org/vocab/quantitykind/Mobility")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    PeltierCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PeltierCoefficient")
    RadiantIntensity = URIRef("http://qudt.org/vocab/quantitykind/RadiantIntensity")
    LuminousFluxPerArea = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxPerArea")
    RelativeMassRatioOfVapour = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassRatioOfVapour")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    SecondStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SecondStageMassRatio")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    RecombinationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/RecombinationCoefficient")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    MassicHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MassicHeatCapacity")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    Constringence = URIRef("http://qudt.org/vocab/quantitykind/Constringence")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    GyromagneticRatio = URIRef("http://qudt.org/vocab/quantitykind/GyromagneticRatio")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    DoseEquivalent = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalent")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    LinearAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAbsorptionCoefficient")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    MagneticSusceptability = URIRef("http://qudt.org/vocab/quantitykind/MagneticSusceptability")
    LengthRatio = URIRef("http://qudt.org/vocab/quantitykind/LengthRatio")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    Constringence = URIRef("http://qudt.org/vocab/quantitykind/Constringence")
    AtmosphericPressure = URIRef("http://qudt.org/vocab/quantitykind/AtmosphericPressure")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    PhotonIntensity = URIRef("http://qudt.org/vocab/quantitykind/PhotonIntensity")
    FrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/FrictionCoefficient")
    SoundEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SoundEnergyDensity")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    LiquidVolume = URIRef("http://qudt.org/vocab/quantitykind/LiquidVolume")
    LogarithmicMedianInformationFlow_SourceToBase10 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicMedianInformationFlow_SourceToBase10")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    Mobility = URIRef("http://qudt.org/vocab/quantitykind/Mobility")
    NozzleThroatPressure = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatPressure")
    Capacitance = URIRef("http://qudt.org/vocab/quantitykind/Capacitance")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    VolumeOrSectionModulus = URIRef("http://qudt.org/vocab/quantitykind/VolumeOrSectionModulus")
    TransmissionRatioBetweenRotationAndTranslation = URIRef("http://qudt.org/vocab/quantitykind/TransmissionRatioBetweenRotationAndTranslation")
    ThermalResistivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistivity")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    NormalizedDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/NormalizedDimensionlessRatio")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    Log10Ratio = URIRef("http://qudt.org/vocab/quantitykind/Log10Ratio")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    ForcePerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/ForcePerAreaTime")
    ChemicalConsumptionPerMass = URIRef("http://qudt.org/vocab/quantitykind/ChemicalConsumptionPerMass")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    PressureBasedAmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedAmountOfSubstanceConcentration")
    ThermalDiffusionRatioCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionRatioCoefficient")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    DiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficient")
    TimeRelatedLogarithmicRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRelatedLogarithmicRatio")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    PRODUCT_OF_INERTIA_X = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA_X")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    InverseVolume = URIRef("http://qudt.org/vocab/quantitykind/InverseVolume")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    TransmittanceDensity = URIRef("http://qudt.org/vocab/quantitykind/TransmittanceDensity")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    Radiosity = URIRef("http://qudt.org/vocab/quantitykind/Radiosity")
    ElectromagneticPermeability = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeability")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    MassConcentration = URIRef("http://qudt.org/vocab/quantitykind/MassConcentration")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    ModulusOfAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfAdmittance")
    AtomicEnergy = URIRef("http://qudt.org/vocab/quantitykind/AtomicEnergy")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    FUEL_BIAS = URIRef("http://qudt.org/vocab/quantitykind/FUEL-BIAS")
    AuxillaryMagneticField = URIRef("http://qudt.org/vocab/quantitykind/AuxillaryMagneticField")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    EquilibriumConstant = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstant")
    DebyeAngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularWavenumber")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    PowerPerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerPerArea")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    SuperconductionTransitionTemperature = URIRef("http://qudt.org/vocab/quantitykind/SuperconductionTransitionTemperature")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    IonCurrent = URIRef("http://qudt.org/vocab/quantitykind/IonCurrent")
    ComplexPower = URIRef("http://qudt.org/vocab/quantitykind/ComplexPower")
    SectionModulus = URIRef("http://qudt.org/vocab/quantitykind/SectionModulus")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    Resistivity = URIRef("http://qudt.org/vocab/quantitykind/Resistivity")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    SoundParticleVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleVelocity")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    NapierianAbsorbance = URIRef("http://qudt.org/vocab/quantitykind/NapierianAbsorbance")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    Circulation = URIRef("http://qudt.org/vocab/quantitykind/Circulation")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    VideoFrameRate = URIRef("http://qudt.org/vocab/quantitykind/VideoFrameRate")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    LengthMass = URIRef("http://qudt.org/vocab/quantitykind/LengthMass")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    ElectricField = URIRef("http://qudt.org/vocab/quantitykind/ElectricField")
    BandwidthDistanceProduct = URIRef("http://qudt.org/vocab/quantitykind/BandwidthDistanceProduct")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    AreaTemperature = URIRef("http://qudt.org/vocab/quantitykind/AreaTemperature")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    MolarFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MolarFlowRate")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    SpecificHeatCapacityAtConstantPressure = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantPressure")
    ExtentOfReaction = URIRef("http://qudt.org/vocab/quantitykind/ExtentOfReaction")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    DewPointTemperature = URIRef("http://qudt.org/vocab/quantitykind/DewPointTemperature")
    DebyeTemperature = URIRef("http://qudt.org/vocab/quantitykind/DebyeTemperature")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    VoltagePercentage = URIRef("http://qudt.org/vocab/quantitykind/VoltagePercentage")
    MOMENT_OF_INERTIA_Y = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Y")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    SoundPowerLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPowerLevel")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    LinearTorque = URIRef("http://qudt.org/vocab/quantitykind/LinearTorque")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    DataTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/DataTransmissionRate")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    QualityFactor = URIRef("http://qudt.org/vocab/quantitykind/QualityFactor")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    PressurePercentage = URIRef("http://qudt.org/vocab/quantitykind/PressurePercentage")
    FirstStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/FirstStageMassRatio")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    BucklingFactor = URIRef("http://qudt.org/vocab/quantitykind/BucklingFactor")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    TorquePerLength = URIRef("http://qudt.org/vocab/quantitykind/TorquePerLength")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    ElectricChargeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeDensity")
    AmountOfSubstancePerUnitVolume = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitVolume")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    PhotoThresholdOfAwarenessFunction = URIRef("http://qudt.org/vocab/quantitykind/PhotoThresholdOfAwarenessFunction")
    FundamentalReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalReciprocalLatticeVector")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    HeatFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/HeatFluxDensity")
    Turbidity = URIRef("http://qudt.org/vocab/quantitykind/Turbidity")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    ActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/ActivityConcentration")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    MolecularMass = URIRef("http://qudt.org/vocab/quantitykind/MolecularMass")
    Incidence = URIRef("http://qudt.org/vocab/quantitykind/Incidence")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    Prevalence = URIRef("http://qudt.org/vocab/quantitykind/Prevalence")
    ThermalEnergyLength = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergyLength")
    SurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceDensity")
    LogarithmicFrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyInterval")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    AmbientPressure = URIRef("http://qudt.org/vocab/quantitykind/AmbientPressure")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    HeatFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/HeatFluxDensity")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    AmountOfSubstancePerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMass")
    WarmReceptorThreshold = URIRef("http://qudt.org/vocab/quantitykind/WarmReceptorThreshold")
    InversePermittivity = URIRef("http://qudt.org/vocab/quantitykind/InversePermittivity")
    StaticFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StaticFrictionCoefficient")
    BodyMassIndex = URIRef("http://qudt.org/vocab/quantitykind/BodyMassIndex")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    MassStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/MassStoppingPower")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    ElectricCurrentPerUnitTemperature = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerUnitTemperature")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    LuminousEmittance = URIRef("http://qudt.org/vocab/quantitykind/LuminousEmittance")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    Landau_GinzburgNumber = URIRef("http://qudt.org/vocab/quantitykind/Landau-GinzburgNumber")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    AreaRatio = URIRef("http://qudt.org/vocab/quantitykind/AreaRatio")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    Radiance = URIRef("http://qudt.org/vocab/quantitykind/Radiance")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    Incidence = URIRef("http://qudt.org/vocab/quantitykind/Incidence")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    Curvature = URIRef("http://qudt.org/vocab/quantitykind/Curvature")
    PermeabilityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermeabilityRatio")
    CoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/CoefficientOfHeatTransfer")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    LinearIonization = URIRef("http://qudt.org/vocab/quantitykind/LinearIonization")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    AreicTorque = URIRef("http://qudt.org/vocab/quantitykind/AreicTorque")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    SoundEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SoundEnergyDensity")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    InformationContentExpressedAsALogarithmToBase10 = URIRef("http://qudt.org/vocab/quantitykind/InformationContentExpressedAsALogarithmToBase10")
    FastFissionFactor = URIRef("http://qudt.org/vocab/quantitykind/FastFissionFactor")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    RotationalMass = URIRef("http://qudt.org/vocab/quantitykind/RotationalMass")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    FUEL_BIAS = URIRef("http://qudt.org/vocab/quantitykind/FUEL-BIAS")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    RelativeHumidity = URIRef("http://qudt.org/vocab/quantitykind/RelativeHumidity")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    EnergyPerAreaElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerAreaElectricCharge")
    AtmosphericHydroxylationRate = URIRef("http://qudt.org/vocab/quantitykind/AtmosphericHydroxylationRate")
    InverseAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/InverseAmountOfSubstance")
    PressureBurningRateConstant = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateConstant")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    SpectralDensityOfVibrationalModes = URIRef("http://qudt.org/vocab/quantitykind/SpectralDensityOfVibrationalModes")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    FissionMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionMultiplicationFactor")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    DatasetOfBits = URIRef("http://qudt.org/vocab/quantitykind/DatasetOfBits")
    BatteryCapacity = URIRef("http://qudt.org/vocab/quantitykind/BatteryCapacity")
    RelativePartialPressure = URIRef("http://qudt.org/vocab/quantitykind/RelativePartialPressure")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    WebTimeAveragePressure = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAveragePressure")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    ResistanceBasedInductance = URIRef("http://qudt.org/vocab/quantitykind/ResistanceBasedInductance")
    Capacity = URIRef("http://qudt.org/vocab/quantitykind/Capacity")
    PressureBurningRateConstant = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateConstant")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    FissionMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionMultiplicationFactor")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    StaticFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StaticFrictionCoefficient")
    ForceConstant = URIRef("http://qudt.org/vocab/quantitykind/ForceConstant")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    GroupSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/GroupSpeedOfSound")
    StaticPressure = URIRef("http://qudt.org/vocab/quantitykind/StaticPressure")
    CurvatureFromRadius = URIRef("http://qudt.org/vocab/quantitykind/CurvatureFromRadius")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    Reluctance = URIRef("http://qudt.org/vocab/quantitykind/Reluctance")
    Acidity = URIRef("http://qudt.org/vocab/quantitykind/Acidity")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    PropellantMeanBulkTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantMeanBulkTemperature")
    MolarAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAbsorptionCoefficient")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    Exposure = URIRef("http://qudt.org/vocab/quantitykind/Exposure")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    Basicity = URIRef("http://qudt.org/vocab/quantitykind/Basicity")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    StructuralEfficiency = URIRef("http://qudt.org/vocab/quantitykind/StructuralEfficiency")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    NuclearEnergy = URIRef("http://qudt.org/vocab/quantitykind/NuclearEnergy")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    TorqueConstant = URIRef("http://qudt.org/vocab/quantitykind/TorqueConstant")
    PressureBasedElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedElectricCurrent")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    RadiantEnergyExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergyExposure")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    ElectricChargeLinearDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeLinearDensity")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    OrbitalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/OrbitalAngularMomentumQuantumNumber")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    FirstStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/FirstStageMassRatio")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    PrincipalQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/PrincipalQuantumNumber")
    ThermalUtilizationFactorForFission = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactorForFission")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    InverseVolume = URIRef("http://qudt.org/vocab/quantitykind/InverseVolume")
    AngularMomentumPerAngle = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentumPerAngle")
    BucklingFactor = URIRef("http://qudt.org/vocab/quantitykind/BucklingFactor")
    FUEL_BIAS = URIRef("http://qudt.org/vocab/quantitykind/FUEL-BIAS")
    TemperatureBasedVelocity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedVelocity")
    InverseLength = URIRef("http://qudt.org/vocab/quantitykind/InverseLength")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    ActivityThresholds = URIRef("http://qudt.org/vocab/quantitykind/ActivityThresholds")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    DebyeAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularFrequency")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    MassPerLength = URIRef("http://qudt.org/vocab/quantitykind/MassPerLength")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    TotalPressure = URIRef("http://qudt.org/vocab/quantitykind/TotalPressure")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    NuclearSpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/NuclearSpinQuantumNumber")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    LinearDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearDensity")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    ForcePerAngle = URIRef("http://qudt.org/vocab/quantitykind/ForcePerAngle")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    HeatFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/HeatFluxDensity")
    MobilityRatio = URIRef("http://qudt.org/vocab/quantitykind/MobilityRatio")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    GeneralizedVelocity = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedVelocity")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    MassRatioOfWaterToDryMatter = URIRef("http://qudt.org/vocab/quantitykind/MassRatioOfWaterToDryMatter")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    NeelTemperature = URIRef("http://qudt.org/vocab/quantitykind/NeelTemperature")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    ResistancePercentage = URIRef("http://qudt.org/vocab/quantitykind/ResistancePercentage")
    ThermodynamicCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicCriticalMagneticFluxDensity")
    SerumOrPlasmaLevel = URIRef("http://qudt.org/vocab/quantitykind/SerumOrPlasmaLevel")
    HeatFlowRatePerUnitArea = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRatePerUnitArea")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    MorbidityRate = URIRef("http://qudt.org/vocab/quantitykind/MorbidityRate")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    UpperCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/UpperCriticalMagneticFluxDensity")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    MolarConductivity = URIRef("http://qudt.org/vocab/quantitykind/MolarConductivity")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    InverseEnergy = URIRef("http://qudt.org/vocab/quantitykind/InverseEnergy")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    MagneticDipoleMomentOfAMolecule = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMomentOfAMolecule")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    ResistancePercentage = URIRef("http://qudt.org/vocab/quantitykind/ResistancePercentage")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    MicroCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/MicroCanonicalPartitionFunction")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    SpecificVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificVolume")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    OsmoticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/OsmoticCoefficient")
    Permittivity = URIRef("http://qudt.org/vocab/quantitykind/Permittivity")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    ResonanceEscapeProbabilityForFission = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbabilityForFission")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    LineicCharge = URIRef("http://qudt.org/vocab/quantitykind/LineicCharge")
    DragCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DragCoefficient")
    Viscosity = URIRef("http://qudt.org/vocab/quantitykind/Viscosity")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    PayloadRatio = URIRef("http://qudt.org/vocab/quantitykind/PayloadRatio")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    CyclotronAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/CyclotronAngularFrequency")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    SpecificWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificWeight")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    SpecificOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificOpticalRotatoryPower")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    TotalMassStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalMassStoppingPower")
    MassConcentrationOfWater = URIRef("http://qudt.org/vocab/quantitykind/MassConcentrationOfWater")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    PartialPressure = URIRef("http://qudt.org/vocab/quantitykind/PartialPressure")
    TemperatureBasedLength = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedLength")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    ReflectanceFactor = URIRef("http://qudt.org/vocab/quantitykind/ReflectanceFactor")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    EinsteinTransitionProbabilityForSpontaneousOrInducedEmissionAndAbsorption = URIRef("http://qudt.org/vocab/quantitykind/EinsteinTransitionProbabilityForSpontaneousOrInducedEmissionAndAbsorption")
    TorsionalSpringConstant = URIRef("http://qudt.org/vocab/quantitykind/TorsionalSpringConstant")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    ParticleNumberDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleNumberDensity")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    PressureBasedElectricVoltage = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedElectricVoltage")
    LinearAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAttenuationCoefficient")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    Permeance = URIRef("http://qudt.org/vocab/quantitykind/Permeance")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    TimeRelatedLogarithmicRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRelatedLogarithmicRatio")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    CatalyticActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivityConcentration")
    MassStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/MassStoppingPower")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    ThermalInsulation = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulation")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    ReynoldsNumber = URIRef("http://qudt.org/vocab/quantitykind/ReynoldsNumber")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    MassConcentrationOfWater = URIRef("http://qudt.org/vocab/quantitykind/MassConcentrationOfWater")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    Slowing_DownDensity = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownDensity")
    MolarAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAttenuationCoefficient")
    AtmosphericHydroxylationRate = URIRef("http://qudt.org/vocab/quantitykind/AtmosphericHydroxylationRate")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    PositivePlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PositivePlaneAngle")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    SpecificThrust = URIRef("http://qudt.org/vocab/quantitykind/SpecificThrust")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    LossAngle = URIRef("http://qudt.org/vocab/quantitykind/LossAngle")
    DynamicFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DynamicFrictionCoefficient")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    BindingFraction = URIRef("http://qudt.org/vocab/quantitykind/BindingFraction")
    PowerPerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerPerArea")
    SpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/SpinQuantumNumber")
    MorbidityRate = URIRef("http://qudt.org/vocab/quantitykind/MorbidityRate")
    DragCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DragCoefficient")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    PolarizationField = URIRef("http://qudt.org/vocab/quantitykind/PolarizationField")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    PoyntingVector = URIRef("http://qudt.org/vocab/quantitykind/PoyntingVector")
    PressureBurningRateIndex = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateIndex")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    RankineTemperature = URIRef("http://qudt.org/vocab/quantitykind/RankineTemperature")
    ModulusOfAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfAdmittance")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    RichardsonConstant = URIRef("http://qudt.org/vocab/quantitykind/RichardsonConstant")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    PositivePlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PositivePlaneAngle")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    SoundExposure = URIRef("http://qudt.org/vocab/quantitykind/SoundExposure")
    LoudnessLevel = URIRef("http://qudt.org/vocab/quantitykind/LoudnessLevel")
    SurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceDensity")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    DoseEquivalent = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalent")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    PropagationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PropagationCoefficient")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    NeelTemperature = URIRef("http://qudt.org/vocab/quantitykind/NeelTemperature")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    ElectricCurrentPerUnitEnergy = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerUnitEnergy")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    Dissipance = URIRef("http://qudt.org/vocab/quantitykind/Dissipance")
    AmountOfSubstanceFraction = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFraction")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    SpecificHeatCapacityAtSaturation = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtSaturation")
    SoilAdsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SoilAdsorptionCoefficient")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    IsentropicCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsentropicCompressibility")
    LogarithmicFrequencyIntervalToBase10 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyIntervalToBase10")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    AmountOfSubstancePerUnitMassPressure = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMassPressure")
    SpectralConcentrationOfVibrationalModes = URIRef("http://qudt.org/vocab/quantitykind/SpectralConcentrationOfVibrationalModes")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    CoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/CoefficientOfHeatTransfer")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    IntinsicCarrierDensity = URIRef("http://qudt.org/vocab/quantitykind/IntinsicCarrierDensity")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    Radioactivity = URIRef("http://qudt.org/vocab/quantitykind/Radioactivity")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    Radiance = URIRef("http://qudt.org/vocab/quantitykind/Radiance")
    IncidenceRate = URIRef("http://qudt.org/vocab/quantitykind/IncidenceRate")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    AtmosphericHydroxylationRate = URIRef("http://qudt.org/vocab/quantitykind/AtmosphericHydroxylationRate")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    DotsPerInch = URIRef("http://qudt.org/vocab/quantitykind/DotsPerInch")
    MagneticDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMoment")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    VoltageRatio = URIRef("http://qudt.org/vocab/quantitykind/VoltageRatio")
    GroupSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/GroupSpeedOfSound")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    ElectricChargeSurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeSurfaceDensity")
    TemperatureRelatedMolarMass = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRelatedMolarMass")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    LinearAcceleration = URIRef("http://qudt.org/vocab/quantitykind/LinearAcceleration")
    PolarizationField = URIRef("http://qudt.org/vocab/quantitykind/PolarizationField")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    MolarThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarThermodynamicEnergy")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    FlightPathAngle = URIRef("http://qudt.org/vocab/quantitykind/FlightPathAngle")
    SurfaceActivityDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceActivityDensity")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    AngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentum")
    HeatFlowRatePerUnitArea = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRatePerUnitArea")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    RF_Power = URIRef("http://qudt.org/vocab/quantitykind/RF-Power")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    IonCurrent = URIRef("http://qudt.org/vocab/quantitykind/IonCurrent")
    MorbidityRate = URIRef("http://qudt.org/vocab/quantitykind/MorbidityRate")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    ElectricCurrentPerUnitTemperature = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerUnitTemperature")
    MolecularMass = URIRef("http://qudt.org/vocab/quantitykind/MolecularMass")
    TemperatureBasedKinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedKinematicViscosity")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    PositiveDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/PositiveDimensionlessRatio")
    RelativePressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/RelativePressureCoefficient")
    EnergyPerArea = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerArea")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    Capacitance = URIRef("http://qudt.org/vocab/quantitykind/Capacitance")
    Lethargy = URIRef("http://qudt.org/vocab/quantitykind/Lethargy")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    ParticleSourceDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleSourceDensity")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    PressureBasedVolume = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedVolume")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    Time_Squared = URIRef("http://qudt.org/vocab/quantitykind/Time_Squared")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    EvaporativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/EvaporativeHeatTransfer")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    SoundPowerLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPowerLevel")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    ElectromagneticWavePhaseSpeed = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticWavePhaseSpeed")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    TrafficIntensity = URIRef("http://qudt.org/vocab/quantitykind/TrafficIntensity")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    NormalizedDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/NormalizedDimensionlessRatio")
    LinearElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrent")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    ResonanceEscapeProbabilityForFission = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbabilityForFission")
    ElectricChargeVolumeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeVolumeDensity")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    SecondStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SecondStageMassRatio")
    LineicCharge = URIRef("http://qudt.org/vocab/quantitykind/LineicCharge")
    FailureRate = URIRef("http://qudt.org/vocab/quantitykind/FailureRate")
    TorsionalSpringConstant = URIRef("http://qudt.org/vocab/quantitykind/TorsionalSpringConstant")
    IsentropicCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsentropicCompressibility")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    LiquidVolume = URIRef("http://qudt.org/vocab/quantitykind/LiquidVolume")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    AmbientPressure = URIRef("http://qudt.org/vocab/quantitykind/AmbientPressure")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    PolarMomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/PolarMomentOfInertia")
    RichardsonConstant = URIRef("http://qudt.org/vocab/quantitykind/RichardsonConstant")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    MassieuFunction = URIRef("http://qudt.org/vocab/quantitykind/MassieuFunction")
    SpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/SpinQuantumNumber")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    StrainEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/StrainEnergyDensity")
    WaterVapourPermeability = URIRef("http://qudt.org/vocab/quantitykind/WaterVapourPermeability")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    TotalAtomicStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalAtomicStoppingPower")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    ReciprocalPlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalPlaneAngle")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    MolarConductivity = URIRef("http://qudt.org/vocab/quantitykind/MolarConductivity")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    ThermalExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalExpansionCoefficient")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    WarpingMoment = URIRef("http://qudt.org/vocab/quantitykind/WarpingMoment")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    LuminousEnergy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEnergy")
    LuminousFluxPerArea = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxPerArea")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    SpecificPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificPower")
    ThermodynamicCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicCriticalMagneticFluxDensity")
    ExhaustGasesSpecificHeat = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasesSpecificHeat")
    CostPerUnitEnergy = URIRef("http://qudt.org/vocab/quantitykind/CostPerUnitEnergy")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    CoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/CoefficientOfHeatTransfer")
    ThermodynamicCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicCriticalMagneticFluxDensity")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    AttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AttenuationCoefficient")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    LengthPercentage = URIRef("http://qudt.org/vocab/quantitykind/LengthPercentage")
    VentilationRatePerFloorArea = URIRef("http://qudt.org/vocab/quantitykind/VentilationRatePerFloorArea")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    SpecificHeatCapacityAtConstantPressure = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantPressure")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    SpecificModulus = URIRef("http://qudt.org/vocab/quantitykind/SpecificModulus")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    TemperatureBasedMassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedMassFlowRate")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    Incidence = URIRef("http://qudt.org/vocab/quantitykind/Incidence")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    Repetency = URIRef("http://qudt.org/vocab/quantitykind/Repetency")
    InverseTime = URIRef("http://qudt.org/vocab/quantitykind/InverseTime")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    KermaRate = URIRef("http://qudt.org/vocab/quantitykind/KermaRate")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    LengthMass = URIRef("http://qudt.org/vocab/quantitykind/LengthMass")
    DataRate = URIRef("http://qudt.org/vocab/quantitykind/DataRate")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    Non_LeakageProbability = URIRef("http://qudt.org/vocab/quantitykind/Non-LeakageProbability")
    PolarMomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/PolarMomentOfInertia")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    CouplingFactor = URIRef("http://qudt.org/vocab/quantitykind/CouplingFactor")
    MolarAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAbsorptionCoefficient")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    SpectralAngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralAngularCrossSection")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    CombinedNonEvaporativeHeatTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CombinedNonEvaporativeHeatTransferCoefficient")
    AbsorbedDose = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDose")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    ElectricCurrentPerAngle = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerAngle")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    Curvature = URIRef("http://qudt.org/vocab/quantitykind/Curvature")
    BioconcentrationFactor = URIRef("http://qudt.org/vocab/quantitykind/BioconcentrationFactor")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    MortalityRate = URIRef("http://qudt.org/vocab/quantitykind/MortalityRate")
    InfiniteMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/InfiniteMultiplicationFactor")
    SpecificThrust = URIRef("http://qudt.org/vocab/quantitykind/SpecificThrust")
    ParticleNumberDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleNumberDensity")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    NeelTemperature = URIRef("http://qudt.org/vocab/quantitykind/NeelTemperature")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    FlightPathAngle = URIRef("http://qudt.org/vocab/quantitykind/FlightPathAngle")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    TorsionalSpringConstant = URIRef("http://qudt.org/vocab/quantitykind/TorsionalSpringConstant")
    SpecificInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificInternalEnergy")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    EnergyPerAreaElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerAreaElectricCharge")
    LogOctanolAirPartitionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LogOctanolAirPartitionCoefficient")
    RecombinationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/RecombinationCoefficient")
    ActivityThresholds = URIRef("http://qudt.org/vocab/quantitykind/ActivityThresholds")
    DragForce = URIRef("http://qudt.org/vocab/quantitykind/DragForce")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    MassFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MassFluxDensity")
    PrincipalQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/PrincipalQuantumNumber")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    LineicLogarithmicRatio = URIRef("http://qudt.org/vocab/quantitykind/LineicLogarithmicRatio")
    BucklingFactor = URIRef("http://qudt.org/vocab/quantitykind/BucklingFactor")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    MotorConstant = URIRef("http://qudt.org/vocab/quantitykind/MotorConstant")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    TemperatureRelatedVolume = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRelatedVolume")
    Basicity = URIRef("http://qudt.org/vocab/quantitykind/Basicity")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    SoundParticleVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleVelocity")
    AcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/AcousticImpedance")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    VoltagePercentage = URIRef("http://qudt.org/vocab/quantitykind/VoltagePercentage")
    KermaRate = URIRef("http://qudt.org/vocab/quantitykind/KermaRate")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    WarmReceptorThreshold = URIRef("http://qudt.org/vocab/quantitykind/WarmReceptorThreshold")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    MassPerLength = URIRef("http://qudt.org/vocab/quantitykind/MassPerLength")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    ModulusOfSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfSubgradeReaction")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    NormalizedDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/NormalizedDimensionlessRatio")
    VideoFrameRate = URIRef("http://qudt.org/vocab/quantitykind/VideoFrameRate")
    FissionMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionMultiplicationFactor")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    ThermalCapacitance = URIRef("http://qudt.org/vocab/quantitykind/ThermalCapacitance")
    NeelTemperature = URIRef("http://qudt.org/vocab/quantitykind/NeelTemperature")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    MicroCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/MicroCanonicalPartitionFunction")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    Absorptance = URIRef("http://qudt.org/vocab/quantitykind/Absorptance")
    ThermalUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactor")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    Impedance = URIRef("http://qudt.org/vocab/quantitykind/Impedance")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    EnergyPerArea = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerArea")
    ParticleSourceDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleSourceDensity")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    RelativeMassConcentrationOfVapour = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassConcentrationOfVapour")
    Turbidity = URIRef("http://qudt.org/vocab/quantitykind/Turbidity")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    MagnetizationField = URIRef("http://qudt.org/vocab/quantitykind/MagnetizationField")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    BioconcentrationFactor = URIRef("http://qudt.org/vocab/quantitykind/BioconcentrationFactor")
    MassNumber = URIRef("http://qudt.org/vocab/quantitykind/MassNumber")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    DiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficient")
    ElectricalResistance = URIRef("http://qudt.org/vocab/quantitykind/ElectricalResistance")
    AtomScatteringFactor = URIRef("http://qudt.org/vocab/quantitykind/AtomScatteringFactor")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    GeneFamilyAbundance = URIRef("http://qudt.org/vocab/quantitykind/GeneFamilyAbundance")
    SecondMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondMomentOfArea")
    SoundVolumeVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundVolumeVelocity")
    Admittance = URIRef("http://qudt.org/vocab/quantitykind/Admittance")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    AngleOfOpticalRotation = URIRef("http://qudt.org/vocab/quantitykind/AngleOfOpticalRotation")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    ReynoldsNumber = URIRef("http://qudt.org/vocab/quantitykind/ReynoldsNumber")
    CharacteristicNumber = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicNumber")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    SecondPolarMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondPolarMomentOfArea")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    MicroCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/MicroCanonicalPartitionFunction")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    RadianceFactor = URIRef("http://qudt.org/vocab/quantitykind/RadianceFactor")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    BulkModulus = URIRef("http://qudt.org/vocab/quantitykind/BulkModulus")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    ActivityCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ActivityCoefficient")
    SpecificSurfaceArea = URIRef("http://qudt.org/vocab/quantitykind/SpecificSurfaceArea")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    AtomicEnergy = URIRef("http://qudt.org/vocab/quantitykind/AtomicEnergy")
    TotalIonization = URIRef("http://qudt.org/vocab/quantitykind/TotalIonization")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    LevelWidth = URIRef("http://qudt.org/vocab/quantitykind/LevelWidth")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    TotalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentumQuantumNumber")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    Kerma = URIRef("http://qudt.org/vocab/quantitykind/Kerma")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    AreicDataVolume = URIRef("http://qudt.org/vocab/quantitykind/AreicDataVolume")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    DebyeAngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularWavenumber")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    SpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/SpinQuantumNumber")
    FrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/FrictionCoefficient")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    IonConcentration = URIRef("http://qudt.org/vocab/quantitykind/IonConcentration")
    LogOctanolWaterPartitionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LogOctanolWaterPartitionCoefficient")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    ModulusOfLinearSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfLinearSubgradeReaction")
    IonCurrent = URIRef("http://qudt.org/vocab/quantitykind/IonCurrent")
    PrincipalQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/PrincipalQuantumNumber")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    AmountOfBiologicallyActiveSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfBiologicallyActiveSubstance")
    ByteTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/ByteTransmissionRate")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    RadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergyDensity")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    RelativeHumidity = URIRef("http://qudt.org/vocab/quantitykind/RelativeHumidity")
    ElectricField = URIRef("http://qudt.org/vocab/quantitykind/ElectricField")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    FundamentalReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalReciprocalLatticeVector")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    RelativeMassConcentrationOfVapour = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassConcentrationOfVapour")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    MeanMassRange = URIRef("http://qudt.org/vocab/quantitykind/MeanMassRange")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    SpecificThrust = URIRef("http://qudt.org/vocab/quantitykind/SpecificThrust")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    VolumetricElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/VolumetricElectricCharge")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    SecondOrderReactionRateConstant = URIRef("http://qudt.org/vocab/quantitykind/SecondOrderReactionRateConstant")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    MassRatioOfWaterVapourToDryGas = URIRef("http://qudt.org/vocab/quantitykind/MassRatioOfWaterVapourToDryGas")
    DoseEquivalent = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalent")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    Luminance = URIRef("http://qudt.org/vocab/quantitykind/Luminance")
    MassPerLength = URIRef("http://qudt.org/vocab/quantitykind/MassPerLength")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    RF_Power = URIRef("http://qudt.org/vocab/quantitykind/RF-Power")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    Solubility_Water = URIRef("http://qudt.org/vocab/quantitykind/Solubility_Water")
    MASS_PROPERTY_UNCERTAINTY = URIRef("http://qudt.org/vocab/quantitykind/MASS-PROPERTY-UNCERTAINTY")
    ThermalUtilizationFactorForFission = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactorForFission")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    SoundReductionIndex = URIRef("http://qudt.org/vocab/quantitykind/SoundReductionIndex")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    Incidence = URIRef("http://qudt.org/vocab/quantitykind/Incidence")
    GFactorOfNucleus = URIRef("http://qudt.org/vocab/quantitykind/GFactorOfNucleus")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    MassPerLength = URIRef("http://qudt.org/vocab/quantitykind/MassPerLength")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    ElectricDipoleMoment_CubicPerEnergy_Squared = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment_CubicPerEnergy_Squared")
    Landau_GinzburgNumber = URIRef("http://qudt.org/vocab/quantitykind/Landau-GinzburgNumber")
    Unbalance = URIRef("http://qudt.org/vocab/quantitykind/Unbalance")
    LossAngle = URIRef("http://qudt.org/vocab/quantitykind/LossAngle")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    Absorptance = URIRef("http://qudt.org/vocab/quantitykind/Absorptance")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    PoissonRatio = URIRef("http://qudt.org/vocab/quantitykind/PoissonRatio")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    ElectricQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricQuadrupoleMoment")
    MotorConstant = URIRef("http://qudt.org/vocab/quantitykind/MotorConstant")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    SpecificElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/SpecificElectricCharge")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    ThermodynamicEntropy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEntropy")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    EnergyFluence = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluence")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    EquilibriumConstantBasedOnConcentration = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantBasedOnConcentration")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    PressurePercentage = URIRef("http://qudt.org/vocab/quantitykind/PressurePercentage")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    MolarThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarThermodynamicEnergy")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    LinearCompressibility = URIRef("http://qudt.org/vocab/quantitykind/LinearCompressibility")
    AngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/AngularCrossSection")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    ReciprocalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalEnergy")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    EnergyPerArea = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerArea")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    FahrenheitTemperature = URIRef("http://qudt.org/vocab/quantitykind/FahrenheitTemperature")
    ElectricDisplacementField = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacementField")
    MassFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MassFluxDensity")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    ParticleFluence = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluence")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    CostPerUnitEnergy = URIRef("http://qudt.org/vocab/quantitykind/CostPerUnitEnergy")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    SecondMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondMomentOfArea")
    Conductance = URIRef("http://qudt.org/vocab/quantitykind/Conductance")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    Debye_WallerFactor = URIRef("http://qudt.org/vocab/quantitykind/Debye-WallerFactor")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    KinematicViscosityOrDiffusionConstantOrThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosityOrDiffusionConstantOrThermalDiffusivity")
    ElectricalResistance = URIRef("http://qudt.org/vocab/quantitykind/ElectricalResistance")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    AreicTorque = URIRef("http://qudt.org/vocab/quantitykind/AreicTorque")
    OsmoticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/OsmoticCoefficient")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    BulkModulus = URIRef("http://qudt.org/vocab/quantitykind/BulkModulus")
    ThermalCoefficientOfLinearExpansion = URIRef("http://qudt.org/vocab/quantitykind/ThermalCoefficientOfLinearExpansion")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    MagneticPolarization = URIRef("http://qudt.org/vocab/quantitykind/MagneticPolarization")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    Gravity_API = URIRef("http://qudt.org/vocab/quantitykind/Gravity_API")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    SoundExposure = URIRef("http://qudt.org/vocab/quantitykind/SoundExposure")
    InverseVolume = URIRef("http://qudt.org/vocab/quantitykind/InverseVolume")
    PowerPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/PowerPerElectricCharge")
    IntinsicCarrierDensity = URIRef("http://qudt.org/vocab/quantitykind/IntinsicCarrierDensity")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    AuxillaryMagneticField = URIRef("http://qudt.org/vocab/quantitykind/AuxillaryMagneticField")
    Reflectivity = URIRef("http://qudt.org/vocab/quantitykind/Reflectivity")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    MagneticSusceptability = URIRef("http://qudt.org/vocab/quantitykind/MagneticSusceptability")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    Exposure = URIRef("http://qudt.org/vocab/quantitykind/Exposure")
    FUEL_BIAS = URIRef("http://qudt.org/vocab/quantitykind/FUEL-BIAS")
    Coercivity = URIRef("http://qudt.org/vocab/quantitykind/Coercivity")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    SecondAxialMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondAxialMomentOfArea")
    InformationContentExpressedAsALogarithmToBase2 = URIRef("http://qudt.org/vocab/quantitykind/InformationContentExpressedAsALogarithmToBase2")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    PressureBasedVolumeFlow = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedVolumeFlow")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    DotsPerInch = URIRef("http://qudt.org/vocab/quantitykind/DotsPerInch")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    SpectralAngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralAngularCrossSection")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    AmbientPressure = URIRef("http://qudt.org/vocab/quantitykind/AmbientPressure")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    ElectricDipoleMoment_QuarticPerEnergy_Cubic = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment_QuarticPerEnergy_Cubic")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    ElectricDisplacement = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacement")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    PowerPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/PowerPerElectricCharge")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    DoseEquivalentRate = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalentRate")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    SecondPolarMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondPolarMomentOfArea")
    TotalLinearStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalLinearStoppingPower")
    MolecularViscosity = URIRef("http://qudt.org/vocab/quantitykind/MolecularViscosity")
    Permittivity = URIRef("http://qudt.org/vocab/quantitykind/Permittivity")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    SurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceDensity")
    HeatFlowRatePerUnitArea = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRatePerUnitArea")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    TotalAngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentum")
    PressureBasedVolumeFlow = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedVolumeFlow")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    ModulusOfRotationalSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfRotationalSubgradeReaction")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    BurstFactor = URIRef("http://qudt.org/vocab/quantitykind/BurstFactor")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    PictureElement = URIRef("http://qudt.org/vocab/quantitykind/PictureElement")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    HeatFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/HeatFluxDensity")
    MolarEntropy = URIRef("http://qudt.org/vocab/quantitykind/MolarEntropy")
    TemperatureAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/TemperatureAmountOfSubstance")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    LowerCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/LowerCriticalMagneticFluxDensity")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    StrainEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/StrainEnergyDensity")
    InverseMass = URIRef("http://qudt.org/vocab/quantitykind/InverseMass")
    VaporPermeability = URIRef("http://qudt.org/vocab/quantitykind/VaporPermeability")
    TemperatureBasedAmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedAmountOfSubstanceConcentration")
    SuperconductionTransitionTemperature = URIRef("http://qudt.org/vocab/quantitykind/SuperconductionTransitionTemperature")
    AmountOfSubstanceFractionOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFractionOfB")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    ElectromagneticPermeability = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeability")
    TimeTemperature = URIRef("http://qudt.org/vocab/quantitykind/TimeTemperature")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    CurrentLinkage = URIRef("http://qudt.org/vocab/quantitykind/CurrentLinkage")
    MassPerLength = URIRef("http://qudt.org/vocab/quantitykind/MassPerLength")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    DynamicPressure = URIRef("http://qudt.org/vocab/quantitykind/DynamicPressure")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    ElectricDipoleMoment_CubicPerEnergy_Squared = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment_CubicPerEnergy_Squared")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    AtomicNumber = URIRef("http://qudt.org/vocab/quantitykind/AtomicNumber")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    Constringence = URIRef("http://qudt.org/vocab/quantitykind/Constringence")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    ExposureRate = URIRef("http://qudt.org/vocab/quantitykind/ExposureRate")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    DecayConstant = URIRef("http://qudt.org/vocab/quantitykind/DecayConstant")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    BucklingFactor = URIRef("http://qudt.org/vocab/quantitykind/BucklingFactor")
    IsentropicCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsentropicCompressibility")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    MechanicalTension = URIRef("http://qudt.org/vocab/quantitykind/MechanicalTension")
    ModulusOfRotationalSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfRotationalSubgradeReaction")
    PeltierCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PeltierCoefficient")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    LeakageFactor = URIRef("http://qudt.org/vocab/quantitykind/LeakageFactor")
    PressureBurningRateIndex = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateIndex")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    RateOfChangeOfTemperature = URIRef("http://qudt.org/vocab/quantitykind/RateOfChangeOfTemperature")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    EquilibriumConstant = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstant")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    MOMENT_OF_INERTIA_Y = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Y")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    Reactivity = URIRef("http://qudt.org/vocab/quantitykind/Reactivity")
    NeutronYieldPerFission = URIRef("http://qudt.org/vocab/quantitykind/NeutronYieldPerFission")
    PressureBurningRateIndex = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateIndex")
    AreaPerTime = URIRef("http://qudt.org/vocab/quantitykind/AreaPerTime")
    Long_RangeOrderParameter = URIRef("http://qudt.org/vocab/quantitykind/Long-RangeOrderParameter")
    DryVolume = URIRef("http://qudt.org/vocab/quantitykind/DryVolume")
    LogarithmRatioToBaseE = URIRef("http://qudt.org/vocab/quantitykind/LogarithmRatioToBaseE")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    DegreeOfDissociation = URIRef("http://qudt.org/vocab/quantitykind/DegreeOfDissociation")
    NuclearQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/NuclearQuadrupoleMoment")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    RatioOfSpecificHeatCapacities = URIRef("http://qudt.org/vocab/quantitykind/RatioOfSpecificHeatCapacities")
    LogarithmicFrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyInterval")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    InverseMass_Squared = URIRef("http://qudt.org/vocab/quantitykind/InverseMass_Squared")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    ExposureOfIonizingRadiation = URIRef("http://qudt.org/vocab/quantitykind/ExposureOfIonizingRadiation")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    SpectralDensityOfVibrationalModes = URIRef("http://qudt.org/vocab/quantitykind/SpectralDensityOfVibrationalModes")
    LeakageFactor = URIRef("http://qudt.org/vocab/quantitykind/LeakageFactor")
    SoundParticleAcceleration = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleAcceleration")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    RecombinationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/RecombinationCoefficient")
    InitialExpansionRatio = URIRef("http://qudt.org/vocab/quantitykind/InitialExpansionRatio")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    Reactance = URIRef("http://qudt.org/vocab/quantitykind/Reactance")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    ActivityCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ActivityCoefficient")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    PropellantTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantTemperature")
    CouplingFactor = URIRef("http://qudt.org/vocab/quantitykind/CouplingFactor")
    VoltagePhasor = URIRef("http://qudt.org/vocab/quantitykind/VoltagePhasor")
    ResidualResistivity = URIRef("http://qudt.org/vocab/quantitykind/ResidualResistivity")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    PressureBasedKinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedKinematicViscosity")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    BiodegredationHalfLife = URIRef("http://qudt.org/vocab/quantitykind/BiodegredationHalfLife")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    PRODUCT_OF_INERTIA_X = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA_X")
    PowerPerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerPerArea")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    SurgeImpedanceOfTheMedium = URIRef("http://qudt.org/vocab/quantitykind/SurgeImpedanceOfTheMedium")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    SunProtectionFactorOfAProduct = URIRef("http://qudt.org/vocab/quantitykind/SunProtectionFactorOfAProduct")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    DataRate = URIRef("http://qudt.org/vocab/quantitykind/DataRate")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    LiquidVolume = URIRef("http://qudt.org/vocab/quantitykind/LiquidVolume")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    LinearStiffness = URIRef("http://qudt.org/vocab/quantitykind/LinearStiffness")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    NapierianAbsorbance = URIRef("http://qudt.org/vocab/quantitykind/NapierianAbsorbance")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    DisplacementCurrent = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrent")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    Vorticity = URIRef("http://qudt.org/vocab/quantitykind/Vorticity")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    RelativePartialPressure = URIRef("http://qudt.org/vocab/quantitykind/RelativePartialPressure")
    DoseEquivalent = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalent")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    SpecificHeatsRatio = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatsRatio")
    BitTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/BitTransmissionRate")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    ThermalInsulation = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulation")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    LarmorAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/LarmorAngularFrequency")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    MagneticAreaMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticAreaMoment")
    MolecularMass = URIRef("http://qudt.org/vocab/quantitykind/MolecularMass")
    DimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/DimensionlessRatio")
    AbsorbedDoseRate = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDoseRate")
    IsentropicCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsentropicCompressibility")
    SpectralRadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SpectralRadiantEnergyDensity")
    NapierianAbsorbance = URIRef("http://qudt.org/vocab/quantitykind/NapierianAbsorbance")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    TemperaturePerTime = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime")
    SpecificHeatCapacityAtConstantPressure = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantPressure")
    ElectricFlux = URIRef("http://qudt.org/vocab/quantitykind/ElectricFlux")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    Viscosity = URIRef("http://qudt.org/vocab/quantitykind/Viscosity")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    EnergyPerAreaElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerAreaElectricCharge")
    ReciprocalVoltage = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalVoltage")
    MassAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAbsorptionCoefficient")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    WaterVapourPermeability = URIRef("http://qudt.org/vocab/quantitykind/WaterVapourPermeability")
    ResistanceBasedInductance = URIRef("http://qudt.org/vocab/quantitykind/ResistanceBasedInductance")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    IntinsicCarrierDensity = URIRef("http://qudt.org/vocab/quantitykind/IntinsicCarrierDensity")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    TotalLinearStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalLinearStoppingPower")
    AreaPerPower = URIRef("http://qudt.org/vocab/quantitykind/AreaPerPower")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    HeatFlowRatePerUnitArea = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRatePerUnitArea")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    TotalCurrent = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrent")
    MagneticReluctivity = URIRef("http://qudt.org/vocab/quantitykind/MagneticReluctivity")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    SpecificHelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificHelmholtzEnergy")
    KermaRate = URIRef("http://qudt.org/vocab/quantitykind/KermaRate")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    InverseVolume = URIRef("http://qudt.org/vocab/quantitykind/InverseVolume")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    Piece = URIRef("http://qudt.org/vocab/quantitykind/Piece")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    SpecificOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificOpticalRotatoryPower")
    MassicHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MassicHeatCapacity")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    AreaPerTime = URIRef("http://qudt.org/vocab/quantitykind/AreaPerTime")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    ThermalExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalExpansionCoefficient")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    CubicElectricDipoleMomentPerSquareEnergy = URIRef("http://qudt.org/vocab/quantitykind/CubicElectricDipoleMomentPerSquareEnergy")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    ElectricDipoleMoment_QuarticPerEnergy_Cubic = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment_QuarticPerEnergy_Cubic")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    TotalLinearStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalLinearStoppingPower")
    InfiniteMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/InfiniteMultiplicationFactor")
    LiftCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LiftCoefficient")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    InverseLength = URIRef("http://qudt.org/vocab/quantitykind/InverseLength")
    BoilingPoint = URIRef("http://qudt.org/vocab/quantitykind/BoilingPoint")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    MolarAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAttenuationCoefficient")
    Concentration = URIRef("http://qudt.org/vocab/quantitykind/Concentration")
    ActivityThresholds = URIRef("http://qudt.org/vocab/quantitykind/ActivityThresholds")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    BatteryCapacity = URIRef("http://qudt.org/vocab/quantitykind/BatteryCapacity")
    Circulation = URIRef("http://qudt.org/vocab/quantitykind/Circulation")
    SoundParticleAcceleration = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleAcceleration")
    LinearForce = URIRef("http://qudt.org/vocab/quantitykind/LinearForce")
    MagneticQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/MagneticQuantumNumber")
    IonConcentration = URIRef("http://qudt.org/vocab/quantitykind/IonConcentration")
    AuditoryThresholds = URIRef("http://qudt.org/vocab/quantitykind/AuditoryThresholds")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    StructureFactor = URIRef("http://qudt.org/vocab/quantitykind/StructureFactor")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    TotalRadiance = URIRef("http://qudt.org/vocab/quantitykind/TotalRadiance")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    IntinsicCarrierDensity = URIRef("http://qudt.org/vocab/quantitykind/IntinsicCarrierDensity")
    SymbolTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/SymbolTransmissionRate")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    Conductance = URIRef("http://qudt.org/vocab/quantitykind/Conductance")
    DisplacementCurrent = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrent")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    ElectronDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectronDensity")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    VoltagePercentage = URIRef("http://qudt.org/vocab/quantitykind/VoltagePercentage")
    NumberDensity = URIRef("http://qudt.org/vocab/quantitykind/NumberDensity")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    VolumicElectromagneticEnergy = URIRef("http://qudt.org/vocab/quantitykind/VolumicElectromagneticEnergy")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    Absorptance = URIRef("http://qudt.org/vocab/quantitykind/Absorptance")
    LogarithmRatioToBase10 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmRatioToBase10")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    ScalarMagneticPotential = URIRef("http://qudt.org/vocab/quantitykind/ScalarMagneticPotential")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    SoilAdsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SoilAdsorptionCoefficient")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    LineicMass = URIRef("http://qudt.org/vocab/quantitykind/LineicMass")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    SecondPolarMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondPolarMomentOfArea")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    MagneticSusceptability = URIRef("http://qudt.org/vocab/quantitykind/MagneticSusceptability")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    MassAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAbsorptionCoefficient")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    ElectricChargeVolumeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeVolumeDensity")
    AngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/AngularCrossSection")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    LandeGFactor = URIRef("http://qudt.org/vocab/quantitykind/LandeGFactor")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    HoleDensity = URIRef("http://qudt.org/vocab/quantitykind/HoleDensity")
    Impedance = URIRef("http://qudt.org/vocab/quantitykind/Impedance")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    ExitPlanePressure = URIRef("http://qudt.org/vocab/quantitykind/ExitPlanePressure")
    AmountOfSubstancePerUnitMassPressure = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMassPressure")
    LuminousIntensityDistribution = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensityDistribution")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    FundamentalReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalReciprocalLatticeVector")
    FahrenheitTemperature = URIRef("http://qudt.org/vocab/quantitykind/FahrenheitTemperature")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    Polarizability = URIRef("http://qudt.org/vocab/quantitykind/Polarizability")
    CurrentLinkage = URIRef("http://qudt.org/vocab/quantitykind/CurrentLinkage")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    BodyMassIndex = URIRef("http://qudt.org/vocab/quantitykind/BodyMassIndex")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    StructuralEfficiency = URIRef("http://qudt.org/vocab/quantitykind/StructuralEfficiency")
    SoilAdsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SoilAdsorptionCoefficient")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    ThrustCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThrustCoefficient")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    TemperatureRatio = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRatio")
    AbsoluteActivity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteActivity")
    RadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergyDensity")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    EnergyDensityOfStates = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensityOfStates")
    Lethargy = URIRef("http://qudt.org/vocab/quantitykind/Lethargy")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    AbsoluteActivity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteActivity")
    MagneticSusceptability = URIRef("http://qudt.org/vocab/quantitykind/MagneticSusceptability")
    ModulusOfImpedance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfImpedance")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    InverseVolume = URIRef("http://qudt.org/vocab/quantitykind/InverseVolume")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    MolarThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarThermodynamicEnergy")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    LogERatio = URIRef("http://qudt.org/vocab/quantitykind/LogERatio")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    PoissonRatio = URIRef("http://qudt.org/vocab/quantitykind/PoissonRatio")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    IonicStrength = URIRef("http://qudt.org/vocab/quantitykind/IonicStrength")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    VolumeThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/VolumeThermalExpansion")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    DimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/DimensionlessRatio")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    LinearStiffness = URIRef("http://qudt.org/vocab/quantitykind/LinearStiffness")
    SpectralRadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SpectralRadiantEnergyDensity")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    MobilityRatio = URIRef("http://qudt.org/vocab/quantitykind/MobilityRatio")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    AbsoluteActivity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteActivity")
    EnergyPerArea = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerArea")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    FermiAngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/FermiAngularWavenumber")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    AccelerationOfGravity = URIRef("http://qudt.org/vocab/quantitykind/AccelerationOfGravity")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    ResonanceEscapeProbability = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbability")
    EquilibriumConstantBasedOnPressure = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantBasedOnPressure")
    ElectricChargeLineDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeLineDensity")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    StoichiometricNumber = URIRef("http://qudt.org/vocab/quantitykind/StoichiometricNumber")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    RateOfRiseOfVoltage = URIRef("http://qudt.org/vocab/quantitykind/RateOfRiseOfVoltage")
    TotalLinearStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalLinearStoppingPower")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    ConductionSpeed = URIRef("http://qudt.org/vocab/quantitykind/ConductionSpeed")
    Solubility_Water = URIRef("http://qudt.org/vocab/quantitykind/Solubility_Water")
    EnergyFluence = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluence")
    MassRatioOfWaterToDryMatter = URIRef("http://qudt.org/vocab/quantitykind/MassRatioOfWaterToDryMatter")
    FrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/FrictionCoefficient")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    EnergyPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerElectricCharge")
    ElectricChargeSurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeSurfaceDensity")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    SurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceDensity")
    DensityOfStates = URIRef("http://qudt.org/vocab/quantitykind/DensityOfStates")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    MagneticSusceptability = URIRef("http://qudt.org/vocab/quantitykind/MagneticSusceptability")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    IntinsicCarrierDensity = URIRef("http://qudt.org/vocab/quantitykind/IntinsicCarrierDensity")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    DiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficient")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    PressureBasedVelocity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedVelocity")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    SphericalIlluminance = URIRef("http://qudt.org/vocab/quantitykind/SphericalIlluminance")
    TrafficIntensity = URIRef("http://qudt.org/vocab/quantitykind/TrafficIntensity")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    MassConcentration = URIRef("http://qudt.org/vocab/quantitykind/MassConcentration")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    Reactivity = URIRef("http://qudt.org/vocab/quantitykind/Reactivity")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    ElectricalPowerToMassRatio = URIRef("http://qudt.org/vocab/quantitykind/ElectricalPowerToMassRatio")
    ExitPlaneTemperature = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneTemperature")
    ExhaustGasesSpecificHeat = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasesSpecificHeat")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    GyromagneticRatio = URIRef("http://qudt.org/vocab/quantitykind/GyromagneticRatio")
    LarmorAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/LarmorAngularFrequency")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    StressOpticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StressOpticCoefficient")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    LuminousEmittance = URIRef("http://qudt.org/vocab/quantitykind/LuminousEmittance")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    InverseLength = URIRef("http://qudt.org/vocab/quantitykind/InverseLength")
    TotalIonization = URIRef("http://qudt.org/vocab/quantitykind/TotalIonization")
    InverseEnergy = URIRef("http://qudt.org/vocab/quantitykind/InverseEnergy")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    DatasetOfBytes = URIRef("http://qudt.org/vocab/quantitykind/DatasetOfBytes")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    ElectricChargePerAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerAmountOfSubstance")
    PositivePlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PositivePlaneAngle")
    CanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/CanonicalPartitionFunction")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    NumberDensity = URIRef("http://qudt.org/vocab/quantitykind/NumberDensity")
    MeltingPoint = URIRef("http://qudt.org/vocab/quantitykind/MeltingPoint")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    DisplacementCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrentDensity")
    Admittance = URIRef("http://qudt.org/vocab/quantitykind/Admittance")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    Repetency = URIRef("http://qudt.org/vocab/quantitykind/Repetency")
    Admittance = URIRef("http://qudt.org/vocab/quantitykind/Admittance")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    ThermalConductance = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductance")
    PressureBasedLength = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedLength")
    Capacity = URIRef("http://qudt.org/vocab/quantitykind/Capacity")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    AtomicNumber = URIRef("http://qudt.org/vocab/quantitykind/AtomicNumber")
    AbsorbedDoseRate = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDoseRate")
    TransmittanceDensity = URIRef("http://qudt.org/vocab/quantitykind/TransmittanceDensity")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    MolecularConcentration = URIRef("http://qudt.org/vocab/quantitykind/MolecularConcentration")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    LineicResistance = URIRef("http://qudt.org/vocab/quantitykind/LineicResistance")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    HamiltonFunction = URIRef("http://qudt.org/vocab/quantitykind/HamiltonFunction")
    EffectiveExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/EffectiveExhaustVelocity")
    DoseEquivalent = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalent")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    EnergyDensityOfStates = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensityOfStates")
    LinearDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearDensity")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    ThermalDiffusionRatioCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionRatioCoefficient")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    IonCurrent = URIRef("http://qudt.org/vocab/quantitykind/IonCurrent")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    Reflectivity = URIRef("http://qudt.org/vocab/quantitykind/Reflectivity")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    LengthEnergy = URIRef("http://qudt.org/vocab/quantitykind/LengthEnergy")
    ElectricDisplacement = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacement")
    LineicDataVolume = URIRef("http://qudt.org/vocab/quantitykind/LineicDataVolume")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    SpecificAcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/SpecificAcousticImpedance")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    MassieuFunction = URIRef("http://qudt.org/vocab/quantitykind/MassieuFunction")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    HeatFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/HeatFluxDensity")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    CatalyticActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivityConcentration")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    Prevalence = URIRef("http://qudt.org/vocab/quantitykind/Prevalence")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    BandwidthDistanceProduct = URIRef("http://qudt.org/vocab/quantitykind/BandwidthDistanceProduct")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    TotalAtomicStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalAtomicStoppingPower")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    SpecificHeatsRatio = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatsRatio")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    NeelTemperature = URIRef("http://qudt.org/vocab/quantitykind/NeelTemperature")
    ElectricChargePerMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerMass")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    SectionModulus = URIRef("http://qudt.org/vocab/quantitykind/SectionModulus")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    LinkedFlux = URIRef("http://qudt.org/vocab/quantitykind/LinkedFlux")
    PositiveDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/PositiveDimensionlessRatio")
    EquilibriumConstantOnConcentrationBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnConcentrationBasis")
    LorenzCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LorenzCoefficient")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    IonConcentration = URIRef("http://qudt.org/vocab/quantitykind/IonConcentration")
    WebTimeAveragePressure = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAveragePressure")
    MechanicalTension = URIRef("http://qudt.org/vocab/quantitykind/MechanicalTension")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    FundamentalReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalReciprocalLatticeVector")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    SoundParticleAcceleration = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleAcceleration")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    LossFactor = URIRef("http://qudt.org/vocab/quantitykind/LossFactor")
    IonTransportNumber = URIRef("http://qudt.org/vocab/quantitykind/IonTransportNumber")
    TemporalSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/TemporalSummationFunction")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    DiastolicBloodPressure = URIRef("http://qudt.org/vocab/quantitykind/DiastolicBloodPressure")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    PressureBasedMass = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedMass")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    KinematicViscosityOrDiffusionConstantOrThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosityOrDiffusionConstantOrThermalDiffusivity")
    SectionModulus = URIRef("http://qudt.org/vocab/quantitykind/SectionModulus")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    Solubility_Water = URIRef("http://qudt.org/vocab/quantitykind/Solubility_Water")
    GeneFamilyAbundance = URIRef("http://qudt.org/vocab/quantitykind/GeneFamilyAbundance")
    MortalityRate = URIRef("http://qudt.org/vocab/quantitykind/MortalityRate")
    GeneralizedMomentum = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedMomentum")
    LinearCompressibility = URIRef("http://qudt.org/vocab/quantitykind/LinearCompressibility")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    NonActivePower = URIRef("http://qudt.org/vocab/quantitykind/NonActivePower")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    MortalityRate = URIRef("http://qudt.org/vocab/quantitykind/MortalityRate")
    VoltagePercentage = URIRef("http://qudt.org/vocab/quantitykind/VoltagePercentage")
    VolumeDensityOfCharge = URIRef("http://qudt.org/vocab/quantitykind/VolumeDensityOfCharge")
    ParticleCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrentDensity")
    LogarithmicFrequencyIntervalToBase10 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyIntervalToBase10")
    SoundParticleVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleVelocity")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    StructuralEfficiency = URIRef("http://qudt.org/vocab/quantitykind/StructuralEfficiency")
    CurrentOfTheAmountOfSubtance = URIRef("http://qudt.org/vocab/quantitykind/CurrentOfTheAmountOfSubtance")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    SpecificGibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificGibbsEnergy")
    SpecificEnthalpy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnthalpy")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    ThrustToWeightRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToWeightRatio")
    SpecificEnthalpy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnthalpy")
    Piece = URIRef("http://qudt.org/vocab/quantitykind/Piece")
    Radioactivity = URIRef("http://qudt.org/vocab/quantitykind/Radioactivity")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    ConductiveHeatTransferRate = URIRef("http://qudt.org/vocab/quantitykind/ConductiveHeatTransferRate")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    LinearAcceleration = URIRef("http://qudt.org/vocab/quantitykind/LinearAcceleration")
    InformationContentExpressedAsALogarithmToBaseE = URIRef("http://qudt.org/vocab/quantitykind/InformationContentExpressedAsALogarithmToBaseE")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    DynamicPressure = URIRef("http://qudt.org/vocab/quantitykind/DynamicPressure")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    ElectricCurrentPerUnitLength = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerUnitLength")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    Energy_Squared = URIRef("http://qudt.org/vocab/quantitykind/Energy_Squared")
    IonDensity = URIRef("http://qudt.org/vocab/quantitykind/IonDensity")
    EnergyDensityOfStates = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensityOfStates")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    QualityFactor = URIRef("http://qudt.org/vocab/quantitykind/QualityFactor")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    ModulusOfRotationalSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfRotationalSubgradeReaction")
    Turbidity = URIRef("http://qudt.org/vocab/quantitykind/Turbidity")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    PressureBasedLength = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedLength")
    ExitPlaneTemperature = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneTemperature")
    FissionFuelUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionFuelUtilizationFactor")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    NeutronDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionCoefficient")
    LuminousIntensityDistribution = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensityDistribution")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    PhotosyntheticPhotonFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/PhotosyntheticPhotonFluxDensity")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    ElectricChargeVolumeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeVolumeDensity")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    MassPerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerAreaTime")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    PressureBurningRateIndex = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateIndex")
    MeltingPoint = URIRef("http://qudt.org/vocab/quantitykind/MeltingPoint")
    StaticFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StaticFrictionCoefficient")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    DecayConstant = URIRef("http://qudt.org/vocab/quantitykind/DecayConstant")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    LengthPercentage = URIRef("http://qudt.org/vocab/quantitykind/LengthPercentage")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    DisplacementCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrentDensity")
    Angle = URIRef("http://qudt.org/vocab/quantitykind/Angle")
    Polarizability = URIRef("http://qudt.org/vocab/quantitykind/Polarizability")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    PRODUCT_OF_INERTIA_X = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA_X")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    SecondMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondMomentOfArea")
    SpecificEnthalpy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnthalpy")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    DensityOfStates = URIRef("http://qudt.org/vocab/quantitykind/DensityOfStates")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    MassNumber = URIRef("http://qudt.org/vocab/quantitykind/MassNumber")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    SpecificModulus = URIRef("http://qudt.org/vocab/quantitykind/SpecificModulus")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    EnergyPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerElectricCharge")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    ThermalDiffusionRatioCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionRatioCoefficient")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    AbsorbedDose = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDose")
    TemperatureGradient = URIRef("http://qudt.org/vocab/quantitykind/TemperatureGradient")
    Fluidity = URIRef("http://qudt.org/vocab/quantitykind/Fluidity")
    IsentropicCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsentropicCompressibility")
    ThomsonCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThomsonCoefficient")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    ResonanceEscapeProbability = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbability")
    MeltingPoint = URIRef("http://qudt.org/vocab/quantitykind/MeltingPoint")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    ThermalExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalExpansionCoefficient")
    Coercivity = URIRef("http://qudt.org/vocab/quantitykind/Coercivity")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    LevelWidth = URIRef("http://qudt.org/vocab/quantitykind/LevelWidth")
    PhotonRadiance = URIRef("http://qudt.org/vocab/quantitykind/PhotonRadiance")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    StressIntensityFactor = URIRef("http://qudt.org/vocab/quantitykind/StressIntensityFactor")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    MassicActivity = URIRef("http://qudt.org/vocab/quantitykind/MassicActivity")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    BitRate = URIRef("http://qudt.org/vocab/quantitykind/BitRate")
    PermeabilityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermeabilityRatio")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    ExhaustGasesSpecificHeat = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasesSpecificHeat")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    IncidenceProportion = URIRef("http://qudt.org/vocab/quantitykind/IncidenceProportion")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    BloodGlucoseLevel = URIRef("http://qudt.org/vocab/quantitykind/BloodGlucoseLevel")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    SoundParticleVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleVelocity")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    PolarMomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/PolarMomentOfInertia")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    MassEnergyTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassEnergyTransferCoefficient")
    ElectricalResistance = URIRef("http://qudt.org/vocab/quantitykind/ElectricalResistance")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    ReciprocalPlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalPlaneAngle")
    TimeConstant_Inductance = URIRef("http://qudt.org/vocab/quantitykind/TimeConstant_Inductance")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    DimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/DimensionlessRatio")
    TemperaturePerTime_Squared = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime_Squared")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    Time_Squared = URIRef("http://qudt.org/vocab/quantitykind/Time_Squared")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    DotsPerInch = URIRef("http://qudt.org/vocab/quantitykind/DotsPerInch")
    ThermalDiffusionFactor = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionFactor")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    ParticleCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrentDensity")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    TemperatureRelatedVolume = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRelatedVolume")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    SphericalIlluminance = URIRef("http://qudt.org/vocab/quantitykind/SphericalIlluminance")
    AreaPerTime = URIRef("http://qudt.org/vocab/quantitykind/AreaPerTime")
    BevelGearPitchAngle = URIRef("http://qudt.org/vocab/quantitykind/BevelGearPitchAngle")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    quantitykind = URIRef("http://qudt.org/vocab/quantitykind")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    AuditoryThresholds = URIRef("http://qudt.org/vocab/quantitykind/AuditoryThresholds")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    VolumeThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/VolumeThermalExpansion")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    ParticleNumberDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleNumberDensity")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    Resistivity = URIRef("http://qudt.org/vocab/quantitykind/Resistivity")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    LossFactor = URIRef("http://qudt.org/vocab/quantitykind/LossFactor")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    VolumetricFlux = URIRef("http://qudt.org/vocab/quantitykind/VolumetricFlux")
    PhotonIntensity = URIRef("http://qudt.org/vocab/quantitykind/PhotonIntensity")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    Constringence = URIRef("http://qudt.org/vocab/quantitykind/Constringence")
    InformationContentExpressedAsALogarithmToBase10 = URIRef("http://qudt.org/vocab/quantitykind/InformationContentExpressedAsALogarithmToBase10")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    LiquidVolume = URIRef("http://qudt.org/vocab/quantitykind/LiquidVolume")
    MassRatio = URIRef("http://qudt.org/vocab/quantitykind/MassRatio")
    MassPerEnergy = URIRef("http://qudt.org/vocab/quantitykind/MassPerEnergy")
    VolumetricEntityDensity = URIRef("http://qudt.org/vocab/quantitykind/VolumetricEntityDensity")
    RelativeMassConcentrationOfVapour = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassConcentrationOfVapour")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    SignalStrength = URIRef("http://qudt.org/vocab/quantitykind/SignalStrength")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    LowerCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/LowerCriticalMagneticFluxDensity")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    EnergyFluence = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluence")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    LogarithmicFrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyInterval")
    MassicPower = URIRef("http://qudt.org/vocab/quantitykind/MassicPower")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    CharacteristicVelocity = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicVelocity")
    NormalizedDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/NormalizedDimensionlessRatio")
    IonCurrent = URIRef("http://qudt.org/vocab/quantitykind/IonCurrent")
    MassTemperature = URIRef("http://qudt.org/vocab/quantitykind/MassTemperature")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    ConductionSpeed = URIRef("http://qudt.org/vocab/quantitykind/ConductionSpeed")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    Flux = URIRef("http://qudt.org/vocab/quantitykind/Flux")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    SpectralConcentrationOfRadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SpectralConcentrationOfRadiantEnergyDensity")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    LinearAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAttenuationCoefficient")
    StandardAbsoluteActivity = URIRef("http://qudt.org/vocab/quantitykind/StandardAbsoluteActivity")
    AbsorbedDose = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDose")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    PowerConstant = URIRef("http://qudt.org/vocab/quantitykind/PowerConstant")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    AngleOfAttack = URIRef("http://qudt.org/vocab/quantitykind/AngleOfAttack")
    TemperatureAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/TemperatureAmountOfSubstance")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    TotalAngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentum")
    ElectricChargeLinearDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeLinearDensity")
    ThermalAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalAdmittance")
    NeelTemperature = URIRef("http://qudt.org/vocab/quantitykind/NeelTemperature")
    MassPerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerAreaTime")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    KineticOrThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticOrThermalEnergy")
    StaticPressure = URIRef("http://qudt.org/vocab/quantitykind/StaticPressure")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    MagnetizationField = URIRef("http://qudt.org/vocab/quantitykind/MagnetizationField")
    ElectricChargePerArea = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerArea")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    MutualInductance = URIRef("http://qudt.org/vocab/quantitykind/MutualInductance")
    SectionModulus = URIRef("http://qudt.org/vocab/quantitykind/SectionModulus")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    ThermalAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalAdmittance")
    DiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficient")
    InverseSquareMass = URIRef("http://qudt.org/vocab/quantitykind/InverseSquareMass")
    EvaporativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/EvaporativeHeatTransfer")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    ElectricChargeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeDensity")
    MechanicalMobility = URIRef("http://qudt.org/vocab/quantitykind/MechanicalMobility")
    ElectromagneticPermeabilityRatio = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeabilityRatio")
    Gradient = URIRef("http://qudt.org/vocab/quantitykind/Gradient")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    StructuralEfficiency = URIRef("http://qudt.org/vocab/quantitykind/StructuralEfficiency")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    ModulusOfLinearSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfLinearSubgradeReaction")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    ElectromagneticPermeabilityRatio = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeabilityRatio")
    ThermalInsulance = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulance")
    SphericalIlluminance = URIRef("http://qudt.org/vocab/quantitykind/SphericalIlluminance")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    AreaTime = URIRef("http://qudt.org/vocab/quantitykind/AreaTime")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    Gravity_API = URIRef("http://qudt.org/vocab/quantitykind/Gravity_API")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    AverageSpecificImpulse = URIRef("http://qudt.org/vocab/quantitykind/AverageSpecificImpulse")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    ResonanceEscapeProbability = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbability")
    AuxillaryMagneticField = URIRef("http://qudt.org/vocab/quantitykind/AuxillaryMagneticField")
    ChemicalConsumptionPerMass = URIRef("http://qudt.org/vocab/quantitykind/ChemicalConsumptionPerMass")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    PressureRatio = URIRef("http://qudt.org/vocab/quantitykind/PressureRatio")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    DiastolicBloodPressure = URIRef("http://qudt.org/vocab/quantitykind/DiastolicBloodPressure")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    DimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/DimensionlessRatio")
    ElectromagneticPermeability = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeability")
    MassRatioOfWaterVapourToDryGas = URIRef("http://qudt.org/vocab/quantitykind/MassRatioOfWaterVapourToDryGas")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    MolarInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarInternalEnergy")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    ThermalDiffusionRatioCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionRatioCoefficient")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    MolarEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarEnergy")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    ElectricFlux = URIRef("http://qudt.org/vocab/quantitykind/ElectricFlux")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    Speed = URIRef("http://qudt.org/vocab/quantitykind/Speed")
    MassAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/MassAmountOfSubstance")
    Fluidity = URIRef("http://qudt.org/vocab/quantitykind/Fluidity")
    Action = URIRef("http://qudt.org/vocab/quantitykind/Action")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    CoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/CoefficientOfHeatTransfer")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    TotalLinearStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalLinearStoppingPower")
    ComplexPower = URIRef("http://qudt.org/vocab/quantitykind/ComplexPower")
    PlanckFunction = URIRef("http://qudt.org/vocab/quantitykind/PlanckFunction")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    AreicDataVolume = URIRef("http://qudt.org/vocab/quantitykind/AreicDataVolume")
    RotationalMass = URIRef("http://qudt.org/vocab/quantitykind/RotationalMass")
    MolarDensity = URIRef("http://qudt.org/vocab/quantitykind/MolarDensity")
    MagneticFluxPerUnitLength = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxPerUnitLength")
    LinearAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAbsorptionCoefficient")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    InformationContentExpressedAsALogarithmToBaseE = URIRef("http://qudt.org/vocab/quantitykind/InformationContentExpressedAsALogarithmToBaseE")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    Dimensionless = URIRef("http://qudt.org/vocab/quantitykind/Dimensionless")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    LogOctanolWaterPartitionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LogOctanolWaterPartitionCoefficient")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    LossAngle = URIRef("http://qudt.org/vocab/quantitykind/LossAngle")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    RateOfChangeOfTemperature = URIRef("http://qudt.org/vocab/quantitykind/RateOfChangeOfTemperature")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    LineicLogarithmicRatio = URIRef("http://qudt.org/vocab/quantitykind/LineicLogarithmicRatio")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    ThermalCoefficientOfLinearExpansion = URIRef("http://qudt.org/vocab/quantitykind/ThermalCoefficientOfLinearExpansion")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    QualityFactor = URIRef("http://qudt.org/vocab/quantitykind/QualityFactor")
    Non_LeakageProbability = URIRef("http://qudt.org/vocab/quantitykind/Non-LeakageProbability")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    MassConcentration = URIRef("http://qudt.org/vocab/quantitykind/MassConcentration")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    PRODUCT_OF_INERTIA_Z = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA_Z")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    MolarAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAttenuationCoefficient")
    MechanicalTension = URIRef("http://qudt.org/vocab/quantitykind/MechanicalTension")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    OsmoticPressure = URIRef("http://qudt.org/vocab/quantitykind/OsmoticPressure")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    PositivePlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PositivePlaneAngle")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    LinearResistance = URIRef("http://qudt.org/vocab/quantitykind/LinearResistance")
    LossAngle = URIRef("http://qudt.org/vocab/quantitykind/LossAngle")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    ElectromagneticEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticEnergyDensity")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    DataRate = URIRef("http://qudt.org/vocab/quantitykind/DataRate")
    DisplacementCurrent = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrent")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    StressOpticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StressOpticCoefficient")
    TrafficIntensity = URIRef("http://qudt.org/vocab/quantitykind/TrafficIntensity")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    InverseLengthTemperature = URIRef("http://qudt.org/vocab/quantitykind/InverseLengthTemperature")
    LinearAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAttenuationCoefficient")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    MassicActivity = URIRef("http://qudt.org/vocab/quantitykind/MassicActivity")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    TimeTemperature = URIRef("http://qudt.org/vocab/quantitykind/TimeTemperature")
    PropagationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PropagationCoefficient")
    WebTimeAveragePressure = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAveragePressure")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    SecondRadiationConstant = URIRef("http://qudt.org/vocab/quantitykind/SecondRadiationConstant")
    InformationContentExpressedAsALogarithmToBase2 = URIRef("http://qudt.org/vocab/quantitykind/InformationContentExpressedAsALogarithmToBase2")
    DimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/DimensionlessRatio")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    LinearThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/LinearThermalExpansion")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    PowerAreaPerSolidAngle = URIRef("http://qudt.org/vocab/quantitykind/PowerAreaPerSolidAngle")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    Circulation = URIRef("http://qudt.org/vocab/quantitykind/Circulation")
    MassPerEnergy = URIRef("http://qudt.org/vocab/quantitykind/MassPerEnergy")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    Admittance = URIRef("http://qudt.org/vocab/quantitykind/Admittance")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    FloatingPointCalculationCapability = URIRef("http://qudt.org/vocab/quantitykind/FloatingPointCalculationCapability")
    CostPerArea = URIRef("http://qudt.org/vocab/quantitykind/CostPerArea")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    DewPointTemperature = URIRef("http://qudt.org/vocab/quantitykind/DewPointTemperature")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    MassAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAttenuationCoefficient")
    TouchThresholds = URIRef("http://qudt.org/vocab/quantitykind/TouchThresholds")
    LinkedFlux = URIRef("http://qudt.org/vocab/quantitykind/LinkedFlux")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    ElectricChargeLinearDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeLinearDensity")
    EquilibriumConstantBasedOnPressure = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantBasedOnPressure")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    HeatFlowRatePerUnitArea = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRatePerUnitArea")
    AtomScatteringFactor = URIRef("http://qudt.org/vocab/quantitykind/AtomScatteringFactor")
    SecondStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SecondStageMassRatio")
    MolalityOfSolute = URIRef("http://qudt.org/vocab/quantitykind/MolalityOfSolute")
    CharacteristicAcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicAcousticImpedance")
    DryVolume = URIRef("http://qudt.org/vocab/quantitykind/DryVolume")
    TemperaturePerTime_Squared = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime_Squared")
    Permittivity = URIRef("http://qudt.org/vocab/quantitykind/Permittivity")
    AttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AttenuationCoefficient")
    IonTransportNumber = URIRef("http://qudt.org/vocab/quantitykind/IonTransportNumber")
    AreaAngle = URIRef("http://qudt.org/vocab/quantitykind/AreaAngle")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    LineicLogarithmicRatio = URIRef("http://qudt.org/vocab/quantitykind/LineicLogarithmicRatio")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    HeatFlowRatePerUnitArea = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRatePerUnitArea")
    MolarInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarInternalEnergy")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    RotationalMass = URIRef("http://qudt.org/vocab/quantitykind/RotationalMass")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    SourceVoltageBetweenSubstances = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltageBetweenSubstances")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    EquilibriumConstantOnPressureBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnPressureBasis")
    HeadEndPressure = URIRef("http://qudt.org/vocab/quantitykind/HeadEndPressure")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    SymbolTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/SymbolTransmissionRate")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    HeatFlowRatePerUnitArea = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRatePerUnitArea")
    MolarAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAttenuationCoefficient")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    SpectralLuminousEfficiency = URIRef("http://qudt.org/vocab/quantitykind/SpectralLuminousEfficiency")
    PictureElement = URIRef("http://qudt.org/vocab/quantitykind/PictureElement")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    LinearCompressibility = URIRef("http://qudt.org/vocab/quantitykind/LinearCompressibility")
    ElectricChargePerArea = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerArea")
    ElectricConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectricConductivity")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    MolarEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarEnergy")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    LinearEnergyTransfer = URIRef("http://qudt.org/vocab/quantitykind/LinearEnergyTransfer")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    EffectiveMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMultiplicationFactor")
    EnergyPerSquareMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerSquareMagneticFluxDensity")
    DragForce = URIRef("http://qudt.org/vocab/quantitykind/DragForce")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    TemperatureGradient = URIRef("http://qudt.org/vocab/quantitykind/TemperatureGradient")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    HenrysLawVolatilityConstant = URIRef("http://qudt.org/vocab/quantitykind/HenrysLawVolatilityConstant")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    MultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/MultiplicationFactor")
    LineicPower = URIRef("http://qudt.org/vocab/quantitykind/LineicPower")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    PowerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerArea")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    Kerma = URIRef("http://qudt.org/vocab/quantitykind/Kerma")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    MagnetomotiveForce = URIRef("http://qudt.org/vocab/quantitykind/MagnetomotiveForce")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    StoichiometricNumber = URIRef("http://qudt.org/vocab/quantitykind/StoichiometricNumber")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    EquilibriumConstantBasedOnPressure = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantBasedOnPressure")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    MeanMassRange = URIRef("http://qudt.org/vocab/quantitykind/MeanMassRange")
    SpecificHeatsRatio = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatsRatio")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    LogarithmicFrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyInterval")
    SoundParticleAcceleration = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleAcceleration")
    SurfaceCoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/SurfaceCoefficientOfHeatTransfer")
    ChargeNumber = URIRef("http://qudt.org/vocab/quantitykind/ChargeNumber")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    RotaryShock = URIRef("http://qudt.org/vocab/quantitykind/RotaryShock")
    Solubility_Water = URIRef("http://qudt.org/vocab/quantitykind/Solubility_Water")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    AngularMomentumPerAngle = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentumPerAngle")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    DewPointTemperature = URIRef("http://qudt.org/vocab/quantitykind/DewPointTemperature")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    AmountOfSubstancePerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMass")
    ThrusterPowerToThrustEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThrusterPowerToThrustEfficiency")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    MagneticReluctivity = URIRef("http://qudt.org/vocab/quantitykind/MagneticReluctivity")
    MadelungConstant = URIRef("http://qudt.org/vocab/quantitykind/MadelungConstant")
    PoyntingVector = URIRef("http://qudt.org/vocab/quantitykind/PoyntingVector")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    RatioOfSpecificHeatCapacities = URIRef("http://qudt.org/vocab/quantitykind/RatioOfSpecificHeatCapacities")
    ComplexPower = URIRef("http://qudt.org/vocab/quantitykind/ComplexPower")
    InverseTimeTemperature = URIRef("http://qudt.org/vocab/quantitykind/InverseTimeTemperature")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    ThermalEnergyLength = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergyLength")
    MagneticAreaMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticAreaMoment")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    RF_Power = URIRef("http://qudt.org/vocab/quantitykind/RF-Power")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    SpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/SpinQuantumNumber")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    LuminousEmittance = URIRef("http://qudt.org/vocab/quantitykind/LuminousEmittance")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    CubicElectricDipoleMomentPerSquareEnergy = URIRef("http://qudt.org/vocab/quantitykind/CubicElectricDipoleMomentPerSquareEnergy")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    VolumetricEntityDensity = URIRef("http://qudt.org/vocab/quantitykind/VolumetricEntityDensity")
    AreaPerTime = URIRef("http://qudt.org/vocab/quantitykind/AreaPerTime")
    SourceVoltage = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltage")
    PolarMomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/PolarMomentOfInertia")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    MOMENT_OF_INERTIA_Z = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Z")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    LengthRatio = URIRef("http://qudt.org/vocab/quantitykind/LengthRatio")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    MassAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAttenuationCoefficient")
    HeartRate = URIRef("http://qudt.org/vocab/quantitykind/HeartRate")
    FlashPoint = URIRef("http://qudt.org/vocab/quantitykind/FlashPoint")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    ReciprocalElectricResistance = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalElectricResistance")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    SurgeImpedanceOfTheMedium = URIRef("http://qudt.org/vocab/quantitykind/SurgeImpedanceOfTheMedium")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    VolumicElectromagneticEnergy = URIRef("http://qudt.org/vocab/quantitykind/VolumicElectromagneticEnergy")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    AmountOfSubstancePerUnitMassPressure = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMassPressure")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    MechanicalSurfaceImpedance = URIRef("http://qudt.org/vocab/quantitykind/MechanicalSurfaceImpedance")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    WaterVaporDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/WaterVaporDiffusionCoefficient")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    IonDensity = URIRef("http://qudt.org/vocab/quantitykind/IonDensity")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    LinearThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/LinearThermalExpansion")
    InverseLength = URIRef("http://qudt.org/vocab/quantitykind/InverseLength")
    StructureFactor = URIRef("http://qudt.org/vocab/quantitykind/StructureFactor")
    StructureFactor = URIRef("http://qudt.org/vocab/quantitykind/StructureFactor")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    BitTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/BitTransmissionRate")
    SpecificGibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificGibbsEnergy")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    MolarFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MolarFlowRate")
    BindingFraction = URIRef("http://qudt.org/vocab/quantitykind/BindingFraction")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    AngleOfOpticalRotation = URIRef("http://qudt.org/vocab/quantitykind/AngleOfOpticalRotation")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    LinearStrain = URIRef("http://qudt.org/vocab/quantitykind/LinearStrain")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    SpecificWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificWeight")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    ThermalExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalExpansionCoefficient")
    PayloadRatio = URIRef("http://qudt.org/vocab/quantitykind/PayloadRatio")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    ThermalAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalAdmittance")
    ThermalConductance = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductance")
    AmountOfSubstancePerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMass")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    SpecificGibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificGibbsEnergy")
    RotationalMass = URIRef("http://qudt.org/vocab/quantitykind/RotationalMass")
    TemperatureAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/TemperatureAmountOfSubstance")
    EquilibriumConstant = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstant")
    StressOpticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StressOpticCoefficient")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    HeatFlowRatePerUnitArea = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRatePerUnitArea")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    DotsPerInch = URIRef("http://qudt.org/vocab/quantitykind/DotsPerInch")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    NeelTemperature = URIRef("http://qudt.org/vocab/quantitykind/NeelTemperature")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    FissionCoreRadiusToHeightRatio = URIRef("http://qudt.org/vocab/quantitykind/FissionCoreRadiusToHeightRatio")
    NormalizedDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/NormalizedDimensionlessRatio")
    LinearStrain = URIRef("http://qudt.org/vocab/quantitykind/LinearStrain")
    SpectralAngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralAngularCrossSection")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    InverseSquareEnergy = URIRef("http://qudt.org/vocab/quantitykind/InverseSquareEnergy")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    AtmosphericHydroxylationRate = URIRef("http://qudt.org/vocab/quantitykind/AtmosphericHydroxylationRate")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    Exposure = URIRef("http://qudt.org/vocab/quantitykind/Exposure")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    CanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/CanonicalPartitionFunction")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    LiftCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LiftCoefficient")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    SpecificEnthalpy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnthalpy")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    LinearEnergyTransfer = URIRef("http://qudt.org/vocab/quantitykind/LinearEnergyTransfer")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    FlashPoint = URIRef("http://qudt.org/vocab/quantitykind/FlashPoint")
    LinearLogarithmicRatio = URIRef("http://qudt.org/vocab/quantitykind/LinearLogarithmicRatio")
    EnergyPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerElectricCharge")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    ElectricChargePerAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerAmountOfSubstance")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    HeartRate = URIRef("http://qudt.org/vocab/quantitykind/HeartRate")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    EccentricityOfOrbit = URIRef("http://qudt.org/vocab/quantitykind/EccentricityOfOrbit")
    DragForce = URIRef("http://qudt.org/vocab/quantitykind/DragForce")
    LowerCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/LowerCriticalMagneticFluxDensity")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    PoyntingVector = URIRef("http://qudt.org/vocab/quantitykind/PoyntingVector")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    MolalityOfSolute = URIRef("http://qudt.org/vocab/quantitykind/MolalityOfSolute")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    TimeRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRatio")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    AreicDataVolume = URIRef("http://qudt.org/vocab/quantitykind/AreicDataVolume")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    ParticleCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrentDensity")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    AverageHeadEndPressure = URIRef("http://qudt.org/vocab/quantitykind/AverageHeadEndPressure")
    ElectricChargeLinearDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeLinearDensity")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    LiquidVolume = URIRef("http://qudt.org/vocab/quantitykind/LiquidVolume")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    PressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PressureCoefficient")
    TemperatureBasedLength = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedLength")
    RelativeMassDensity = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDensity")
    TemperatureDifference = URIRef("http://qudt.org/vocab/quantitykind/TemperatureDifference")
    LogarithmicFrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyInterval")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    BevelGearPitchAngle = URIRef("http://qudt.org/vocab/quantitykind/BevelGearPitchAngle")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    LinearAcceleration = URIRef("http://qudt.org/vocab/quantitykind/LinearAcceleration")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    Gravity_API = URIRef("http://qudt.org/vocab/quantitykind/Gravity_API")
    TotalRadiance = URIRef("http://qudt.org/vocab/quantitykind/TotalRadiance")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    WarmReceptorThreshold = URIRef("http://qudt.org/vocab/quantitykind/WarmReceptorThreshold")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    FundamentalReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalReciprocalLatticeVector")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    PressureBurningRateConstant = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateConstant")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    TotalAngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentum")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    TimeRelatedLogarithmicRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRelatedLogarithmicRatio")
    Viscosity = URIRef("http://qudt.org/vocab/quantitykind/Viscosity")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    AngleOfOpticalRotation = URIRef("http://qudt.org/vocab/quantitykind/AngleOfOpticalRotation")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    LinearThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/LinearThermalExpansion")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    LinearIonization = URIRef("http://qudt.org/vocab/quantitykind/LinearIonization")
    ReciprocalElectricResistance = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalElectricResistance")
    Chromaticity = URIRef("http://qudt.org/vocab/quantitykind/Chromaticity")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    ByteRate = URIRef("http://qudt.org/vocab/quantitykind/ByteRate")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    PRODUCT_OF_INERTIA = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA")
    StructuralEfficiency = URIRef("http://qudt.org/vocab/quantitykind/StructuralEfficiency")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    LogarithmicMedianInformationFlow_SourceToBaseE = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicMedianInformationFlow_SourceToBaseE")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    EnergyPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerElectricCharge")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    VolumeDensityOfCharge = URIRef("http://qudt.org/vocab/quantitykind/VolumeDensityOfCharge")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    PressureBasedDynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedDynamicViscosity")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    ComplexPower = URIRef("http://qudt.org/vocab/quantitykind/ComplexPower")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    ElectricCurrentPhasor = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPhasor")
    KermaRate = URIRef("http://qudt.org/vocab/quantitykind/KermaRate")
    BulkModulus = URIRef("http://qudt.org/vocab/quantitykind/BulkModulus")
    GeneFamilyAbundance = URIRef("http://qudt.org/vocab/quantitykind/GeneFamilyAbundance")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    MOMENT_OF_INERTIA_Z = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Z")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    MagneticPolarization = URIRef("http://qudt.org/vocab/quantitykind/MagneticPolarization")
    ThermalAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalAdmittance")
    ThermalDiffusionFactor = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionFactor")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    ElectricChargeLinearDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeLinearDensity")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    SpecificEntropy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEntropy")
    SpecificGibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificGibbsEnergy")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    ThermodynamicEntropy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEntropy")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    AuxillaryMagneticField = URIRef("http://qudt.org/vocab/quantitykind/AuxillaryMagneticField")
    WebTimeAveragePressure = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAveragePressure")
    HallCoefficient = URIRef("http://qudt.org/vocab/quantitykind/HallCoefficient")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    VolumicAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/VolumicAmountOfSubstance")
    DisplacementCurrent = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrent")
    AbsoluteActivity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteActivity")
    MadelungConstant = URIRef("http://qudt.org/vocab/quantitykind/MadelungConstant")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    CyclotronAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/CyclotronAngularFrequency")
    MicrobialFormation = URIRef("http://qudt.org/vocab/quantitykind/MicrobialFormation")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    Vorticity = URIRef("http://qudt.org/vocab/quantitykind/Vorticity")
    PlanckFunction = URIRef("http://qudt.org/vocab/quantitykind/PlanckFunction")
    DegreeOfDissociation = URIRef("http://qudt.org/vocab/quantitykind/DegreeOfDissociation")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    MagneticDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMoment")
    Permeance = URIRef("http://qudt.org/vocab/quantitykind/Permeance")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    WaterVaporDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/WaterVaporDiffusionCoefficient")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    NuclearSpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/NuclearSpinQuantumNumber")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    MassieuFunction = URIRef("http://qudt.org/vocab/quantitykind/MassieuFunction")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    AngleOfAttack = URIRef("http://qudt.org/vocab/quantitykind/AngleOfAttack")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    Voltage = URIRef("http://qudt.org/vocab/quantitykind/Voltage")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    ThermalInsulance = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulance")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    LinearPower = URIRef("http://qudt.org/vocab/quantitykind/LinearPower")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    Gravity_API = URIRef("http://qudt.org/vocab/quantitykind/Gravity_API")
    PeltierCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PeltierCoefficient")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    StressOpticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StressOpticCoefficient")
    BloodGlucoseLevel_Mass = URIRef("http://qudt.org/vocab/quantitykind/BloodGlucoseLevel_Mass")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    AreicMass = URIRef("http://qudt.org/vocab/quantitykind/AreicMass")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    LinearAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAbsorptionCoefficient")
    IncidenceRate = URIRef("http://qudt.org/vocab/quantitykind/IncidenceRate")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    Kerma = URIRef("http://qudt.org/vocab/quantitykind/Kerma")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    SpecificPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificPower")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    PhaseCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PhaseCoefficient")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    StructureFactor = URIRef("http://qudt.org/vocab/quantitykind/StructureFactor")
    PressureBasedDensity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedDensity")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    LinearForce = URIRef("http://qudt.org/vocab/quantitykind/LinearForce")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    EquilibriumConstantOnPressureBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnPressureBasis")
    Gravity_API = URIRef("http://qudt.org/vocab/quantitykind/Gravity_API")
    SpecificElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/SpecificElectricCurrent")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    MagneticAreaMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticAreaMoment")
    ElectricDisplacementField = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacementField")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    Constringence = URIRef("http://qudt.org/vocab/quantitykind/Constringence")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    CharacteristicAcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicAcousticImpedance")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    MassRelatedElectricalCurrent = URIRef("http://qudt.org/vocab/quantitykind/MassRelatedElectricalCurrent")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    MagneticReluctivity = URIRef("http://qudt.org/vocab/quantitykind/MagneticReluctivity")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    RF_Power = URIRef("http://qudt.org/vocab/quantitykind/RF-Power")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    RateOfChangeOfTemperature = URIRef("http://qudt.org/vocab/quantitykind/RateOfChangeOfTemperature")
    PressureBasedVolumeFlow = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedVolumeFlow")
    Susceptance = URIRef("http://qudt.org/vocab/quantitykind/Susceptance")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    AcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/AcousticImpedance")
    SystolicBloodPressure = URIRef("http://qudt.org/vocab/quantitykind/SystolicBloodPressure")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    Reflectivity = URIRef("http://qudt.org/vocab/quantitykind/Reflectivity")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    DiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficient")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    LuminousEnergy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEnergy")
    MassRatio = URIRef("http://qudt.org/vocab/quantitykind/MassRatio")
    CoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/CoefficientOfHeatTransfer")
    EnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensity")
    MagneticPolarization = URIRef("http://qudt.org/vocab/quantitykind/MagneticPolarization")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    AccelerationOfGravity = URIRef("http://qudt.org/vocab/quantitykind/AccelerationOfGravity")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    VolumetricBitDensity = URIRef("http://qudt.org/vocab/quantitykind/VolumetricBitDensity")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    SecondMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondMomentOfArea")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    WaterVaporDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/WaterVaporDiffusionCoefficient")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    StaticPressure = URIRef("http://qudt.org/vocab/quantitykind/StaticPressure")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    AcceptorDensity = URIRef("http://qudt.org/vocab/quantitykind/AcceptorDensity")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    SuperconductionTransitionTemperature = URIRef("http://qudt.org/vocab/quantitykind/SuperconductionTransitionTemperature")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    ElectromagneticEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticEnergyDensity")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    TimeRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRatio")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    LinearThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/LinearThermalExpansion")
    LuminousFluxPerArea = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxPerArea")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    MOMENT_OF_INERTIA_Y = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Y")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    ElectromagneticPermeability = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeability")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    Repetency = URIRef("http://qudt.org/vocab/quantitykind/Repetency")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    VolumeOrSectionModulus = URIRef("http://qudt.org/vocab/quantitykind/VolumeOrSectionModulus")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    PRODUCT_OF_INERTIA = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA")
    ParticleFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluenceRate")
    MassPerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerAreaTime")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    EnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensity")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    Impedance = URIRef("http://qudt.org/vocab/quantitykind/Impedance")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    SpecificActivity = URIRef("http://qudt.org/vocab/quantitykind/SpecificActivity")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    StandardChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/StandardChemicalPotential")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    BatteryCapacity = URIRef("http://qudt.org/vocab/quantitykind/BatteryCapacity")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    DisplacementCurrent = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrent")
    BloodGlucoseLevel_Mass = URIRef("http://qudt.org/vocab/quantitykind/BloodGlucoseLevel_Mass")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    HeatFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/HeatFluxDensity")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    SoundParticleVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleVelocity")
    ThermalUtilizationFactorForFission = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactorForFission")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    ElectricalConductance = URIRef("http://qudt.org/vocab/quantitykind/ElectricalConductance")
    ElectricalPowerToMassRatio = URIRef("http://qudt.org/vocab/quantitykind/ElectricalPowerToMassRatio")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    LogOctanolAirPartitionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LogOctanolAirPartitionCoefficient")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    Vorticity = URIRef("http://qudt.org/vocab/quantitykind/Vorticity")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    AmountOfSubstanceFraction = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFraction")
    FundamentalReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalReciprocalLatticeVector")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    MomentumPerAngle = URIRef("http://qudt.org/vocab/quantitykind/MomentumPerAngle")
    PhaseSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/PhaseSpeedOfSound")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    Solubility_Water = URIRef("http://qudt.org/vocab/quantitykind/Solubility_Water")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    SoundEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SoundEnergyDensity")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    LarmorAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/LarmorAngularFrequency")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    GeneralizedMomentum = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedMomentum")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    LineicTorque = URIRef("http://qudt.org/vocab/quantitykind/LineicTorque")
    SpecificHelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificHelmholtzEnergy")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    Angle = URIRef("http://qudt.org/vocab/quantitykind/Angle")
    OsmoticPressure = URIRef("http://qudt.org/vocab/quantitykind/OsmoticPressure")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    PositiveDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/PositiveDimensionlessRatio")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    MassRatio = URIRef("http://qudt.org/vocab/quantitykind/MassRatio")
    TotalAngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentum")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    TemperatureBasedMass = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedMass")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    MagneticTension = URIRef("http://qudt.org/vocab/quantitykind/MagneticTension")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    AreaThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/AreaThermalExpansion")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    TemperatureBasedLength = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedLength")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    MassFraction = URIRef("http://qudt.org/vocab/quantitykind/MassFraction")
    GroupSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/GroupSpeedOfSound")
    PropellantTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantTemperature")
    Adaptation = URIRef("http://qudt.org/vocab/quantitykind/Adaptation")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    PressureRatio = URIRef("http://qudt.org/vocab/quantitykind/PressureRatio")
    LinearForce = URIRef("http://qudt.org/vocab/quantitykind/LinearForce")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    MeanMassRange = URIRef("http://qudt.org/vocab/quantitykind/MeanMassRange")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    LuminousEmittance = URIRef("http://qudt.org/vocab/quantitykind/LuminousEmittance")
    IncidenceProportion = URIRef("http://qudt.org/vocab/quantitykind/IncidenceProportion")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    TouchThresholds = URIRef("http://qudt.org/vocab/quantitykind/TouchThresholds")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    FissionFuelUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionFuelUtilizationFactor")
    LogarithmicMedianInformationFlow_SourceToBase2 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicMedianInformationFlow_SourceToBase2")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    AmountOfSubstanceConcentrationOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentrationOfB")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    SoundParticleVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleVelocity")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    LinkedFlux = URIRef("http://qudt.org/vocab/quantitykind/LinkedFlux")
    AngularDistance = URIRef("http://qudt.org/vocab/quantitykind/AngularDistance")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    TotalRadiance = URIRef("http://qudt.org/vocab/quantitykind/TotalRadiance")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    ReciprocalVoltage = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalVoltage")
    AngleOfAttack = URIRef("http://qudt.org/vocab/quantitykind/AngleOfAttack")
    LogarithmicMedianInformationFlow_SourceToBaseE = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicMedianInformationFlow_SourceToBaseE")
    PropagationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PropagationCoefficient")
    QuantityOfLight = URIRef("http://qudt.org/vocab/quantitykind/QuantityOfLight")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    ChemicalConsumptionPerMass = URIRef("http://qudt.org/vocab/quantitykind/ChemicalConsumptionPerMass")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    Reflectance = URIRef("http://qudt.org/vocab/quantitykind/Reflectance")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    SpecificVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificVolume")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    SoundParticleAcceleration = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleAcceleration")
    DisplacementCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrentDensity")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    InverseTimeTemperature = URIRef("http://qudt.org/vocab/quantitykind/InverseTimeTemperature")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    ScalarMagneticPotential = URIRef("http://qudt.org/vocab/quantitykind/ScalarMagneticPotential")
    SpectralConcentrationOfVibrationalModes = URIRef("http://qudt.org/vocab/quantitykind/SpectralConcentrationOfVibrationalModes")
    InverseAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/InverseAmountOfSubstance")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    Gradient = URIRef("http://qudt.org/vocab/quantitykind/Gradient")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    LuminousExposure = URIRef("http://qudt.org/vocab/quantitykind/LuminousExposure")
    PressureBasedMolality = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedMolality")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    MassTemperature = URIRef("http://qudt.org/vocab/quantitykind/MassTemperature")
    AverageLogarithmicEnergyDecrement = URIRef("http://qudt.org/vocab/quantitykind/AverageLogarithmicEnergyDecrement")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    PartialPressure = URIRef("http://qudt.org/vocab/quantitykind/PartialPressure")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    EnergyDensityOfStates = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensityOfStates")
    AmountOfSubstancePerUnitVolume = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitVolume")
    VoltageRatio = URIRef("http://qudt.org/vocab/quantitykind/VoltageRatio")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    VolumicElectromagneticEnergy = URIRef("http://qudt.org/vocab/quantitykind/VolumicElectromagneticEnergy")
    InformationContent = URIRef("http://qudt.org/vocab/quantitykind/InformationContent")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    MolecularMass = URIRef("http://qudt.org/vocab/quantitykind/MolecularMass")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    SecondStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SecondStageMassRatio")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    PhaseCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PhaseCoefficient")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    SuperconductionTransitionTemperature = URIRef("http://qudt.org/vocab/quantitykind/SuperconductionTransitionTemperature")
    Period = URIRef("http://qudt.org/vocab/quantitykind/Period")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    ThermalInsulance = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulance")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    EvaporativeHeatTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/EvaporativeHeatTransferCoefficient")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    Flux = URIRef("http://qudt.org/vocab/quantitykind/Flux")
    SoundPressure = URIRef("http://qudt.org/vocab/quantitykind/SoundPressure")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    ReciprocalVoltage = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalVoltage")
    BloodGlucoseLevel = URIRef("http://qudt.org/vocab/quantitykind/BloodGlucoseLevel")
    DryVolume = URIRef("http://qudt.org/vocab/quantitykind/DryVolume")
    QuarticElectricDipoleMomentPerCubicEnergy = URIRef("http://qudt.org/vocab/quantitykind/QuarticElectricDipoleMomentPerCubicEnergy")
    TimePercentage = URIRef("http://qudt.org/vocab/quantitykind/TimePercentage")
    AmountOfSubstancePerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMass")
    Kerma = URIRef("http://qudt.org/vocab/quantitykind/Kerma")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    Radiance = URIRef("http://qudt.org/vocab/quantitykind/Radiance")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    Population = URIRef("http://qudt.org/vocab/quantitykind/Population")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    SoundPowerLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPowerLevel")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    AreaThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/AreaThermalExpansion")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    DonorDensity = URIRef("http://qudt.org/vocab/quantitykind/DonorDensity")
    DataRate = URIRef("http://qudt.org/vocab/quantitykind/DataRate")
    ThermalDiffusionRatio = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionRatio")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    Reactance = URIRef("http://qudt.org/vocab/quantitykind/Reactance")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    EquilibriumConstant = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstant")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    FermiTemperature = URIRef("http://qudt.org/vocab/quantitykind/FermiTemperature")
    InverseMass_Squared = URIRef("http://qudt.org/vocab/quantitykind/InverseMass_Squared")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    SpectralConcentrationOfRadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SpectralConcentrationOfRadiantEnergyDensity")
    ThrustToWeightRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToWeightRatio")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    SoundParticleAcceleration = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleAcceleration")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    ExposureRate = URIRef("http://qudt.org/vocab/quantitykind/ExposureRate")
    TemperatureRatio = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRatio")
    SoundVolumeVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundVolumeVelocity")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    SourceVoltageBetweenSubstances = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltageBetweenSubstances")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    CharacteristicVelocity = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicVelocity")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    TorqueConstant = URIRef("http://qudt.org/vocab/quantitykind/TorqueConstant")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    Constringence = URIRef("http://qudt.org/vocab/quantitykind/Constringence")
    LinearStiffness = URIRef("http://qudt.org/vocab/quantitykind/LinearStiffness")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    MadelungConstant = URIRef("http://qudt.org/vocab/quantitykind/MadelungConstant")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    FissionMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionMultiplicationFactor")
    AmountOfSubstancePerUnitMassPressure = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMassPressure")
    SpecificElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/SpecificElectricCurrent")
    AmountOfSubstanceFraction = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFraction")
    MolecularViscosity = URIRef("http://qudt.org/vocab/quantitykind/MolecularViscosity")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    LineicLogarithmicRatio = URIRef("http://qudt.org/vocab/quantitykind/LineicLogarithmicRatio")
    RadianceFactor = URIRef("http://qudt.org/vocab/quantitykind/RadianceFactor")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    ThermalTransmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalTransmittance")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    LinearMomentum = URIRef("http://qudt.org/vocab/quantitykind/LinearMomentum")
    AngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentum")
    ElectricChargeLineDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeLineDensity")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    PropellantTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantTemperature")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    PartialPressure = URIRef("http://qudt.org/vocab/quantitykind/PartialPressure")
    MagneticDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMoment")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    PressureBasedKinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedKinematicViscosity")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    VolumetricHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/VolumetricHeatCapacity")
    ThrustToMassRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToMassRatio")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    ChargeNumber = URIRef("http://qudt.org/vocab/quantitykind/ChargeNumber")
    MassTemperature = URIRef("http://qudt.org/vocab/quantitykind/MassTemperature")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    MolarAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAttenuationCoefficient")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    Polarizability = URIRef("http://qudt.org/vocab/quantitykind/Polarizability")
    LinearAcceleration = URIRef("http://qudt.org/vocab/quantitykind/LinearAcceleration")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    AccelerationOfGravity = URIRef("http://qudt.org/vocab/quantitykind/AccelerationOfGravity")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    MagneticTension = URIRef("http://qudt.org/vocab/quantitykind/MagneticTension")
    MagneticTension = URIRef("http://qudt.org/vocab/quantitykind/MagneticTension")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    SurfaceActivityDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceActivityDensity")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    EquilibriumConstantOnPressureBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnPressureBasis")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    FrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/FrictionCoefficient")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    LineicResolution = URIRef("http://qudt.org/vocab/quantitykind/LineicResolution")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    SpecificInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificInternalEnergy")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    DensityOfStates = URIRef("http://qudt.org/vocab/quantitykind/DensityOfStates")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    ConductionSpeed = URIRef("http://qudt.org/vocab/quantitykind/ConductionSpeed")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    NuclearSpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/NuclearSpinQuantumNumber")
    TemperatureBasedVelocity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedVelocity")
    ElectricDisplacement = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacement")
    ResonanceEscapeProbability = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbability")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    ExpansionRatio = URIRef("http://qudt.org/vocab/quantitykind/ExpansionRatio")
    NumberOfParticles = URIRef("http://qudt.org/vocab/quantitykind/NumberOfParticles")
    MagneticDipoleMomentOfAMolecule = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMomentOfAMolecule")
    AttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AttenuationCoefficient")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    Kerma = URIRef("http://qudt.org/vocab/quantitykind/Kerma")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    ResonanceEscapeProbability = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbability")
    AngularReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/AngularReciprocalLatticeVector")
    EinsteinTransitionProbability = URIRef("http://qudt.org/vocab/quantitykind/EinsteinTransitionProbability")
    MagneticField = URIRef("http://qudt.org/vocab/quantitykind/MagneticField")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    ElectronDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectronDensity")
    SignalStrength = URIRef("http://qudt.org/vocab/quantitykind/SignalStrength")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    DoseEquivalentRate = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalentRate")
    PlanckFunction = URIRef("http://qudt.org/vocab/quantitykind/PlanckFunction")
    Adaptation = URIRef("http://qudt.org/vocab/quantitykind/Adaptation")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    EquilibriumConstantOnConcentrationBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnConcentrationBasis")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    AmountOfSubstancePerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMass")
    ConductiveHeatTransferRate = URIRef("http://qudt.org/vocab/quantitykind/ConductiveHeatTransferRate")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    IsothermalMoistureCapacity = URIRef("http://qudt.org/vocab/quantitykind/IsothermalMoistureCapacity")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    FrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/FrictionCoefficient")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    EnergyExpenditure = URIRef("http://qudt.org/vocab/quantitykind/EnergyExpenditure")
    ModulusOfLinearSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfLinearSubgradeReaction")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    Lethargy = URIRef("http://qudt.org/vocab/quantitykind/Lethargy")
    EnergyPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerElectricCharge")
    EquilibriumConstantOnPressureBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnPressureBasis")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    SeebeckCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SeebeckCoefficient")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    SpecificVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificVolume")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    SourceVoltageBetweenSubstances = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltageBetweenSubstances")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    SpecificInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificInternalEnergy")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    ActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/ActivityConcentration")
    HeatFlowRatePerUnitArea = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRatePerUnitArea")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    SpecificInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificInternalEnergy")
    ElectricCurrentPerUnitLength = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerUnitLength")
    VoltagePhasor = URIRef("http://qudt.org/vocab/quantitykind/VoltagePhasor")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    InverseLengthTemperature = URIRef("http://qudt.org/vocab/quantitykind/InverseLengthTemperature")
    StressIntensityFactor = URIRef("http://qudt.org/vocab/quantitykind/StressIntensityFactor")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    PolarizationField = URIRef("http://qudt.org/vocab/quantitykind/PolarizationField")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    ConductionSpeed = URIRef("http://qudt.org/vocab/quantitykind/ConductionSpeed")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    MolarAngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/MolarAngularMomentum")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    BandwidthLengthProduct = URIRef("http://qudt.org/vocab/quantitykind/BandwidthLengthProduct")
    MolecularConcentration = URIRef("http://qudt.org/vocab/quantitykind/MolecularConcentration")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    RotaryShock = URIRef("http://qudt.org/vocab/quantitykind/RotaryShock")
    IonCurrent = URIRef("http://qudt.org/vocab/quantitykind/IonCurrent")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    PressureBasedMass = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedMass")
    ElectronDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectronDensity")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    SpectralCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralCrossSection")
    MolarEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarEnergy")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    ElectricChargeSurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeSurfaceDensity")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    DoseEquivalent = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalent")
    SpecificEntropy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEntropy")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    ThermalConductance = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductance")
    LuminousEmittance = URIRef("http://qudt.org/vocab/quantitykind/LuminousEmittance")
    AngleOfAttack = URIRef("http://qudt.org/vocab/quantitykind/AngleOfAttack")
    CoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/CoefficientOfHeatTransfer")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    LinearDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearDensity")
    ReynoldsNumber = URIRef("http://qudt.org/vocab/quantitykind/ReynoldsNumber")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    IonDensity = URIRef("http://qudt.org/vocab/quantitykind/IonDensity")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    InverseLength = URIRef("http://qudt.org/vocab/quantitykind/InverseLength")
    LiftCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LiftCoefficient")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    Viscosity = URIRef("http://qudt.org/vocab/quantitykind/Viscosity")
    ElectricField = URIRef("http://qudt.org/vocab/quantitykind/ElectricField")
    AreicTorque = URIRef("http://qudt.org/vocab/quantitykind/AreicTorque")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    LinearElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrent")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    ThrustToWeightRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToWeightRatio")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    Radiosity = URIRef("http://qudt.org/vocab/quantitykind/Radiosity")
    IonCurrent = URIRef("http://qudt.org/vocab/quantitykind/IonCurrent")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    Voltage = URIRef("http://qudt.org/vocab/quantitykind/Voltage")
    PressureBasedVelocity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedVelocity")
    DataRate = URIRef("http://qudt.org/vocab/quantitykind/DataRate")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    SpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/SpinQuantumNumber")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    TemperatureRateOfChange = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRateOfChange")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    OlfactoryThreshold = URIRef("http://qudt.org/vocab/quantitykind/OlfactoryThreshold")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    RiseOfOffStateVoltage = URIRef("http://qudt.org/vocab/quantitykind/RiseOfOffStateVoltage")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    ActivityThresholds = URIRef("http://qudt.org/vocab/quantitykind/ActivityThresholds")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    CatalyticActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivityConcentration")
    GyromagneticRatio = URIRef("http://qudt.org/vocab/quantitykind/GyromagneticRatio")
    ExitPlaneTemperature = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneTemperature")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    ElectricConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectricConductivity")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    EffectiveMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMultiplicationFactor")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    ElectricField = URIRef("http://qudt.org/vocab/quantitykind/ElectricField")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    LogarithmicFrequencyIntervalToBase10 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyIntervalToBase10")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    VolumePerArea = URIRef("http://qudt.org/vocab/quantitykind/VolumePerArea")
    Loudness = URIRef("http://qudt.org/vocab/quantitykind/Loudness")
    BevelGearPitchAngle = URIRef("http://qudt.org/vocab/quantitykind/BevelGearPitchAngle")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    PropellantMeanBulkTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantMeanBulkTemperature")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    SurfaceCoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/SurfaceCoefficientOfHeatTransfer")
    NuclearQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/NuclearQuadrupoleMoment")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    Permeability = URIRef("http://qudt.org/vocab/quantitykind/Permeability")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    SecondMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondMomentOfArea")
    RF_Power = URIRef("http://qudt.org/vocab/quantitykind/RF-Power")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    StatisticalWeight = URIRef("http://qudt.org/vocab/quantitykind/StatisticalWeight")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    SecondMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondMomentOfArea")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    PhotonRadiance = URIRef("http://qudt.org/vocab/quantitykind/PhotonRadiance")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    MagnetomotiveForce = URIRef("http://qudt.org/vocab/quantitykind/MagnetomotiveForce")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    CyclotronAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/CyclotronAngularFrequency")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    CurvatureFromRadius = URIRef("http://qudt.org/vocab/quantitykind/CurvatureFromRadius")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    AreaTime = URIRef("http://qudt.org/vocab/quantitykind/AreaTime")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    MagneticPolarization = URIRef("http://qudt.org/vocab/quantitykind/MagneticPolarization")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    MassEnergyTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassEnergyTransferCoefficient")
    Absorptance = URIRef("http://qudt.org/vocab/quantitykind/Absorptance")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    Speed = URIRef("http://qudt.org/vocab/quantitykind/Speed")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    SignalStrength = URIRef("http://qudt.org/vocab/quantitykind/SignalStrength")
    ActivityRelatedByMass = URIRef("http://qudt.org/vocab/quantitykind/ActivityRelatedByMass")
    OsmoticPressure = URIRef("http://qudt.org/vocab/quantitykind/OsmoticPressure")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    Basicity = URIRef("http://qudt.org/vocab/quantitykind/Basicity")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    SoundParticleAcceleration = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleAcceleration")
    ReflectanceFactor = URIRef("http://qudt.org/vocab/quantitykind/ReflectanceFactor")
    Impedance = URIRef("http://qudt.org/vocab/quantitykind/Impedance")
    InverseSquareMass = URIRef("http://qudt.org/vocab/quantitykind/InverseSquareMass")
    LandeGFactor = URIRef("http://qudt.org/vocab/quantitykind/LandeGFactor")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    PositiveDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/PositiveDimensionlessRatio")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    NeutronDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionCoefficient")
    ActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/ActivityConcentration")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    RespiratoryRate = URIRef("http://qudt.org/vocab/quantitykind/RespiratoryRate")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    RecombinationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/RecombinationCoefficient")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    ByteDataVolume = URIRef("http://qudt.org/vocab/quantitykind/ByteDataVolume")
    Conductance = URIRef("http://qudt.org/vocab/quantitykind/Conductance")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    ThrusterPowerToThrustEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThrusterPowerToThrustEfficiency")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    MOMENT_OF_INERTIA_Y = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Y")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    Dissipance = URIRef("http://qudt.org/vocab/quantitykind/Dissipance")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    ResistanceRatio = URIRef("http://qudt.org/vocab/quantitykind/ResistanceRatio")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    Permittivity = URIRef("http://qudt.org/vocab/quantitykind/Permittivity")
    Speed = URIRef("http://qudt.org/vocab/quantitykind/Speed")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    ElectricDisplacement = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacement")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    RelativeLuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/RelativeLuminousFlux")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    MeanMassRange = URIRef("http://qudt.org/vocab/quantitykind/MeanMassRange")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    LeakageFactor = URIRef("http://qudt.org/vocab/quantitykind/LeakageFactor")
    MagneticTension = URIRef("http://qudt.org/vocab/quantitykind/MagneticTension")
    DynamicFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DynamicFrictionCoefficient")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    InverseMass_Squared = URIRef("http://qudt.org/vocab/quantitykind/InverseMass_Squared")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    PoyntingVector = URIRef("http://qudt.org/vocab/quantitykind/PoyntingVector")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    VolumeFlowRate_SurfaceRelated = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate_SurfaceRelated")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    MagneticFluxDensityOrMagneticPolarization = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensityOrMagneticPolarization")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    StressOpticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StressOpticCoefficient")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    ElectricChargePerMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerMass")
    MagnetomotiveForce = URIRef("http://qudt.org/vocab/quantitykind/MagnetomotiveForce")
    GroupSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/GroupSpeedOfSound")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    ThermalTransmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalTransmittance")
    IsothermalMoistureCapacity = URIRef("http://qudt.org/vocab/quantitykind/IsothermalMoistureCapacity")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    StaticFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StaticFrictionCoefficient")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    SectionAreaIntegral = URIRef("http://qudt.org/vocab/quantitykind/SectionAreaIntegral")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    PressureBurningRateConstant = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateConstant")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    InfiniteMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/InfiniteMultiplicationFactor")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    Log10FrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/Log10FrequencyInterval")
    AngularReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/AngularReciprocalLatticeVector")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    LuminousEfficacy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEfficacy")
    DoseEquivalent = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalent")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    GeneralizedCoordinate = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedCoordinate")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    ElectricChargePerAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerAmountOfSubstance")
    CyclotronAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/CyclotronAngularFrequency")
    ResistanceRatio = URIRef("http://qudt.org/vocab/quantitykind/ResistanceRatio")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    EnergyPerAreaElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerAreaElectricCharge")
    AngularDistance = URIRef("http://qudt.org/vocab/quantitykind/AngularDistance")
    PressureBurningRateIndex = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateIndex")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    TotalIonization = URIRef("http://qudt.org/vocab/quantitykind/TotalIonization")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    ElectromagneticPermeability = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeability")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    CurrentLinkage = URIRef("http://qudt.org/vocab/quantitykind/CurrentLinkage")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    ElectricDisplacement = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacement")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    LarmorAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/LarmorAngularFrequency")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    SecondPolarMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondPolarMomentOfArea")
    PowerPerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerPerArea")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    SecondMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondMomentOfArea")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    EquilibriumConstantOnPressureBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnPressureBasis")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    SourceVoltageBetweenSubstances = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltageBetweenSubstances")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    TimeTemperature = URIRef("http://qudt.org/vocab/quantitykind/TimeTemperature")
    AmountOfSubstancePerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMass")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    Landau_GinzburgNumber = URIRef("http://qudt.org/vocab/quantitykind/Landau-GinzburgNumber")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    ResonanceEscapeProbabilityForFission = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbabilityForFission")
    MolecularConcentration = URIRef("http://qudt.org/vocab/quantitykind/MolecularConcentration")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    MassRelatedElectricalCurrent = URIRef("http://qudt.org/vocab/quantitykind/MassRelatedElectricalCurrent")
    MaximumExpectedOperatingPressure = URIRef("http://qudt.org/vocab/quantitykind/MaximumExpectedOperatingPressure")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    EffectiveMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMultiplicationFactor")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    ComplexPower = URIRef("http://qudt.org/vocab/quantitykind/ComplexPower")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    QuantityOfLight = URIRef("http://qudt.org/vocab/quantitykind/QuantityOfLight")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    HyperfineStructureQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/HyperfineStructureQuantumNumber")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    MOMENT_OF_INERTIA_Z = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Z")
    TotalAngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentum")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    BioconcentrationFactor = URIRef("http://qudt.org/vocab/quantitykind/BioconcentrationFactor")
    Angle = URIRef("http://qudt.org/vocab/quantitykind/Angle")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    Dimensionless = URIRef("http://qudt.org/vocab/quantitykind/Dimensionless")
    LinearAcceleration = URIRef("http://qudt.org/vocab/quantitykind/LinearAcceleration")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    OlfactoryThreshold = URIRef("http://qudt.org/vocab/quantitykind/OlfactoryThreshold")
    TimeRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRatio")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    SpectralCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralCrossSection")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    MolarOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/MolarOpticalRotatoryPower")
    SoundParticleAcceleration = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleAcceleration")
    DynamicPressure = URIRef("http://qudt.org/vocab/quantitykind/DynamicPressure")
    CurvatureFromRadius = URIRef("http://qudt.org/vocab/quantitykind/CurvatureFromRadius")
    MolarOpticalRotationalAbility = URIRef("http://qudt.org/vocab/quantitykind/MolarOpticalRotationalAbility")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    ChargeNumber = URIRef("http://qudt.org/vocab/quantitykind/ChargeNumber")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    MassPerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerAreaTime")
    EnergyPerTemperature = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerTemperature")
    DonorDensity = URIRef("http://qudt.org/vocab/quantitykind/DonorDensity")
    ReynoldsNumber = URIRef("http://qudt.org/vocab/quantitykind/ReynoldsNumber")
    Dimensionless = URIRef("http://qudt.org/vocab/quantitykind/Dimensionless")
    MolarFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MolarFlowRate")
    MassicPower = URIRef("http://qudt.org/vocab/quantitykind/MassicPower")
    Compressibility = URIRef("http://qudt.org/vocab/quantitykind/Compressibility")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    Compressibility = URIRef("http://qudt.org/vocab/quantitykind/Compressibility")
    Basicity = URIRef("http://qudt.org/vocab/quantitykind/Basicity")
    Gravity_API = URIRef("http://qudt.org/vocab/quantitykind/Gravity_API")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    HoleDensity = URIRef("http://qudt.org/vocab/quantitykind/HoleDensity")
    ThermalUtilizationFactorForFission = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactorForFission")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    SurfaceRelatedVolumeFlow = URIRef("http://qudt.org/vocab/quantitykind/SurfaceRelatedVolumeFlow")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    MassConcentrationOfWater = URIRef("http://qudt.org/vocab/quantitykind/MassConcentrationOfWater")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    NumberDensity = URIRef("http://qudt.org/vocab/quantitykind/NumberDensity")
    EnergyPerMagneticFluxDensity_Squared = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerMagneticFluxDensity_Squared")
    SpecificHeatCapacityAtSaturation = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtSaturation")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    PhotonLuminance = URIRef("http://qudt.org/vocab/quantitykind/PhotonLuminance")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    VisionThresholds = URIRef("http://qudt.org/vocab/quantitykind/VisionThresholds")
    OrbitalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/OrbitalAngularMomentumQuantumNumber")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    LuminousExposure = URIRef("http://qudt.org/vocab/quantitykind/LuminousExposure")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    ThermodynamicCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicCriticalMagneticFluxDensity")
    MagnetomotiveForce = URIRef("http://qudt.org/vocab/quantitykind/MagnetomotiveForce")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    ElectricChargeVolumeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeVolumeDensity")
    IntinsicCarrierDensity = URIRef("http://qudt.org/vocab/quantitykind/IntinsicCarrierDensity")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    ParticleNumberDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleNumberDensity")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    Acidity = URIRef("http://qudt.org/vocab/quantitykind/Acidity")
    RespiratoryRate = URIRef("http://qudt.org/vocab/quantitykind/RespiratoryRate")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    PrincipalQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/PrincipalQuantumNumber")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    AreaAngle = URIRef("http://qudt.org/vocab/quantitykind/AreaAngle")
    SpecificGibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificGibbsEnergy")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    VolumicDataQuantity = URIRef("http://qudt.org/vocab/quantitykind/VolumicDataQuantity")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    MolalityOfSolute = URIRef("http://qudt.org/vocab/quantitykind/MolalityOfSolute")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    DonorDensity = URIRef("http://qudt.org/vocab/quantitykind/DonorDensity")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    Dissipance = URIRef("http://qudt.org/vocab/quantitykind/Dissipance")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    SecondStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SecondStageMassRatio")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    StoichiometricNumber = URIRef("http://qudt.org/vocab/quantitykind/StoichiometricNumber")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    AngleOfAttack = URIRef("http://qudt.org/vocab/quantitykind/AngleOfAttack")
    MassPerLength = URIRef("http://qudt.org/vocab/quantitykind/MassPerLength")
    GeneralizedForce = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedForce")
    SoundParticleVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleVelocity")
    OrbitalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/OrbitalAngularMomentumQuantumNumber")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    NeutronYieldPerAbsorption = URIRef("http://qudt.org/vocab/quantitykind/NeutronYieldPerAbsorption")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    PrincipalQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/PrincipalQuantumNumber")
    ThrustToMassRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToMassRatio")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    ModulusOfSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfSubgradeReaction")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    SpecificHeatCapacityAtConstantVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantVolume")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    VoltagePhasor = URIRef("http://qudt.org/vocab/quantitykind/VoltagePhasor")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    PressureBurningRateConstant = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateConstant")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    SpecificOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificOpticalRotatoryPower")
    FissionFuelUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionFuelUtilizationFactor")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    AreaPerTime = URIRef("http://qudt.org/vocab/quantitykind/AreaPerTime")
    FissionMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionMultiplicationFactor")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    ParticleNumberDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleNumberDensity")
    GrowingDegreeDay_Cereal = URIRef("http://qudt.org/vocab/quantitykind/GrowingDegreeDay_Cereal")
    ElectricFlux = URIRef("http://qudt.org/vocab/quantitykind/ElectricFlux")
    EquivalenceDoseOutput = URIRef("http://qudt.org/vocab/quantitykind/EquivalenceDoseOutput")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    MorbidityRate = URIRef("http://qudt.org/vocab/quantitykind/MorbidityRate")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    Angle = URIRef("http://qudt.org/vocab/quantitykind/Angle")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    Flux = URIRef("http://qudt.org/vocab/quantitykind/Flux")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    SpectralAngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralAngularCrossSection")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    AuxillaryMagneticField = URIRef("http://qudt.org/vocab/quantitykind/AuxillaryMagneticField")
    Admittance = URIRef("http://qudt.org/vocab/quantitykind/Admittance")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    HeatFlowRatePerUnitArea = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRatePerUnitArea")
    ResonanceEscapeProbabilityForFission = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbabilityForFission")
    PressureBasedAmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedAmountOfSubstanceConcentration")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    Vorticity = URIRef("http://qudt.org/vocab/quantitykind/Vorticity")
    PositivePlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PositivePlaneAngle")
    InverseVolume = URIRef("http://qudt.org/vocab/quantitykind/InverseVolume")
    MassFractionOfWater = URIRef("http://qudt.org/vocab/quantitykind/MassFractionOfWater")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    LossFactor = URIRef("http://qudt.org/vocab/quantitykind/LossFactor")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    StandardChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/StandardChemicalPotential")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    MicroCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/MicroCanonicalPartitionFunction")
    ParticleNumberDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleNumberDensity")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    DebyeAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularFrequency")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    MolarFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MolarFlowRate")
    PropagationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PropagationCoefficient")
    EccentricityOfOrbit = URIRef("http://qudt.org/vocab/quantitykind/EccentricityOfOrbit")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    AreaTemperature = URIRef("http://qudt.org/vocab/quantitykind/AreaTemperature")
    InverseTimeTemperature = URIRef("http://qudt.org/vocab/quantitykind/InverseTimeTemperature")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    VolumicAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/VolumicAmountOfSubstance")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    AverageLogarithmicEnergyDecrement = URIRef("http://qudt.org/vocab/quantitykind/AverageLogarithmicEnergyDecrement")
    SignalStrength = URIRef("http://qudt.org/vocab/quantitykind/SignalStrength")
    GustatoryThreshold = URIRef("http://qudt.org/vocab/quantitykind/GustatoryThreshold")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    HeatFlowRatePerUnitArea = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRatePerUnitArea")
    ActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/ActivityConcentration")
    LinearDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearDensity")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    PressureBasedKinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedKinematicViscosity")
    ElectricField = URIRef("http://qudt.org/vocab/quantitykind/ElectricField")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    AcceptorDensity = URIRef("http://qudt.org/vocab/quantitykind/AcceptorDensity")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    VolumeThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/VolumeThermalExpansion")
    AreaPerTime = URIRef("http://qudt.org/vocab/quantitykind/AreaPerTime")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    MicroCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/MicroCanonicalPartitionFunction")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    MadelungConstant = URIRef("http://qudt.org/vocab/quantitykind/MadelungConstant")
    ExposureRate = URIRef("http://qudt.org/vocab/quantitykind/ExposureRate")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    TotalCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrentDensity")
    OsmoticPressure = URIRef("http://qudt.org/vocab/quantitykind/OsmoticPressure")
    CouplingFactor = URIRef("http://qudt.org/vocab/quantitykind/CouplingFactor")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    SpecificInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificInternalEnergy")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    MolarConductivity = URIRef("http://qudt.org/vocab/quantitykind/MolarConductivity")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    MolalityOfSolute = URIRef("http://qudt.org/vocab/quantitykind/MolalityOfSolute")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    LandeGFactor = URIRef("http://qudt.org/vocab/quantitykind/LandeGFactor")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    AbsorbedDose = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDose")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    MassFractionOfWater = URIRef("http://qudt.org/vocab/quantitykind/MassFractionOfWater")
    VaporPermeability = URIRef("http://qudt.org/vocab/quantitykind/VaporPermeability")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    MagneticAreaMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticAreaMoment")
    AmountOfSubstanceConcentrationOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentrationOfB")
    TimeRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRatio")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    SurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceDensity")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    Dissipance = URIRef("http://qudt.org/vocab/quantitykind/Dissipance")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    MagneticDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMoment")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    CurrentLinkage = URIRef("http://qudt.org/vocab/quantitykind/CurrentLinkage")
    TemperatureDifference = URIRef("http://qudt.org/vocab/quantitykind/TemperatureDifference")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    InformationFlowRate = URIRef("http://qudt.org/vocab/quantitykind/InformationFlowRate")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    ByteDataVolume = URIRef("http://qudt.org/vocab/quantitykind/ByteDataVolume")
    Susceptance = URIRef("http://qudt.org/vocab/quantitykind/Susceptance")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    SoundReductionIndex = URIRef("http://qudt.org/vocab/quantitykind/SoundReductionIndex")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    AngleOfOpticalRotation = URIRef("http://qudt.org/vocab/quantitykind/AngleOfOpticalRotation")
    StaticFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StaticFrictionCoefficient")
    EffectiveMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMultiplicationFactor")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    ReynoldsNumber = URIRef("http://qudt.org/vocab/quantitykind/ReynoldsNumber")
    CubicElectricDipoleMomentPerSquareEnergy = URIRef("http://qudt.org/vocab/quantitykind/CubicElectricDipoleMomentPerSquareEnergy")
    TotalLinearStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalLinearStoppingPower")
    ElectricConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectricConductivity")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    AttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AttenuationCoefficient")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    AmountOfSubstanceFractionOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFractionOfB")
    MassAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAttenuationCoefficient")
    SeebeckCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SeebeckCoefficient")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    SpecificInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificInternalEnergy")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    AccelerationOfGravity = URIRef("http://qudt.org/vocab/quantitykind/AccelerationOfGravity")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    LinearDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearDensity")
    MagnetomotiveForce = URIRef("http://qudt.org/vocab/quantitykind/MagnetomotiveForce")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    MortalityRate = URIRef("http://qudt.org/vocab/quantitykind/MortalityRate")
    EquilibriumConstantBasedOnPressure = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantBasedOnPressure")
    VolumeDensityOfCharge = URIRef("http://qudt.org/vocab/quantitykind/VolumeDensityOfCharge")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    PositiveDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/PositiveDimensionlessRatio")
    PRODUCT_OF_INERTIA_Y = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA_Y")
    FissionFuelUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionFuelUtilizationFactor")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    PH = URIRef("http://qudt.org/vocab/quantitykind/PH")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    MassAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/MassAmountOfSubstance")
    AngularDistance = URIRef("http://qudt.org/vocab/quantitykind/AngularDistance")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    MolarThermalCapacity = URIRef("http://qudt.org/vocab/quantitykind/MolarThermalCapacity")
    ChemicalConsumptionPerMass = URIRef("http://qudt.org/vocab/quantitykind/ChemicalConsumptionPerMass")
    MolalityOfSolute = URIRef("http://qudt.org/vocab/quantitykind/MolalityOfSolute")
    KermaRate = URIRef("http://qudt.org/vocab/quantitykind/KermaRate")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    TemperaturePerMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerMagneticFluxDensity")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    CurrentOfTheAmountOfSubtance = URIRef("http://qudt.org/vocab/quantitykind/CurrentOfTheAmountOfSubtance")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    Impulse = URIRef("http://qudt.org/vocab/quantitykind/Impulse")
    AngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/AngularCrossSection")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    IonDensity = URIRef("http://qudt.org/vocab/quantitykind/IonDensity")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    TrafficIntensity = URIRef("http://qudt.org/vocab/quantitykind/TrafficIntensity")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    ElectricChargePerArea = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerArea")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    SpecificActivity = URIRef("http://qudt.org/vocab/quantitykind/SpecificActivity")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    TorquePerAngle = URIRef("http://qudt.org/vocab/quantitykind/TorquePerAngle")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    LengthRatio = URIRef("http://qudt.org/vocab/quantitykind/LengthRatio")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    SingleStageLauncherMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SingleStageLauncherMassRatio")
    BoilingPoint = URIRef("http://qudt.org/vocab/quantitykind/BoilingPoint")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    LarmorAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/LarmorAngularFrequency")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    PolarMomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/PolarMomentOfInertia")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    GasLeakRate = URIRef("http://qudt.org/vocab/quantitykind/GasLeakRate")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    TotalCurrent = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrent")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    Ratio = URIRef("http://qudt.org/vocab/quantitykind/Ratio")
    StaticFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StaticFrictionCoefficient")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    MolarOpticalRotationalAbility = URIRef("http://qudt.org/vocab/quantitykind/MolarOpticalRotationalAbility")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    VolumetricElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/VolumetricElectricCharge")
    PressureBasedQuantity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedQuantity")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    LinearElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrent")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    Unbalance = URIRef("http://qudt.org/vocab/quantitykind/Unbalance")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    ElectricChargeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeDensity")
    BulkModulus = URIRef("http://qudt.org/vocab/quantitykind/BulkModulus")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    EnergyContent = URIRef("http://qudt.org/vocab/quantitykind/EnergyContent")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    AverageLogarithmicEnergyDecrement = URIRef("http://qudt.org/vocab/quantitykind/AverageLogarithmicEnergyDecrement")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    StaticFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StaticFrictionCoefficient")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    PressureBurningRateIndex = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateIndex")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    IncidenceProportion = URIRef("http://qudt.org/vocab/quantitykind/IncidenceProportion")
    PressureBasedAmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedAmountOfSubstanceConcentration")
    Loudness = URIRef("http://qudt.org/vocab/quantitykind/Loudness")
    ThrustCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThrustCoefficient")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    Turns = URIRef("http://qudt.org/vocab/quantitykind/Turns")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    LogarithmicMedianInformationFlow_SourceToBaseE = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicMedianInformationFlow_SourceToBaseE")
    ElectromagneticEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticEnergyDensity")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    MassicActivity = URIRef("http://qudt.org/vocab/quantitykind/MassicActivity")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    TimeSquared = URIRef("http://qudt.org/vocab/quantitykind/TimeSquared")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    ForcePerAngle = URIRef("http://qudt.org/vocab/quantitykind/ForcePerAngle")
    LinearAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAbsorptionCoefficient")
    SeebeckCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SeebeckCoefficient")
    SuperconductionTransitionTemperature = URIRef("http://qudt.org/vocab/quantitykind/SuperconductionTransitionTemperature")
    Duv = URIRef("http://qudt.org/vocab/quantitykind/Duv")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    Mobility = URIRef("http://qudt.org/vocab/quantitykind/Mobility")
    TorsionalSpringConstant = URIRef("http://qudt.org/vocab/quantitykind/TorsionalSpringConstant")
    PackingFraction = URIRef("http://qudt.org/vocab/quantitykind/PackingFraction")
    LinearStiffness = URIRef("http://qudt.org/vocab/quantitykind/LinearStiffness")
    Susceptance = URIRef("http://qudt.org/vocab/quantitykind/Susceptance")
    LuminousExitance = URIRef("http://qudt.org/vocab/quantitykind/LuminousExitance")
    ElectronDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectronDensity")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    BiodegredationHalfLife = URIRef("http://qudt.org/vocab/quantitykind/BiodegredationHalfLife")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    Absorptance = URIRef("http://qudt.org/vocab/quantitykind/Absorptance")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    Coercivity = URIRef("http://qudt.org/vocab/quantitykind/Coercivity")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    NeutronDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionCoefficient")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    EarthquakeMagnitude = URIRef("http://qudt.org/vocab/quantitykind/EarthquakeMagnitude")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    GeneralizedVelocity = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedVelocity")
    FastFissionFactor = URIRef("http://qudt.org/vocab/quantitykind/FastFissionFactor")
    EnergyPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerElectricCharge")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    ConvectiveHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/ConvectiveHeatTransfer")
    GeneralizedCoordinate = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedCoordinate")
    SpecificHelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificHelmholtzEnergy")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    MassPerTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerTime")
    TorqueConstant = URIRef("http://qudt.org/vocab/quantitykind/TorqueConstant")
    LinearDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearDensity")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    MassRatio = URIRef("http://qudt.org/vocab/quantitykind/MassRatio")
    SoundVolumeVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundVolumeVelocity")
    PrincipalQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/PrincipalQuantumNumber")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    TrafficIntensity = URIRef("http://qudt.org/vocab/quantitykind/TrafficIntensity")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    AmountOfSubstancePerUnitVolume = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitVolume")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    ReciprocalElectricResistance = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalElectricResistance")
    MassFractionOfDryMatter = URIRef("http://qudt.org/vocab/quantitykind/MassFractionOfDryMatter")
    ChemicalAffinity = URIRef("http://qudt.org/vocab/quantitykind/ChemicalAffinity")
    StandardGravitationalParameter = URIRef("http://qudt.org/vocab/quantitykind/StandardGravitationalParameter")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    NumberOfParticles = URIRef("http://qudt.org/vocab/quantitykind/NumberOfParticles")
    EinsteinCoefficients = URIRef("http://qudt.org/vocab/quantitykind/EinsteinCoefficients")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    InternalConversionFactor = URIRef("http://qudt.org/vocab/quantitykind/InternalConversionFactor")
    TemperaturePerTime = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime")
    MagnetomotiveForce = URIRef("http://qudt.org/vocab/quantitykind/MagnetomotiveForce")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    ThermalUtilizationFactorForFission = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactorForFission")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    ElectronDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectronDensity")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    PressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PressureCoefficient")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    VolumetricHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/VolumetricHeatCapacity")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    TemperatureDifference = URIRef("http://qudt.org/vocab/quantitykind/TemperatureDifference")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    Action = URIRef("http://qudt.org/vocab/quantitykind/Action")
    AtomicStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/AtomicStoppingPower")
    StandardAbsoluteActivity = URIRef("http://qudt.org/vocab/quantitykind/StandardAbsoluteActivity")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    HoleDensity = URIRef("http://qudt.org/vocab/quantitykind/HoleDensity")
    ParticleSourceDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleSourceDensity")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    AtmosphericPressure = URIRef("http://qudt.org/vocab/quantitykind/AtmosphericPressure")
    TemperatureBasedMass = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedMass")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    Prevalence = URIRef("http://qudt.org/vocab/quantitykind/Prevalence")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    KineticOrThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticOrThermalEnergy")
    UpperCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/UpperCriticalMagneticFluxDensity")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    LinearForce = URIRef("http://qudt.org/vocab/quantitykind/LinearForce")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    ExtentOfReaction = URIRef("http://qudt.org/vocab/quantitykind/ExtentOfReaction")
    Time_Squared = URIRef("http://qudt.org/vocab/quantitykind/Time_Squared")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    SpectralConcentrationOfRadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SpectralConcentrationOfRadiantEnergyDensity")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    BoilingPoint = URIRef("http://qudt.org/vocab/quantitykind/BoilingPoint")
    LinearIonization = URIRef("http://qudt.org/vocab/quantitykind/LinearIonization")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    PressureBasedVelocity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedVelocity")
    SpecificThrust = URIRef("http://qudt.org/vocab/quantitykind/SpecificThrust")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    ThrustToWeightRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToWeightRatio")
    PressureBasedMassFlow = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedMassFlow")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    EquilibriumConstantOnPressureBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnPressureBasis")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    BevelGearPitchAngle = URIRef("http://qudt.org/vocab/quantitykind/BevelGearPitchAngle")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    AngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentum")
    LineicResistance = URIRef("http://qudt.org/vocab/quantitykind/LineicResistance")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    SeebeckCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SeebeckCoefficient")
    StandardGravitationalParameter = URIRef("http://qudt.org/vocab/quantitykind/StandardGravitationalParameter")
    SectionModulus = URIRef("http://qudt.org/vocab/quantitykind/SectionModulus")
    MassAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAttenuationCoefficient")
    MassNumber = URIRef("http://qudt.org/vocab/quantitykind/MassNumber")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    MolarEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarEnergy")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    TemperatureBasedDensity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedDensity")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    ThermodynamicCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicCriticalMagneticFluxDensity")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    TemperaturePerTime = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    InternalConversionFactor = URIRef("http://qudt.org/vocab/quantitykind/InternalConversionFactor")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    Short_RangeOrderParameter = URIRef("http://qudt.org/vocab/quantitykind/Short-RangeOrderParameter")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    MassPerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerAreaTime")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    PayloadRatio = URIRef("http://qudt.org/vocab/quantitykind/PayloadRatio")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    SoundExposure = URIRef("http://qudt.org/vocab/quantitykind/SoundExposure")
    MolarHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MolarHeatCapacity")
    Rotary_TranslatoryMotionConversion = URIRef("http://qudt.org/vocab/quantitykind/Rotary-TranslatoryMotionConversion")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    ElectricChargePerMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerMass")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    CorrelatedColorTemperature = URIRef("http://qudt.org/vocab/quantitykind/CorrelatedColorTemperature")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    LorenzCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LorenzCoefficient")
    Circulation = URIRef("http://qudt.org/vocab/quantitykind/Circulation")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    SpecificHeatsRatio = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatsRatio")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    PropagationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PropagationCoefficient")
    DryVolume = URIRef("http://qudt.org/vocab/quantitykind/DryVolume")
    RecombinationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/RecombinationCoefficient")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    HamiltonFunction = URIRef("http://qudt.org/vocab/quantitykind/HamiltonFunction")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    ParticleFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluenceRate")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    SoundReductionIndex = URIRef("http://qudt.org/vocab/quantitykind/SoundReductionIndex")
    Emissivity = URIRef("http://qudt.org/vocab/quantitykind/Emissivity")
    PermittivityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermittivityRatio")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    DebyeAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularFrequency")
    QuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/QuantumNumber")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    PowerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerArea")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    SourceVoltageBetweenSubstances = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltageBetweenSubstances")
    LinearElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrentDensity")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    Impedance = URIRef("http://qudt.org/vocab/quantitykind/Impedance")
    AcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/AcousticImpedance")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    ChemicalAffinity = URIRef("http://qudt.org/vocab/quantitykind/ChemicalAffinity")
    LineicTorque = URIRef("http://qudt.org/vocab/quantitykind/LineicTorque")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    StructuralEfficiency = URIRef("http://qudt.org/vocab/quantitykind/StructuralEfficiency")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    InverseTimeTemperature = URIRef("http://qudt.org/vocab/quantitykind/InverseTimeTemperature")
    StressIntensityFactor = URIRef("http://qudt.org/vocab/quantitykind/StressIntensityFactor")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    ThrustToWeightRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToWeightRatio")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    QuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/QuantumNumber")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    AttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AttenuationCoefficient")
    ForcePerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/ForcePerAreaTime")
    SpecificThrust = URIRef("http://qudt.org/vocab/quantitykind/SpecificThrust")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    PH = URIRef("http://qudt.org/vocab/quantitykind/PH")
    Period = URIRef("http://qudt.org/vocab/quantitykind/Period")
    Chromaticity = URIRef("http://qudt.org/vocab/quantitykind/Chromaticity")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    SingleStageLauncherMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SingleStageLauncherMassRatio")
    Duv = URIRef("http://qudt.org/vocab/quantitykind/Duv")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    LagrangeFunction = URIRef("http://qudt.org/vocab/quantitykind/LagrangeFunction")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    AreaPerTime = URIRef("http://qudt.org/vocab/quantitykind/AreaPerTime")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    SoundPressure = URIRef("http://qudt.org/vocab/quantitykind/SoundPressure")
    ChargeNumber = URIRef("http://qudt.org/vocab/quantitykind/ChargeNumber")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    OlfactoryThreshold = URIRef("http://qudt.org/vocab/quantitykind/OlfactoryThreshold")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    StateDensityAsExpressionOfAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/StateDensityAsExpressionOfAngularFrequency")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    TotalIonization = URIRef("http://qudt.org/vocab/quantitykind/TotalIonization")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    MolecularConcentration = URIRef("http://qudt.org/vocab/quantitykind/MolecularConcentration")
    InfiniteMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/InfiniteMultiplicationFactor")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    PhaseCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PhaseCoefficient")
    SoundPowerLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPowerLevel")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    BevelGearPitchAngle = URIRef("http://qudt.org/vocab/quantitykind/BevelGearPitchAngle")
    EquivalenceDoseOutput = URIRef("http://qudt.org/vocab/quantitykind/EquivalenceDoseOutput")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    MechanicalSurfaceImpedance = URIRef("http://qudt.org/vocab/quantitykind/MechanicalSurfaceImpedance")
    ElectricCurrentPhasor = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPhasor")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    MobilityRatio = URIRef("http://qudt.org/vocab/quantitykind/MobilityRatio")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    UpperCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/UpperCriticalMagneticFluxDensity")
    MolarOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/MolarOpticalRotatoryPower")
    EquilibriumConstantOnConcentrationBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnConcentrationBasis")
    StaticFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StaticFrictionCoefficient")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    IonicStrength = URIRef("http://qudt.org/vocab/quantitykind/IonicStrength")
    AverageHeadEndPressure = URIRef("http://qudt.org/vocab/quantitykind/AverageHeadEndPressure")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    PositivePlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PositivePlaneAngle")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    TemperatureBasedVelocity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedVelocity")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    ModulusOfImpedance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfImpedance")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    MassConcentrationOfWaterVapour = URIRef("http://qudt.org/vocab/quantitykind/MassConcentrationOfWaterVapour")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    LinearElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrent")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    Compressibility = URIRef("http://qudt.org/vocab/quantitykind/Compressibility")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    VolumeFlowRate_SurfaceRelated = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate_SurfaceRelated")
    ElectricConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectricConductivity")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    LogarithmicFrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyInterval")
    AreaPerTime = URIRef("http://qudt.org/vocab/quantitykind/AreaPerTime")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    CatalyticActivity = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivity")
    LengthRatio = URIRef("http://qudt.org/vocab/quantitykind/LengthRatio")
    MolarOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/MolarOpticalRotatoryPower")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    Count = URIRef("http://qudt.org/vocab/quantitykind/Count")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    MolarRefractivity = URIRef("http://qudt.org/vocab/quantitykind/MolarRefractivity")
    EnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensity")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    ExposureRate = URIRef("http://qudt.org/vocab/quantitykind/ExposureRate")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    MassConcentration = URIRef("http://qudt.org/vocab/quantitykind/MassConcentration")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    SpecificElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/SpecificElectricCurrent")
    ThermalInsulance = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulance")
    RelativeMassExcess = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassExcess")
    SourceVoltage = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltage")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    Reluctance = URIRef("http://qudt.org/vocab/quantitykind/Reluctance")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    MassAmountOfSubstanceTemperature = URIRef("http://qudt.org/vocab/quantitykind/MassAmountOfSubstanceTemperature")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    ParticleNumberDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleNumberDensity")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    MassPerLength = URIRef("http://qudt.org/vocab/quantitykind/MassPerLength")
    SourceVoltageBetweenSubstances = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltageBetweenSubstances")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    LengthPerUnitElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/LengthPerUnitElectricCurrent")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    ExhaustGasesSpecificHeat = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasesSpecificHeat")
    AngleOfAttack = URIRef("http://qudt.org/vocab/quantitykind/AngleOfAttack")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    TemperatureRateOfChange = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRateOfChange")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    MechanicalImpedance = URIRef("http://qudt.org/vocab/quantitykind/MechanicalImpedance")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    NuclearQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/NuclearQuadrupoleMoment")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    Resistivity = URIRef("http://qudt.org/vocab/quantitykind/Resistivity")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    ElectricChargePerAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerAmountOfSubstance")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    Capacity = URIRef("http://qudt.org/vocab/quantitykind/Capacity")
    AreaThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/AreaThermalExpansion")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    LuminousEnergy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEnergy")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    ThermalExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalExpansionCoefficient")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    DistanceTraveledDuringBurn = URIRef("http://qudt.org/vocab/quantitykind/DistanceTraveledDuringBurn")
    ElectricChargePerMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerMass")
    MadelungConstant = URIRef("http://qudt.org/vocab/quantitykind/MadelungConstant")
    MorbidityRate = URIRef("http://qudt.org/vocab/quantitykind/MorbidityRate")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    Compressibility = URIRef("http://qudt.org/vocab/quantitykind/Compressibility")
    Unbalance = URIRef("http://qudt.org/vocab/quantitykind/Unbalance")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    MagneticFluxDensityOrMagneticPolarization = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensityOrMagneticPolarization")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    RadiantIntensity = URIRef("http://qudt.org/vocab/quantitykind/RadiantIntensity")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    Susceptance = URIRef("http://qudt.org/vocab/quantitykind/Susceptance")
    Ratio = URIRef("http://qudt.org/vocab/quantitykind/Ratio")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    Angle = URIRef("http://qudt.org/vocab/quantitykind/Angle")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    LossAngle = URIRef("http://qudt.org/vocab/quantitykind/LossAngle")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    PressureBurningRateConstant = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateConstant")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    LossAngle = URIRef("http://qudt.org/vocab/quantitykind/LossAngle")
    DegreeOfDissociation = URIRef("http://qudt.org/vocab/quantitykind/DegreeOfDissociation")
    ReynoldsNumber = URIRef("http://qudt.org/vocab/quantitykind/ReynoldsNumber")
    BulkModulus = URIRef("http://qudt.org/vocab/quantitykind/BulkModulus")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    FissionMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionMultiplicationFactor")
    DimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/DimensionlessRatio")
    CyclotronAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/CyclotronAngularFrequency")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    MOMENT_OF_INERTIA_Y = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Y")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    LuminousExposure = URIRef("http://qudt.org/vocab/quantitykind/LuminousExposure")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    Angle = URIRef("http://qudt.org/vocab/quantitykind/Angle")
    MassicHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MassicHeatCapacity")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    InverseEnergy_Squared = URIRef("http://qudt.org/vocab/quantitykind/InverseEnergy_Squared")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    CorrelatedColorTemperature = URIRef("http://qudt.org/vocab/quantitykind/CorrelatedColorTemperature")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    TotalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentumQuantumNumber")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    Radioactivity = URIRef("http://qudt.org/vocab/quantitykind/Radioactivity")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    SpecificImpulse = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulse")
    TimeTemperature = URIRef("http://qudt.org/vocab/quantitykind/TimeTemperature")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    ConductiveHeatTransferRate = URIRef("http://qudt.org/vocab/quantitykind/ConductiveHeatTransferRate")
    LandeGFactor = URIRef("http://qudt.org/vocab/quantitykind/LandeGFactor")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    ThrustToMassRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToMassRatio")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    AreaMass = URIRef("http://qudt.org/vocab/quantitykind/AreaMass")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    VideoFrameRate = URIRef("http://qudt.org/vocab/quantitykind/VideoFrameRate")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    Reflectance = URIRef("http://qudt.org/vocab/quantitykind/Reflectance")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    MassPerTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerTime")
    MolecularConcentration = URIRef("http://qudt.org/vocab/quantitykind/MolecularConcentration")
    AmountOfSubstancePerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMass")
    DonorDensity = URIRef("http://qudt.org/vocab/quantitykind/DonorDensity")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    MagneticAreaMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticAreaMoment")
    LoudnessLevel = URIRef("http://qudt.org/vocab/quantitykind/LoudnessLevel")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    ElectromagneticPermeability = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeability")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    RelativePartialPressure = URIRef("http://qudt.org/vocab/quantitykind/RelativePartialPressure")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    LinearAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAttenuationCoefficient")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    TotalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentumQuantumNumber")
    StateDensityAsExpressionOfAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/StateDensityAsExpressionOfAngularFrequency")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    NeutronYieldPerAbsorption = URIRef("http://qudt.org/vocab/quantitykind/NeutronYieldPerAbsorption")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    DebyeAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularFrequency")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    MultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/MultiplicationFactor")
    RankineTemperature = URIRef("http://qudt.org/vocab/quantitykind/RankineTemperature")
    AverageHeadEndPressure = URIRef("http://qudt.org/vocab/quantitykind/AverageHeadEndPressure")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    AcceptorDensity = URIRef("http://qudt.org/vocab/quantitykind/AcceptorDensity")
    ResonanceEscapeProbabilityForFission = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbabilityForFission")
    SpecificHeatVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatVolume")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    CostPerArea = URIRef("http://qudt.org/vocab/quantitykind/CostPerArea")
    SpecificEntropy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEntropy")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    RadiantFluence = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluence")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    DisplacementCurrent = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrent")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    MolecularMass = URIRef("http://qudt.org/vocab/quantitykind/MolecularMass")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    NeutronDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionCoefficient")
    RelativeLuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/RelativeLuminousFlux")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    ModulusOfAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfAdmittance")
    NeutronDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionCoefficient")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    VolumetricHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/VolumetricHeatCapacity")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    ComplexFrequency_Real = URIRef("http://qudt.org/vocab/quantitykind/ComplexFrequency_Real")
    LinearMomentum = URIRef("http://qudt.org/vocab/quantitykind/LinearMomentum")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    GrowingDegreeDay_Cereal = URIRef("http://qudt.org/vocab/quantitykind/GrowingDegreeDay_Cereal")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    InformationContent = URIRef("http://qudt.org/vocab/quantitykind/InformationContent")
    ElectromagneticWavePhaseSpeed = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticWavePhaseSpeed")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    Coercivity = URIRef("http://qudt.org/vocab/quantitykind/Coercivity")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    Permittivity = URIRef("http://qudt.org/vocab/quantitykind/Permittivity")
    VoltageRatio = URIRef("http://qudt.org/vocab/quantitykind/VoltageRatio")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    SuperconductionTransitionTemperature = URIRef("http://qudt.org/vocab/quantitykind/SuperconductionTransitionTemperature")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    PressureBurningRateIndex = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateIndex")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    HeadEndPressure = URIRef("http://qudt.org/vocab/quantitykind/HeadEndPressure")
    SpecificWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificWeight")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    Debye_WallerFactor = URIRef("http://qudt.org/vocab/quantitykind/Debye-WallerFactor")
    ResidualResistivity = URIRef("http://qudt.org/vocab/quantitykind/ResidualResistivity")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    MassicHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MassicHeatCapacity")
    EnergyExpenditure = URIRef("http://qudt.org/vocab/quantitykind/EnergyExpenditure")
    VentilationRatePerFloorArea = URIRef("http://qudt.org/vocab/quantitykind/VentilationRatePerFloorArea")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    SpectralAngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralAngularCrossSection")
    Gravity_API = URIRef("http://qudt.org/vocab/quantitykind/Gravity_API")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    ElectricCurrentPerUnitTemperature = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerUnitTemperature")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    ForcePerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ForcePerElectricCharge")
    MagneticDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMoment")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    RelativeHumidity = URIRef("http://qudt.org/vocab/quantitykind/RelativeHumidity")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    DiastolicBloodPressure = URIRef("http://qudt.org/vocab/quantitykind/DiastolicBloodPressure")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    SoundPressure = URIRef("http://qudt.org/vocab/quantitykind/SoundPressure")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    HenrysLawVolatilityConstant = URIRef("http://qudt.org/vocab/quantitykind/HenrysLawVolatilityConstant")
    ElectricQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricQuadrupoleMoment")
    ThrustToWeightRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToWeightRatio")
    ThermalUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactor")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    SoundEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SoundEnergyDensity")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    HenrysLawVolatilityConstant = URIRef("http://qudt.org/vocab/quantitykind/HenrysLawVolatilityConstant")
    RecombinationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/RecombinationCoefficient")
    FirstStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/FirstStageMassRatio")
    LineicResolution = URIRef("http://qudt.org/vocab/quantitykind/LineicResolution")
    Flux = URIRef("http://qudt.org/vocab/quantitykind/Flux")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    AmbientPressure = URIRef("http://qudt.org/vocab/quantitykind/AmbientPressure")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    ElectricField = URIRef("http://qudt.org/vocab/quantitykind/ElectricField")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    DataRate = URIRef("http://qudt.org/vocab/quantitykind/DataRate")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    LineicMass = URIRef("http://qudt.org/vocab/quantitykind/LineicMass")
    Reflectivity = URIRef("http://qudt.org/vocab/quantitykind/Reflectivity")
    MeltingPoint = URIRef("http://qudt.org/vocab/quantitykind/MeltingPoint")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    TemperatureDifference = URIRef("http://qudt.org/vocab/quantitykind/TemperatureDifference")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    FrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/FrictionCoefficient")
    Non_LeakageProbability = URIRef("http://qudt.org/vocab/quantitykind/Non-LeakageProbability")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    HallCoefficient = URIRef("http://qudt.org/vocab/quantitykind/HallCoefficient")
    EquilibriumConstantBasedOnConcentration = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantBasedOnConcentration")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    PressureBasedDensity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedDensity")
    TimeRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRatio")
    VolumetricHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/VolumetricHeatCapacity")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    AngleOfOpticalRotation = URIRef("http://qudt.org/vocab/quantitykind/AngleOfOpticalRotation")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    PressureBasedElectricVoltage = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedElectricVoltage")
    MagneticDipoleMomentOfAMolecule = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMomentOfAMolecule")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    InformationContentExpressedAsALogarithmToBase10 = URIRef("http://qudt.org/vocab/quantitykind/InformationContentExpressedAsALogarithmToBase10")
    TorquePerAngle = URIRef("http://qudt.org/vocab/quantitykind/TorquePerAngle")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    MolarHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MolarHeatCapacity")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    LossFactor = URIRef("http://qudt.org/vocab/quantitykind/LossFactor")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    DynamicFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DynamicFrictionCoefficient")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    MassPerEnergy = URIRef("http://qudt.org/vocab/quantitykind/MassPerEnergy")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    ExposureRateOfIonizingRadiation = URIRef("http://qudt.org/vocab/quantitykind/ExposureRateOfIonizingRadiation")
    LineicResistance = URIRef("http://qudt.org/vocab/quantitykind/LineicResistance")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    AreaAngle = URIRef("http://qudt.org/vocab/quantitykind/AreaAngle")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    SoundParticleAcceleration = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleAcceleration")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    VolumeThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/VolumeThermalExpansion")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    MechanicalSurfaceImpedance = URIRef("http://qudt.org/vocab/quantitykind/MechanicalSurfaceImpedance")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    SoundEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SoundEnergyDensity")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    LinearStiffness = URIRef("http://qudt.org/vocab/quantitykind/LinearStiffness")
    SoilAdsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SoilAdsorptionCoefficient")
    SphericalIlluminance = URIRef("http://qudt.org/vocab/quantitykind/SphericalIlluminance")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    MolarEntropy = URIRef("http://qudt.org/vocab/quantitykind/MolarEntropy")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    Loudness = URIRef("http://qudt.org/vocab/quantitykind/Loudness")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    InversePressure = URIRef("http://qudt.org/vocab/quantitykind/InversePressure")
    ResistanceBasedInductance = URIRef("http://qudt.org/vocab/quantitykind/ResistanceBasedInductance")
    BulkModulus = URIRef("http://qudt.org/vocab/quantitykind/BulkModulus")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    ExhaustGasMeanMolecularWeight = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasMeanMolecularWeight")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    LogarithmRatioToBase10 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmRatioToBase10")
    MolarAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAbsorptionCoefficient")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    TotalPressure = URIRef("http://qudt.org/vocab/quantitykind/TotalPressure")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    PhaseSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/PhaseSpeedOfSound")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    EinsteinTransitionProbabilityForSpontaneousOrInducedEmissionAndAbsorption = URIRef("http://qudt.org/vocab/quantitykind/EinsteinTransitionProbabilityForSpontaneousOrInducedEmissionAndAbsorption")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    ComplexPower = URIRef("http://qudt.org/vocab/quantitykind/ComplexPower")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    PRODUCT_OF_INERTIA = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    ScalarMagneticPotential = URIRef("http://qudt.org/vocab/quantitykind/ScalarMagneticPotential")
    CutoffCurrentRating = URIRef("http://qudt.org/vocab/quantitykind/CutoffCurrentRating")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    PressureInRelationToVolumeFlow = URIRef("http://qudt.org/vocab/quantitykind/PressureInRelationToVolumeFlow")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    BindingFraction = URIRef("http://qudt.org/vocab/quantitykind/BindingFraction")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    SuperconductionTransitionTemperature = URIRef("http://qudt.org/vocab/quantitykind/SuperconductionTransitionTemperature")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    TemperatureAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/TemperatureAmountOfSubstance")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    LinearAcceleration = URIRef("http://qudt.org/vocab/quantitykind/LinearAcceleration")
    TotalMassStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalMassStoppingPower")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    UpperCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/UpperCriticalMagneticFluxDensity")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    InitialExpansionRatio = URIRef("http://qudt.org/vocab/quantitykind/InitialExpansionRatio")
    TimeRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRatio")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    LengthRatio = URIRef("http://qudt.org/vocab/quantitykind/LengthRatio")
    ExposureRate = URIRef("http://qudt.org/vocab/quantitykind/ExposureRate")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    OrbitalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/OrbitalAngularMomentumQuantumNumber")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    Conductance = URIRef("http://qudt.org/vocab/quantitykind/Conductance")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    ScalarMagneticPotential = URIRef("http://qudt.org/vocab/quantitykind/ScalarMagneticPotential")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    LogarithmicMedianInformationFlow_SourceToBase2 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicMedianInformationFlow_SourceToBase2")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    Viscosity = URIRef("http://qudt.org/vocab/quantitykind/Viscosity")
    TemperaturePerTime_Squared = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime_Squared")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    ThermalInsulation = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulation")
    ThermalDiffusionRatio = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionRatio")
    MutualInductance = URIRef("http://qudt.org/vocab/quantitykind/MutualInductance")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    LinearMass = URIRef("http://qudt.org/vocab/quantitykind/LinearMass")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    MobilityRatio = URIRef("http://qudt.org/vocab/quantitykind/MobilityRatio")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    SpecificHelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificHelmholtzEnergy")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    EquivalenceDoseOutput = URIRef("http://qudt.org/vocab/quantitykind/EquivalenceDoseOutput")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    MassieuFunction = URIRef("http://qudt.org/vocab/quantitykind/MassieuFunction")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    VolumetricEntityDensity = URIRef("http://qudt.org/vocab/quantitykind/VolumetricEntityDensity")
    AbsorbedDoseRate = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDoseRate")
    OlfactoryThreshold = URIRef("http://qudt.org/vocab/quantitykind/OlfactoryThreshold")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    ElectricChargeLinearDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeLinearDensity")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    FrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/FrictionCoefficient")
    Population = URIRef("http://qudt.org/vocab/quantitykind/Population")
    SoundPowerLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPowerLevel")
    AngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/AngularCrossSection")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    ThermalDiffusionRatio = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionRatio")
    SuperconductionTransitionTemperature = URIRef("http://qudt.org/vocab/quantitykind/SuperconductionTransitionTemperature")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    Gravity_API = URIRef("http://qudt.org/vocab/quantitykind/Gravity_API")
    LinearForce = URIRef("http://qudt.org/vocab/quantitykind/LinearForce")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    LineicDataVolume = URIRef("http://qudt.org/vocab/quantitykind/LineicDataVolume")
    FishBiotransformationHalfLife = URIRef("http://qudt.org/vocab/quantitykind/FishBiotransformationHalfLife")
    ThermodynamicCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicCriticalMagneticFluxDensity")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    LuminousEfficacy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEfficacy")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    TimeSquared = URIRef("http://qudt.org/vocab/quantitykind/TimeSquared")
    VolumicDataQuantity = URIRef("http://qudt.org/vocab/quantitykind/VolumicDataQuantity")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    Turns = URIRef("http://qudt.org/vocab/quantitykind/Turns")
    ModulusOfAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfAdmittance")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    ElectromagneticEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticEnergyDensity")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    MassPerTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerTime")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    LinearElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrent")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    RichardsonConstant = URIRef("http://qudt.org/vocab/quantitykind/RichardsonConstant")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    ActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/ActivityConcentration")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    PackingFraction = URIRef("http://qudt.org/vocab/quantitykind/PackingFraction")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    HeatFlowRatePerUnitArea = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRatePerUnitArea")
    LinearAcceleration = URIRef("http://qudt.org/vocab/quantitykind/LinearAcceleration")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    LinearLogarithmicRatio = URIRef("http://qudt.org/vocab/quantitykind/LinearLogarithmicRatio")
    EnergyContent = URIRef("http://qudt.org/vocab/quantitykind/EnergyContent")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    SphericalIlluminance = URIRef("http://qudt.org/vocab/quantitykind/SphericalIlluminance")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    RelativeLuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/RelativeLuminousFlux")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    EvaporativeHeatTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/EvaporativeHeatTransferCoefficient")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    Permittivity = URIRef("http://qudt.org/vocab/quantitykind/Permittivity")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    ElectromagneticWavePhaseSpeed = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticWavePhaseSpeed")
    DisplacementCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrentDensity")
    AbsoluteActivity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteActivity")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    AmountOfBiologicallyActiveSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfBiologicallyActiveSubstance")
    Adaptation = URIRef("http://qudt.org/vocab/quantitykind/Adaptation")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    Curvature = URIRef("http://qudt.org/vocab/quantitykind/Curvature")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    DegreeOfDissociation = URIRef("http://qudt.org/vocab/quantitykind/DegreeOfDissociation")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    MotorConstant = URIRef("http://qudt.org/vocab/quantitykind/MotorConstant")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    MolarAngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/MolarAngularMomentum")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    DatasetOfBytes = URIRef("http://qudt.org/vocab/quantitykind/DatasetOfBytes")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    EinsteinTransitionProbabilityForSpontaneousOrInducedEmissionAndAbsorption = URIRef("http://qudt.org/vocab/quantitykind/EinsteinTransitionProbabilityForSpontaneousOrInducedEmissionAndAbsorption")
    AngularReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/AngularReciprocalLatticeVector")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    DewPointTemperature = URIRef("http://qudt.org/vocab/quantitykind/DewPointTemperature")
    QuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/QuantumNumber")
    MassRatioOfWaterToDryMatter = URIRef("http://qudt.org/vocab/quantitykind/MassRatioOfWaterToDryMatter")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    ElectricField = URIRef("http://qudt.org/vocab/quantitykind/ElectricField")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    Flux = URIRef("http://qudt.org/vocab/quantitykind/Flux")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    MassRelatedElectricalCurrent = URIRef("http://qudt.org/vocab/quantitykind/MassRelatedElectricalCurrent")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    RotationalMass = URIRef("http://qudt.org/vocab/quantitykind/RotationalMass")
    LinearIonization = URIRef("http://qudt.org/vocab/quantitykind/LinearIonization")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    AtomicNumber = URIRef("http://qudt.org/vocab/quantitykind/AtomicNumber")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    MassFractionOfDryMatter = URIRef("http://qudt.org/vocab/quantitykind/MassFractionOfDryMatter")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    MassPerTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerTime")
    RadiantFluence = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluence")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    ActivityCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ActivityCoefficient")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    SoundVolumeVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundVolumeVelocity")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    Circulation = URIRef("http://qudt.org/vocab/quantitykind/Circulation")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    TimeSquared = URIRef("http://qudt.org/vocab/quantitykind/TimeSquared")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    Mobility = URIRef("http://qudt.org/vocab/quantitykind/Mobility")
    ExchangeIntegral = URIRef("http://qudt.org/vocab/quantitykind/ExchangeIntegral")
    AverageHeadEndPressure = URIRef("http://qudt.org/vocab/quantitykind/AverageHeadEndPressure")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    ExhaustGasesSpecificHeat = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasesSpecificHeat")
    MagneticPolarization = URIRef("http://qudt.org/vocab/quantitykind/MagneticPolarization")
    Admittance = URIRef("http://qudt.org/vocab/quantitykind/Admittance")
    AtmosphericHydroxylationRate = URIRef("http://qudt.org/vocab/quantitykind/AtmosphericHydroxylationRate")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    DonorDensity = URIRef("http://qudt.org/vocab/quantitykind/DonorDensity")
    AreicMass = URIRef("http://qudt.org/vocab/quantitykind/AreicMass")
    PressureInRelationToVolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/PressureInRelationToVolumeFlowRate")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    IonDensity = URIRef("http://qudt.org/vocab/quantitykind/IonDensity")
    SpecificVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificVolume")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    ElectricCurrentPerUnitTemperature = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerUnitTemperature")
    IonTransportNumber = URIRef("http://qudt.org/vocab/quantitykind/IonTransportNumber")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    Reluctance = URIRef("http://qudt.org/vocab/quantitykind/Reluctance")
    ElectronMobility = URIRef("http://qudt.org/vocab/quantitykind/ElectronMobility")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    OsmoticPressure = URIRef("http://qudt.org/vocab/quantitykind/OsmoticPressure")
    StructuralEfficiency = URIRef("http://qudt.org/vocab/quantitykind/StructuralEfficiency")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    Count = URIRef("http://qudt.org/vocab/quantitykind/Count")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    TemperatureRateOfChange = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRateOfChange")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    SignalDetectionThreshold = URIRef("http://qudt.org/vocab/quantitykind/SignalDetectionThreshold")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    SingleStageLauncherMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SingleStageLauncherMassRatio")
    LineicResolution = URIRef("http://qudt.org/vocab/quantitykind/LineicResolution")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    MolarEntropy = URIRef("http://qudt.org/vocab/quantitykind/MolarEntropy")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    Reluctance = URIRef("http://qudt.org/vocab/quantitykind/Reluctance")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    LuminousEnergy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEnergy")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    SoundExposureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundExposureLevel")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    Action = URIRef("http://qudt.org/vocab/quantitykind/Action")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    ForcePerAngle = URIRef("http://qudt.org/vocab/quantitykind/ForcePerAngle")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    SoundEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SoundEnergyDensity")
    SpecificActivity = URIRef("http://qudt.org/vocab/quantitykind/SpecificActivity")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    IonTransportNumber = URIRef("http://qudt.org/vocab/quantitykind/IonTransportNumber")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    MolarAngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/MolarAngularMomentum")
    MagneticField = URIRef("http://qudt.org/vocab/quantitykind/MagneticField")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    FrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/FrictionCoefficient")
    StatisticalWeight = URIRef("http://qudt.org/vocab/quantitykind/StatisticalWeight")
    ModulusOfRotationalSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfRotationalSubgradeReaction")
    FirstStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/FirstStageMassRatio")
    Log10FrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/Log10FrequencyInterval")
    VolumeThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/VolumeThermalExpansion")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    ModulusOfAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfAdmittance")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    IntinsicCarrierDensity = URIRef("http://qudt.org/vocab/quantitykind/IntinsicCarrierDensity")
    BucklingFactor = URIRef("http://qudt.org/vocab/quantitykind/BucklingFactor")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    BitTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/BitTransmissionRate")
    Long_RangeOrderParameter = URIRef("http://qudt.org/vocab/quantitykind/Long-RangeOrderParameter")
    LengthTemperature = URIRef("http://qudt.org/vocab/quantitykind/LengthTemperature")
    CyclotronAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/CyclotronAngularFrequency")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    RichardsonConstant = URIRef("http://qudt.org/vocab/quantitykind/RichardsonConstant")
    AngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/AngularCrossSection")
    ModulusOfSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfSubgradeReaction")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    Short_RangeOrderParameter = URIRef("http://qudt.org/vocab/quantitykind/Short-RangeOrderParameter")
    EnergyPerSquareMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerSquareMagneticFluxDensity")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    Reflectivity = URIRef("http://qudt.org/vocab/quantitykind/Reflectivity")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    PayloadRatio = URIRef("http://qudt.org/vocab/quantitykind/PayloadRatio")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    RotationalStiffness = URIRef("http://qudt.org/vocab/quantitykind/RotationalStiffness")
    InversePressure = URIRef("http://qudt.org/vocab/quantitykind/InversePressure")
    LarmorAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/LarmorAngularFrequency")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    PressureBurningRateIndex = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateIndex")
    RadianceFactor = URIRef("http://qudt.org/vocab/quantitykind/RadianceFactor")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    LinearLogarithmicRatio = URIRef("http://qudt.org/vocab/quantitykind/LinearLogarithmicRatio")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    HeatFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/HeatFluxDensity")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    CostPerUnitPower = URIRef("http://qudt.org/vocab/quantitykind/CostPerUnitPower")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    ThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusivity")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    RF_Power = URIRef("http://qudt.org/vocab/quantitykind/RF-Power")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    Acidity = URIRef("http://qudt.org/vocab/quantitykind/Acidity")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    MassPerTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerTime")
    InverseTime_Squared = URIRef("http://qudt.org/vocab/quantitykind/InverseTime_Squared")
    FloatingPointCalculationCapability = URIRef("http://qudt.org/vocab/quantitykind/FloatingPointCalculationCapability")
    LoudnessLevel = URIRef("http://qudt.org/vocab/quantitykind/LoudnessLevel")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    LogERatio = URIRef("http://qudt.org/vocab/quantitykind/LogERatio")
    IncidenceProportion = URIRef("http://qudt.org/vocab/quantitykind/IncidenceProportion")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    StatisticalWeight = URIRef("http://qudt.org/vocab/quantitykind/StatisticalWeight")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    ExposureRate = URIRef("http://qudt.org/vocab/quantitykind/ExposureRate")
    AttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AttenuationCoefficient")
    LinearAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAbsorptionCoefficient")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    AbsorbedDose = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDose")
    Admittance = URIRef("http://qudt.org/vocab/quantitykind/Admittance")
    MassPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/MassPerElectricCharge")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    Temperature = URIRef("http://qudt.org/vocab/quantitykind/Temperature")
    ElectricQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricQuadrupoleMoment")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    RadiantFluence = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluence")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    SpecificEnthalpy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnthalpy")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    LuminousIntensityDistribution = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensityDistribution")
    Coercivity = URIRef("http://qudt.org/vocab/quantitykind/Coercivity")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    CurvatureFromRadius = URIRef("http://qudt.org/vocab/quantitykind/CurvatureFromRadius")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    PackingFraction = URIRef("http://qudt.org/vocab/quantitykind/PackingFraction")
    LinkedFlux = URIRef("http://qudt.org/vocab/quantitykind/LinkedFlux")
    DynamicFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DynamicFrictionCoefficient")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    SerumOrPlasmaLevel = URIRef("http://qudt.org/vocab/quantitykind/SerumOrPlasmaLevel")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    ForcePerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/ForcePerAreaTime")
    SpecificHeatVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatVolume")
    QuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/QuantumNumber")
    LinearIonization = URIRef("http://qudt.org/vocab/quantitykind/LinearIonization")
    ThermalConductance = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductance")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    BurstFactor = URIRef("http://qudt.org/vocab/quantitykind/BurstFactor")
    StandardGravitationalParameter = URIRef("http://qudt.org/vocab/quantitykind/StandardGravitationalParameter")
    ElectromagneticEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticEnergyDensity")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    SourceVoltage = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltage")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    LinearElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrentDensity")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    MolarEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarEnergy")
    MolarFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MolarFlowRate")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    Duv = URIRef("http://qudt.org/vocab/quantitykind/Duv")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    SurfaceRelatedVolumeFlow = URIRef("http://qudt.org/vocab/quantitykind/SurfaceRelatedVolumeFlow")
    MagneticQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/MagneticQuantumNumber")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    GasLeakRate = URIRef("http://qudt.org/vocab/quantitykind/GasLeakRate")
    FlightPathAngle = URIRef("http://qudt.org/vocab/quantitykind/FlightPathAngle")
    MassEnergyTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassEnergyTransferCoefficient")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    AmountOfSubstancePerUnitMassPressure = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMassPressure")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    VoltagePercentage = URIRef("http://qudt.org/vocab/quantitykind/VoltagePercentage")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    MagneticFluxPerUnitLength = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxPerUnitLength")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    Circulation = URIRef("http://qudt.org/vocab/quantitykind/Circulation")
    HamiltonFunction = URIRef("http://qudt.org/vocab/quantitykind/HamiltonFunction")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    CyclotronAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/CyclotronAngularFrequency")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    TrafficIntensity = URIRef("http://qudt.org/vocab/quantitykind/TrafficIntensity")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    ConvectiveHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/ConvectiveHeatTransfer")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    Voltage = URIRef("http://qudt.org/vocab/quantitykind/Voltage")
    PositivePlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PositivePlaneAngle")
    IsentropicCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsentropicCompressibility")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    MassicActivity = URIRef("http://qudt.org/vocab/quantitykind/MassicActivity")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    ElectronDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectronDensity")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    QuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/QuantumNumber")
    LengthPerUnitElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/LengthPerUnitElectricCurrent")
    MolarFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MolarFlowRate")
    AuxillaryMagneticField = URIRef("http://qudt.org/vocab/quantitykind/AuxillaryMagneticField")
    TimeRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRatio")
    RelativeHumidity = URIRef("http://qudt.org/vocab/quantitykind/RelativeHumidity")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    LinearVoltageCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearVoltageCoefficient")
    EquilibriumConstantOnConcentrationBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnConcentrationBasis")
    EquilibriumConstant = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstant")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    Count = URIRef("http://qudt.org/vocab/quantitykind/Count")
    SpecificModulus = URIRef("http://qudt.org/vocab/quantitykind/SpecificModulus")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    LinearElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrent")
    MassPerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerAreaTime")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    DiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficient")
    LengthMolarEnergy = URIRef("http://qudt.org/vocab/quantitykind/LengthMolarEnergy")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    NeutronDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionCoefficient")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    BiodegredationHalfLife = URIRef("http://qudt.org/vocab/quantitykind/BiodegredationHalfLife")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    TemperatureBasedQuantity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedQuantity")
    ResidualResistivity = URIRef("http://qudt.org/vocab/quantitykind/ResidualResistivity")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    InverseTemperature = URIRef("http://qudt.org/vocab/quantitykind/InverseTemperature")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    SpecificGibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificGibbsEnergy")
    ElectricFlux = URIRef("http://qudt.org/vocab/quantitykind/ElectricFlux")
    PressureInRelationToVolumeFlow = URIRef("http://qudt.org/vocab/quantitykind/PressureInRelationToVolumeFlow")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    LinearAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAbsorptionCoefficient")
    Debye_WallerFactor = URIRef("http://qudt.org/vocab/quantitykind/Debye-WallerFactor")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    Half_Life = URIRef("http://qudt.org/vocab/quantitykind/Half-Life")
    LoudnessLevel = URIRef("http://qudt.org/vocab/quantitykind/LoudnessLevel")
    CurrentOfTheAmountOfSubtance = URIRef("http://qudt.org/vocab/quantitykind/CurrentOfTheAmountOfSubtance")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    SecondRadiationConstant = URIRef("http://qudt.org/vocab/quantitykind/SecondRadiationConstant")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    LinearElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrentDensity")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    EquilibriumConstant = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstant")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    InversePressure = URIRef("http://qudt.org/vocab/quantitykind/InversePressure")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    VolumeOrSectionModulus = URIRef("http://qudt.org/vocab/quantitykind/VolumeOrSectionModulus")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    InternalConversionFactor = URIRef("http://qudt.org/vocab/quantitykind/InternalConversionFactor")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    ElectrolyticConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectrolyticConductivity")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    StandardGravitationalParameter = URIRef("http://qudt.org/vocab/quantitykind/StandardGravitationalParameter")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    MadelungConstant = URIRef("http://qudt.org/vocab/quantitykind/MadelungConstant")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    CurrentLinkage = URIRef("http://qudt.org/vocab/quantitykind/CurrentLinkage")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    AngleOfOpticalRotation = URIRef("http://qudt.org/vocab/quantitykind/AngleOfOpticalRotation")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    BevelGearPitchAngle = URIRef("http://qudt.org/vocab/quantitykind/BevelGearPitchAngle")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    Concentration = URIRef("http://qudt.org/vocab/quantitykind/Concentration")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    PolarizationField = URIRef("http://qudt.org/vocab/quantitykind/PolarizationField")
    MassRatioOfWaterVapourToDryGas = URIRef("http://qudt.org/vocab/quantitykind/MassRatioOfWaterVapourToDryGas")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    PowerPerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerPerArea")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    StaticPressure = URIRef("http://qudt.org/vocab/quantitykind/StaticPressure")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    AccelerationOfGravity = URIRef("http://qudt.org/vocab/quantitykind/AccelerationOfGravity")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    UpperCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/UpperCriticalMagneticFluxDensity")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    PressureLossPerLength = URIRef("http://qudt.org/vocab/quantitykind/PressureLossPerLength")
    RadianceFactor = URIRef("http://qudt.org/vocab/quantitykind/RadianceFactor")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    PolarizationField = URIRef("http://qudt.org/vocab/quantitykind/PolarizationField")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    SpecificInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificInternalEnergy")
    BevelGearPitchAngle = URIRef("http://qudt.org/vocab/quantitykind/BevelGearPitchAngle")
    TemperatureRelatedVolume = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRelatedVolume")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    PropellantMeanBulkTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantMeanBulkTemperature")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    ExitPlanePressure = URIRef("http://qudt.org/vocab/quantitykind/ExitPlanePressure")
    Ratio = URIRef("http://qudt.org/vocab/quantitykind/Ratio")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    PressureBasedElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedElectricCurrent")
    PressureBasedMass = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedMass")
    AreaPerPower = URIRef("http://qudt.org/vocab/quantitykind/AreaPerPower")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    FundamentalReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalReciprocalLatticeVector")
    SystolicBloodPressure = URIRef("http://qudt.org/vocab/quantitykind/SystolicBloodPressure")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    PRODUCT_OF_INERTIA = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    Admittance = URIRef("http://qudt.org/vocab/quantitykind/Admittance")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    ThermalUtilizationFactorForFission = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactorForFission")
    PermittivityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermittivityRatio")
    PressureInRelationToVolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/PressureInRelationToVolumeFlowRate")
    ActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/ActivityConcentration")
    LinearForce = URIRef("http://qudt.org/vocab/quantitykind/LinearForce")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    IntinsicCarrierDensity = URIRef("http://qudt.org/vocab/quantitykind/IntinsicCarrierDensity")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    PressureGradient = URIRef("http://qudt.org/vocab/quantitykind/PressureGradient")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    PH = URIRef("http://qudt.org/vocab/quantitykind/PH")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    ThermodynamicEntropy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEntropy")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    EnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensity")
    RichardsonConstant = URIRef("http://qudt.org/vocab/quantitykind/RichardsonConstant")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    DoseEquivalent = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalent")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    LengthRatio = URIRef("http://qudt.org/vocab/quantitykind/LengthRatio")
    MassRatio = URIRef("http://qudt.org/vocab/quantitykind/MassRatio")
    StaticFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StaticFrictionCoefficient")
    SignalStrength = URIRef("http://qudt.org/vocab/quantitykind/SignalStrength")
    Capacitance = URIRef("http://qudt.org/vocab/quantitykind/Capacitance")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    Circulation = URIRef("http://qudt.org/vocab/quantitykind/Circulation")
    MassConcentrationOfWaterVapour = URIRef("http://qudt.org/vocab/quantitykind/MassConcentrationOfWaterVapour")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    Impedance = URIRef("http://qudt.org/vocab/quantitykind/Impedance")
    DewPointTemperature = URIRef("http://qudt.org/vocab/quantitykind/DewPointTemperature")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    LossAngle = URIRef("http://qudt.org/vocab/quantitykind/LossAngle")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    HoleDensity = URIRef("http://qudt.org/vocab/quantitykind/HoleDensity")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    MassPerLength = URIRef("http://qudt.org/vocab/quantitykind/MassPerLength")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    StandardChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/StandardChemicalPotential")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    StateDensity = URIRef("http://qudt.org/vocab/quantitykind/StateDensity")
    MadelungConstant = URIRef("http://qudt.org/vocab/quantitykind/MadelungConstant")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    LineicLogarithmicRatio = URIRef("http://qudt.org/vocab/quantitykind/LineicLogarithmicRatio")
    VoltageRatio = URIRef("http://qudt.org/vocab/quantitykind/VoltageRatio")
    Vorticity = URIRef("http://qudt.org/vocab/quantitykind/Vorticity")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    PRODUCT_OF_INERTIA_Z = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA_Z")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    MagneticReluctivity = URIRef("http://qudt.org/vocab/quantitykind/MagneticReluctivity")
    ElectricCurrentPerUnitEnergy = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerUnitEnergy")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    GruneisenParameter = URIRef("http://qudt.org/vocab/quantitykind/GruneisenParameter")
    ElectricChargeSurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeSurfaceDensity")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    PressureBurningRateIndex = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateIndex")
    CyclotronAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/CyclotronAngularFrequency")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    RelativeLuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/RelativeLuminousFlux")
    SoundVolumeVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundVolumeVelocity")
    AbsoluteTypographicMeasurement = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteTypographicMeasurement")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    TemperatureDifference = URIRef("http://qudt.org/vocab/quantitykind/TemperatureDifference")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    RadiantEnergyExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergyExposure")
    ElectricFlux = URIRef("http://qudt.org/vocab/quantitykind/ElectricFlux")
    AreaRatio = URIRef("http://qudt.org/vocab/quantitykind/AreaRatio")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    Impulse = URIRef("http://qudt.org/vocab/quantitykind/Impulse")
    MassPerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerAreaTime")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    ScalarMagneticPotential = URIRef("http://qudt.org/vocab/quantitykind/ScalarMagneticPotential")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    MassConcentrationOfWaterVapour = URIRef("http://qudt.org/vocab/quantitykind/MassConcentrationOfWaterVapour")
    TotalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentumQuantumNumber")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    LarmorAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/LarmorAngularFrequency")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    InverseSquareTime = URIRef("http://qudt.org/vocab/quantitykind/InverseSquareTime")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    InverseLength = URIRef("http://qudt.org/vocab/quantitykind/InverseLength")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    TransmittanceDensity = URIRef("http://qudt.org/vocab/quantitykind/TransmittanceDensity")
    IonicStrength = URIRef("http://qudt.org/vocab/quantitykind/IonicStrength")
    Temperature = URIRef("http://qudt.org/vocab/quantitykind/Temperature")
    Reflectivity = URIRef("http://qudt.org/vocab/quantitykind/Reflectivity")
    MultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/MultiplicationFactor")
    CutoffCurrentRating = URIRef("http://qudt.org/vocab/quantitykind/CutoffCurrentRating")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    Emissivity = URIRef("http://qudt.org/vocab/quantitykind/Emissivity")
    NozzleThroatPressure = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatPressure")
    CurvatureFromRadius = URIRef("http://qudt.org/vocab/quantitykind/CurvatureFromRadius")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    MagnetizationField = URIRef("http://qudt.org/vocab/quantitykind/MagnetizationField")
    PressureBasedAmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedAmountOfSubstanceConcentration")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    PhaseCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PhaseCoefficient")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    SpecificHeatsRatio = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatsRatio")
    MolarInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarInternalEnergy")
    ThermalCapacitance = URIRef("http://qudt.org/vocab/quantitykind/ThermalCapacitance")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    ElectricCurrentPerUnitEnergy = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerUnitEnergy")
    CouplingFactor = URIRef("http://qudt.org/vocab/quantitykind/CouplingFactor")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    TemperatureRatio = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRatio")
    SoundReductionIndex = URIRef("http://qudt.org/vocab/quantitykind/SoundReductionIndex")
    SpecificVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificVolume")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    InverseSquareEnergy = URIRef("http://qudt.org/vocab/quantitykind/InverseSquareEnergy")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    NuclearEnergy = URIRef("http://qudt.org/vocab/quantitykind/NuclearEnergy")
    InformationFlowRate = URIRef("http://qudt.org/vocab/quantitykind/InformationFlowRate")
    IncidenceRate = URIRef("http://qudt.org/vocab/quantitykind/IncidenceRate")
    FahrenheitTemperature = URIRef("http://qudt.org/vocab/quantitykind/FahrenheitTemperature")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    FirstStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/FirstStageMassRatio")
    TotalAtomicStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalAtomicStoppingPower")
    StandardChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/StandardChemicalPotential")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    PayloadRatio = URIRef("http://qudt.org/vocab/quantitykind/PayloadRatio")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    SecondPolarMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondPolarMomentOfArea")
    TotalCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrentDensity")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    Radiosity = URIRef("http://qudt.org/vocab/quantitykind/Radiosity")
    ElectricChargeLineDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeLineDensity")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    WarpingConstant = URIRef("http://qudt.org/vocab/quantitykind/WarpingConstant")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    AreaMass = URIRef("http://qudt.org/vocab/quantitykind/AreaMass")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    RF_Power = URIRef("http://qudt.org/vocab/quantitykind/RF-Power")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    TouchThresholds = URIRef("http://qudt.org/vocab/quantitykind/TouchThresholds")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    IonDensity = URIRef("http://qudt.org/vocab/quantitykind/IonDensity")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    AtmosphericPressure = URIRef("http://qudt.org/vocab/quantitykind/AtmosphericPressure")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    SpecificHeatsRatio = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatsRatio")
    Voltage = URIRef("http://qudt.org/vocab/quantitykind/Voltage")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    Lethargy = URIRef("http://qudt.org/vocab/quantitykind/Lethargy")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    AmbientPressure = URIRef("http://qudt.org/vocab/quantitykind/AmbientPressure")
    ForcePerLength = URIRef("http://qudt.org/vocab/quantitykind/ForcePerLength")
    SignalDetectionThreshold = URIRef("http://qudt.org/vocab/quantitykind/SignalDetectionThreshold")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    OlfactoryThreshold = URIRef("http://qudt.org/vocab/quantitykind/OlfactoryThreshold")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    TemperatureBasedVelocity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedVelocity")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    ChemicalAffinity = URIRef("http://qudt.org/vocab/quantitykind/ChemicalAffinity")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    RotationalMass = URIRef("http://qudt.org/vocab/quantitykind/RotationalMass")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    AcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/AcousticImpedance")
    Emissivity = URIRef("http://qudt.org/vocab/quantitykind/Emissivity")
    DragCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DragCoefficient")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    EarthquakeMagnitude = URIRef("http://qudt.org/vocab/quantitykind/EarthquakeMagnitude")
    ElectricDisplacementField = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacementField")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    WarpingConstant = URIRef("http://qudt.org/vocab/quantitykind/WarpingConstant")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    IonTransportNumber = URIRef("http://qudt.org/vocab/quantitykind/IonTransportNumber")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    InverseEnergy_Squared = URIRef("http://qudt.org/vocab/quantitykind/InverseEnergy_Squared")
    LinearVoltageCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearVoltageCoefficient")
    TimeRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRatio")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    FastFissionFactor = URIRef("http://qudt.org/vocab/quantitykind/FastFissionFactor")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    MagnetomotiveForce = URIRef("http://qudt.org/vocab/quantitykind/MagnetomotiveForce")
    Permeability = URIRef("http://qudt.org/vocab/quantitykind/Permeability")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    MassieuFunction = URIRef("http://qudt.org/vocab/quantitykind/MassieuFunction")
    AtomicNumber = URIRef("http://qudt.org/vocab/quantitykind/AtomicNumber")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    RotationalStiffness = URIRef("http://qudt.org/vocab/quantitykind/RotationalStiffness")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    PolarMomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/PolarMomentOfInertia")
    TemperatureBasedMassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedMassFlowRate")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    ThermalConductance = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductance")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    VolumeFlowRate_SurfaceRelated = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate_SurfaceRelated")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    Population = URIRef("http://qudt.org/vocab/quantitykind/Population")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    DebyeAngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularWavenumber")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    Solubility_Water = URIRef("http://qudt.org/vocab/quantitykind/Solubility_Water")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    SpecificHeatVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatVolume")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    DisplacementCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrentDensity")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    LineicMass = URIRef("http://qudt.org/vocab/quantitykind/LineicMass")
    SpectralRadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SpectralRadiantEnergyDensity")
    FrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/FrictionCoefficient")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    DonorDensity = URIRef("http://qudt.org/vocab/quantitykind/DonorDensity")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    SecondStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SecondStageMassRatio")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    Angle = URIRef("http://qudt.org/vocab/quantitykind/Angle")
    ElectricDipoleMoment_CubicPerEnergy_Squared = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment_CubicPerEnergy_Squared")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    ResistanceRatio = URIRef("http://qudt.org/vocab/quantitykind/ResistanceRatio")
    WaterVapourPermeability = URIRef("http://qudt.org/vocab/quantitykind/WaterVapourPermeability")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    MolarHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MolarHeatCapacity")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    EnergyPerSquareMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerSquareMagneticFluxDensity")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    RadiantFluence = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluence")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    Polarizability = URIRef("http://qudt.org/vocab/quantitykind/Polarizability")
    ExtentOfReaction = URIRef("http://qudt.org/vocab/quantitykind/ExtentOfReaction")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    LarmorAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/LarmorAngularFrequency")
    EquilibriumConstantOnConcentrationBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnConcentrationBasis")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    MadelungConstant = URIRef("http://qudt.org/vocab/quantitykind/MadelungConstant")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    ElectromagneticEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticEnergyDensity")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    EnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensity")
    Mobility = URIRef("http://qudt.org/vocab/quantitykind/Mobility")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    PartialPressure = URIRef("http://qudt.org/vocab/quantitykind/PartialPressure")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    LowerCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/LowerCriticalMagneticFluxDensity")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    StructuralEfficiency = URIRef("http://qudt.org/vocab/quantitykind/StructuralEfficiency")
    PayloadRatio = URIRef("http://qudt.org/vocab/quantitykind/PayloadRatio")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    IonDensity = URIRef("http://qudt.org/vocab/quantitykind/IonDensity")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    AngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentum")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    StrainEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/StrainEnergyDensity")
    AreaPerLength = URIRef("http://qudt.org/vocab/quantitykind/AreaPerLength")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    ParticleFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluenceRate")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    InverseLength = URIRef("http://qudt.org/vocab/quantitykind/InverseLength")
    MagnetomotiveForce = URIRef("http://qudt.org/vocab/quantitykind/MagnetomotiveForce")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    SoundParticleVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleVelocity")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    RadiantFluence = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluence")
    PressureBasedVolumeFlow = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedVolumeFlow")
    EinsteinTransitionProbability = URIRef("http://qudt.org/vocab/quantitykind/EinsteinTransitionProbability")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    SecondMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondMomentOfArea")
    MassieuFunction = URIRef("http://qudt.org/vocab/quantitykind/MassieuFunction")
    IonCurrent = URIRef("http://qudt.org/vocab/quantitykind/IonCurrent")
    StructuralEfficiency = URIRef("http://qudt.org/vocab/quantitykind/StructuralEfficiency")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    ElectricChargeVolumeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeVolumeDensity")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    TemperaturePerTime = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    ParticleNumberDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleNumberDensity")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    TemperatureBasedVolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedVolumeFlowRate")
    SoundParticleVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleVelocity")
    SpecificGibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificGibbsEnergy")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    InversePermittivity = URIRef("http://qudt.org/vocab/quantitykind/InversePermittivity")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    LowerCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/LowerCriticalMagneticFluxDensity")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    EnergyPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerElectricCharge")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    BiodegredationHalfLife = URIRef("http://qudt.org/vocab/quantitykind/BiodegredationHalfLife")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    FissionMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionMultiplicationFactor")
    MassNumber = URIRef("http://qudt.org/vocab/quantitykind/MassNumber")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    MassRatioOfWaterToDryMatter = URIRef("http://qudt.org/vocab/quantitykind/MassRatioOfWaterToDryMatter")
    MechanicalImpedance = URIRef("http://qudt.org/vocab/quantitykind/MechanicalImpedance")
    TemperatureRelatedVolume = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRelatedVolume")
    FissionCoreRadiusToHeightRatio = URIRef("http://qudt.org/vocab/quantitykind/FissionCoreRadiusToHeightRatio")
    TotalCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrentDensity")
    MassicHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MassicHeatCapacity")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    IntinsicCarrierDensity = URIRef("http://qudt.org/vocab/quantitykind/IntinsicCarrierDensity")
    ExposureOfIonizingRadiation = URIRef("http://qudt.org/vocab/quantitykind/ExposureOfIonizingRadiation")
    SpecificHeatCapacityAtSaturation = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtSaturation")
    FastFissionFactor = URIRef("http://qudt.org/vocab/quantitykind/FastFissionFactor")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    RelativePressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/RelativePressureCoefficient")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    GFactorOfNucleus = URIRef("http://qudt.org/vocab/quantitykind/GFactorOfNucleus")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    AttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AttenuationCoefficient")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    EvaporativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/EvaporativeHeatTransfer")
    LinkedFlux = URIRef("http://qudt.org/vocab/quantitykind/LinkedFlux")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    NonActivePower = URIRef("http://qudt.org/vocab/quantitykind/NonActivePower")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    EnergyPerAreaElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerAreaElectricCharge")
    LogOctanolAirPartitionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LogOctanolAirPartitionCoefficient")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    MOMENT_OF_INERTIA_Z = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Z")
    AreaBitDensity = URIRef("http://qudt.org/vocab/quantitykind/AreaBitDensity")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    ElectricChargeVolumeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeVolumeDensity")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    Capacitance = URIRef("http://qudt.org/vocab/quantitykind/Capacitance")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    LinearEnergyTransfer = URIRef("http://qudt.org/vocab/quantitykind/LinearEnergyTransfer")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    TotalPressure = URIRef("http://qudt.org/vocab/quantitykind/TotalPressure")
    LinearStrain = URIRef("http://qudt.org/vocab/quantitykind/LinearStrain")
    AmountOfBiologicallyActiveSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfBiologicallyActiveSubstance")
    SoundParticleAcceleration = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleAcceleration")
    VolumetricEntityDensity = URIRef("http://qudt.org/vocab/quantitykind/VolumetricEntityDensity")
    ElectricChargePerMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerMass")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    PowerPerAreaAngle = URIRef("http://qudt.org/vocab/quantitykind/PowerPerAreaAngle")
    ElectricChargeVolumeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeVolumeDensity")
    TorquePerLength = URIRef("http://qudt.org/vocab/quantitykind/TorquePerLength")
    NumberDensity = URIRef("http://qudt.org/vocab/quantitykind/NumberDensity")
    Admittance = URIRef("http://qudt.org/vocab/quantitykind/Admittance")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    NumberDensity = URIRef("http://qudt.org/vocab/quantitykind/NumberDensity")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    GrandCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/GrandCanonicalPartitionFunction")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    DynamicFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DynamicFrictionCoefficient")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    Admittance = URIRef("http://qudt.org/vocab/quantitykind/Admittance")
    SpectralRadiantEnergyDensityInTermsOfWavelength = URIRef("http://qudt.org/vocab/quantitykind/SpectralRadiantEnergyDensityInTermsOfWavelength")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    MadelungConstant = URIRef("http://qudt.org/vocab/quantitykind/MadelungConstant")
    RadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergyDensity")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    RotationalMass = URIRef("http://qudt.org/vocab/quantitykind/RotationalMass")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    ThermalResistivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistivity")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    CoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/CoefficientOfHeatTransfer")
    Slowing_DownDensity = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownDensity")
    Polarizability = URIRef("http://qudt.org/vocab/quantitykind/Polarizability")
    EccentricityOfOrbit = URIRef("http://qudt.org/vocab/quantitykind/EccentricityOfOrbit")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    TemperatureBasedDynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedDynamicViscosity")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    MassFractionOfDryMatter = URIRef("http://qudt.org/vocab/quantitykind/MassFractionOfDryMatter")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    VolumetricFlux = URIRef("http://qudt.org/vocab/quantitykind/VolumetricFlux")
    Compressibility = URIRef("http://qudt.org/vocab/quantitykind/Compressibility")
    PackingFraction = URIRef("http://qudt.org/vocab/quantitykind/PackingFraction")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    LinearElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrentDensity")
    Absorptance = URIRef("http://qudt.org/vocab/quantitykind/Absorptance")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    LineicResolution = URIRef("http://qudt.org/vocab/quantitykind/LineicResolution")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    FastFissionFactor = URIRef("http://qudt.org/vocab/quantitykind/FastFissionFactor")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    OrbitalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/OrbitalAngularMomentumQuantumNumber")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    SurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceDensity")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    DragCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DragCoefficient")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    InfiniteMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/InfiniteMultiplicationFactor")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    LinearElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCharge")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    ThermodynamicEntropy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEntropy")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    FlightPathAngle = URIRef("http://qudt.org/vocab/quantitykind/FlightPathAngle")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    LogOctanolWaterPartitionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LogOctanolWaterPartitionCoefficient")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    NeutralRatio = URIRef("http://qudt.org/vocab/quantitykind/NeutralRatio")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    FUEL_BIAS = URIRef("http://qudt.org/vocab/quantitykind/FUEL-BIAS")
    ModulusOfLinearSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfLinearSubgradeReaction")
    ThermalAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalAdmittance")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    SecondRadiationConstant = URIRef("http://qudt.org/vocab/quantitykind/SecondRadiationConstant")
    FailureRate = URIRef("http://qudt.org/vocab/quantitykind/FailureRate")
    LinearAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAttenuationCoefficient")
    QuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/QuantumNumber")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    EnergyPerMassAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerMassAmountOfSubstance")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    WaterVaporDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/WaterVaporDiffusionCoefficient")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    LogarithmRatioToBase10 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmRatioToBase10")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    InitialExpansionRatio = URIRef("http://qudt.org/vocab/quantitykind/InitialExpansionRatio")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    AngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentum")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    MolarEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarEnergy")
    ElectricCurrentPerUnitTemperature = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerUnitTemperature")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    ResonanceEscapeProbabilityForFission = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbabilityForFission")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    LagrangeFunction = URIRef("http://qudt.org/vocab/quantitykind/LagrangeFunction")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    SecondMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondMomentOfArea")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    ThermalDiffusionRatio = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionRatio")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    SignalStrength = URIRef("http://qudt.org/vocab/quantitykind/SignalStrength")
    FailureRate = URIRef("http://qudt.org/vocab/quantitykind/FailureRate")
    TemperaturePerTime_Squared = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime_Squared")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    MaximumOperatingPressure = URIRef("http://qudt.org/vocab/quantitykind/MaximumOperatingPressure")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    BucklingFactor = URIRef("http://qudt.org/vocab/quantitykind/BucklingFactor")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    VolumetricOutputPower = URIRef("http://qudt.org/vocab/quantitykind/VolumetricOutputPower")
    TemperaturePerMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerMagneticFluxDensity")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    LandeGFactor = URIRef("http://qudt.org/vocab/quantitykind/LandeGFactor")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    SpecificModulus = URIRef("http://qudt.org/vocab/quantitykind/SpecificModulus")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    RespiratoryRate = URIRef("http://qudt.org/vocab/quantitykind/RespiratoryRate")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    Short_RangeOrderParameter = URIRef("http://qudt.org/vocab/quantitykind/Short-RangeOrderParameter")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    TemperatureBasedDynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedDynamicViscosity")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    PropellantTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantTemperature")
    SecondOrderReactionRateConstant = URIRef("http://qudt.org/vocab/quantitykind/SecondOrderReactionRateConstant")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    ModulusOfImpedance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfImpedance")
    Slowing_DownDensity = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownDensity")
    CostPerArea = URIRef("http://qudt.org/vocab/quantitykind/CostPerArea")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    EnergyPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerElectricCharge")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    Reactivity = URIRef("http://qudt.org/vocab/quantitykind/Reactivity")
    NeutronYieldPerFission = URIRef("http://qudt.org/vocab/quantitykind/NeutronYieldPerFission")
    LossAngle = URIRef("http://qudt.org/vocab/quantitykind/LossAngle")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    EquilibriumConstantOnConcentrationBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnConcentrationBasis")
    SpecificEnthalpy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnthalpy")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    OsmoticPressure = URIRef("http://qudt.org/vocab/quantitykind/OsmoticPressure")
    LinearElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrentDensity")
    MechanicalTension = URIRef("http://qudt.org/vocab/quantitykind/MechanicalTension")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    BucklingFactor = URIRef("http://qudt.org/vocab/quantitykind/BucklingFactor")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    TemperatureBasedKinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedKinematicViscosity")
    PowerPerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerPerArea")
    PhotonIntensity = URIRef("http://qudt.org/vocab/quantitykind/PhotonIntensity")
    TimeSquared = URIRef("http://qudt.org/vocab/quantitykind/TimeSquared")
    PressureGradient = URIRef("http://qudt.org/vocab/quantitykind/PressureGradient")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    SpecificHeatsRatio = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatsRatio")
    RF_Power = URIRef("http://qudt.org/vocab/quantitykind/RF-Power")
    BiodegredationHalfLife = URIRef("http://qudt.org/vocab/quantitykind/BiodegredationHalfLife")
    PropellantBurnRate = URIRef("http://qudt.org/vocab/quantitykind/PropellantBurnRate")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    Half_Life = URIRef("http://qudt.org/vocab/quantitykind/Half-Life")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    LuminousEnergy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEnergy")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    FlightPathAngle = URIRef("http://qudt.org/vocab/quantitykind/FlightPathAngle")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    Adaptation = URIRef("http://qudt.org/vocab/quantitykind/Adaptation")
    EquilibriumConstantBasedOnConcentration = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantBasedOnConcentration")
    AreicEnergyFlow = URIRef("http://qudt.org/vocab/quantitykind/AreicEnergyFlow")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    ExhaustGasesSpecificHeat = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasesSpecificHeat")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    LineicTorque = URIRef("http://qudt.org/vocab/quantitykind/LineicTorque")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    GeneFamilyAbundance = URIRef("http://qudt.org/vocab/quantitykind/GeneFamilyAbundance")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    RadioactiveDecay = URIRef("http://qudt.org/vocab/quantitykind/RadioactiveDecay")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    RelativeLuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/RelativeLuminousFlux")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    Conductance = URIRef("http://qudt.org/vocab/quantitykind/Conductance")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    TemperatureGradient = URIRef("http://qudt.org/vocab/quantitykind/TemperatureGradient")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    ModulusOfRotationalSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfRotationalSubgradeReaction")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    DebyeAngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularWavenumber")
    Voltage = URIRef("http://qudt.org/vocab/quantitykind/Voltage")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    PlanckFunction = URIRef("http://qudt.org/vocab/quantitykind/PlanckFunction")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    MagneticQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/MagneticQuantumNumber")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    CouplingFactor = URIRef("http://qudt.org/vocab/quantitykind/CouplingFactor")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    AbsoluteActivity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteActivity")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    QualityFactor = URIRef("http://qudt.org/vocab/quantitykind/QualityFactor")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    ElectricChargePerArea = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerArea")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    CostPerUnitEnergy = URIRef("http://qudt.org/vocab/quantitykind/CostPerUnitEnergy")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    Gradient = URIRef("http://qudt.org/vocab/quantitykind/Gradient")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    SpecificInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificInternalEnergy")
    MassEnergyTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassEnergyTransferCoefficient")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    MagneticSusceptability = URIRef("http://qudt.org/vocab/quantitykind/MagneticSusceptability")
    EnergyContent = URIRef("http://qudt.org/vocab/quantitykind/EnergyContent")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    FUEL_BIAS = URIRef("http://qudt.org/vocab/quantitykind/FUEL-BIAS")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    ExitPlanePressure = URIRef("http://qudt.org/vocab/quantitykind/ExitPlanePressure")
    InternalConversionFactor = URIRef("http://qudt.org/vocab/quantitykind/InternalConversionFactor")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    UpperCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/UpperCriticalMagneticFluxDensity")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    VaporPermeability = URIRef("http://qudt.org/vocab/quantitykind/VaporPermeability")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    SecondOrderReactionRateConstant = URIRef("http://qudt.org/vocab/quantitykind/SecondOrderReactionRateConstant")
    ThermalExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalExpansionCoefficient")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    SpectralConcentrationOfVibrationalModes = URIRef("http://qudt.org/vocab/quantitykind/SpectralConcentrationOfVibrationalModes")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    StateDensityAsExpressionOfAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/StateDensityAsExpressionOfAngularFrequency")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    HenrysLawVolatilityConstant = URIRef("http://qudt.org/vocab/quantitykind/HenrysLawVolatilityConstant")
    FermiTemperature = URIRef("http://qudt.org/vocab/quantitykind/FermiTemperature")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    EffectiveMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMultiplicationFactor")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    PeltierCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PeltierCoefficient")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    Permeance = URIRef("http://qudt.org/vocab/quantitykind/Permeance")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    VolumetricOutputPower = URIRef("http://qudt.org/vocab/quantitykind/VolumetricOutputPower")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    StaticPressure = URIRef("http://qudt.org/vocab/quantitykind/StaticPressure")
    MechanicalTension = URIRef("http://qudt.org/vocab/quantitykind/MechanicalTension")
    PressureBasedTemperature = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedTemperature")
    PressureInRelationToVolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/PressureInRelationToVolumeFlowRate")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    ThermalConductance = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductance")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    DataRate = URIRef("http://qudt.org/vocab/quantitykind/DataRate")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    StandardChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/StandardChemicalPotential")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    BandwidthLengthProduct = URIRef("http://qudt.org/vocab/quantitykind/BandwidthLengthProduct")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    MaximumExpectedOperatingPressure = URIRef("http://qudt.org/vocab/quantitykind/MaximumExpectedOperatingPressure")
    MassicTorque = URIRef("http://qudt.org/vocab/quantitykind/MassicTorque")
    MOMENT_OF_INERTIA_Y = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Y")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    CharacteristicAcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicAcousticImpedance")
    FlightPathAngle = URIRef("http://qudt.org/vocab/quantitykind/FlightPathAngle")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    MultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/MultiplicationFactor")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    RatioOfSpecificHeatCapacities = URIRef("http://qudt.org/vocab/quantitykind/RatioOfSpecificHeatCapacities")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    LuminousEnergy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEnergy")
    PoissonRatio = URIRef("http://qudt.org/vocab/quantitykind/PoissonRatio")
    BindingFraction = URIRef("http://qudt.org/vocab/quantitykind/BindingFraction")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    Acidity = URIRef("http://qudt.org/vocab/quantitykind/Acidity")
    LinearStiffness = URIRef("http://qudt.org/vocab/quantitykind/LinearStiffness")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    LinearStiffness = URIRef("http://qudt.org/vocab/quantitykind/LinearStiffness")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    PlanckFunction = URIRef("http://qudt.org/vocab/quantitykind/PlanckFunction")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    Reactance = URIRef("http://qudt.org/vocab/quantitykind/Reactance")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    Permittivity = URIRef("http://qudt.org/vocab/quantitykind/Permittivity")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    VolumeThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/VolumeThermalExpansion")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    ParticleNumberDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleNumberDensity")
    PolarizationField = URIRef("http://qudt.org/vocab/quantitykind/PolarizationField")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    LeakageFactor = URIRef("http://qudt.org/vocab/quantitykind/LeakageFactor")
    DatasetOfBits = URIRef("http://qudt.org/vocab/quantitykind/DatasetOfBits")
    MassPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/MassPerElectricCharge")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    AngleOfOpticalRotation = URIRef("http://qudt.org/vocab/quantitykind/AngleOfOpticalRotation")
    SpecificElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/SpecificElectricCharge")
    AmountOfSubstanceConcentrationOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentrationOfB")
    SpecificActivity = URIRef("http://qudt.org/vocab/quantitykind/SpecificActivity")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    ThrustToWeightRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToWeightRatio")
    SecondPolarMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondPolarMomentOfArea")
    RadiantIntensity = URIRef("http://qudt.org/vocab/quantitykind/RadiantIntensity")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    SpectralRadiantEnergyDensityInTermsOfWavelength = URIRef("http://qudt.org/vocab/quantitykind/SpectralRadiantEnergyDensityInTermsOfWavelength")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    PressureInRelationToVolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/PressureInRelationToVolumeFlowRate")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    VideoFrameRate = URIRef("http://qudt.org/vocab/quantitykind/VideoFrameRate")
    ModulusOfLinearSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfLinearSubgradeReaction")
    LinearEnergyTransfer = URIRef("http://qudt.org/vocab/quantitykind/LinearEnergyTransfer")
    OsmoticPressure = URIRef("http://qudt.org/vocab/quantitykind/OsmoticPressure")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    NeutronYieldPerAbsorption = URIRef("http://qudt.org/vocab/quantitykind/NeutronYieldPerAbsorption")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    ModulusOfImpedance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfImpedance")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    SignalStrength = URIRef("http://qudt.org/vocab/quantitykind/SignalStrength")
    Radiance = URIRef("http://qudt.org/vocab/quantitykind/Radiance")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    ReciprocalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalEnergy")
    GeneralizedCoordinate = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedCoordinate")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    ThermalEnergyLength = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergyLength")
    ActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/ActivityConcentration")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    ThomsonCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThomsonCoefficient")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    LengthRatio = URIRef("http://qudt.org/vocab/quantitykind/LengthRatio")
    PermeabilityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermeabilityRatio")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    StatisticalWeight = URIRef("http://qudt.org/vocab/quantitykind/StatisticalWeight")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    ThermalTransmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalTransmittance")
    SpecificInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificInternalEnergy")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    TorsionalRigidity = URIRef("http://qudt.org/vocab/quantitykind/TorsionalRigidity")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    LuminousExposure = URIRef("http://qudt.org/vocab/quantitykind/LuminousExposure")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    ActionTime = URIRef("http://qudt.org/vocab/quantitykind/ActionTime")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    SingleStageLauncherMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SingleStageLauncherMassRatio")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    ElectromagneticEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticEnergyDensity")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    LogOctanolAirPartitionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LogOctanolAirPartitionCoefficient")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    AmountOfSubstanceFraction = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFraction")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    LiquidVolume = URIRef("http://qudt.org/vocab/quantitykind/LiquidVolume")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    PermittivityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermittivityRatio")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    ThermalTransmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalTransmittance")
    RelativeMassRatioOfVapour = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassRatioOfVapour")
    LinearForce = URIRef("http://qudt.org/vocab/quantitykind/LinearForce")
    ElectricField = URIRef("http://qudt.org/vocab/quantitykind/ElectricField")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    LinearForce = URIRef("http://qudt.org/vocab/quantitykind/LinearForce")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    PayloadRatio = URIRef("http://qudt.org/vocab/quantitykind/PayloadRatio")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    PositiveDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/PositiveDimensionlessRatio")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    TemperatureBasedKinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedKinematicViscosity")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    AbsorbedDose = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDose")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    TotalRadiance = URIRef("http://qudt.org/vocab/quantitykind/TotalRadiance")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    UpperCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/UpperCriticalMagneticFluxDensity")
    DensityInCombustionChamber = URIRef("http://qudt.org/vocab/quantitykind/DensityInCombustionChamber")
    PermeabilityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermeabilityRatio")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    EinsteinCoefficients = URIRef("http://qudt.org/vocab/quantitykind/EinsteinCoefficients")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    RadiantIntensity = URIRef("http://qudt.org/vocab/quantitykind/RadiantIntensity")
    BitRate = URIRef("http://qudt.org/vocab/quantitykind/BitRate")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    SpecificSurfaceArea = URIRef("http://qudt.org/vocab/quantitykind/SpecificSurfaceArea")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    LevelWidth = URIRef("http://qudt.org/vocab/quantitykind/LevelWidth")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    ForcePerLength = URIRef("http://qudt.org/vocab/quantitykind/ForcePerLength")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    FundamentalReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalReciprocalLatticeVector")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    EnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensity")
    SoundExposure = URIRef("http://qudt.org/vocab/quantitykind/SoundExposure")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    GeneralizedVelocity = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedVelocity")
    FailureRate = URIRef("http://qudt.org/vocab/quantitykind/FailureRate")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    StaticPressure = URIRef("http://qudt.org/vocab/quantitykind/StaticPressure")
    TotalMassStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalMassStoppingPower")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    MechanicalSurfaceImpedance = URIRef("http://qudt.org/vocab/quantitykind/MechanicalSurfaceImpedance")
    EquilibriumConstantOnConcentrationBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnConcentrationBasis")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    Speed = URIRef("http://qudt.org/vocab/quantitykind/Speed")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    CatalyticActivity = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivity")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    GeneralizedVelocity = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedVelocity")
    TransmittanceDensity = URIRef("http://qudt.org/vocab/quantitykind/TransmittanceDensity")
    MadelungConstant = URIRef("http://qudt.org/vocab/quantitykind/MadelungConstant")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    SpecificHeatCapacityAtSaturation = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtSaturation")
    Capacity = URIRef("http://qudt.org/vocab/quantitykind/Capacity")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    LineicCharge = URIRef("http://qudt.org/vocab/quantitykind/LineicCharge")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    AuditoryThresholds = URIRef("http://qudt.org/vocab/quantitykind/AuditoryThresholds")
    IsentropicCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsentropicCompressibility")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    ByteRate = URIRef("http://qudt.org/vocab/quantitykind/ByteRate")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    Asset = URIRef("http://qudt.org/vocab/quantitykind/Asset")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    MadelungConstant = URIRef("http://qudt.org/vocab/quantitykind/MadelungConstant")
    HeartRate = URIRef("http://qudt.org/vocab/quantitykind/HeartRate")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    VolumicElectromagneticEnergy = URIRef("http://qudt.org/vocab/quantitykind/VolumicElectromagneticEnergy")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    TotalIonization = URIRef("http://qudt.org/vocab/quantitykind/TotalIonization")
    MagneticField = URIRef("http://qudt.org/vocab/quantitykind/MagneticField")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    SpecificGibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificGibbsEnergy")
    TotalAtomicStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalAtomicStoppingPower")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    MassicTorque = URIRef("http://qudt.org/vocab/quantitykind/MassicTorque")
    Loudness = URIRef("http://qudt.org/vocab/quantitykind/Loudness")
    LuminousExposure = URIRef("http://qudt.org/vocab/quantitykind/LuminousExposure")
    LinearAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAbsorptionCoefficient")
    KineticOrThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticOrThermalEnergy")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    LengthRatio = URIRef("http://qudt.org/vocab/quantitykind/LengthRatio")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    MolalityOfSolute = URIRef("http://qudt.org/vocab/quantitykind/MolalityOfSolute")
    MagneticFluxDensityOrMagneticPolarization = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensityOrMagneticPolarization")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    LineicCharge = URIRef("http://qudt.org/vocab/quantitykind/LineicCharge")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    Angle = URIRef("http://qudt.org/vocab/quantitykind/Angle")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    MassPerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerAreaTime")
    ThermalInsulance = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulance")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    PoyntingVector = URIRef("http://qudt.org/vocab/quantitykind/PoyntingVector")
    LinearMomentum = URIRef("http://qudt.org/vocab/quantitykind/LinearMomentum")
    Conductance = URIRef("http://qudt.org/vocab/quantitykind/Conductance")
    SpecificOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificOpticalRotatoryPower")
    WarmReceptorThreshold = URIRef("http://qudt.org/vocab/quantitykind/WarmReceptorThreshold")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    SpecificPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificPower")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    EquilibriumConstant = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstant")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    PermittivityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermittivityRatio")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    CharacteristicVelocity = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicVelocity")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    LiftCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LiftCoefficient")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    SpecificEnthalpy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnthalpy")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    ThermalExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalExpansionCoefficient")
    FermiAngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/FermiAngularWavenumber")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    CostPerArea = URIRef("http://qudt.org/vocab/quantitykind/CostPerArea")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    ThermalDiffusionRatioCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionRatioCoefficient")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    Permittivity = URIRef("http://qudt.org/vocab/quantitykind/Permittivity")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    ThomsonCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThomsonCoefficient")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    Vorticity = URIRef("http://qudt.org/vocab/quantitykind/Vorticity")
    SpecificAcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/SpecificAcousticImpedance")
    AccelerationOfGravity = URIRef("http://qudt.org/vocab/quantitykind/AccelerationOfGravity")
    Log10FrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/Log10FrequencyInterval")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    ElectricChargePerArea = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerArea")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    InverseEnergy_Squared = URIRef("http://qudt.org/vocab/quantitykind/InverseEnergy_Squared")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    ElectricChargeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeDensity")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    LinearElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrent")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    MolarHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MolarHeatCapacity")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    ElectricChargeLinearDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeLinearDensity")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    AtmosphericPressure = URIRef("http://qudt.org/vocab/quantitykind/AtmosphericPressure")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    PhotosyntheticPhotonFlux = URIRef("http://qudt.org/vocab/quantitykind/PhotosyntheticPhotonFlux")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    MeanMassRange = URIRef("http://qudt.org/vocab/quantitykind/MeanMassRange")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    TotalAngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentum")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    EnergyFluence = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluence")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    BandwidthLengthProduct = URIRef("http://qudt.org/vocab/quantitykind/BandwidthLengthProduct")
    SpectralDensityOfVibrationalModes = URIRef("http://qudt.org/vocab/quantitykind/SpectralDensityOfVibrationalModes")
    AreicMass = URIRef("http://qudt.org/vocab/quantitykind/AreicMass")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    SquareEnergy = URIRef("http://qudt.org/vocab/quantitykind/SquareEnergy")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    Slowing_DownDensity = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownDensity")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    EnergyExpenditure = URIRef("http://qudt.org/vocab/quantitykind/EnergyExpenditure")
    SurfaceCoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/SurfaceCoefficientOfHeatTransfer")
    SingleStageLauncherMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SingleStageLauncherMassRatio")
    PositiveDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/PositiveDimensionlessRatio")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    ElectricChargeLinearDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeLinearDensity")
    CouplingFactor = URIRef("http://qudt.org/vocab/quantitykind/CouplingFactor")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    ThermalCoefficientOfLinearExpansion = URIRef("http://qudt.org/vocab/quantitykind/ThermalCoefficientOfLinearExpansion")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    MassPerLength = URIRef("http://qudt.org/vocab/quantitykind/MassPerLength")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    ThermalDiffusionRatioCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionRatioCoefficient")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    ThermodynamicEntropy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEntropy")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    OrbitalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/OrbitalAngularMomentumQuantumNumber")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    DiastolicBloodPressure = URIRef("http://qudt.org/vocab/quantitykind/DiastolicBloodPressure")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    Kerma = URIRef("http://qudt.org/vocab/quantitykind/Kerma")
    TimeRelatedLogarithmicRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRelatedLogarithmicRatio")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    QuarticElectricDipoleMomentPerCubicEnergy = URIRef("http://qudt.org/vocab/quantitykind/QuarticElectricDipoleMomentPerCubicEnergy")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    ParticleSourceDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleSourceDensity")
    Half_Life = URIRef("http://qudt.org/vocab/quantitykind/Half-Life")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    OsmoticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/OsmoticCoefficient")
    TransmittanceDensity = URIRef("http://qudt.org/vocab/quantitykind/TransmittanceDensity")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    SingleStageLauncherMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SingleStageLauncherMassRatio")
    MolarConductivity = URIRef("http://qudt.org/vocab/quantitykind/MolarConductivity")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    BulkModulus = URIRef("http://qudt.org/vocab/quantitykind/BulkModulus")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    ExposureOfIonizingRadiation = URIRef("http://qudt.org/vocab/quantitykind/ExposureOfIonizingRadiation")
    NumberDensity = URIRef("http://qudt.org/vocab/quantitykind/NumberDensity")
    MutualInductance = URIRef("http://qudt.org/vocab/quantitykind/MutualInductance")
    SpecificInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificInternalEnergy")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    EnergyContent = URIRef("http://qudt.org/vocab/quantitykind/EnergyContent")
    DecayConstant = URIRef("http://qudt.org/vocab/quantitykind/DecayConstant")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    EffectiveExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/EffectiveExhaustVelocity")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    SurgeImpedanceOfTheMedium = URIRef("http://qudt.org/vocab/quantitykind/SurgeImpedanceOfTheMedium")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    MolarEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarEnergy")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    TemperatureRateOfChange = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRateOfChange")
    RankineTemperature = URIRef("http://qudt.org/vocab/quantitykind/RankineTemperature")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    LiftCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LiftCoefficient")
    LinearIonization = URIRef("http://qudt.org/vocab/quantitykind/LinearIonization")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    SoundParticleAcceleration = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleAcceleration")
    PressureBasedLength = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedLength")
    SoundExposureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundExposureLevel")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    PressureRatio = URIRef("http://qudt.org/vocab/quantitykind/PressureRatio")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    SpecificHeatCapacityAtConstantVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantVolume")
    AmountOfSubstanceConcentrationOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentrationOfB")
    ResistanceBasedInductance = URIRef("http://qudt.org/vocab/quantitykind/ResistanceBasedInductance")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    MassFractionOfWater = URIRef("http://qudt.org/vocab/quantitykind/MassFractionOfWater")
    CyclotronAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/CyclotronAngularFrequency")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    Solubility_Water = URIRef("http://qudt.org/vocab/quantitykind/Solubility_Water")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    ThermalUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactor")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    SingleStageLauncherMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SingleStageLauncherMassRatio")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    PressureGradient = URIRef("http://qudt.org/vocab/quantitykind/PressureGradient")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    IsothermalMoistureCapacity = URIRef("http://qudt.org/vocab/quantitykind/IsothermalMoistureCapacity")
    DiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficient")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    PropagationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PropagationCoefficient")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    LinearEnergyTransfer = URIRef("http://qudt.org/vocab/quantitykind/LinearEnergyTransfer")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    LinearAcceleration = URIRef("http://qudt.org/vocab/quantitykind/LinearAcceleration")
    MolecularConcentration = URIRef("http://qudt.org/vocab/quantitykind/MolecularConcentration")
    LossAngle = URIRef("http://qudt.org/vocab/quantitykind/LossAngle")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    LevelWidth = URIRef("http://qudt.org/vocab/quantitykind/LevelWidth")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    ElectricDipoleMoment_QuarticPerEnergy_Cubic = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment_QuarticPerEnergy_Cubic")
    MassStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/MassStoppingPower")
    SpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/SpinQuantumNumber")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    CutoffCurrentRating = URIRef("http://qudt.org/vocab/quantitykind/CutoffCurrentRating")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    ResistanceBasedInductance = URIRef("http://qudt.org/vocab/quantitykind/ResistanceBasedInductance")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    ExpansionRatio = URIRef("http://qudt.org/vocab/quantitykind/ExpansionRatio")
    MagnetizationField = URIRef("http://qudt.org/vocab/quantitykind/MagnetizationField")
    Permeability = URIRef("http://qudt.org/vocab/quantitykind/Permeability")
    PressureGradient = URIRef("http://qudt.org/vocab/quantitykind/PressureGradient")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    LarmorAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/LarmorAngularFrequency")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    GrowingDegreeDay_Cereal = URIRef("http://qudt.org/vocab/quantitykind/GrowingDegreeDay_Cereal")
    ExhaustGasesSpecificHeat = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasesSpecificHeat")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    DryVolume = URIRef("http://qudt.org/vocab/quantitykind/DryVolume")
    Slowing_DownDensity = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownDensity")
    MultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/MultiplicationFactor")
    LinkedFlux = URIRef("http://qudt.org/vocab/quantitykind/LinkedFlux")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    StressIntensityFactor = URIRef("http://qudt.org/vocab/quantitykind/StressIntensityFactor")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    ThermalTransmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalTransmittance")
    Flux = URIRef("http://qudt.org/vocab/quantitykind/Flux")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    TemperatureBasedMass = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedMass")
    Dissipance = URIRef("http://qudt.org/vocab/quantitykind/Dissipance")
    TemperaturePerTime = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime")
    Incidence = URIRef("http://qudt.org/vocab/quantitykind/Incidence")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    PolarMomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/PolarMomentOfInertia")
    AttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AttenuationCoefficient")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    Permeance = URIRef("http://qudt.org/vocab/quantitykind/Permeance")
    VisionThresholds = URIRef("http://qudt.org/vocab/quantitykind/VisionThresholds")
    CostPerUnitPower = URIRef("http://qudt.org/vocab/quantitykind/CostPerUnitPower")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    ResistanceRatio = URIRef("http://qudt.org/vocab/quantitykind/ResistanceRatio")
    MotorConstant = URIRef("http://qudt.org/vocab/quantitykind/MotorConstant")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    MassAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAbsorptionCoefficient")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    NeelTemperature = URIRef("http://qudt.org/vocab/quantitykind/NeelTemperature")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    PressureBasedTemperature = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedTemperature")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    Circulation = URIRef("http://qudt.org/vocab/quantitykind/Circulation")
    PressurePercentage = URIRef("http://qudt.org/vocab/quantitykind/PressurePercentage")
    PermeabilityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermeabilityRatio")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    PropellantBurnRate = URIRef("http://qudt.org/vocab/quantitykind/PropellantBurnRate")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    ThrustToWeightRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToWeightRatio")
    LuminousEfficacy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEfficacy")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    MassEnergyTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassEnergyTransferCoefficient")
    Adaptation = URIRef("http://qudt.org/vocab/quantitykind/Adaptation")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    SuperconductionTransitionTemperature = URIRef("http://qudt.org/vocab/quantitykind/SuperconductionTransitionTemperature")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    PowerPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/PowerPerElectricCharge")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    ChargeNumber = URIRef("http://qudt.org/vocab/quantitykind/ChargeNumber")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    SpectralRadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SpectralRadiantEnergyDensity")
    LuminousExposure = URIRef("http://qudt.org/vocab/quantitykind/LuminousExposure")
    MeltingPoint = URIRef("http://qudt.org/vocab/quantitykind/MeltingPoint")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    TotalMassStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalMassStoppingPower")
    CatalyticActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivityConcentration")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    MassPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/MassPerElectricCharge")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    ReynoldsNumber = URIRef("http://qudt.org/vocab/quantitykind/ReynoldsNumber")

    _NS = Namespace("https://qudt.org/vocab/unit/")